var __defProp = Object.defineProperty;
var __export = (target, all) => {
  for (var name in all)
    __defProp(target, name, { get: all[name], enumerable: true });
};

// src/components/Accordion/Accordion.tsx
import { Children as Children2, Fragment, isValidElement as isValidElement4, useRef as useRef3 } from "react";
import { css as css7 } from "@emotion/react";
import styled7 from "@emotion/styled";
import { omit as omit3 } from "@gilbarbara/helpers";
import { useLifecycleHooks } from "@gilbarbara/hooks";
import is5 from "is-lite";

// src/hooks/useKeyboardNavigation.ts
import { useCallback, useEffect } from "react";
import { useLatest } from "@gilbarbara/hooks";
function useKeyboardNavigation(elementRef, options) {
  const { arrowNavigation, disabled, escCallback, initialFocusedElement, selector, trapFocus } = options;
  const escCallbackRef = useLatest(escCallback);
  const canBeTabbed = useCallback((element) => {
    const { tabIndex } = element;
    if (tabIndex === null || tabIndex < 0) {
      return false;
    }
    return !!element;
  }, []);
  const getValidElements = useCallback(() => {
    return [...elementRef.current?.querySelectorAll(selector) ?? []].filter(
      canBeTabbed
    );
  }, [elementRef, canBeTabbed, selector]);
  const getElementIndex = useCallback((elements) => {
    return elements.indexOf(document.activeElement);
  }, []);
  const isLastElement = useCallback((elements, index) => {
    return index === elements.length - 1;
  }, []);
  const interceptArrows = useCallback(
    (event) => {
      const elements = getValidElements();
      if (!elements.length) {
        return;
      }
      const isPrevious = ["ArrowLeft", "ArrowUp"].includes(event.code);
      const initialIndex = getElementIndex(elements);
      let index = getElementIndex(elements);
      if (isPrevious) {
        if (trapFocus) {
          index = index === 0 ? elements.length - 1 : index - 1;
        } else {
          index = index === 0 ? index : index - 1;
        }
      } else {
        index = !isLastElement(elements, index) || trapFocus ? (index + 1) % elements.length : index;
      }
      if (initialIndex !== index) {
        event.preventDefault();
        elements[index].focus();
      }
    },
    [getValidElements, getElementIndex, isLastElement, trapFocus]
  );
  const interceptTab = useCallback(
    (event) => {
      const elements = getValidElements();
      if (!elements.length) {
        return;
      }
      const { shiftKey } = event;
      const initialIndex = getElementIndex(elements);
      let index = getElementIndex(elements);
      if (shiftKey) {
        if (trapFocus) {
          index = index === 0 ? elements.length - 1 : index - 1;
        } else {
          index = index === 0 ? index : index - 1;
        }
      } else {
        index = !isLastElement(elements, index) || trapFocus ? (index + 1) % elements.length : index;
      }
      if (initialIndex !== index) {
        event.preventDefault();
        elements[index].focus();
      }
    },
    [getValidElements, getElementIndex, isLastElement, trapFocus]
  );
  const allowArrowNavigation = useCallback(
    (types) => {
      return types.includes(arrowNavigation);
    },
    [arrowNavigation]
  );
  const handleKeyDown2 = useCallback(
    (event) => {
      const { code } = event;
      if (code === "Tab") {
        interceptTab(event);
      } else if (escCallbackRef.current && code === "Escape") {
        escCallbackRef.current();
      } else if (["ArrowLeft", "ArrowRight"].includes(code) && allowArrowNavigation(["horizontal", "both"])) {
        interceptArrows(event);
      } else if (["ArrowDown", "ArrowUp"].includes(code) && allowArrowNavigation(["vertical", "both"])) {
        interceptArrows(event);
      }
    },
    [allowArrowNavigation, escCallbackRef, interceptArrows, interceptTab]
  );
  const checkFocus = useCallback((target) => {
    if (target && document.activeElement !== target) {
      target.focus();
      window.requestAnimationFrame(() => checkFocus(target));
    }
  }, []);
  const setFocus = useCallback(() => {
    if (!initialFocusedElement) {
      return;
    }
    const target = typeof initialFocusedElement === "string" ? elementRef.current?.querySelector(initialFocusedElement) : initialFocusedElement;
    if (target) {
      window.requestAnimationFrame(() => checkFocus(target));
    }
  }, [checkFocus, elementRef, initialFocusedElement]);
  useEffect(() => {
    if (disabled) {
      return () => {
      };
    }
    window.addEventListener("keydown", handleKeyDown2);
    setFocus();
    return () => {
      if (!disabled) {
        window.removeEventListener("keydown", handleKeyDown2);
      }
    };
  }, [disabled, handleKeyDown2, setFocus]);
  const addScope = useCallback(() => {
    if (!disabled) {
      window.addEventListener("keydown", handleKeyDown2);
    }
  }, [disabled, handleKeyDown2]);
  const removeScope = useCallback(() => {
    if (!disabled) {
      window.removeEventListener("keydown", handleKeyDown2);
    }
  }, [disabled, handleKeyDown2]);
  return {
    addScope,
    removeScope
  };
}

// src/modules/system.ts
import isPropValid from "@emotion/is-prop-valid";
import { css as css2 } from "@emotion/react";
import {
  capitalize,
  cleanUpObject,
  objectEntries as objectEntries3,
  objectKeys as objectKeys3,
  px as px2,
  sortObjectKeys
} from "@gilbarbara/helpers";
import { opacify } from "colorizr";
import is2 from "is-lite";

// src/modules/colors.ts
import { objectKeys } from "@gilbarbara/helpers";
import {
  textColor as contrastingColor,
  darken,
  hex2hsl,
  hsl2hex,
  lighten,
  parseCSS
} from "colorizr";

// src/modules/theme.ts
var theme_exports = {};
__export(theme_exports, {
  avatar: () => avatar,
  black: () => black,
  breakpoints: () => breakpoints,
  button: () => button,
  colors: () => colors,
  darkColor: () => darkColor,
  darkMode: () => darkMode,
  dataAttributeName: () => dataAttributeName,
  easing: () => easing,
  fontFamily: () => fontFamily,
  fontMonospace: () => fontMonospace,
  fontWeights: () => fontWeights,
  grayScale: () => grayScale,
  image: () => image,
  inputHeight: () => inputHeight,
  inputPaddingY: () => inputPaddingY,
  lightColor: () => lightColor,
  opacity: () => opacity,
  opacityDisabled: () => opacityDisabled,
  outlineOffset: () => outlineOffset,
  outlineOpacity: () => outlineOpacity,
  outlineWidth: () => outlineWidth,
  outlineZIndex: () => outlineZIndex,
  paragraphMarginBetween: () => paragraphMarginBetween,
  radius: () => radius,
  selectPaddingY: () => selectPaddingY,
  shadow: () => shadow,
  shadowDark: () => shadowDark,
  spacing: () => spacing,
  swatchOptions: () => swatchOptions,
  textColorOptions: () => textColorOptions,
  typography: () => typography,
  variants: () => variants,
  white: () => white,
  zIndex: () => zIndex
});
import { objectEntries } from "@gilbarbara/helpers";
import { swatch } from "colorizr";
var breakpoints = {
  /** @default 320px */
  xxs: "320px",
  /** @default 375px */
  xs: "375px",
  /** @default 400px */
  sm: "400px",
  /** @default 768px */
  md: "768px",
  /** @default 1024px */
  lg: "1024px",
  /** @default 1280px */
  xl: "1280px",
  /** @default 1440px */
  xxl: "1440px",
  /** @default 1680px */
  xxxl: "1680px"
};
var dataAttributeName = "component-name";
var darkMode = false;
var easing = "cubic-bezier(0.65, 0.815, 0.735, 0.395)";
var fontFamily = "inherit";
var fontMonospace = "Courier, monospace";
var fontWeights = {
  normal: 400,
  bold: 700
};
var opacity = {
  /** @default 0.72 */
  semiOpaque: 0.72,
  /** @default 0.64 */
  intense: 0.64,
  /** @default 0.32 */
  medium: 0.32,
  /** @default 0.16 */
  light: 0.16,
  /** @default 0.08 */
  semiTransparent: 0.08
};
var opacityDisabled = opacity.intense;
var outlineOffset = 1;
var outlineOpacity = 0.6;
var outlineWidth = 3;
var outlineZIndex = 10;
var radius = {
  /** @default 0px */
  none: "0px",
  /** @default 4px */
  xxs: "4px",
  /** @default 8px */
  xs: "8px",
  /** @default 12px */
  sm: "12px",
  /** @default 16px */
  md: "16px",
  /** @default 24px */
  lg: "24px",
  /** @default 32px */
  xl: "32px",
  /** @default 9999px */
  full: "9999px",
  /** @default 50% */
  round: "50%"
};
var shadow = {
  low: "2px 4px 16px 2px rgba(148, 148, 148, 0.16)",
  mid: "2px 4px 16px 4px rgba(148, 148, 148, 0.24)",
  high: "2px 4px 16px 8px rgba(148, 148, 148, 0.32)"
};
var shadowDark = {
  low: "2px 4px 16px 2px rgba(32, 32, 32, 0.16)",
  mid: "2px 4px 16px 4px rgba(32, 32, 32, 0.24)",
  high: "2px 4px 16px 8px rgba(32, 32, 32, 0.32)"
};
var spacing = {
  /** @default 2px */
  xxxs: "2px",
  /** @default 4px */
  xxs: "4px",
  /** @default 8px */
  xs: "8px",
  /** @default 12px */
  sm: "12px",
  /** @default 16px */
  md: "16px",
  /** @default 24px */
  lg: "24px",
  /** @default 32px */
  xl: "32px",
  /** @default 48px */
  xxl: "48px",
  /** @default 64px */
  xxxl: "64px",
  /** @default 96px */
  jumbo: "96px"
};
var typography = {
  xxs: {
    /** @default 10px */
    fontSize: "10px",
    lineHeight: 1.1
  },
  xs: {
    /** @default 12px */
    fontSize: "12px",
    lineHeight: 1.2
  },
  sm: {
    /** @default 14px */
    fontSize: "14px",
    lineHeight: 1.2
  },
  md: {
    /** @default 16px */
    fontSize: "16px",
    lineHeight: 1.2
  },
  lg: {
    /** @default 18px */
    fontSize: "18px",
    lineHeight: 1.2
  },
  xl: {
    /** @default 20px */
    fontSize: "20px",
    lineHeight: 1.2
  },
  h6: {
    /** @default 16px */
    fontSize: "16px",
    lineHeight: 1.2
  },
  h5: {
    /** @default 18px */
    fontSize: "18px",
    lineHeight: 1.2
  },
  h4: {
    /** @default 20px */
    fontSize: "20px",
    lineHeight: 1.2
  },
  h3: {
    /** @default 24px */
    fontSize: "24px",
    lineHeight: 1.2
  },
  h2: {
    /** @default 28px */
    fontSize: "28px",
    lineHeight: 1.2
  },
  h1: {
    /** @default 32px */
    fontSize: "32px",
    lineHeight: 1.2
  },
  jumbo: {
    /** @default 48px */
    fontSize: "48px",
    lineHeight: 1.2
  },
  jumboLarge: {
    /** @default 64px */
    fontSize: "64px",
    lineHeight: 1.2
  }
};
var zIndex = {
  xxs: 10,
  xs: 20,
  sm: 50,
  md: 100,
  lg: 200,
  xl: 500,
  xxl: 1e3
};
var textColorOptions = {
  threshold: 128
};
var swatchOptions = {};
var black = "#000";
var white = "#fff";
var darkColor = "#262626";
var lightColor = "#f5f5f5";
var grayScale = {
  /** @default #fcfcfc */
  "10": "#fcfcfc",
  /** @default #fafafa */
  "20": "#fafafa",
  /** @default #f7f7f7 */
  "30": "#f7f7f7",
  /**
   * Lightest
   * @default #f5f5f5
   * */
  "40": "#f5f5f5",
  /** @default #f2f2f2 */
  "50": "#f2f2f2",
  /**
   * Lighter
   * @default #e6e6e6
   */
  "100": "#e6e6e6",
  /** @default #d9d9d9 */
  "150": "#d9d9d9",
  /**
   * Light
   * @default #cccccc
   */
  "200": "#cccccc",
  /** @default #b3b3b3 */
  "300": "#b3b3b3",
  /** @default #999999 */
  "400": "#999999",
  /**
   * Mid
   * @default #808080
   */
  "500": "#808080",
  /** @default #666666 */
  "600": "#666666",
  /**
   * Dark
   * @default #4d4d4d
   */
  "700": "#4d4d4d",
  /** @default #404040 */
  "750": "#404040",
  /**
   * Darker
   * @default #333333
   */
  "800": "#333333",
  /** @default #262626 */
  "850": "#262626",
  /**
   * Darkest
   * @default #1a1a1a
   */
  "900": "#1a1a1a",
  /** @default #0d0d0d */
  "950": "#0d0d0d"
};
var colors = {
  /** @default #0049DB */
  primary: "#0049DB",
  /** @default #006157 */
  secondary: "#006157",
  /** @default #b3b3b3 */
  gray: "#b3b3b3",
  /** @default #ff5e5e */
  red: "#ff5e5e",
  /** @default #ff995d */
  orange: "#ff995d",
  /** @default #ffe166 */
  yellow: "#ffe166",
  /** @default #d9ff66 */
  lime: "#d9ff66",
  /** @default #a8ff66 */
  citrus: "#a8ff66",
  /** @default #58d063 */
  green: "#58d063",
  /** @default #52d6c5 */
  teal: "#52d6c5",
  /** @default #0bc5ea */
  cyan: "#0bc5ea",
  /** @default #66a5ff */
  blue: "#66a5ff",
  /** @default #8a8fff */
  indigo: "#8a8fff",
  /** @default #ad7bff */
  purple: "#ad7bff",
  /** @default #ee63ab */
  pink: "#ee63ab"
};
var variants = objectEntries(colors).reduce(
  (acc, [key, value]) => {
    acc[key] = swatch(value, swatchOptions);
    return acc;
  },
  {}
);
var avatar = {
  xs: {
    size: "24px",
    fontSize: "12px"
  },
  sm: {
    size: "32px",
    fontSize: "14px"
  },
  md: {
    size: "48px",
    fontSize: "18px"
  },
  lg: {
    size: "64px",
    fontSize: "24px"
  },
  xl: {
    size: "96px",
    fontSize: "40px"
  },
  jumbo: {
    size: "128px",
    fontSize: "52px"
  }
};
var button = {
  xs: {
    borderRadius: "4px",
    fontSize: "12px",
    fontWeight: 700,
    height: "24px",
    lineHeight: 1.2,
    padding: ["4px", "8px"]
  },
  sm: {
    borderRadius: "8px",
    fontSize: "14px",
    fontWeight: 700,
    height: "32px",
    lineHeight: 1.2,
    padding: ["6px", "12px"]
  },
  md: {
    borderRadius: "8px",
    fontSize: "16px",
    fontWeight: 700,
    height: "40px",
    lineHeight: 1.3,
    padding: ["8px", "16px"]
  },
  lg: {
    borderRadius: "8px",
    fontSize: "18px",
    fontWeight: 700,
    height: "48px",
    lineHeight: 1.4,
    padding: ["10px", "20px"]
  },
  xl: {
    borderRadius: "8px",
    fontSize: "24px",
    fontWeight: 700,
    height: "56px",
    lineHeight: 1.4,
    padding: ["12px", "24px"]
  }
};
var image = {
  animationDuration: 1.5,
  radius: "none",
  skeletonBg: grayScale[50],
  skeletonColor: grayScale[100],
  timingFunction: "ease-in-out"
};
var inputHeight = {
  /** @default 32px */
  sm: "32px",
  /** @default 40px */
  md: "40px",
  /** @default 48px */
  lg: "48px"
};
var inputPaddingY = {
  sm: spacing.xs,
  md: spacing.sm,
  lg: spacing.md
};
var paragraphMarginBetween = spacing.sm;
var selectPaddingY = {
  sm: spacing.xxs,
  md: spacing.xs,
  lg: spacing.sm
};

// src/modules/colors.ts
function getColorComplement(color) {
  const { l } = parseCSS(color, "hsl");
  return l >= 90 ? darken(color, 10) : lighten(color, 10);
}
function getColorTokens(mainColor, textColor2, currentTheme = theme_exports) {
  const { colors: colors2, textColorOptions: textColorOptions2, variants: variants2 } = currentTheme;
  try {
    const variantKeys = objectKeys(variants2);
    const selectedTextColor = textColor2 && variantKeys.some((d) => textColor2.startsWith(d)) ? getColorTokens(textColor2, null, theme_exports)?.mainColor : textColor2;
    switch (mainColor) {
      case "black": {
        return {
          mainColor: black,
          textColor: selectedTextColor ?? white,
          hoverColor: grayScale["800"]
        };
      }
      case "white": {
        return {
          mainColor: white,
          textColor: selectedTextColor ?? black,
          hoverColor: grayScale["100"]
        };
      }
      case "transparent": {
        return {
          mainColor: "transparent",
          textColor: selectedTextColor ?? black,
          hoverColor: "transparent"
        };
      }
      default: {
        if (variantKeys.some((d) => mainColor.startsWith(d))) {
          const [variant, tone] = mainColor.split(".");
          const selectedMainColor = tone ? variants2[variant][tone] : colors2[variant];
          return {
            mainColor: selectedMainColor,
            textColor: selectedTextColor ?? contrastingColor(selectedMainColor, textColorOptions2),
            hoverColor: getColorComplement(selectedMainColor),
            variant
          };
        }
        return {
          mainColor,
          textColor: selectedTextColor ?? contrastingColor(mainColor, textColorOptions2),
          hoverColor: getColorComplement(mainColor)
        };
      }
    }
  } catch {
    return {
      mainColor: colors2.primary,
      textColor: contrastingColor(colors2.primary),
      hoverColor: getColorComplement(colors2.primary),
      variant: "primary"
    };
  }
}
function getColorWithTone(color, tone) {
  const hsl = hex2hsl(parseCSS(color, "hex"));
  const lightness = 100 - parseInt(tone, 10) / 10;
  return hsl2hex({ ...hsl, l: lightness });
}

// src/modules/helpers.ts
import { css } from "@emotion/react";
import { canUseDOM, objectEntries as objectEntries2, objectKeys as objectKeys2, px } from "@gilbarbara/helpers";
import { swatch as swatch2 } from "colorizr";
import { deepmergeCustom } from "deepmerge-ts";
import is from "is-lite";
var { breakpoints: breakpoints2 } = theme_exports;
var deepmerge = deepmergeCustom({
  mergeArrays: false
});
function clearNumber(value) {
  return value.replace(/\D+/g, "");
}
function convertCamelCaseToKebabCase(string_) {
  return string_.replace(/[A-Z]/g, (match) => `-${match.toLowerCase()}`);
}
function convertKebabCaseToCamelCase(value) {
  return value.replace(/-./g, (m) => m[1].toUpperCase());
}
function createMediaQuery(size, mediaQueries) {
  if (isCSSUnit(size) || is.numericString(size)) {
    return `@media screen and (min-width: ${px(size)})`;
  }
  return mediaQueries[size];
}
function formatBreakpoints(theme) {
  return Object.entries(theme.breakpoints).reduce(
    (acc, [key, value]) => {
      acc[key] = parseInt(value, 10);
      return acc;
    },
    { _: 0 }
  );
}
function getElement(target) {
  if (!canUseDOM()) {
    return null;
  }
  let targetEl;
  if (typeof target === "string") {
    targetEl = document.querySelector(target);
  } else {
    targetEl = target && "current" in target ? target.current : target;
  }
  return targetEl;
}
function getMediaQueries() {
  return objectKeys2(breakpoints2).filter((d) => Number.isNaN(parseInt(d, 10))).reduce((acc, d) => {
    acc[d] = `@media screen and (min-width: ${px(breakpoints2[d])})`;
    return acc;
  }, {});
}
function isCSSUnit(value) {
  const units = ["em", "px", "rem", "vh", "vmax", "vmin", "vw"];
  const regex = new RegExp(`\\d+(${units.join("|")})$`);
  return typeof value === "string" && regex.test(value);
}
function mergeTheme(customTheme = {}) {
  const nextTheme = deepmerge({ ...theme_exports }, customTheme);
  const baseVariants = objectEntries2(nextTheme.colors).reduce(
    (acc, [key, value]) => {
      acc[key] = swatch2(value, nextTheme.swatchOptions);
      return acc;
    },
    {}
  );
  return {
    ...nextTheme,
    variants: deepmerge(baseVariants, customTheme.variants ?? {})
  };
}
function responsive(rules) {
  const entries = {};
  const mediaQueries = getMediaQueries();
  for (const rule in rules) {
    if ({}.hasOwnProperty.call(rules, rule)) {
      const styles2 = rules[rule];
      const query = createMediaQuery(rule, mediaQueries);
      if (rule === "_") {
        Object.entries(styles2).forEach(([k, v]) => {
          entries[k] = v;
        });
      } else if (query) {
        entries[query] = styles2;
      }
    }
  }
  return css(entries);
}
function stringifyCSSProperties(style) {
  if (!style || !is.plainObject(style)) {
    return "";
  }
  return objectKeys2(style).reduce((accumulator, key) => {
    const cssKey = convertCamelCaseToKebabCase(key);
    const cssValue = is.string(style[key]) ? px(style[key].replace("'", "")) : style[key];
    return `${accumulator}${cssKey}:${cssValue};`;
  }, "");
}

// src/modules/system.ts
function alignStyles(props) {
  const { align } = props;
  if (align) {
    return {
      textAlign: align
    };
  }
  return {};
}
function getContainerStyles(props, options) {
  const { responsive: responsive2 = true, verticalPadding = false } = options ?? {};
  const { spacing: spacing2 } = props.theme;
  return css2`
    padding-left: ${spacing2.md};
    padding-right: ${spacing2.md};

    ${verticalPadding && css2`
      padding-bottom: ${spacing2.md};
      padding-top: ${spacing2.md};
    `}

    ${responsive2 && responsive({
    lg: {
      paddingLeft: spacing2.xl,
      paddingRight: spacing2.xl
    }
  })}

    ${responsive2 && verticalPadding && responsive({
    lg: {
      paddingBottom: spacing2.xl,
      paddingTop: spacing2.xl
    }
  })}
  `;
}
function getDisableStyles(props, options = {}) {
  const { borderless, theme, variant } = props;
  const { hasPlaceholder, isButton } = options;
  const { darkMode: darkMode2, grayScale: grayScale2 } = theme;
  let backgroundColor;
  let borderColor = darkMode2 ? grayScale2["800"] : grayScale2["100"];
  let color = darkMode2 ? grayScale2["100"] : grayScale2["700"];
  const placeholderColor = darkMode2 ? grayScale2["600"] : grayScale2["300"];
  if (!borderless) {
    backgroundColor = darkMode2 ? grayScale2["900"] : grayScale2["30"];
  }
  if (isButton) {
    backgroundColor = darkMode2 ? grayScale2["800"] : grayScale2["100"];
    borderColor = darkMode2 ? grayScale2["800"] : grayScale2["100"];
    color = grayScale2["500"];
    if (variant === "clean") {
      backgroundColor = "transparent";
      borderColor = "transparent";
    }
    if (variant === "bordered") {
      backgroundColor = "transparent";
    }
  }
  return css2`
    background-color: ${backgroundColor};
    border-color: ${borderColor};
    color: ${color};
    cursor: not-allowed;

    ${hasPlaceholder && css2`
      &::placeholder {
        color: ${placeholderColor};
      }
    `}
  `;
}
function getOutlineStyles(color, { outlineOffset: outlineOffset2, outlineOpacity: outlineOpacity2, outlineWidth: outlineWidth2, outlineZIndex: outlineZIndex2 } = theme_exports) {
  return {
    outline: `${opacify(color, outlineOpacity2)} solid ${px2(outlineWidth2)}`,
    outlineOffset: px2(outlineOffset2),
    zIndex: outlineZIndex2
  };
}
function getStyledOptions(...exclude) {
  return {
    shouldForwardProp: (prop) => isPropValid(prop) && ![
      "bg",
      "color",
      "direction",
      "display",
      "height",
      "letterSpacing",
      "loading",
      "margin",
      "opacity",
      "orientation",
      "overflow",
      "padding",
      "pointerEvents",
      "radius",
      "shadow",
      "size",
      "textDecoration",
      "textTransform",
      "transform",
      "width",
      "wordSpacing",
      "wrap",
      ...exclude
    ].includes(prop) && !["onApply", "onClear", "onCreate", "onDropdown", "onOpen", "onSelect"].some(
      (d) => prop.startsWith(d)
    )
  };
}
function getStyles(props, options = {}) {
  const { busy, display, textAlign, theme } = props;
  const { lineHeightCustom, skipBorder, skipColor, skipShadow, skipSpacing, useFontSize } = options;
  const { fontFamily: fontFamily2 } = theme;
  const styles2 = {
    ...borderStyles(props),
    ...!skipColor ? colorStyles(props, { skipBorder, skipShadow }) : {},
    ...dimensionStyles(props),
    ...flexBoxStyles(props),
    ...flexItemStyles(props),
    ...gridStyles(props),
    ...layoutStyles(props),
    ...positioningStyles(props),
    ...radiusStyles(props),
    ...shadowStyles(props),
    ...textStyles(props, { lineHeightCustom, skipFontSizing: !useFontSize }),
    ...!skipSpacing ? marginStyles(props) : {},
    ...!skipSpacing ? paddingStyles(props) : {},
    boxSizing: "border-box",
    display,
    fontFamily: fontFamily2,
    textAlign
  };
  if (busy) {
    styles2.pointerEvents = "none";
  }
  return sortObjectKeys(cleanUpObject(styles2));
}
var appearanceStyles = {
  appearance: "none"
};
function baseStyles(theme = theme_exports) {
  return {
    boxSizing: "border-box",
    fontFamily: theme.fontFamily
  };
}
function borderStyles(props) {
  const { border, theme } = props;
  let { mainColor: borderColor } = getColorTokens("gray.100", null, theme);
  const defaultBorder = `1px solid ${borderColor}`;
  let output = {};
  const getBorderValue = (side, value = defaultBorder) => {
    const item = {};
    if (["bottom", "left", "right", "top"].includes(side)) {
      item[`border${capitalize(side)}`] = value;
    } else if (["end", "start"].includes(side)) {
      item[`borderInline${capitalize(side)}`] = value;
    } else if (side === "horizontal") {
      item.borderBottom = value;
      item.borderTop = value;
    } else if (side === "vertical") {
      item.borderLeft = value;
      item.borderRight = value;
    } else {
      item.border = value;
    }
    return item;
  };
  const getBorderItem = (item) => {
    const { color = "gray.100", side = "all", size = "1px", style = "solid" } = item;
    ({ mainColor: borderColor } = getColorTokens(color, null, theme));
    const value = `${px2(size)} ${style} ${borderColor}`;
    return getBorderValue(side, value);
  };
  if (is2.nullOrUndefined(border)) {
    return output;
  }
  if (is2.boolean(border)) {
    output.border = border ? defaultBorder : void 0;
  } else if (is2.string(border)) {
    output = getBorderValue(border);
  } else if (is2.array(border)) {
    const items = [];
    border.forEach((item) => {
      items.push(getBorderItem(item));
    });
    output = items.reduce((acc, item) => {
      objectEntries3(item).forEach(([key, value]) => {
        acc[key] = value;
      });
      return acc;
    }, {});
  } else {
    output = getBorderItem(border);
  }
  return output;
}
function colorStyles(props, options = {}) {
  const { skipBorder = false, skipShadow = false } = options;
  const { bg, color, theme, variant } = props;
  const isTransparent = !!variant && ["bordered", "clean"].includes(variant);
  const styles2 = {};
  if (bg) {
    const { mainColor, textColor: textColor2 } = getColorTokens(bg, color, theme);
    styles2.backgroundColor = isTransparent ? "transparent" : mainColor;
    styles2.color = isTransparent ? mainColor : textColor2;
    if (color) {
      styles2.color = textColor2;
    }
    if (!skipBorder) {
      styles2.border = variant === "clean" ? 0 : `1px solid ${mainColor}`;
    }
    if (variant === "shadow" && !skipShadow) {
      const shadowColor = opacify(mainColor, 0.5);
      styles2.boxShadow = `0 6px 12px -3px ${shadowColor},0 4px 6px -4px ${shadowColor}`;
    }
    return styles2;
  }
  if (color) {
    const { mainColor } = getColorTokens(color, null, theme);
    styles2.color = mainColor;
  }
  return styles2;
}
function dimensionStyles(props) {
  const { height, maxHeight, maxWidth, minHeight, minWidth, width } = props;
  const output = {};
  if (!is2.nullOrUndefined(height)) {
    output.height = px2(height);
  }
  if (!is2.nullOrUndefined(maxHeight)) {
    output.maxHeight = px2(maxHeight);
  }
  if (!is2.nullOrUndefined(maxWidth)) {
    output.maxWidth = px2(maxWidth);
  }
  if (!is2.nullOrUndefined(minHeight)) {
    output.minHeight = px2(minHeight);
  }
  if (!is2.nullOrUndefined(minWidth)) {
    output.minWidth = px2(minWidth);
  }
  if (!is2.nullOrUndefined(width)) {
    output.width = px2(width);
  }
  return output;
}
function flexBoxStyles(props) {
  const {
    align,
    alignContent,
    direction,
    gap,
    justify,
    justifyItems,
    placeContent,
    placeItems,
    theme,
    wrap
  } = props;
  const spacingKeys = objectKeys3(theme.spacing);
  let gapValue = px2(gap);
  if (is2.string(gap) && spacingKeys.includes(gap)) {
    gapValue = theme.spacing[gap];
  }
  return {
    alignContent,
    alignItems: align,
    flexDirection: direction,
    flexWrap: wrap,
    gap: gapValue,
    justifyContent: justify,
    justifyItems,
    placeContent,
    placeItems
  };
}
function flexItemStyles(props) {
  const { alignSelf, basis, fill, flex, justifySelf, order } = props;
  const output = {};
  if (!is2.nullOrUndefined(fill)) {
    output.height = fill === true || fill === "vertical" ? "100%" : void 0;
    output.width = fill === true || fill === "horizontal" ? "100%" : void 0;
  }
  if (!is2.nullOrUndefined(flex)) {
    if (is2.boolean(flex)) {
      output.flex = flex ? "1 1" : "0 0";
    } else if (is2.string(flex)) {
      output.flex = flex === "grow" ? "1 0" : "0 1";
    } else {
      if (is2.number(flex.grow)) {
        output.flexGrow = flex.grow;
      }
      if (is2.number(flex.shrink)) {
        output.flexShrink = flex.shrink;
      }
    }
  }
  return {
    ...output,
    alignSelf,
    flexBasis: basis,
    justifySelf,
    order
  };
}
function gridStyles(props) {
  const {
    area,
    autoColumns,
    autoFlow,
    autoRows,
    column,
    columnEnd,
    columnGap,
    columnStart,
    grid,
    row,
    rowEnd,
    rowGap,
    rowStart,
    template,
    templateAreas,
    templateColumns,
    templateRows,
    theme
  } = props;
  const spacingKeys = objectKeys3(theme.spacing);
  let columnGapValue = px2(columnGap);
  let rowGapValue = px2(rowGap);
  if (is2.string(columnGap) && spacingKeys.includes(columnGap)) {
    columnGapValue = theme.spacing[columnGap];
  }
  if (is2.string(rowGap) && spacingKeys.includes(rowGap)) {
    rowGapValue = theme.spacing[rowGap];
  }
  return {
    columnGap: columnGapValue,
    grid,
    gridArea: area,
    gridAutoColumns: autoColumns,
    gridAutoFlow: autoFlow,
    gridAutoRows: autoRows,
    gridColumn: column,
    gridColumnEnd: columnEnd,
    gridColumnStart: columnStart,
    gridRow: row,
    gridRowEnd: rowEnd,
    gridRowStart: rowStart,
    gridTemplate: template,
    gridTemplateAreas: templateAreas,
    gridTemplateColumns: templateColumns,
    gridTemplateRows: templateRows,
    rowGap: rowGapValue
  };
}
function hoverStyles(props) {
  const { bg, color, disabled, theme, variant } = props;
  const styles2 = {};
  if (!bg || disabled) {
    return {};
  }
  const { hoverColor } = getColorTokens(bg, color, theme);
  if (variant === "bordered") {
    styles2.color = hoverColor;
    styles2.borderColor = hoverColor;
  } else if (variant === "clean") {
    styles2.color = hoverColor;
  } else {
    styles2.backgroundColor = hoverColor;
    styles2.borderColor = hoverColor;
  }
  return styles2;
}
function inputStyles(props, type) {
  const {
    accent = "primary",
    borderless,
    height = "md",
    multiple,
    prefixSpacing,
    suffixSpacing,
    theme,
    width
  } = props;
  const {
    darkColor: darkColor2,
    darkMode: darkMode2,
    fontFamily: fontFamily2,
    grayScale: grayScale2,
    inputHeight: inputHeight2,
    inputPaddingY: inputPaddingY2,
    lightColor: lightColor2,
    radius: radius2,
    selectPaddingY: selectPaddingY2,
    spacing: spacing2,
    typography: typography2,
    white: white2
  } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  const isSelect = is2.boolean(multiple);
  const placeholderColor = grayScale2["500"];
  let componentHeight;
  let paddingY = inputPaddingY2[height];
  let paddingLeft = borderless ? 0 : spacing2.md;
  let paddingRight = borderless ? 0 : spacing2.md;
  if (type === "textarea") {
    paddingY = spacing2.xs;
  } else if (!multiple) {
    componentHeight = inputHeight2[height];
  }
  if (isSelect) {
    paddingY = selectPaddingY2[height];
    paddingRight = spacing2.lg;
  }
  if (prefixSpacing) {
    paddingLeft = is2.boolean(prefixSpacing) ? "40px" : px2(prefixSpacing);
  }
  if (suffixSpacing) {
    paddingRight = is2.boolean(suffixSpacing) ? "40px" : px2(suffixSpacing);
  }
  const disabled = getDisableStyles(props, { hasPlaceholder: true });
  const styles2 = borderless ? css2`
        background-color: transparent;
        border: 0;
        border-bottom: 1px solid ${darkMode2 ? grayScale2["700"] : grayScale2["500"]};
      ` : css2`
        background-color: ${darkMode2 ? grayScale2["800"] : white2};
        border: 1px solid ${darkMode2 ? grayScale2["700"] : grayScale2["500"]};
        border-radius: ${radius2.xs};
      `;
  return css2`
    color: ${darkMode2 ? lightColor2 : darkColor2};
    display: block;
    font-family: ${fontFamily2};
    font-size: ${typography2.md.fontSize};
    height: ${componentHeight};
    line-height: 1.4;
    padding: ${paddingY} ${paddingRight} ${paddingY} ${paddingLeft};
    width: ${width ? px2(width) : "100%"};
    ${styles2}

    &:focus {
      ${!!borderless && `
box-shadow: 0 3px 0 0 ${opacify(mainColor, theme.outlineOpacity)};
outline: none;
`}
      ${!borderless && getOutlineStyles(mainColor, theme)}
    }

    &:disabled {
      ${disabled}
    }

    ${!isSelect && css2`
      &::placeholder {
        color: ${placeholderColor};
      }

      &:not(:placeholder-shown) {
        border-color: ${mainColor};
      }

      &:read-only {
        ${disabled}
      }
    `}
  `;
}
function layoutStyles(props) {
  const { display } = props;
  const output = {};
  [
    "opacity",
    "overflow",
    "pointerEvents",
    "textAlign",
    "transition",
    "transform",
    "transformOrigin"
  ].forEach((prop) => {
    const value = props[prop];
    if (!is2.nullOrUndefined(value)) {
      output[prop] = value;
    }
  });
  if (!is2.nullOrUndefined(display)) {
    output.display = display;
  }
  return output;
}
function marginStyles(props) {
  const { m, margin, mb, ml, mr, mt, mx, my, theme } = props;
  const { spacing: spacing2 } = theme;
  const output = {};
  if (!is2.undefined(m)) {
    output.margin = m ? spacing2[m] : m;
  }
  if (!is2.undefined(margin)) {
    output.margin = margin ? spacing2[margin] : margin;
  }
  if (!is2.undefined(my)) {
    output.marginBottom = my ? spacing2[my] : my;
    output.marginTop = my ? spacing2[my] : my;
  } else {
    if (!is2.undefined(mb)) {
      output.marginBottom = mb === "auto" || mb === 0 ? mb : spacing2[mb];
    }
    if (!is2.undefined(mt)) {
      output.marginTop = mt === "auto" || mt === 0 ? mt : spacing2[mt];
    }
  }
  if (!is2.undefined(mx)) {
    output.marginLeft = mx === "auto" || mx === 0 ? mx : spacing2[mx];
    output.marginRight = mx === "auto" || mx === 0 ? mx : spacing2[mx];
  } else {
    if (!is2.undefined(ml)) {
      output.marginLeft = ml === "auto" || ml === 0 ? ml : spacing2[ml];
    }
    if (!is2.undefined(mr)) {
      output.marginRight = mr === "auto" || mr === 0 ? mr : spacing2[mr];
    }
  }
  return output;
}
function outlineStyles(color, theme = theme_exports) {
  const outline = getOutlineStyles(color, theme);
  return css2`
    @supports not selector(:focus-visible) {
      &:focus {
        ${outline}
      }
    }

    &:focus-visible {
      ${outline}
    }
  `;
}
function paddingStyles(props, force = false) {
  const { p, padding, pb, pl, pr, pt, px: paddingX, py, theme } = props;
  const { spacing: spacing2 } = theme;
  const output = {};
  if (!is2.nullOrUndefined(p)) {
    output.padding = is2.number(p) ? p : spacing2[p];
  }
  if (!is2.nullOrUndefined(padding)) {
    output.padding = is2.number(padding) ? padding : spacing2[padding];
  }
  if (!is2.nullOrUndefined(py)) {
    output.paddingBottom = is2.number(py) ? py : spacing2[py];
    output.paddingTop = is2.number(py) ? py : spacing2[py];
  } else {
    if (!is2.nullOrUndefined(pb)) {
      output.paddingBottom = is2.number(pb) ? pb : spacing2[pb];
    }
    if (!is2.nullOrUndefined(pt)) {
      output.paddingTop = is2.number(pt) ? pt : spacing2[pt];
    }
  }
  if (!is2.nullOrUndefined(paddingX)) {
    output.paddingLeft = is2.number(paddingX) ? paddingX : spacing2[paddingX];
    output.paddingRight = is2.number(paddingX) ? paddingX : spacing2[paddingX];
  } else {
    if (!is2.nullOrUndefined(pl)) {
      output.paddingLeft = is2.number(pl) ? pl : spacing2[pl];
    }
    if (!is2.nullOrUndefined(pr)) {
      output.paddingRight = is2.number(pr) ? pr : spacing2[pr];
    }
  }
  if (force) {
    return objectEntries3(output).reduce((acc, [key, value]) => {
      acc[key] = `${value} !important`;
      return acc;
    }, {});
  }
  return output;
}
function positioningStyles(props) {
  const { bottom, left, right, top } = props;
  const output = {};
  ["position", "zIndex"].forEach((prop) => {
    const value = props[prop];
    if (!is2.nullOrUndefined(value)) {
      output[prop] = value;
    }
  });
  if (!is2.nullOrUndefined(bottom)) {
    output.bottom = px2(bottom);
  }
  if (!is2.nullOrUndefined(left)) {
    output.left = px2(left);
  }
  if (!is2.nullOrUndefined(right)) {
    output.right = px2(right);
  }
  if (!is2.nullOrUndefined(top)) {
    output.top = px2(top);
  }
  return output;
}
function radiusStyles(props) {
  const { radius: radius2 } = props.theme;
  const output = {};
  if (is2.plainObject(props.radius)) {
    const { bottom, left, right, top } = props.radius;
    if (top) {
      output.borderTopLeftRadius = radius2[top];
      output.borderTopRightRadius = radius2[top];
    }
    if (right) {
      output.borderTopRightRadius = radius2[right];
      output.borderBottomRightRadius = radius2[right];
    }
    if (bottom) {
      output.borderBottomRightRadius = radius2[bottom];
      output.borderBottomLeftRadius = radius2[bottom];
    }
    if (left) {
      output.borderBottomLeftRadius = radius2[left];
      output.borderTopLeftRadius = radius2[left];
    }
  } else if (props.radius) {
    output.borderRadius = radius2[props.radius];
  }
  return output;
}
function shadowStyles(props) {
  const { darkMode: darkMode2, shadow: shadow2, shadowDark: shadowDark2 } = props.theme;
  if (props.shadow) {
    return {
      boxShadow: darkMode2 ? shadowDark2[props.shadow] : shadow2[props.shadow]
    };
  }
  return {};
}
function textStyles(props, options = {}) {
  const { bold = false, italic = false, lineHeight, size, theme } = props;
  const { fontWeights: fontWeights2, typography: typography2 } = theme;
  const { lineHeightCustom, skipFontSizing } = options;
  const output = {};
  ["letterSpacing", "lineHeight", "textDecoration", "textTransform", "wordSpacing"].forEach((prop) => {
    const value = props[prop];
    if (!is2.nullOrUndefined(value)) {
      output[prop] = value;
    }
  });
  if (bold) {
    output.fontWeight = fontWeights2.bold;
  }
  if (italic) {
    output.fontStyle = "italic";
  }
  if (size && !skipFontSizing) {
    const { fontSize, lineHeight: typographyLineHeight } = typography2[size];
    const fontWeight = bold ? fontWeights2.bold : fontWeights2.normal;
    output.fontSize = fontSize;
    output.fontWeight = fontWeight;
    output.lineHeight = lineHeight ?? lineHeightCustom ?? typographyLineHeight;
  }
  return output;
}

// src/components/Divider/Divider.tsx
import { css as css3 } from "@emotion/react";
import styled from "@emotion/styled";
import { omit, px as px3 } from "@gilbarbara/helpers";

// src/hooks/useComponentProps.ts
import { mergeProps } from "@gilbarbara/helpers";

// src/hooks/useTheme.tsx
import { useCallback as useCallback2, useRef } from "react";
import { useTheme as useThemeEmotion } from "@emotion/react";
import deepEqual from "@gilbarbara/deep-equal";
var storedEmotionTheme;
var storedTheme;
function useTheme() {
  const emotionTheme = useThemeEmotion();
  const needsUpdate = !storedTheme || !deepEqual(storedEmotionTheme, emotionTheme);
  const nextTheme = useRef(storedTheme ?? emotionTheme);
  if (needsUpdate) {
    storedEmotionTheme = emotionTheme;
    nextTheme.current = mergeTheme(emotionTheme);
    storedTheme = nextTheme.current;
  }
  const { dataAttributeName: dataAttributeName2 } = nextTheme.current;
  const getDataAttributes = useCallback2(
    (name) => {
      return {
        [`data-${dataAttributeName2}`]: name
      };
    },
    [dataAttributeName2]
  );
  return { getDataAttributes, theme: nextTheme.current };
}

// src/hooks/useComponentProps.ts
function useComponentProps(props, defaultProps61 = {}) {
  const { getDataAttributes, theme } = useTheme();
  const propsWithTheme = { ...props, theme };
  return {
    componentProps: mergeProps(defaultProps61, propsWithTheme),
    getDataAttributes
  };
}

// src/modules/options.ts
import { sortByLocaleCompare } from "@gilbarbara/helpers";
var iconsPack = [
  { name: "align-bottom", categories: ["layout"] },
  { name: "align-center", categories: ["layout"] },
  { name: "align-left", categories: ["layout"] },
  { name: "align-middle", categories: ["layout"] },
  { name: "align-right", categories: ["layout"] },
  { name: "align-top", categories: ["layout"] },
  { name: "apple-watch", categories: ["devices"] },
  { name: "arrange-back", categories: ["layout"] },
  { name: "arrange-front", categories: ["layout"] },
  { name: "attachment", categories: ["ui"] },
  { name: "backspace", categories: ["arrows"] },
  { name: "band-aid", categories: ["misc"] },
  { name: "battery", categories: ["devices"] },
  { name: "battery-empty", categories: ["devices"] },
  { name: "battery-full", categories: ["devices"] },
  { name: "board", categories: ["ui"] },
  { name: "border-all", categories: ["layout"] },
  { name: "border-bottom", categories: ["layout"] },
  { name: "border-left", categories: ["layout"] },
  { name: "border-right", categories: ["layout"] },
  { name: "border-style-dashed", categories: ["layout"] },
  { name: "border-style-dotted", categories: ["layout"] },
  { name: "border-style-solid", categories: ["layout"] },
  { name: "border-top", categories: ["layout"] },
  { name: "bot", categories: ["misc"] },
  { name: "bowl", categories: ["misc"] },
  { name: "boy", categories: ["misc"] },
  { name: "briefcase", categories: ["ui"] },
  { name: "browse", categories: ["ui"] },
  { name: "browser", categories: ["ui"] },
  { name: "calculator", categories: ["devices"] },
  { name: "calendar-dates", categories: ["date"] },
  { name: "calendar-due", categories: ["date"] },
  { name: "calendar-next", categories: ["date"] },
  { name: "calendar-today", categories: ["date"] },
  { name: "calendar", categories: ["date"] },
  { name: "calibrate", categories: ["misc"] },
  { name: "captions", categories: ["ui"] },
  { name: "card-clubs", categories: ["misc"] },
  { name: "card-diamonds", categories: ["misc"] },
  { name: "card-hearts", categories: ["misc"] },
  { name: "card-spades", categories: ["misc"] },
  { name: "carousel", categories: ["ui"] },
  { name: "cast", categories: ["ui"] },
  { name: "chart", categories: ["ui"] },
  { name: "clapper-board", categories: ["multimedia"] },
  { name: "clipboard", categories: ["ui"] },
  { name: "code", categories: ["development"] },
  { name: "code-slash", categories: ["development"] },
  { name: "collage", categories: ["ui"] },
  { name: "color-bucket", categories: ["ui"] },
  { name: "color-picker", categories: ["ui"] },
  { name: "community", categories: ["misc"] },
  { name: "components", categories: ["ui"] },
  { name: "compress-left", categories: ["arrows"] },
  { name: "compress-right", categories: ["arrows"] },
  { name: "compress-v", categories: ["arrows"] },
  { name: "compress", categories: ["arrows"] },
  { name: "controller", categories: ["ui"] },
  { name: "corner-double-down-left", categories: ["arrows"] },
  { name: "corner-double-down-right", categories: ["arrows"] },
  { name: "corner-double-left-down", categories: ["arrows"] },
  { name: "corner-double-left-up", categories: ["arrows"] },
  { name: "corner-double-right-down", categories: ["arrows"] },
  { name: "corner-double-right-up", categories: ["arrows"] },
  { name: "corner-double-up-left", categories: ["arrows"] },
  { name: "corner-double-up-right", categories: ["arrows"] },
  { name: "corner-down-left", categories: ["arrows"] },
  { name: "corner-down-right", categories: ["arrows"] },
  { name: "corner-left-down", categories: ["arrows"] },
  { name: "corner-left-up", categories: ["arrows"] },
  { name: "corner-right-down", categories: ["arrows"] },
  { name: "corner-right-up", categories: ["arrows"] },
  { name: "corner-up-left", categories: ["arrows"] },
  { name: "corner-up-right", categories: ["arrows"] },
  { name: "credit-card", categories: ["misc"] },
  { name: "crop", categories: ["ui"] },
  { name: "dark-mode", categories: ["ui"] },
  { name: "desktop", categories: ["ui"] },
  { name: "details-less", categories: ["layout"] },
  { name: "details-more", categories: ["layout"] },
  { name: "dialpad", categories: ["ui"] },
  { name: "dice-1", categories: ["misc"] },
  { name: "dice-2", categories: ["misc"] },
  { name: "dice-3", categories: ["misc"] },
  { name: "dice-4", categories: ["misc"] },
  { name: "dice-5", categories: ["misc"] },
  { name: "dice-6", categories: ["misc"] },
  { name: "display-flex", categories: ["layout"] },
  { name: "display-fullwidth", categories: ["layout"] },
  { name: "display-grid", categories: ["layout"] },
  { name: "display-spacing", categories: ["layout"] },
  { name: "distribute-horizontal", categories: ["layout"] },
  { name: "distribute-vertical", categories: ["layout"] },
  { name: "dock-bottom", categories: ["ui"] },
  { name: "dock-left", categories: ["ui"] },
  { name: "dock-right", categories: ["ui"] },
  { name: "dock-window", categories: ["ui"] },
  { name: "drive", categories: ["devices"] },
  { name: "drop-invert", categories: ["ui"] },
  { name: "drop-opacity", categories: ["ui"] },
  { name: "drop", categories: ["ui"] },
  { name: "duplicate", categories: ["ui"] },
  { name: "edit-black-point", categories: ["ui"] },
  { name: "edit-contrast", categories: ["ui"] },
  { name: "edit-exposure", categories: ["ui"] },
  { name: "edit-fade", categories: ["ui"] },
  { name: "edit-flip-h", categories: ["ui"] },
  { name: "edit-flip-v", categories: ["ui"] },
  { name: "edit-highlight", categories: ["ui"] },
  { name: "edit-markup", categories: ["ui"] },
  { name: "edit-mask", categories: ["ui"] },
  { name: "edit-noise", categories: ["ui"] },
  { name: "edit-shadows", categories: ["ui"] },
  { name: "edit-straight", categories: ["ui"] },
  { name: "edit-unmask", categories: ["ui"] },
  { name: "enter", categories: ["ui"] },
  { name: "erase", categories: ["ui"] },
  { name: "euro", categories: ["misc"] },
  { name: "export", categories: ["ui"] },
  { name: "extension-add", categories: ["ui"] },
  { name: "extension-remove", categories: ["ui"] },
  { name: "extension", categories: ["ui"] },
  { name: "external", categories: ["ui"] },
  { name: "feed", categories: ["ui"] },
  { name: "file-add", categories: ["ui"] },
  { name: "file-document", categories: ["ui"] },
  { name: "file-remove", categories: ["ui"] },
  { name: "file", categories: ["ui"] },
  { name: "film", categories: ["multimedia"] },
  { name: "filters", categories: ["ui"] },
  { name: "folder-add", categories: ["ui"] },
  { name: "folder-remove", categories: ["ui"] },
  { name: "folder", categories: ["ui"] },
  { name: "font-height", categories: ["typography"] },
  { name: "font-spacing", categories: ["typography"] },
  { name: "format-center", categories: ["typography"] },
  { name: "format-color", categories: ["typography"] },
  { name: "format-heading", categories: ["typography"] },
  { name: "format-indent-decrease", categories: ["typography"] },
  { name: "format-indent-increase", categories: ["typography"] },
  { name: "format-italic", categories: ["typography"] },
  { name: "format-justify", categories: ["typography"] },
  { name: "format-left", categories: ["typography"] },
  { name: "format-line-height", categories: ["typography"] },
  { name: "format-right", categories: ["typography"] },
  { name: "format-separator", categories: ["typography"] },
  { name: "format-slash", categories: ["typography"] },
  { name: "format-text", categories: ["typography"] },
  { name: "format-underline", categories: ["typography"] },
  { name: "format-uppercase", categories: ["typography"] },
  { name: "games", categories: ["devices"] },
  { name: "gender-female", categories: ["misc"] },
  { name: "gender-male", categories: ["misc"] },
  { name: "girl", categories: ["misc"] },
  { name: "glass-alt", categories: ["misc"] },
  { name: "home-screen", categories: ["devices"] },
  { name: "image", categories: ["ui"] },
  { name: "import", categories: ["ui"] },
  { name: "inpicture", categories: ["multimedia"] },
  { name: "insert-after-o", categories: ["ui"] },
  { name: "insert-after-r", categories: ["ui"] },
  { name: "insert-after", categories: ["ui"] },
  { name: "insert-before-o", categories: ["ui"] },
  { name: "insert-before-r", categories: ["ui"] },
  { name: "insert-before", categories: ["ui"] },
  { name: "insights", categories: ["ui"] },
  { name: "internal", categories: ["ui"] },
  { name: "laptop", categories: ["devices"] },
  { name: "list-tree", categories: ["ui"] },
  { name: "list", categories: ["ui"] },
  { name: "lock-unlock", categories: ["ui"] },
  { name: "lock", categories: ["ui"] },
  { name: "log-off", categories: ["ui"] },
  { name: "loupe", categories: ["ui"] },
  { name: "magnet", categories: ["misc"] },
  { name: "mail-forward", categories: ["ui"] },
  { name: "mail-reply", categories: ["ui"] },
  { name: "maximize", categories: ["ui"] },
  { name: "maximize-alt", categories: ["arrows", "ui"] },
  { name: "menu-boxed", categories: ["ui"] },
  { name: "menu-grid-o", categories: ["ui"] },
  { name: "menu-grid-r", categories: ["ui"] },
  { name: "menu-left-alt", categories: ["ui"] },
  { name: "menu-left", categories: ["ui"] },
  { name: "menu-motion", categories: ["ui"] },
  { name: "menu-right-alt", categories: ["ui"] },
  { name: "menu-right", categories: ["ui"] },
  { name: "menu", categories: ["ui"] },
  { name: "merge-horizontal", categories: ["ui"] },
  { name: "merge-vertical", categories: ["ui"] },
  { name: "mini-player", categories: ["multimedia"] },
  { name: "minimize-alt", categories: ["ui"] },
  { name: "minimize", categories: ["ui"] },
  { name: "mouse", categories: ["devices"] },
  { name: "move-down", categories: ["ui"] },
  { name: "move-left", categories: ["ui"] },
  { name: "move-right", categories: ["ui"] },
  { name: "move-up", categories: ["ui"] },
  { name: "notifications", categories: ["ui"] },
  { name: "pacman", categories: ["misc"] },
  { name: "path-back", categories: ["layout"] },
  { name: "path-crop", categories: ["layout"] },
  { name: "path-divide", categories: ["layout"] },
  { name: "path-exclude", categories: ["layout"] },
  { name: "path-front", categories: ["layout"] },
  { name: "path-intersect", categories: ["layout"] },
  { name: "path-outline", categories: ["layout"] },
  { name: "path-trim", categories: ["layout"] },
  { name: "path-unite", categories: ["layout"] },
  { name: "performance", categories: ["ui"] },
  { name: "piano", categories: ["multimedia"] },
  { name: "pill", categories: ["misc"] },
  { name: "plug", categories: ["ui"] },
  { name: "pokemon", categories: ["misc"] },
  { name: "poll", categories: ["ui"] },
  { name: "printer", categories: ["devices"] },
  { name: "profile", categories: ["ui"] },
  { name: "pull-clear", categories: ["ui"] },
  { name: "push-chevron-down-o", categories: ["ui", "circle"] },
  { name: "push-chevron-down-r", categories: ["ui", "square"] },
  { name: "push-chevron-down", categories: ["ui"] },
  { name: "push-chevron-left-o", categories: ["ui", "circle"] },
  { name: "push-chevron-left-r", categories: ["ui", "square"] },
  { name: "push-chevron-left", categories: ["ui"] },
  { name: "push-chevron-right-o", categories: ["ui", "circle"] },
  { name: "push-chevron-right-r", categories: ["ui", "square"] },
  { name: "push-chevron-right", categories: ["ui"] },
  { name: "push-chevron-up-o", categories: ["ui", "circle"] },
  { name: "push-chevron-up-r", categories: ["ui", "square"] },
  { name: "push-chevron-up", categories: ["ui"] },
  { name: "push-down", categories: ["ui"] },
  { name: "push-left", categories: ["ui"] },
  { name: "push-right", categories: ["ui"] },
  { name: "push-up", categories: ["ui"] },
  { name: "qr", categories: ["ui"] },
  { name: "quote-o", categories: ["ui"] },
  { name: "quote", categories: ["ui"] },
  { name: "radio-check", categories: ["ui"] },
  { name: "radio-checked", categories: ["ui"] },
  { name: "ratio", categories: ["ui"] },
  { name: "redo", categories: ["ui"] },
  { name: "remove-r", categories: ["ui", "square"] },
  { name: "remove", categories: ["ui"] },
  { name: "rename", categories: ["ui"] },
  { name: "reorder", categories: ["ui"] },
  { name: "row-first", categories: ["layout"] },
  { name: "row-last", categories: ["layout"] },
  { name: "ruler", categories: ["ui"] },
  { name: "scan", categories: ["ui"] },
  { name: "screen-mirror", categories: ["ui"] },
  { name: "screen-wide", categories: ["ui"] },
  { name: "screen", categories: ["ui"] },
  { name: "scroll-h", categories: ["ui"] },
  { name: "scroll-v", categories: ["ui"] },
  { name: "search-found", categories: ["ui"] },
  { name: "search-loading", categories: ["ui"] },
  { name: "search", categories: ["ui"] },
  { name: "select-o", categories: ["ui", "circle"] },
  { name: "select-r", categories: ["ui", "square"] },
  { name: "select", categories: ["ui"] },
  { name: "shopping-bag", categories: ["ui"] },
  { name: "shopping-cart", categories: ["ui"] },
  { name: "sidebar-open", categories: ["ui"] },
  { name: "sidebar-right", categories: ["ui"] },
  { name: "sidebar", categories: ["ui"] },
  { name: "signal", categories: ["ui"] },
  { name: "size", categories: ["ui"] },
  { name: "smartphone", categories: ["devices"] },
  { name: "smile-mouth-open", categories: ["misc"] },
  { name: "smile-neutral", categories: ["misc"] },
  { name: "smile-no-mouth", categories: ["misc"] },
  { name: "smile-none", categories: ["misc"] },
  { name: "smile-sad", categories: ["misc"] },
  { name: "smile-upside", categories: ["misc"] },
  { name: "smile", categories: ["misc"] },
  { name: "space-between-v", categories: ["layout"] },
  { name: "space-between", categories: ["layout"] },
  { name: "spinner-alt", categories: ["loaders"] },
  { name: "spinner-two-alt", categories: ["loaders"] },
  { name: "spinner-two", categories: ["loaders"] },
  { name: "spinner", categories: ["loaders"] },
  { name: "swap-vertical", categories: ["ui"] },
  { name: "swap", categories: ["ui"] },
  { name: "tab", categories: ["ui"] },
  { name: "terrain", categories: ["misc"] },
  { name: "thermostat", categories: ["misc"] },
  { name: "today", categories: ["ui"] },
  { name: "toggle-off", categories: ["ui"] },
  { name: "toggle-on", categories: ["ui"] },
  { name: "toggle-square-off", categories: ["ui"] },
  { name: "toggle-square", categories: ["ui"] },
  { name: "toolbar-bottom", categories: ["ui"] },
  { name: "toolbar-left", categories: ["ui"] },
  { name: "toolbar-right", categories: ["ui"] },
  { name: "toolbar-top", categories: ["ui"] },
  { name: "toolbox", categories: ["ui"] },
  { name: "touchpad", categories: ["devices"] },
  { name: "track", categories: ["ui"] },
  { name: "transcript", categories: ["ui"] },
  { name: "trash-empty", categories: ["ui"] },
  { name: "trash", categories: ["ui"] },
  { name: "trending-down", categories: ["ui"] },
  { name: "trending", categories: ["ui"] },
  { name: "tv", categories: ["devices"] },
  { name: "ui-kit", categories: ["misc"] },
  { name: "umbrella", categories: ["misc"] },
  { name: "undo", categories: ["ui"] },
  { name: "usb", categories: ["devices"] },
  { name: "usb-c", categories: ["devices"] },
  { name: "view-cols", categories: ["layout"] },
  { name: "view-comfortable", categories: ["layout"] },
  { name: "view-day", categories: ["layout"] },
  { name: "view-grid", categories: ["layout"] },
  { name: "view-list", categories: ["layout"] },
  { name: "view-month", categories: ["layout"] },
  { name: "view-split", categories: ["layout"] },
  { name: "voicemail-o", categories: ["ui", "circle"] },
  { name: "voicemail-r", categories: ["ui"] },
  { name: "voicemail", categories: ["ui"] },
  { name: "work-alt", categories: ["ui"] },
  { name: "yinyang", categories: ["misc"] },
  { name: "zoom-in", categories: ["ui"] },
  { name: "zoom-out", categories: ["ui"] }
];
var iconsCustom = [
  { name: "accessibility", categories: ["ui"] },
  { name: "accessibility-circle", categories: ["ui", "circle"] },
  { name: "accessibility-o", categories: ["ui", "circle"] },
  { name: "airplane", categories: ["misc"] },
  { name: "airpods", categories: ["devices", "multimedia"] },
  { name: "alarm", categories: ["time"] },
  { name: "album", categories: ["multimedia"] },
  { name: "anchor", categories: ["misc"] },
  { name: "angular", categories: ["development"] },
  { name: "api", categories: ["development"] },
  { name: "api-alt", categories: ["development"] },
  { name: "apple", categories: ["brand"] },
  { name: "approximately-equal", categories: ["math"] },
  { name: "arc", categories: ["browsers"] },
  { name: "archive", categories: ["ui"] },
  { name: "arrow-bottom-left-o", categories: ["arrows", "circle"] },
  { name: "arrow-bottom-left-r", categories: ["arrows", "square"] },
  { name: "arrow-bottom-left", categories: ["arrows"] },
  { name: "arrow-bottom-right-o", categories: ["arrows", "circle"] },
  { name: "arrow-bottom-right-r", categories: ["arrows", "square"] },
  { name: "arrow-bottom-right", categories: ["arrows"] },
  { name: "arrow-down-o", categories: ["arrows", "circle"] },
  { name: "arrow-down-r", categories: ["arrows", "square"] },
  { name: "arrow-down", categories: ["arrows"] },
  { name: "arrows-exchange-alt-v", categories: ["arrows"] },
  { name: "arrows-exchange-alt", categories: ["arrows"] },
  { name: "arrows-exchange-v", categories: ["arrows"] },
  { name: "arrows-exchange", categories: ["arrows"] },
  { name: "arrows-expand-down-left", categories: ["arrows"] },
  { name: "arrows-expand-down-right", categories: ["arrows"] },
  { name: "arrows-expand-left", categories: ["arrows"] },
  { name: "arrows-expand-right", categories: ["arrows"] },
  { name: "arrows-expand-up-left", categories: ["arrows"] },
  { name: "arrows-expand-up-right", categories: ["arrows"] },
  { name: "arrows-h", categories: ["arrows"] },
  { name: "arrows-h-alt", categories: ["arrows"] },
  { name: "arrow-left-o", categories: ["arrows", "circle"] },
  { name: "arrow-left-r", categories: ["arrows", "square"] },
  { name: "arrow-left", categories: ["arrows"] },
  { name: "arrow-right-o", categories: ["arrows", "circle"] },
  { name: "arrow-right-r", categories: ["arrows", "square"] },
  { name: "arrow-right", categories: ["arrows"] },
  { name: "arrows-scroll-h", categories: ["arrows"] },
  { name: "arrows-scroll-v", categories: ["arrows"] },
  { name: "arrow-switch", categories: ["arrows"] },
  { name: "arrow-switch-o", categories: ["arrows"] },
  { name: "arrow-switch-r", categories: ["arrows"] },
  { name: "arrow-top-left-o", categories: ["arrows", "circle"] },
  { name: "arrow-top-left-r", categories: ["arrows", "square"] },
  { name: "arrow-top-left", categories: ["arrows"] },
  { name: "arrow-top-right-o", categories: ["arrows", "circle"] },
  { name: "arrow-top-right-r", categories: ["arrows", "square"] },
  { name: "arrow-top-right", categories: ["arrows"] },
  { name: "arrow-up-o", categories: ["arrows", "circle"] },
  { name: "arrow-up-r", categories: ["arrows", "square"] },
  { name: "arrow-up", categories: ["arrows"] },
  { name: "arrows-v", categories: ["arrows"] },
  { name: "arrows-v-alt", categories: ["arrows"] },
  { name: "asterisk", categories: ["misc"] },
  { name: "asterisk-o", categories: ["misc", "circle"] },
  { name: "asterisk-r", categories: ["misc", "square"] },
  { name: "atlassian", categories: ["development"] },
  { name: "attribution", categories: ["multimedia"] },
  { name: "award", categories: ["misc"] },
  { name: "badge", categories: ["misc"] },
  { name: "bamboo", categories: ["development"] },
  { name: "bell", categories: ["ui"] },
  { name: "bell-o", categories: ["ui"] },
  { name: "bell-slash", categories: ["ui"] },
  { name: "bitbucket", categories: ["development"] },
  { name: "blob", categories: ["misc"] },
  { name: "block-o", categories: ["ui", "circle"] },
  { name: "blocked", categories: ["ui"] },
  { name: "bluetooth", categories: ["devices"] },
  { name: "book", categories: ["ui"] },
  { name: "bookmark", categories: ["ui"] },
  { name: "bookmark-slash", categories: ["ui"] },
  { name: "box", categories: ["misc"] },
  { name: "bug", categories: ["development"] },
  { name: "bullseye", categories: ["misc"] },
  { name: "bullseye-arrow", categories: ["misc"] },
  { name: "c-plus-plus", categories: ["development"] },
  { name: "cache", categories: ["development"] },
  { name: "camera", categories: ["devices", "multimedia"] },
  { name: "camera-alt", categories: ["devices", "multimedia"] },
  { name: "categories", categories: ["ui"] },
  { name: "chart-activity", categories: ["ui"] },
  { name: "chart-bar", categories: ["ui"] },
  { name: "chart-line", categories: ["ui"] },
  { name: "chart-trending-down", categories: ["ui"] },
  { name: "chart-trending-up", categories: ["ui"] },
  { name: "check", categories: ["ui"] },
  { name: "check-heavy", categories: ["ui"] },
  { name: "check-circle", categories: ["ui", "circle"] },
  { name: "check-o", categories: ["ui", "circle"] },
  { name: "check-r", categories: ["ui", "square"] },
  { name: "checklist", categories: ["ui"] },
  { name: "chevron-double-down-o", categories: ["arrows", "circle"] },
  { name: "chevron-double-down-r", categories: ["arrows", "square"] },
  { name: "chevron-double-left-o", categories: ["arrows", "circle"] },
  { name: "chevron-double-left-r", categories: ["arrows", "square"] },
  { name: "chevron-double-right-o", categories: ["arrows", "circle"] },
  { name: "chevron-double-right-r", categories: ["arrows", "square"] },
  { name: "chevron-double-up-o", categories: ["arrows", "circle"] },
  { name: "chevron-double-up-r", categories: ["arrows", "square"] },
  { name: "chevron-down-o", categories: ["arrows", "circle"] },
  { name: "chevron-down-r", categories: ["arrows", "square"] },
  { name: "chevron-down", categories: ["arrows"] },
  { name: "chevron-left-o", categories: ["arrows", "circle"] },
  { name: "chevron-left-r", categories: ["arrows", "square"] },
  { name: "chevron-left", categories: ["arrows"] },
  { name: "chevron-right-o", categories: ["arrows", "circle"] },
  { name: "chevron-right-r", categories: ["arrows", "square"] },
  { name: "chevron-right", categories: ["arrows"] },
  { name: "chevron-up-o", categories: ["arrows", "circle"] },
  { name: "chevron-up-r", categories: ["arrows", "square"] },
  { name: "chevron-up", categories: ["arrows"] },
  { name: "chevron-double-down", categories: ["arrows"] },
  { name: "chevron-double-left", categories: ["arrows"] },
  { name: "chevron-double-right", categories: ["arrows"] },
  { name: "chevron-double-up", categories: ["arrows"] },
  { name: "chip", categories: ["devices"] },
  { name: "chrome", categories: ["browsers"] },
  { name: "circle", categories: ["shapes"] },
  { name: "circle-ci", categories: ["development"] },
  { name: "circle-half", categories: ["shapes"] },
  { name: "clock", categories: ["time"] },
  { name: "close", categories: ["ui"] },
  { name: "close-heavy", categories: ["ui"] },
  { name: "close-circle", categories: ["ui", "circle"] },
  { name: "close-o", categories: ["ui", "circle"] },
  { name: "close-r", categories: ["ui", "square"] },
  { name: "cloud", categories: ["ui"] },
  { name: "cloud-slash", categories: ["ui"] },
  { name: "code-climate", categories: ["development"] },
  { name: "code-review", categories: ["development"] },
  { name: "codepen", categories: ["development"] },
  { name: "codesandbox", categories: ["development"] },
  { name: "codescan", categories: ["development"] },
  { name: "coffee", categories: ["misc"] },
  { name: "cog", categories: ["ui"] },
  { name: "command-key", categories: ["devices"] },
  { name: "command-palette", categories: ["development"] },
  { name: "comment", categories: ["ui"] },
  { name: "comment-external", categories: ["ui"] },
  { name: "container", categories: ["misc"] },
  { name: "control-key", categories: ["devices"] },
  { name: "copy", categories: ["ui"] },
  { name: "copyright", categories: ["ui"] },
  { name: "cross", categories: ["misc"] },
  { name: "crosshair", categories: ["ui", "circle"] },
  { name: "crown", categories: ["misc"] },
  { name: "cursor", categories: ["ui"] },
  { name: "danger-circle", categories: ["ui", "circle"] },
  { name: "danger-o", categories: ["ui", "circle"] },
  { name: "database", categories: ["development"] },
  { name: "delta", categories: ["math"] },
  { name: "devices", categories: ["devices"] },
  { name: "diamond", categories: ["shapes"] },
  { name: "digital-ocean", categories: ["development"] },
  { name: "disc", categories: ["multimedia"] },
  { name: "discord", categories: ["brand"] },
  { name: "discussion", categories: ["misc"] },
  { name: "discussion-closed", categories: ["misc"] },
  { name: "discussion-duplicated", categories: ["misc"] },
  { name: "discussion-outdated", categories: ["misc"] },
  { name: "divide", categories: ["math"] },
  { name: "divide-heavy", categories: ["math"] },
  { name: "download", categories: ["ui"] },
  { name: "draft", categories: ["ui"] },
  { name: "drag", categories: ["arrows", "ui"] },
  { name: "drag-alt", categories: ["ui"] },
  { name: "dribble", categories: ["brand"] },
  { name: "dropbox", categories: ["brand"] },
  { name: "edge", categories: ["browsers"] },
  { name: "eject", categories: ["multimedia"] },
  { name: "ellipsis", categories: ["misc"] },
  { name: "equal", categories: ["math"] },
  { name: "equal-heavy", categories: ["math"] },
  { name: "expand", categories: ["arrows"] },
  { name: "eye", categories: ["ui"] },
  { name: "eye-slash", categories: ["ui"] },
  { name: "facebook", categories: ["brand"] },
  { name: "figma", categories: ["brand"] },
  { name: "filter", categories: ["ui"] },
  { name: "fingerprint", categories: ["misc"] },
  { name: "firefox", categories: ["browsers"] },
  { name: "flag", categories: ["ui"] },
  { name: "flag-alt", categories: ["ui"] },
  { name: "flame", categories: ["ui"] },
  { name: "flash", categories: ["ui"] },
  { name: "flash-circle", categories: ["ui", "circle"] },
  { name: "flash-o", categories: ["ui", "circle"] },
  { name: "focus", categories: ["ui"] },
  { name: "fold", categories: ["misc"] },
  { name: "fold-down", categories: ["misc"] },
  { name: "fold-up", categories: ["misc"] },
  { name: "format-bold", categories: ["typography"] },
  { name: "format-strikethrough", categories: ["typography"] },
  { name: "framer", categories: ["brand"] },
  { name: "function", categories: ["development"] },
  { name: "gauge", categories: ["time"] },
  { name: "ghost", categories: ["misc"] },
  { name: "gift", categories: ["misc"] },
  { name: "git", categories: ["development"] },
  { name: "git-branch", categories: ["development"] },
  { name: "git-commit", categories: ["development"] },
  { name: "git-compare", categories: ["development"] },
  { name: "git-fork", categories: ["development"] },
  { name: "git-merge", categories: ["development"] },
  { name: "git-pull-request", categories: ["development"] },
  { name: "github", categories: ["development"] },
  { name: "github-actions", categories: ["development"] },
  { name: "github-copilot", categories: ["development"] },
  { name: "gitlab", categories: ["development"] },
  { name: "gitter", categories: ["development"] },
  { name: "glass", categories: ["misc"] },
  { name: "glasses", categories: ["misc"] },
  { name: "globe", categories: ["ui"] },
  { name: "google", categories: ["brand"] },
  { name: "google-calendar", categories: ["brand"] },
  { name: "google-drive", categories: ["brand"] },
  { name: "google-meet", categories: ["brand"] },
  { name: "grabber", categories: ["ui"] },
  { name: "graph", categories: ["ui"] },
  { name: "greater-than", categories: ["math"] },
  { name: "greater-than-or-equal", categories: ["math"] },
  { name: "hash", categories: ["ui"] },
  { name: "headphone", categories: ["devices", "multimedia"] },
  { name: "heart", categories: ["ui"] },
  { name: "heart-o", categories: ["ui"] },
  { name: "help", categories: ["ui"] },
  { name: "hexagon", categories: ["shapes"] },
  { name: "history", categories: ["ui"] },
  { name: "home", categories: ["ui"] },
  { name: "hook", categories: ["misc"] },
  { name: "hourglass", categories: ["time"] },
  { name: "inbox", categories: ["ui"] },
  { name: "infinity", categories: ["misc"] },
  { name: "info", categories: ["ui"] },
  { name: "info-circle", categories: ["ui", "circle"] },
  { name: "info-o", categories: ["ui", "circle"] },
  { name: "instagram", categories: ["brand"] },
  { name: "invision", categories: ["brand"] },
  { name: "iterations", categories: ["ui"] },
  { name: "javascript", categories: ["development"] },
  { name: "jenkins", categories: ["development"] },
  { name: "jest", categories: ["development"] },
  { name: "jsfiddle", categories: ["development"] },
  { name: "key", categories: ["ui"] },
  { name: "key-alt", categories: ["ui"] },
  { name: "keyboard", categories: ["devices"] },
  { name: "keyhole-circle", categories: ["ui", "circle"] },
  { name: "keyhole-o", categories: ["ui", "circle"] },
  { name: "kotlin", categories: ["development"] },
  { name: "law", categories: ["misc"] },
  { name: "layout-grid", categories: ["layout"] },
  { name: "layout-grid-small", categories: ["layout"] },
  { name: "layout-list", categories: ["layout"] },
  { name: "layout-pin", categories: ["layout"] },
  { name: "leaf", categories: ["misc"] },
  { name: "less-than", categories: ["math"] },
  { name: "less-than-or-equal", categories: ["math"] },
  { name: "lightbulb", categories: ["misc"] },
  { name: "link", categories: ["ui"] },
  { name: "linkedin", categories: ["brand"] },
  { name: "live", categories: ["multimedia"] },
  { name: "live-photo", categories: ["multimedia"] },
  { name: "loadbar", categories: ["loaders"] },
  { name: "loadbar-alt", categories: ["loaders"] },
  { name: "loadbar-doc", categories: ["loaders"] },
  { name: "loadbar-sound", categories: ["loaders"] },
  { name: "location", categories: ["ui"] },
  { name: "log", categories: ["misc"] },
  { name: "loom", categories: ["brand"] },
  { name: "mail", categories: ["ui"] },
  { name: "mail-read", categories: ["ui"] },
  { name: "markdown", categories: ["development"] },
  { name: "megaphone", categories: ["misc"] },
  { name: "mention", categories: ["ui"] },
  { name: "menu-close", categories: ["ui"] },
  { name: "menu-open", categories: ["ui"] },
  { name: "menu-round-circle", categories: ["ui", "circle"] },
  { name: "menu-round-o", categories: ["ui", "circle"] },
  { name: "message", categories: ["ui"] },
  { name: "message-circle", categories: ["ui", "circle"] },
  { name: "message-o", categories: ["ui", "circle"] },
  { name: "messenger", categories: ["brand"] },
  { name: "meta", categories: ["brand"] },
  { name: "meter", categories: ["ui"] },
  { name: "mic", categories: ["devices", "multimedia"] },
  { name: "mic-slash", categories: ["devices", "multimedia"] },
  { name: "microsoft", categories: ["brand"] },
  { name: "microsoft-teams", categories: ["brand"] },
  { name: "microsoft-windows", categories: ["brand"] },
  { name: "middleware", categories: ["development"] },
  { name: "milestone", categories: ["misc"] },
  { name: "minus", categories: ["math"] },
  { name: "minus-heavy", categories: ["math"] },
  { name: "minus-circle", categories: ["ui", "circle"] },
  { name: "minus-o", categories: ["ui", "circle"] },
  { name: "minus-r", categories: ["ui", "square"] },
  { name: "money-sign", categories: ["misc"] },
  { name: "moon", categories: ["misc"] },
  { name: "more", categories: ["ui"] },
  { name: "more-circle", categories: ["ui", "circle"] },
  { name: "more-o", categories: ["ui", "circle"] },
  { name: "more-r", categories: ["ui", "square"] },
  { name: "more-vertical", categories: ["ui"] },
  { name: "more-vertical-circle", categories: ["ui", "circle"] },
  { name: "more-vertical-o", categories: ["ui", "circle"] },
  { name: "more-vertical-r", categories: ["ui", "square"] },
  { name: "multi-select", categories: ["ui"] },
  { name: "music-note", categories: ["multimedia"] },
  { name: "music-note-alt", categories: ["multimedia"] },
  { name: "next", categories: ["multimedia"] },
  { name: "next-o", categories: ["multimedia", "circle"] },
  { name: "next-r", categories: ["multimedia", "square"] },
  { name: "next.js", categories: ["development"] },
  { name: "node.js", categories: ["development"] },
  { name: "not-equal", categories: ["math"] },
  { name: "note", categories: ["ui"] },
  { name: "notebook", categories: ["ui"] },
  { name: "npm", categories: ["development"] },
  { name: "numbers", categories: ["ui"] },
  { name: "opera", categories: ["browsers"] },
  { name: "option-key", categories: ["devices"] },
  { name: "options", categories: ["ui"] },
  { name: "organization", categories: ["ui"] },
  { name: "package", categories: ["misc"] },
  { name: "paintbrush", categories: ["ui"] },
  { name: "palette", categories: ["ui"] },
  { name: "paperclip", categories: ["ui"] },
  { name: "password", categories: ["ui"] },
  { name: "patreon", categories: ["brand"] },
  { name: "pause", categories: ["multimedia"] },
  { name: "pause-o", categories: ["multimedia", "circle"] },
  { name: "pause-r", categories: ["multimedia", "square"] },
  { name: "paypal", categories: ["brand"] },
  { name: "pen", categories: ["ui"] },
  { name: "pencil", categories: ["ui"] },
  { name: "percent", categories: ["math"] },
  { name: "phone", categories: ["devices"] },
  { name: "phone-o", categories: ["devices"] },
  { name: "pi", categories: ["math"] },
  { name: "pin", categories: ["ui"] },
  { name: "pin-slash", categories: ["ui"] },
  { name: "play", categories: ["multimedia"] },
  { name: "play-backwards", categories: ["multimedia"] },
  { name: "play-forwards", categories: ["multimedia"] },
  { name: "play-o", categories: ["multimedia", "circle"] },
  { name: "play-r", categories: ["multimedia", "square"] },
  { name: "playlist", categories: ["multimedia"] },
  { name: "playlist-add", categories: ["multimedia"] },
  { name: "playlist-check", categories: ["multimedia"] },
  { name: "playlist-remove", categories: ["multimedia"] },
  { name: "playlist-search", categories: ["multimedia"] },
  { name: "plus", categories: ["math"] },
  { name: "plus-heavy", categories: ["math"] },
  { name: "plus-circle", categories: ["ui", "circle"] },
  { name: "plus-minus", categories: ["math"] },
  { name: "plus-minus-slash", categories: ["math"] },
  { name: "plus-o", categories: ["ui", "circle"] },
  { name: "plus-r", categories: ["ui", "square"] },
  { name: "podcast", categories: ["multimedia"] },
  { name: "previous", categories: ["multimedia"] },
  { name: "previous-o", categories: ["multimedia", "circle"] },
  { name: "previous-r", categories: ["multimedia", "square"] },
  { name: "product-hunt", categories: ["brand"] },
  { name: "project", categories: ["misc"] },
  { name: "pulse", categories: ["ui"] },
  { name: "puzzle", categories: ["misc"] },
  { name: "python", categories: ["development"] },
  { name: "ram", categories: ["devices"] },
  { name: "react", categories: ["development"] },
  { name: "record-o", categories: ["multimedia", "circle"] },
  { name: "redux", categories: ["development"] },
  { name: "repeat", categories: ["multimedia", "ui"] },
  { name: "repo", categories: ["misc"] },
  { name: "report", categories: ["misc"] },
  { name: "return", categories: ["ui"] },
  { name: "roadmap", categories: ["misc"] },
  { name: "rocket", categories: ["misc"] },
  { name: "rocket-chat", categories: ["brand"] },
  { name: "route", categories: ["development"] },
  { name: "rust", categories: ["development"] },
  { name: "safari", categories: ["browsers"] },
  { name: "safe", categories: ["misc"] },
  { name: "send", categories: ["ui"] },
  { name: "send-alt", categories: ["ui"] },
  { name: "server", categories: ["development"] },
  { name: "server-alt", categories: ["development"] },
  { name: "serverless", categories: ["development"] },
  { name: "serverless-alt", categories: ["development"] },
  { name: "share", categories: ["ui"] },
  { name: "shareplay", categories: ["multimedia"] },
  { name: "share-mobile", categories: ["ui"] },
  { name: "shield", categories: ["misc"] },
  { name: "shield-slash", categories: ["misc"] },
  { name: "shift-key", categories: ["devices"] },
  { name: "shortcuts", categories: ["ui"] },
  { name: "shuffle", categories: ["multimedia"] },
  { name: "side-by-side", categories: ["ui"] },
  { name: "sigma", categories: ["math"] },
  { name: "sign-in", categories: ["ui"] },
  { name: "sign-out", categories: ["ui"] },
  { name: "single-select", categories: ["ui"] },
  { name: "skype", categories: ["brand"] },
  { name: "slack", categories: ["brand"] },
  { name: "sort", categories: ["ui"] },
  { name: "sort-asc", categories: ["ui"] },
  { name: "sort-desc", categories: ["ui"] },
  { name: "sparkle", categories: ["ui"] },
  { name: "sparkle-o", categories: ["ui"] },
  { name: "sparkles", categories: ["ui"] },
  { name: "speaker", categories: ["multimedia"] },
  { name: "spotify", categories: ["brand"] },
  { name: "square", categories: ["shapes"] },
  { name: "square-payments", categories: ["brand"] },
  { name: "square-root", categories: ["math"] },
  { name: "stack", categories: ["layout"] },
  { name: "stacked", categories: ["ui"] },
  { name: "star", categories: ["ui"] },
  { name: "star-half", categories: ["ui"] },
  { name: "star-o", categories: ["ui"] },
  { name: "star-half-o", categories: ["ui"] },
  { name: "stop", categories: ["multimedia"] },
  { name: "stop-o", categories: ["multimedia", "circle"] },
  { name: "stop-r", categories: ["multimedia", "square"] },
  { name: "stop-sign", categories: ["misc"] },
  { name: "stopwatch", categories: ["time"] },
  { name: "storybook", categories: ["brand"] },
  { name: "student", categories: ["misc"] },
  { name: "style", categories: ["ui"] },
  { name: "sun", categories: ["misc"] },
  { name: "svelte", categories: ["development"] },
  { name: "swift", categories: ["development"] },
  { name: "sync", categories: ["ui"] },
  { name: "sync-alt", categories: ["ui"] },
  { name: "tab-key", categories: ["devices"] },
  { name: "tag", categories: ["ui"] },
  { name: "tags", categories: ["ui"] },
  { name: "tasklist", categories: ["ui"] },
  { name: "template", categories: ["layout"] },
  { name: "terminal", categories: ["development"] },
  { name: "thumbs-down", categories: ["ui"] },
  { name: "thumbs-up", categories: ["ui"] },
  { name: "tidal", categories: ["brand"] },
  { name: "timelapse", categories: ["time"] },
  { name: "timer", categories: ["time"] },
  { name: "times", categories: ["math"] },
  { name: "times-heavy", categories: ["math"] },
  { name: "tools", categories: ["ui"] },
  { name: "tools-alt", categories: ["ui"] },
  { name: "touch-id", categories: ["devices"] },
  { name: "travis-ci", categories: ["development"] },
  { name: "tree", categories: ["misc"] },
  { name: "trello", categories: ["brand"] },
  { name: "triangle", categories: ["shapes"] },
  { name: "trophy", categories: ["misc"] },
  { name: "tumblr", categories: ["brand"] },
  { name: "twilio", categories: ["development"] },
  { name: "twitch", categories: ["brand"] },
  { name: "twitter", categories: ["brand"] },
  { name: "typescript", categories: ["development"] },
  { name: "unavailable-o", categories: ["ui", "circle"] },
  { name: "unblock-o", categories: ["ui", "circle"] },
  { name: "unfold", categories: ["misc"] },
  { name: "unlink", categories: ["ui"] },
  { name: "unread", categories: ["ui"] },
  { name: "unverified", categories: ["misc"] },
  { name: "upload", categories: ["ui"] },
  { name: "user", categories: ["ui"] },
  { name: "user-add", categories: ["ui"] },
  { name: "user-remove", categories: ["ui"] },
  { name: "users", categories: ["ui"] },
  { name: "vector", categories: ["ui"] },
  { name: "vercel", categories: ["development"] },
  { name: "verified", categories: ["misc"] },
  { name: "versions", categories: ["development"] },
  { name: "video", categories: ["multimedia"] },
  { name: "video-camera", categories: ["devices", "multimedia"] },
  { name: "vimeo", categories: ["brand"] },
  { name: "vinyl", categories: ["multimedia"] },
  { name: "volume-high", categories: ["multimedia"] },
  { name: "volume-low", categories: ["multimedia"] },
  { name: "volume-mid", categories: ["multimedia"] },
  { name: "vscode", categories: ["development"] },
  { name: "vue", categories: ["development"] },
  { name: "wand", categories: ["misc"] },
  { name: "wave", categories: ["misc"] },
  { name: "webcam", categories: ["devices", "multimedia"] },
  { name: "webhook", categories: ["development"] },
  { name: "website", categories: ["ui"] },
  { name: "webstorm", categories: ["development"] },
  { name: "whatsapp", categories: ["brand"] },
  { name: "wheelchair", categories: ["ui"] },
  { name: "wi-fi", categories: ["devices"] },
  { name: "workflow", categories: ["development"] },
  { name: "workplace", categories: ["brand"] },
  { name: "youtube", categories: ["brand"] },
  { name: "zap", categories: ["ui"] },
  { name: "zigzag", categories: ["shapes"] },
  { name: "zoom", categories: ["brand"] }
];
var icons = [...iconsCustom, ...iconsPack].sort(sortByLocaleCompare("name"));
var sizes = ["sm", "md", "lg"];
var textSizes = ["xxs", "xs", ...sizes, "xl"];
var textDefaultOptions = {
  bold: false,
  italic: false,
  size: "md"
};

// src/components/Divider/useDivider.ts
var defaultProps = {
  ...textDefaultOptions,
  align: "center",
  borderSize: "sm",
  borderStyle: "solid",
  color: "gray.200",
  gap: "xs",
  length: "100%",
  minBorderWidth: 50,
  orientation: "horizontal",
  spacing: "md"
};
function useDivider(props) {
  return useComponentProps(props, defaultProps);
}

// src/components/Divider/Divider.tsx
import { jsx } from "react/jsx-runtime";
var borderSizes = {
  sm: "1px",
  md: "2px",
  lg: "4px"
};
var StyledDivider = styled("div", getStyledOptions("type"))(
  {
    alignItems: "center",
    flexDirection: "row",
    display: "flex",
    lineHeight: 1,
    position: "relative"
  },
  (props) => {
    const {
      align,
      borderSize,
      borderStyle,
      children,
      color,
      gap,
      length,
      minBorderWidth,
      orientation,
      spacing: spacing2,
      theme
    } = props;
    const { spacing: spacingTheme } = theme;
    const isHorizontal = orientation === "horizontal";
    let marginStart = 0;
    let marginEnd = 0;
    let mainColor = color;
    if (spacing2) {
      if (Array.isArray(spacing2)) {
        marginStart = spacing2[0] ? spacingTheme[spacing2[0]] : 0;
        marginEnd = spacing2[1] ? spacingTheme[spacing2[1]] : 0;
      } else {
        marginStart = spacingTheme[spacing2];
        marginEnd = spacingTheme[spacing2];
      }
    }
    if (color !== "transparent") {
      ({ mainColor } = getColorTokens(color, null, theme));
    }
    const selectedDimension = borderSizes[borderSize];
    const margin = isHorizontal ? css3`
          margin-bottom: ${marginStart};
          margin-top: ${marginEnd};
        ` : css3`
          margin-left: ${marginStart};
          margin-right: ${marginEnd};
        `;
    if (isHorizontal && children) {
      return css3`
        color: ${mainColor};
        ${margin};
        width: ${px3(length)};
        ${alignStyles(props)};
        ${getStyles(omit(props, "align"), { useFontSize: true })};

        &:before,
        &:after {
          border-top: ${borderSizes[borderSize]} ${borderStyle} ${mainColor};
          content: '';
          display: inline-flex;
          min-width: ${px3(minBorderWidth)};
          flex-grow: 1;
        }

        &:before {
          flex-grow: ${["center", "right"].includes(align) ? 1 : 0};
          margin-right: ${spacingTheme[gap]};
        }

        &:after {
          flex-grow: ${["center", "left"].includes(align) ? 1 : 0};
          margin-left: ${spacingTheme[gap]};
        }
      `;
    }
    return css3`
      border-bottom: ${isHorizontal ? `${selectedDimension} ${borderStyle} ${mainColor}` : void 0};
      border-left: ${isHorizontal ? void 0 : `${selectedDimension} ${borderStyle} ${mainColor}`};
      height: ${isHorizontal ? void 0 : px3(length)};
      ${margin};
      text-indent: -9999px;
      width: ${px3(isHorizontal ? length : selectedDimension)};
      ${marginStyles(props)};
    `;
  }
);
function Divider(props) {
  const { componentProps, getDataAttributes } = useDivider(props);
  return /* @__PURE__ */ jsx(StyledDivider, { ...getDataAttributes("Divider"), role: "separator", ...componentProps });
}
Divider.displayName = "Divider";

// src/components/Accordion/AccordionItem.tsx
import { isValidElement as isValidElement3 } from "react";

// src/components/Collapse/Collapse.tsx
import { isValidElement, useEffect as useEffect2, useId, useRef as useRef2, useState } from "react";
import { css as css6, keyframes as keyframes3 } from "@emotion/react";
import styled5 from "@emotion/styled";
import { px as px6 } from "@gilbarbara/helpers";
import { usePrevious } from "@gilbarbara/hooks";
import is3 from "is-lite";

// src/components/ButtonUnstyled/ButtonUnstyled.tsx
import { forwardRef as forwardRef2 } from "react";
import { css as css5 } from "@emotion/react";
import styled3 from "@emotion/styled";

// src/components/Icon/Icon.tsx
import { forwardRef, useMemo } from "react";
import SVG from "react-inlinesvg";
import innerText from "react-innertext";
import { css as css4, keyframes as keyframes2 } from "@emotion/react";
import styled2 from "@emotion/styled";
import { omit as omit2, px as px5 } from "@gilbarbara/helpers";

// src/modules/animations.ts
import { keyframes } from "@emotion/react";
import { px as px4 } from "@gilbarbara/helpers";
import scroll from "scroll";
function animateIcon(target, color, theme = theme_exports) {
  const { mainColor } = getColorTokens(color, null, theme);
  if (!target) {
    return;
  }
  const style = `color: ${mainColor}; position: absolute; top: ${target.offsetTop}px;
    left: ${target.offsetLeft}px;
    transition: opacity 0.6s, transform 0.6s;`;
  const iconClone = document.createElement("span");
  iconClone.innerHTML = target.innerHTML;
  iconClone.setAttribute("style", style);
  target.parentElement?.appendChild(iconClone);
  setTimeout(() => {
    iconClone.setAttribute("style", `${style}opacity:0;transform: scale(4);`);
  }, 100);
  iconClone.addEventListener("transitionend", () => {
    if (iconClone.parentNode !== null) {
      iconClone.parentNode.removeChild(iconClone);
    }
  });
}
var fadeIn = keyframes`
  0% {
    opacity: 0;
  }

  100% {
    opacity: 1;
  }
`;
var fadeOut = keyframes`
  0% {
    opacity: 1;
  }

  100% {
    opacity: 0;
  }
`;
var fadeInOut = keyframes`
  0% {
    opacity: 0;
  }

  50% {
    opacity: 1;
  }

  100% {
    opacity: 0;
  }
`;
var horizontalScale = keyframes`
  0% {
    transform: translateX(-50%) scaleX(.2);
  }
  
  100% {
    transform: translateX(100%) scaleX(1);
  }
`;
var ripple = keyframes`
  0% {
    transform: scale(0);
    opacity: 1;
  }
  
  100% {
    transform: scale(1.1);
    opacity: 0;
  }
`;
var rotate = keyframes`
  100% {
    transform: rotate(360deg);
  }
`;
function scrollDocument() {
  return document.scrollingElement || document.createElement("body");
}
function scrollTo(value, options = {}) {
  const { element = scrollDocument(), scrollDuration = 400 } = options;
  return new Promise((resolve, reject) => {
    const { scrollTop } = element;
    const nextValue = scrollDocument().scrollTop + value;
    const limit = nextValue > scrollTop ? nextValue - scrollTop : scrollTop - nextValue;
    scroll.top(element, nextValue, { duration: limit < 100 ? 50 : scrollDuration }, (error) => {
      if (error && error.message !== "Element already at target scroll position") {
        return reject(error);
      }
      return resolve();
    });
  });
}

// src/components/Icon/useIcon.ts
var defaultProps3 = {
  size: 16,
  spin: false
};
function useIcon(props) {
  return useComponentProps(props, defaultProps3);
}

// src/components/Icon/Icon.tsx
import { jsx as jsx2 } from "react/jsx-runtime";
var loadBar = keyframes2`
  0%, 100% { transform: translateX(0); width: 4px; }
  25%, 75% { transform: translateX(0); width: 24px; }
  50% { transform: translateX(20px); width: 4px }
`;
var loadBarDocument = keyframes2`
  0%, 10% { transform: translateX(-100%) }
  50%, 60% { transform: translateX(0) }
`;
var loadBarSound = keyframes2`
  10% {transform: scaleY(0.2) }
  30% {transform: scaleY(0.8) }
  60% {transform: scaleY(0.7) }
  80% {transform: scaleY(0.2) }
  100% {transform: scaleY(1) }
`;
var StyledIcon = styled2("span", getStyledOptions())(
  {
    display: "inline-flex",
    lineHeight: 1
  },
  (props) => {
    const { color, name = "", size, spin, theme } = props;
    let iconColor = color ?? "inherit";
    if (color) {
      const { mainColor } = getColorTokens(color, null, theme);
      iconColor = mainColor;
    }
    return css4`
      color: ${iconColor};
      height: ${px5(size)};
      width: ${px5(size)};
      ${getStyles(omit2(props, "size"))};

      > * {
        ${(!!spin || name.startsWith("spinner")) && css4`
          animation: ${rotate} 1s infinite linear;
        `};
      }

      ${["loadbar", "loadbar-alt"].includes(name) && css4`
        rect:last-of-type {
          animation: ${loadBar} 2s infinite linear;
        }
      `};

      ${name === "loadbar-doc" && css4`
        g > rect {
          animation: ${loadBarDocument} 1s linear infinite alternate;
        }
      `};

      ${name === "loadbar-sound" && css4`
        g > rect {
          animation: ${loadBarSound} 1s linear infinite alternate;
          transform: scaleY(0);
          transform-origin: bottom;

          &:nth-of-type(2) {
            animation-delay: 0.2s;
          }

          &:nth-of-type(3) {
            animation-delay: 0.4s;
          }
        }
      `};
    `;
  }
);
var Icon = forwardRef((props, ref) => {
  const { componentProps, getDataAttributes } = useIcon(props);
  const { name, size = 16, title, url, ...rest } = componentProps;
  const iconURL = useMemo(() => {
    if (name) {
      const urlPrefix = iconsCustom.some((d) => d.name === name) ? "https://files.gilbarbara.dev/icons/" : "https://cdn.jsdelivr.net/npm/css.gg/icons/svg/";
      return `${urlPrefix}${name}.svg`;
    } else if (url) {
      return url;
    }
    return "";
  }, [name, url]);
  if (!iconURL) {
    return null;
  }
  let titleSVG;
  if (title !== null) {
    titleSVG = title ? innerText(title) : name;
  } else {
    titleSVG = null;
  }
  return /* @__PURE__ */ jsx2(StyledIcon, { ref, name, size, ...getDataAttributes("Icon"), ...rest, children: /* @__PURE__ */ jsx2(SVG, { height: size, src: iconURL, title: titleSVG, width: size }) });
});
Icon.displayName = "Icon";

// src/components/ButtonUnstyled/useButtonUnstyled.ts
var defaultProps4 = {
  ...textDefaultOptions,
  align: "center",
  busy: false,
  disabled: false,
  type: "button"
};
function useButtonUnstyled(props) {
  return useComponentProps(props, defaultProps4);
}

// src/components/ButtonUnstyled/ButtonUnstyled.tsx
import { jsx as jsx3, jsxs } from "react/jsx-runtime";
var StyledButtonUnstyled = styled3("button", getStyledOptions())(
  {
    backgroundColor: "transparent",
    border: 0,
    color: "inherit",
    cursor: "pointer",
    display: "inline-flex",
    fontFamily: "inherit",
    lineHeight: 1,
    padding: 0
  },
  (props) => {
    return css5`
      ${appearanceStyles};
      ${getStyles(props, { useFontSize: true })};

      :disabled {
        cursor: not-allowed;
        opacity: ${props.theme.opacityDisabled};
      }
    `;
  }
);
var ButtonUnstyled = forwardRef2((props, ref) => {
  const { componentProps, getDataAttributes } = useButtonUnstyled(props);
  const { busy, children } = componentProps;
  const { fontSize = "16px" } = textStyles(componentProps);
  return /* @__PURE__ */ jsxs(StyledButtonUnstyled, { ref, ...getDataAttributes("ButtonUnstyled"), ...componentProps, children: [
    children,
    busy && /* @__PURE__ */ jsx3(Icon, { ml: "xxs", name: "spinner", size: parseInt(`${fontSize}`, 10) + 2, spin: true })
  ] });
});
ButtonUnstyled.displayName = "ButtonUnstyled";

// src/components/Flex/Flex.tsx
import { forwardRef as forwardRef3 } from "react";
import styled4 from "@emotion/styled";

// src/components/Flex/useFlex.ts
var flexDefaultProps = {
  display: "flex"
};
var flexCenterDefaultProps = {
  align: "center",
  direction: "column",
  display: "flex",
  justify: "center"
};
var flexInlineDefaultProps = {
  align: "center",
  as: "span",
  direction: "row",
  display: "inline-flex"
};
function useFlex(props, type) {
  let defaultProps61 = flexDefaultProps;
  if (type === "FlexCenter") {
    defaultProps61 = flexCenterDefaultProps;
  } else if (type === "FlexInline") {
    defaultProps61 = flexInlineDefaultProps;
  }
  return useComponentProps(props, defaultProps61);
}

// src/components/Flex/Flex.tsx
import { jsx as jsx4 } from "react/jsx-runtime";
var StyledFlex = styled4("div", getStyledOptions("fill"))(
  {},
  (props) => getStyles(props, { skipBorder: true, useFontSize: true })
);
var Flex = forwardRef3((props, ref) => {
  const { componentProps, getDataAttributes } = useFlex(props, "Flex");
  return /* @__PURE__ */ jsx4(StyledFlex, { ref, ...getDataAttributes("Flex"), ...componentProps });
});
Flex.displayName = "Box";
var FlexCenter = forwardRef3((props, ref) => {
  const { componentProps, getDataAttributes } = useFlex(props, "FlexCenter");
  return /* @__PURE__ */ jsx4(StyledFlex, { ref, ...getDataAttributes("FlexCenter"), ...componentProps });
});
FlexCenter.displayName = "FlexCenter";
var FlexInline = forwardRef3((props, ref) => {
  const { componentProps, getDataAttributes } = useFlex(props, "FlexInline");
  return /* @__PURE__ */ jsx4(StyledFlex, { ref, ...getDataAttributes("FlexInline"), ...componentProps });
});
FlexInline.displayName = "FlexInline";

// src/components/Collapse/useCollapse.ts
var defaultProps5 = {
  animationEnterDuration: 0.3,
  animationExitDuration: 0.3,
  "aria-label": "Toggle the content",
  componentName: "Collapse",
  defaultOpen: false,
  disabled: false,
  gap: "xs",
  headerAlign: "start",
  hideHeaderToggle: false,
  initialHeight: 0,
  showBottomToggle: false
};
function useCollapse(props) {
  return useComponentProps(props, defaultProps5);
}

// src/components/Collapse/Collapse.tsx
import { jsx as jsx5, jsxs as jsxs2 } from "react/jsx-runtime";
var StyledCollapse = styled5("div")(
  {
    display: "flex",
    flexDirection: "column"
  },
  (props) => getStyles(props)
);
var Header = styled5.button((props) => {
  const { bg = "primary", color, disabled, gap, theme } = props;
  const { opacity: opacity2, spacing: spacing2 } = theme;
  const { mainColor } = getColorTokens(bg, color, theme);
  return css6`
    all: unset;
    align-items: center;
    cursor: pointer;
    display: flex;
    gap: ${spacing2[gap]};
    justify-content: space-between;
    width: 100%;
    ${outlineStyles(mainColor, theme)};

    ${disabled && css6`
      cursor: not-allowed;
      opacity: ${opacity2.medium};
    `}
  `;
});
var getContentAnimation = (initialHeight, endHeight, marginTop) => keyframes3`
  0% {
    height: ${px6(initialHeight)};
    opacity: ${initialHeight ? 1 : 0};
    margin-top: 0;
    visibility: hidden;
  }
  100% {
    height: ${px6(endHeight)};
    opacity: 1;
    margin-top: ${marginTop};
    visibility: visible;
  }
`;
var Content = styled5("div")((props) => {
  const {
    animationEnterDuration,
    animationExitDuration,
    hasTitle,
    initialHeight,
    isOpen,
    maxHeight,
    scrollHeight,
    shouldAnimate,
    theme
  } = props;
  const { spacing: spacing2 } = theme;
  let animation3;
  let height = initialHeight;
  let marginTop = hasTitle ? spacing2.xs : void 0;
  if (shouldAnimate) {
    animation3 = css6`
      animation: ${getContentAnimation(initialHeight, maxHeight ?? scrollHeight, marginTop)}
        ${isOpen ? animationEnterDuration : animationExitDuration}s ease-in-out forwards
        ${isOpen ? "" : " reverse"};
    `;
  } else {
    height = isOpen ? maxHeight || scrollHeight || "auto" : initialHeight;
    marginTop = isOpen ? marginTop : void 0;
  }
  return css6`
    ${animation3};
    height: ${px6(height)};
    margin-top: ${marginTop};
    overflow: hidden;
    visibility: ${isOpen ? "visible" : "hidden"};
  `;
});
var HeaderToggle = styled5("span")((props) => {
  const { isOpen } = props;
  return css6`
    align-self: center;
    display: inline-flex;
    transform: rotate(${isOpen ? -90 : 0}deg);
    transition: transform 0.3s;
    transform-origin: center;
  `;
});
function Collapse(props) {
  const {
    componentProps: {
      "aria-label": ariaLabel,
      bottomToggle,
      componentName,
      defaultOpen,
      disabled,
      gap,
      headerAlign,
      headerToggle = /* @__PURE__ */ jsx5(Icon, { name: "chevron-left", title: null }),
      hideHeaderToggle,
      id,
      onToggle,
      open,
      role,
      showBottomToggle,
      startContent,
      title,
      ...rest
    },
    getDataAttributes
  } = useCollapse(props);
  const contentId = useId();
  const isControlled = is3.boolean(open);
  const [isOpen, setIsOpen] = useState(isControlled ? open : defaultOpen);
  const [shouldAnimate, setShouldAnimate] = useState(false);
  const contentRef = useRef2(null);
  const previousIsOpen = usePrevious(isOpen);
  useEffect2(() => {
    if (isControlled) {
      setIsOpen(open);
      setShouldAnimate(is3.boolean(previousIsOpen) && previousIsOpen !== open);
    }
  }, [isControlled, open, previousIsOpen]);
  const handleAnimationEnd = () => {
    setShouldAnimate(false);
  };
  const handleClickToggle = () => {
    if (!isControlled) {
      setIsOpen(!isOpen);
      setShouldAnimate(true);
    }
    onToggle?.(isControlled ? open : !isOpen, id);
  };
  const hasTitle = Boolean(title);
  const toggleProps = {
    "aria-controls": contentId,
    "aria-expanded": isOpen,
    "aria-label": ariaLabel,
    "data-open": isOpen,
    "data-disabled": disabled,
    disabled,
    onClick: handleClickToggle
  };
  const content = {};
  if (!hideHeaderToggle) {
    content.headerToggle = /* @__PURE__ */ jsx5(HeaderToggle, { isOpen, children: is3.function(headerToggle) ? headerToggle({ isOpen, isDisabled: disabled }) : headerToggle });
  }
  if (startContent) {
    content.startContent = isValidElement(startContent) ? startContent : /* @__PURE__ */ jsx5("span", { ...getDataAttributes("AccordionItemStartContent"), children: startContent });
  }
  if (hasTitle) {
    content.header = /* @__PURE__ */ jsxs2(
      Header,
      {
        ...getDataAttributes(`${componentName}Header`),
        ...toggleProps,
        role,
        ...rest,
        gap,
        children: [
          /* @__PURE__ */ jsxs2(FlexInline, { flex: true, gap, children: [
            content.startContent,
            isValidElement(title) ? title : /* @__PURE__ */ jsx5(
              FlexInline,
              {
                align: headerAlign,
                ...getDataAttributes(`${componentName}Title`),
                direction: "column",
                flex: true,
                size: "lg",
                theme: rest.theme,
                children: title
              }
            )
          ] }),
          content.headerToggle
        ]
      }
    );
  }
  if (showBottomToggle) {
    content.footer = /* @__PURE__ */ jsx5(Flex, { mt: "xs", ...getDataAttributes(`${componentName}Footer`), children: bottomToggle ? bottomToggle({ isOpen, toggleProps }) : /* @__PURE__ */ jsx5(ButtonUnstyled, { color: "gray.500", size: "xs", ...toggleProps, children: isOpen ? "hide" : "show more" }) });
  }
  return /* @__PURE__ */ jsxs2(StyledCollapse, { ...getDataAttributes(componentName), ...rest, children: [
    content.header,
    /* @__PURE__ */ jsx5(
      Content,
      {
        ref: contentRef,
        ...getDataAttributes(`${componentName}Content`),
        hasTitle,
        id: contentId,
        isOpen,
        onAnimationEnd: handleAnimationEnd,
        scrollHeight: contentRef.current?.scrollHeight ?? 0,
        shouldAnimate,
        ...rest
      }
    ),
    content.footer
  ] });
}
Collapse.displayName = "Collapse";

// src/components/Text/Text.tsx
import { forwardRef as forwardRef4 } from "react";
import styled6 from "@emotion/styled";

// src/components/Text/useText.ts
function useText(props) {
  return useComponentProps(props, textDefaultOptions);
}

// src/components/Text/Text.tsx
import { jsx as jsx6 } from "react/jsx-runtime";
var StyledText = styled6("span", getStyledOptions())(
  {
    display: "inline-block",
    textDecoration: "inherit"
  },
  (props) => getStyles(props, { skipSpacing: true, useFontSize: true })
);
var Text = forwardRef4((props, ref) => {
  const { componentProps, getDataAttributes } = useText(props);
  return /* @__PURE__ */ jsx6(StyledText, { ref, ...getDataAttributes("Text"), ...componentProps });
});
Text.displayName = "Text";

// src/components/Accordion/useAccordion.ts
import {
  Children,
  isValidElement as isValidElement2,
  useCallback as useCallback3,
  useState as useState2
} from "react";
import { useEffectDeepCompare } from "@gilbarbara/hooks";
import is4 from "is-lite";
var defaultProps6 = {
  compact: false,
  disabled: false,
  headerAlign: "start",
  hideDivider: false,
  hideToggle: false,
  variant: "clean",
  selectionMode: "single"
};
function useAccordion(props, childType) {
  const { componentProps, getDataAttributes } = useComponentProps(props, defaultProps6);
  const { children, initialSelectedIds, onChange, selectedIds, selectionMode } = componentProps;
  const items = Children.map(
    children,
    (child) => !isValidElement2(child) || child.type !== childType ? "" : child.props.id
  );
  const [activeItems, setActiveItems] = useState2(() => {
    let keys = [];
    if (selectedIds) {
      keys = selectedIds === "all" ? items : selectedIds;
    }
    if (initialSelectedIds) {
      keys = initialSelectedIds === "all" ? items : initialSelectedIds;
    }
    return keys;
  });
  const isControlled = is4.defined(selectedIds);
  const isSelectable = selectionMode !== "none";
  const isSingle = selectionMode === "single";
  useEffectDeepCompare(() => {
    if (selectedIds) {
      setActiveItems(selectedIds === "all" ? items : selectedIds);
    }
  }, [items, selectedIds]);
  const onToggle = useCallback3(
    (isOpen, id) => {
      if (!id) {
        return;
      }
      let nextActiveItems;
      if (isSingle) {
        nextActiveItems = !isOpen ? [id] : [];
      } else {
        nextActiveItems = !isOpen ? [...activeItems, id] : activeItems.filter((key) => key !== id);
      }
      onChange?.(nextActiveItems);
      if (isControlled || !isSelectable) {
        return;
      }
      setActiveItems(nextActiveItems);
    },
    [activeItems, isControlled, isSelectable, isSingle, onChange]
  );
  return {
    activeItems,
    componentProps,
    getDataAttributes,
    onToggle
  };
}
function useAccordionItem(props) {
  return useComponentProps(props);
}

// src/components/Accordion/AccordionItem.tsx
import { jsx as jsx7, jsxs as jsxs3 } from "react/jsx-runtime";
function AccordionItem(props) {
  return /* @__PURE__ */ jsx7(AccordionItemBase, { ...props });
}
function AccordionItemBase(props) {
  const { componentProps, getDataAttributes } = useAccordionItem(props);
  const { children, compact, headerAlign, hideToggle, subtitle, title, ...rest } = componentProps;
  const content = {
    title: isValidElement3(title) ? title : /* @__PURE__ */ jsx7(Text, { size: compact ? "md" : "lg", children: title })
  };
  if (subtitle) {
    content.subtitle = isValidElement3(subtitle) ? subtitle : /* @__PURE__ */ jsx7(Text, { color: "gray.500", children: subtitle });
  }
  content.header = /* @__PURE__ */ jsxs3(
    FlexInline,
    {
      ...getDataAttributes("AccordionItemWrapper"),
      align: headerAlign,
      direction: "column",
      flex: true,
      py: compact ? void 0 : "xs",
      children: [
        content.title,
        content.subtitle
      ]
    }
  );
  return /* @__PURE__ */ jsx7(
    Collapse,
    {
      componentName: "AccordionItem",
      hideHeaderToggle: hideToggle,
      ...rest,
      role: "region",
      title: content.header,
      children
    }
  );
}

// src/components/Accordion/Accordion.tsx
import { jsx as jsx8, jsxs as jsxs4 } from "react/jsx-runtime";
var StyledAccordion = styled7("div", getStyledOptions())(
  {
    display: "flex",
    flexDirection: "column"
  },
  (props) => {
    const { shadow: shadow2, theme, variant = "sm" } = props;
    const { darkColor: darkColor2, darkMode: darkMode2, grayScale: grayScale2, radius: radius2, shadow: themeShadow, spacing: spacing2, white: white2 } = theme;
    const variantStyles = {};
    if (["bordered", "shadow"].includes(variant)) {
      variantStyles.padding = `${spacing2.xs} ${spacing2.md}`;
      variantStyles.borderRadius = radius2.md;
    }
    if (variant === "bordered") {
      variantStyles.border = `2px solid ${grayScale2[200]} `;
    }
    if (["bordered", "shadow"].includes(variant)) {
      variantStyles.backgroundColor = darkMode2 ? darkColor2 : white2;
    }
    if (variant === "shadow" && !is5.defined(shadow2)) {
      variantStyles.boxShadow = themeShadow.mid;
    }
    return css7`
      ${getStyles(omit3(props, "variant"), { skipShadow: true })};
      ${variantStyles};
    `;
  }
);
function Accordion(props) {
  const { activeItems, componentProps, getDataAttributes, onToggle } = useAccordion(
    props,
    AccordionItem
  );
  const {
    children,
    compact,
    disabled,
    disabledIds,
    dividerProps,
    headerAlign,
    hideDivider,
    hideToggle,
    initialSelectedIds,
    onChange,
    selectedIds,
    selectionMode,
    theme,
    variant,
    ...rest
  } = componentProps;
  const ref = useRef3(null);
  const { addScope, removeScope } = useKeyboardNavigation(ref, {
    arrowNavigation: "vertical",
    selector: `[data-${theme.dataAttributeName}="AccordionItemHeader"]`
  });
  const handleClickToggle = (isOpen, id) => {
    onToggle(isOpen, id);
  };
  useLifecycleHooks(
    () => {
      addScope();
    },
    () => {
      removeScope();
    }
  );
  const showDivider = !hideDivider;
  return /* @__PURE__ */ jsx8(
    StyledAccordion,
    {
      ref,
      ...getDataAttributes("Accordion"),
      ...rest,
      theme,
      variant,
      children: Children2.map(children, (child, index) => {
        if (!isValidElement4(child) || child.type !== AccordionItem) {
          console.error("Invalid children detected. Only the AccordionItem component is allowed.");
          return null;
        }
        const { id, ...childProps } = child.props;
        const splitProps = {};
        const notLastChild = index < Children2.count(children) - 1;
        const isSplit = variant === "split";
        if (isSplit) {
          splitProps.px = "md";
          splitProps.radius = "sm";
          splitProps.shadow = "mid";
        }
        const isDisabled = disabled || disabledIds?.includes(id) || childProps.disabled;
        return /* @__PURE__ */ jsxs4(Fragment, { children: [
          /* @__PURE__ */ jsx8(
            AccordionItemBase,
            {
              compact,
              disabled: isDisabled,
              headerAlign,
              hideToggle: hideToggle ?? childProps.hideToggle,
              id,
              onToggle: handleClickToggle,
              open: activeItems.includes(id),
              py: "xs",
              ...childProps,
              ...splitProps
            }
          ),
          showDivider && notLastChild && /* @__PURE__ */ jsx8(
            Divider,
            {
              color: isSplit ? "transparent" : void 0,
              spacing: isSplit ? "xs" : 0,
              ...dividerProps
            }
          )
        ] }, id);
      })
    }
  );
}
Accordion.displayName = "Accordion";

// src/components/Alert/Alert.tsx
import { forwardRef as forwardRef5, isValidElement as isValidElement5 } from "react";
import { css as css8 } from "@emotion/react";
import styled8 from "@emotion/styled";

// src/components/Alert/useAlert.ts
function getColor(type, light) {
  const colors2 = {
    success: light ? "green.100" : "green.600",
    warning: light ? "orange.100" : "orange.600",
    error: light ? "red.100" : "red.600",
    info: light ? "blue.100" : "blue.600",
    neutral: light ? "gray.100" : "gray.600"
  };
  return colors2[type];
}
function getIconOptions(props) {
  const { bg, color, theme, type, variant } = props;
  const notSolid = ["bordered", "light"].includes(variant);
  let iconColor = getColorTokens(getColor(type), null, theme)[notSolid ? "mainColor" : "textColor"];
  if (bg) {
    iconColor = getColorTokens(bg, null, theme)[variant === "bordered" ? "mainColor" : "textColor"];
  }
  if (color) {
    iconColor = getColorTokens(color, null, theme).mainColor;
  }
  const options = {
    success: {
      color: iconColor,
      icon: "check-circle"
    },
    warning: {
      color: iconColor,
      icon: "danger-circle"
    },
    error: {
      color: iconColor,
      icon: "close-circle"
    },
    info: {
      color: iconColor,
      icon: "info-circle"
    },
    neutral: {
      color: iconColor,
      icon: "flash-o"
    }
  };
  return options[type];
}
var defaultProps7 = {
  align: "center",
  direction: "row",
  gap: "sm",
  hideIcon: false,
  iconSize: 20,
  padding: "md",
  radius: "xs",
  type: "success",
  variant: "solid",
  width: "100%"
};
function useAlert(props) {
  return useComponentProps(props, defaultProps7);
}

// src/components/Alert/Alert.tsx
import { jsx as jsx9, jsxs as jsxs5 } from "react/jsx-runtime";
var StyledAlert = styled8("div", getStyledOptions("type"))(
  {
    display: "flex",
    position: "relative",
    width: "100%"
  },
  (props) => {
    const { align, bg, direction, theme, type, variant } = props;
    let { mainColor, textColor: textColor2 } = getColorTokens(getColor(type, variant === "light"), null, theme);
    if (bg) {
      ({ mainColor, textColor: textColor2 } = getColorTokens(bg, null, theme));
    }
    let bgColor = mainColor;
    let border;
    let selectedColor = textColor2;
    if (variant === "bordered") {
      border = `1px solid ${mainColor}`;
      bgColor = "transparent";
      selectedColor = mainColor;
    } else if (variant === "light") {
      selectedColor = getColorTokens(getColor(type), null, theme).mainColor;
    }
    return css8`
      align-items: ${align};
      background-color: ${bgColor};
      border: ${border};
      color: ${selectedColor};
      flex-direction: ${direction};
      width: 100%;
      ${getStyles(props, { skipBorder: true })};
    `;
  }
);
var Alert = forwardRef5((props, ref) => {
  const { componentProps, getDataAttributes } = useAlert(props);
  const { children, direction, hideIcon, icon, iconSize, type, ...rest } = componentProps;
  const selected = getIconOptions(componentProps);
  return /* @__PURE__ */ jsxs5(
    StyledAlert,
    {
      ref,
      ...getDataAttributes("Alert"),
      direction,
      role: "alert",
      type,
      ...rest,
      children: [
        !hideIcon && /* @__PURE__ */ jsx9(Icon, { color: selected.color, name: icon ?? selected.icon, size: iconSize }),
        isValidElement5(children) ? children : /* @__PURE__ */ jsx9(Text, { children })
      ]
    }
  );
});
Alert.displayName = "Alert";

// src/components/Anchor/Anchor.tsx
import { forwardRef as forwardRef6, isValidElement as isValidElement6 } from "react";
import { css as css9 } from "@emotion/react";
import styled9 from "@emotion/styled";

// src/components/Anchor/useAnchor.ts
import { omit as omit4 } from "@gilbarbara/helpers";
var defaultProps8 = {
  ...omit4(textDefaultOptions, "size"),
  color: "primary",
  external: false,
  gap: "xxs",
  hideDecoration: false
};
function useAnchor(props) {
  return useComponentProps(props, defaultProps8);
}

// src/components/Anchor/Anchor.tsx
import { jsx as jsx10, jsxs as jsxs6 } from "react/jsx-runtime";
var StyledAnchor = styled9("a", getStyledOptions())(
  {
    alignItems: "center",
    color: "inherit",
    cursor: "pointer",
    display: "inline-flex",
    padding: 0
  },
  (props) => {
    const { hideDecoration } = props;
    return css9`
      text-decoration: ${hideDecoration ? "none" : "underline"};
      ${getStyles(props, { lineHeightCustom: 1, useFontSize: true })};
    `;
  }
);
var Anchor = forwardRef6((props, ref) => {
  const { componentProps, getDataAttributes } = useAnchor(props);
  const { children, endContent, external, startContent, ...rest } = componentProps;
  const additionalProps = {};
  if (external) {
    additionalProps.rel = "noopener noreferrer";
    additionalProps.target = "_blank";
  }
  const content = {};
  if (startContent) {
    content.startContent = isValidElement6(startContent) ? startContent : /* @__PURE__ */ jsx10("span", { children: startContent });
  }
  if (endContent) {
    content.endContent = isValidElement6(endContent) ? endContent : /* @__PURE__ */ jsx10("span", { children: endContent });
  }
  return /* @__PURE__ */ jsxs6(StyledAnchor, { ref, ...getDataAttributes("Anchor"), ...additionalProps, ...rest, children: [
    content.startContent,
    /* @__PURE__ */ jsx10("span", { children }),
    content.endContent
  ] });
});
Anchor.displayName = "Anchor";

// src/components/AspectRatio/AspectRatio.tsx
import { forwardRef as forwardRef7 } from "react";
import { css as css10 } from "@emotion/react";
import styled10 from "@emotion/styled";
import { px as px7, round } from "@gilbarbara/helpers";

// src/components/AspectRatio/useAspectRatio.ts
function useAspectRatio(props) {
  return useComponentProps(props);
}

// src/components/AspectRatio/AspectRatio.tsx
import { jsx as jsx11 } from "react/jsx-runtime";
var StyledAspectRatio = styled10("div", getStyledOptions())(
  css10`
    display: flex;
    overflow: hidden;
    position: relative;
    width: 100%;

    &:before {
      content: '';
      display: flex;
      width: 100%;
    }

    > img,
    > video {
      object-fit: cover;
    }

    > * {
      align-self: center;
      display: flex;
      height: 100%;
      inset: 0;
      justify-content: center;
      position: absolute;
      width: 100%;
    }
  `,
  (props) => {
    const { maxWidth, ratio } = props;
    return css10`
      max-width: ${maxWidth ? px7(maxWidth) : "none"};
      ${getStyles(props)};

      &:before {
        padding-bottom: ${`${round(1 / ratio * 100)}%`};
      }
    `;
  }
);
var AspectRatio = forwardRef7((props, ref) => {
  const { componentProps, getDataAttributes } = useAspectRatio(props);
  return /* @__PURE__ */ jsx11(StyledAspectRatio, { ref, ...getDataAttributes("AspectRatio"), ...componentProps });
});
AspectRatio.displayName = "AspectRatio";

// src/components/Avatar/Avatar.tsx
import { forwardRef as forwardRef8 } from "react";
import { css as css11 } from "@emotion/react";
import styled11 from "@emotion/styled";
import { getInitials, omit as omit5, px as px8 } from "@gilbarbara/helpers";

// src/components/Avatar/useAvatar.ts
var defaultProps9 = {
  bg: "primary",
  borderColor: "primary",
  bordered: false,
  size: "md",
  radius: "round"
};
function useAvatar(props) {
  return useComponentProps(props, defaultProps9);
}

// src/components/Avatar/Avatar.tsx
import { jsx as jsx12 } from "react/jsx-runtime";
function getSize(props) {
  const { fontSize, size, theme } = props;
  const selectedSize = typeof size === "number" ? {
    size: `${size}px`,
    fontSize: `${size / 2}px`
  } : theme.avatar[size];
  if (fontSize) {
    selectedSize.fontSize = px8(fontSize);
  }
  return selectedSize;
}
var StyledAvatar = styled11("div", getStyledOptions())(
  {
    alignItems: "center",
    display: "flex",
    flexShrink: 0,
    justifyContent: "center",
    outlineOffset: "2px",
    overflow: "hidden"
  },
  (props) => {
    const { borderColor, bordered, theme } = props;
    const { size } = getSize(props);
    const { mainColor } = getColorTokens(borderColor, null, theme);
    return css11`
      outline: ${bordered ? `2px solid ${mainColor}` : "none"};
      height: ${size};
      width: ${size};
      ${getStyles(omit5(props, "size"), { skipColor: true })};
    `;
  }
);
var Circle = styled11("div", getStyledOptions())(
  {
    alignItems: "center",
    display: "flex",
    justifyContent: "center",
    textAlign: "center"
  },
  (props) => {
    const { fontSize, size } = getSize(props);
    return css11`
      height: ${size};
      font-size: ${fontSize};
      width: ${size};
      ${colorStyles(props)};
    `;
  }
);
var Avatar = forwardRef8((props, ref) => {
  const { componentProps, getDataAttributes } = useAvatar(props);
  const { fallback, image: image2, name, ...rest } = componentProps;
  const { size } = getSize(componentProps);
  let content;
  if (image2) {
    content = /* @__PURE__ */ jsx12("img", { alt: name ?? "User", height: size, src: image2, width: size });
  } else if (name) {
    content = /* @__PURE__ */ jsx12(Circle, { ...rest, children: getInitials(name).toUpperCase() });
  } else if (fallback) {
    content = /* @__PURE__ */ jsx12(Circle, { ...rest, children: fallback });
  } else {
    const avatarSize = parseInt(size, 10);
    const iconSize = avatarSize * 0.7;
    content = /* @__PURE__ */ jsx12(Circle, { ...rest, children: /* @__PURE__ */ jsx12(Icon, { name: "user", size: iconSize }) });
  }
  return /* @__PURE__ */ jsx12(
    StyledAvatar,
    {
      ref,
      "aria-label": name ?? "Unknown",
      ...getDataAttributes("Avatar"),
      ...rest,
      children: content
    }
  );
});
Avatar.displayName = "Avatar";

// src/components/Badge/Badge.tsx
import { useMemo as useMemo2 } from "react";
import { css as css12 } from "@emotion/react";
import styled12 from "@emotion/styled";
import { px as px9 } from "@gilbarbara/helpers";

// src/components/Badge/useBadge.ts
var defaultProps10 = {
  bg: "primary",
  hideBorder: false,
  dot: false,
  hideBadge: false,
  placement: "top-right",
  radius: "sm",
  shape: "rectangle",
  size: "md"
};
function useBadge(props) {
  return useComponentProps(props, defaultProps10);
}

// src/components/Badge/Badge.tsx
import { jsx as jsx13, jsxs as jsxs7 } from "react/jsx-runtime";
var StyledBadgeWrapper = styled12("div", getStyledOptions("shape"))(
  {
    display: "flex",
    position: "relative",
    width: "min-content"
  },
  (props) => getStyles(props, { skipColor: true })
);
var StyledBadge = styled12("span", getStyledOptions("shape"))(
  {
    alignItems: "center",
    display: "inline-flex",
    justifyContent: "center",
    lineHeight: 1,
    position: "absolute",
    transition: "opacity 0.3s"
  },
  (props) => {
    const {
      borderColor,
      dot,
      hideBadge,
      hideBorder,
      offsetX,
      offsetY,
      placement,
      shape,
      size,
      theme
    } = props;
    const { black: black2, darkMode: darkMode2, spacing: spacing2, typography: typography2, white: white2 } = theme;
    let borderColorValue = darkMode2 ? black2 : white2;
    const offsetValue = dot || shape === "circle" ? "10%" : "5%";
    const transformValue = dot ? "50%" : "40%";
    let position = {};
    if (borderColor) {
      borderColorValue = getColorTokens(borderColor, null, theme).mainColor;
    }
    const sizingMap = {
      sm: {
        fontSize: typography2.xs.fontSize,
        padding: dot ? void 0 : "2px",
        size: dot ? "12px" : "16px"
      },
      md: {
        fontSize: typography2.sm.fontSize,
        padding: dot ? void 0 : spacing2.xxs,
        size: dot ? "14px" : "20px"
      },
      lg: {
        fontSize: typography2.md.fontSize,
        padding: dot ? void 0 : spacing2.xxs,
        size: dot ? "16px" : "24px"
      }
    };
    switch (placement) {
      case "top-right": {
        position = css12`
          top: ${px9(offsetY ?? offsetValue)};
          right: ${px9(offsetX ?? offsetValue)};
          transform: translate(${transformValue}, -${transformValue});
        `;
        break;
      }
      case "top-left": {
        position = css12`
          top: ${px9(offsetY ?? offsetValue)};
          left: ${px9(offsetX ?? offsetValue)};
          transform: translate(-${transformValue}, -${transformValue});
        `;
        break;
      }
      case "bottom-right": {
        position = css12`
          bottom: ${px9(offsetY ?? offsetValue)};
          right: ${px9(offsetX ?? offsetValue)};
          transform: translate(${transformValue}, ${transformValue});
        `;
        break;
      }
      case "bottom-left": {
        position = css12`
          bottom: ${px9(offsetY ?? offsetValue)};
          left: ${px9(offsetX ?? offsetValue)};
          transform: translate(-${transformValue}, ${transformValue});
        `;
        break;
      }
    }
    return css12`
      ${!hideBorder ? `border: 2px solid ${borderColorValue};` : void 0};
      font-size: ${sizingMap[size].fontSize};
      height: ${sizingMap[size].size};
      opacity: ${hideBadge ? 0 : 1};
      padding-left: ${sizingMap[size].padding};
      padding-right: ${sizingMap[size].padding};
      min-width: ${sizingMap[size].size};
      ${position};
      ${getStyles(props, { skipBorder: true })};
    `;
  }
);
function Badge(props) {
  const { componentProps, getDataAttributes } = useBadge(props);
  const { children, content, dot, ...rest } = componentProps;
  const isDot = useMemo2(() => dot || !content || !content.toString().length, [content, dot]);
  return /* @__PURE__ */ jsxs7(StyledBadgeWrapper, { ...getDataAttributes("Badge"), ...rest, children: [
    children,
    /* @__PURE__ */ jsx13(StyledBadge, { dot: isDot, ...rest, children: !isDot && content })
  ] });
}
Badge.displayName = "Badge";

// src/components/Box/Box.tsx
import { forwardRef as forwardRef9 } from "react";
import styled13 from "@emotion/styled";

// src/components/Box/useBox.ts
var defaultProps11 = {
  display: "block"
};
function useBox(props) {
  return useComponentProps(props, defaultProps11);
}

// src/components/Box/Box.tsx
import { jsx as jsx14 } from "react/jsx-runtime";
var StyledBox = styled13(
  "div",
  getStyledOptions("fill")
)((props) => getStyles(props, { skipBorder: true, useFontSize: true }));
var Box = forwardRef9((props, ref) => {
  const { componentProps, getDataAttributes } = useBox(props);
  return /* @__PURE__ */ jsx14(StyledBox, { ref, ...getDataAttributes("Box"), ...componentProps });
});
Box.displayName = "Box";

// src/components/Button/Button.tsx
import { forwardRef as forwardRef10, isValidElement as isValidElement7, useRef as useRef4 } from "react";
import { css as css14 } from "@emotion/react";
import styled15 from "@emotion/styled";
import { omit as omit6, px as px11 } from "@gilbarbara/helpers";
import { useMergeRefs } from "@gilbarbara/hooks";

// src/components/Ripple/Ripple.tsx
import { css as css13 } from "@emotion/react";
import styled14 from "@emotion/styled";
import { px as px10 } from "@gilbarbara/helpers";
import { lighten as lighten2 } from "colorizr";
import { Fragment as Fragment2, jsx as jsx15 } from "react/jsx-runtime";
var defaultProps12 = {
  duration: "0.6s"
};
var StyledRipple = styled14(
  "span",
  getStyledOptions()
)((props) => {
  const { color, duration, theme } = props;
  const { mainColor } = getColorTokens(color, null, theme);
  return css13`
    animation: ${ripple} ${duration} forwards;
    background-color: ${lighten2(mainColor, 40)};
    border-radius: 50%;
    position: absolute;
    z-index: 0;
  `;
});
function Ripple(props) {
  const {
    componentProps: { color, duration, onClear, ripples, theme },
    getDataAttributes
  } = useComponentProps(props, defaultProps12);
  return /* @__PURE__ */ jsx15(Fragment2, { children: ripples.map(({ key, size, x, y }) => /* @__PURE__ */ jsx15(
    StyledRipple,
    {
      color,
      ...getDataAttributes("Ripple"),
      duration,
      onAnimationEnd: () => onClear(key),
      style: {
        height: px10(size),
        left: px10(x),
        top: px10(y),
        width: px10(size)
      },
      theme
    },
    key
  )) });
}
Ripple.displayName = "Ripple";

// src/components/Ripple/useRipple.tsx
import { useCallback as useCallback4, useState as useState3 } from "react";
import { randomNumber } from "@gilbarbara/helpers";
function useRipple(props = {}) {
  const [ripples, setRipples] = useState3([]);
  const onClick = useCallback4((event) => {
    const trigger = event.currentTarget;
    const size = Math.max(trigger.clientWidth, trigger.clientHeight);
    const rect = trigger.getBoundingClientRect();
    setRipples((previousRipples) => [
      ...previousRipples,
      {
        key: Number(`${previousRipples.length}${randomNumber(0, 1e3)}`),
        size,
        x: event.clientX - rect.left - size / 2,
        y: event.clientY - rect.top - size / 2
      }
    ]);
  }, []);
  const onClear = useCallback4((key) => {
    setRipples((previousState) => previousState.filter((ripple2) => ripple2.key !== key));
  }, []);
  return { ripples, onClick, onClear, ...props };
}

// src/components/Button/useButton.ts
var defaultProps13 = {
  bg: "primary",
  block: false,
  busy: false,
  disabled: false,
  disableRipple: false,
  gap: "xs",
  iconOnly: false,
  light: false,
  size: "md",
  spinnerPosition: "end",
  type: "button",
  variant: "solid",
  wide: false
};
function useButton(props) {
  return useComponentProps(props, defaultProps13);
}

// src/components/Button/Button.tsx
import { jsx as jsx16, jsxs as jsxs8 } from "react/jsx-runtime";
var StyledButton = styled15("button", getStyledOptions())(
  {
    alignItems: "center",
    boxShadow: "none",
    cursor: "pointer",
    display: "inline-flex",
    justifyContent: "center",
    overflow: "hidden",
    position: "relative",
    transition: "background-color 0.6s, border-color 0.6s"
  },
  (props) => {
    const { bg, block, color, iconOnly, light, size, theme, wide } = props;
    const { borderRadius, fontSize, fontWeight, height, lineHeight, padding } = theme.button[size];
    let buttonPadding = `${padding[0]} ${wide ? px11(parseInt(padding[1], 10) * 2) : padding[1]}`;
    if (iconOnly) {
      buttonPadding = "0px";
    }
    const { mainColor } = getColorTokens(bg, color, theme);
    return css14`
      border-radius: ${borderRadius};
      font-size: ${fontSize};
      font-weight: ${light ? 400 : fontWeight};
      min-height: ${height};
      min-width: ${height};
      line-height: ${lineHeight};
      padding: ${buttonPadding};
      width: ${block ? "100%" : "auto"};
      ${getStyles(props)};
      ${outlineStyles(mainColor, theme)};

      &:disabled {
        ${getDisableStyles(props, { isButton: true })};
      }

      &:hover {
        ${hoverStyles(props)};
      }
    `;
  }
);
var Button = forwardRef10((props, ref) => {
  const { componentProps, getDataAttributes } = useButton(props);
  const {
    bg,
    busy,
    children,
    disableRipple,
    endContent,
    iconOnly,
    onClick,
    size,
    spinner,
    spinnerPosition,
    startContent,
    theme
  } = componentProps;
  const { onClick: onClickRipple, ...rippleProps } = useRipple();
  const localRef = useRef4(null);
  const mergedRefs = useMergeRefs(localRef, ref);
  const { fontSize } = theme.button[size];
  const handleClick = (event) => {
    onClick?.(event);
    if (busy || disableRipple) {
      return;
    }
    onClickRipple(event);
  };
  const content = {
    children,
    spinner: busy && (spinner ?? /* @__PURE__ */ jsx16(Icon, { name: "spinner", size: parseInt(fontSize, 10) + 4, spin: true }))
  };
  if (iconOnly && busy) {
    content.children = content.spinner;
    content.spinner = "";
  }
  if (startContent) {
    content.startContent = isValidElement7(startContent) ? startContent : /* @__PURE__ */ jsx16("span", { children: startContent });
  }
  if (endContent) {
    content.endContent = isValidElement7(endContent) ? endContent : /* @__PURE__ */ jsx16("span", { children: endContent });
  }
  if (!disableRipple) {
    content.ripple = /* @__PURE__ */ jsx16(Ripple, { color: bg, ...rippleProps });
  }
  return /* @__PURE__ */ jsxs8(
    StyledButton,
    {
      ref: mergedRefs,
      ...getDataAttributes("Button"),
      onClick: handleClick,
      ...omit6(componentProps, "onClick"),
      children: [
        content.startContent,
        spinnerPosition === "start" && content.spinner,
        content.children,
        spinnerPosition === "end" && content.spinner,
        content.endContent,
        content.ripple
      ]
    }
  );
});
Button.displayName = "Button";

// src/components/ButtonGroup/ButtonGroup.tsx
import { Children as Children3, cloneElement, useState as useState4 } from "react";
import innerText2 from "react-innertext";
import styled16 from "@emotion/styled";
import { opacify as opacify2 } from "colorizr";
import is6 from "is-lite";

// src/components/ButtonGroup/useButtonGroup.ts
var defaultProps15 = {
  bg: "primary",
  disabled: false,
  selectedVariant: "solid",
  size: "md",
  unselectedVariant: "bordered"
};
function useButtonGroup(props) {
  return useComponentProps(props, defaultProps15);
}

// src/components/ButtonGroup/ButtonGroup.tsx
import { jsx as jsx17 } from "react/jsx-runtime";
var StyledButtonGroup = styled16("div", getStyledOptions())(
  `
    display: flex;

    > button {
      + button {
        margin-left: -1px;
      }

      &:first-of-type {
        border-bottom-right-radius: 0;
        border-top-right-radius: 0;
      }

      &:last-of-type {
        border-bottom-left-radius: 0;
        border-top-left-radius: 0;
      }

      &:not(:first-of-type):not(:last-of-type) {
        border-radius: 0;
      }
    }
  `,
  (props) => getStyles(props)
);
function ButtonGroup(props) {
  const { componentProps, getDataAttributes } = useButtonGroup(props);
  const {
    bg,
    children,
    color,
    defaultSelected,
    disabled,
    items,
    onClick,
    selected,
    selectedVariant,
    size,
    unselectedVariant,
    ...rest
  } = componentProps;
  const hasItems = is6.array(items) && !!items.length;
  const isControlled = hasItems && !!selected;
  const [active, setActive] = useState4(
    items?.findIndex((item) => {
      const labelText = innerText2(item.label);
      if (isControlled) {
        return item.id === selected || labelText === selected;
      }
      if (defaultSelected) {
        return item.id === defaultSelected || labelText === defaultSelected;
      }
      return 0;
    }) ?? 0
  );
  const handleClick = (event) => {
    const { index } = event.currentTarget.dataset;
    onClick?.(event);
    if (hasItems && !isControlled) {
      if (index) {
        setActive(Number(index));
      }
    }
  };
  const buttonProps = {
    bg,
    color,
    disabled,
    size
  };
  const content = items ? items.map((item, index) => {
    const { disabled: itemDisabled, id, label, ...itemProps } = item;
    const styles2 = {};
    const labelText = innerText2(label);
    const isSelected = isControlled ? id === selected || labelText === selected : index === active;
    const variant = isSelected ? selectedVariant : unselectedVariant;
    if (itemDisabled) {
      styles2.color = opacify2(
        getColorTokens(color ?? bg, null, rest.theme).mainColor,
        rest.theme.opacityDisabled
      );
      styles2.cursor = "not-allowed";
      buttonProps.disableRipple = true;
    }
    return /* @__PURE__ */ jsx17(
      Button,
      {
        "data-id": id,
        "data-index": index,
        "data-label": labelText,
        "data-selected": isSelected,
        onClick: itemDisabled ? void 0 : handleClick,
        style: styles2,
        variant,
        ...buttonProps,
        ...itemProps,
        children: label
      },
      index
    );
  }) : Children3.map(children, (child) => cloneElement(child, { ...buttonProps }));
  return /* @__PURE__ */ jsx17(StyledButtonGroup, { ...getDataAttributes("ButtonGroup"), ...rest, children: content });
}
ButtonGroup.displayName = "ButtonGroup";

// src/components/ButtonSplit/ButtonSplit.tsx
import { useCallback as useCallback7, useState as useState9 } from "react";
import { css as css21 } from "@emotion/react";
import styled23 from "@emotion/styled";
import { omit as omit8 } from "@gilbarbara/helpers";

// src/components/Menu/Item.tsx
import { isValidElement as isValidElement8 } from "react";
import { css as css15 } from "@emotion/react";
import styled17 from "@emotion/styled";
import is7 from "is-lite";

// src/components/Menu/useMenu.tsx
import {
  createContext,
  useContext,
  useMemo as useMemo3,
  useState as useState5
} from "react";
import { useEffectDeepCompare as useEffectDeepCompare2 } from "@gilbarbara/hooks";
import { jsx as jsx18 } from "react/jsx-runtime";
var defaultProps16 = {
  accent: "primary",
  button: /* @__PURE__ */ jsx18(Icon, { name: "more-vertical-o", size: 24, title: null }),
  disabled: false,
  disableCloseOnBlur: false,
  disableKeyboardNavigation: false,
  labels: {
    close: "Close menu",
    name: "Menu",
    open: "Open menu"
  },
  minWidth: 200,
  orientation: "vertical",
  position: "bottom-right",
  trigger: "click"
};
var MenuContext = createContext(void 0);
MenuContext.displayName = "MenuContext";
function MenuProvider({ children, closeMenu, props }) {
  const [state, setState] = useState5(props);
  useEffectDeepCompare2(() => {
    setState(props);
  }, [props]);
  const value = useMemo3(
    () => ({
      closeMenu,
      state
    }),
    [closeMenu, state]
  );
  return /* @__PURE__ */ jsx18(MenuContext.Provider, { value, children });
}
function useMenu(props) {
  return useComponentProps(props, defaultProps16);
}
function useMenuContext() {
  const context = useContext(MenuContext);
  if (!context) {
    throw new Error("useMenuContext must be used within a MenuProvider");
  }
  return context;
}

// src/components/Menu/Item.tsx
import { jsx as jsx19 } from "react/jsx-runtime";
var StyledMenuItem = styled17("li", getStyledOptions())(
  {
    display: "flex",
    transition: "background-color 0.3s"
  },
  (props) => {
    const { accent = "primary", bg, color, disabled = false, disableHover, theme, wrap } = props;
    const { darkMode: darkMode2, grayScale: grayScale2, opacityDisabled: opacityDisabled2, spacing: spacing2, typography: typography2 } = theme;
    const themeColor = darkMode2 ? grayScale2["200"] : grayScale2["800"];
    const { mainColor, textColor: textColor2 } = getColorTokens(accent, color, theme);
    let bgColor;
    if (bg) {
      bgColor = getColorTokens(bg, null, theme).mainColor;
    }
    return css15`
      background-color: ${bgColor};
      color: ${themeColor};
      cursor: ${disabled ? "not-allowed" : "pointer"};
      font-size: ${typography2.md.fontSize};
      opacity: ${disabled ? opacityDisabled2 : 1};
      padding: ${spacing2.xs} ${spacing2.sm};
      white-space: ${wrap ? "normal" : "nowrap"};
      ${paddingStyles(props)};

      a {
        color: ${themeColor};
        text-decoration: none;
      }

      ${!disabled && !disableHover && css15`
        &:focus-visible,
        &:hover,
        &:active {
          background-color: ${mainColor};
          color: ${textColor2};

          * {
            color: ${textColor2};
          }
        }
      `};
    `;
  }
);
var StyledMenuItemContent = styled17("span")`
  align-items: center;
  display: flex;
  flex-grow: 1;
`;
function MenuItem(props) {
  const {
    componentProps: {
      accent,
      children,
      disableAutoClose = false,
      disabled,
      disableHover = false,
      onToggle,
      ...rest
    },
    getDataAttributes
  } = useMenu(props);
  const { closeMenu, state } = useMenuContext();
  const handleToggle = (event) => {
    if (disabled) {
      return;
    }
    if ("code" in event && !state.disableKeyboardNavigation) {
      if (["Enter", "Space"].includes(event.code)) {
        onToggle?.(event, closeMenu);
        if (!disableAutoClose) {
          closeMenu();
        }
      }
    } else {
      onToggle?.(event, closeMenu);
      if (!disableAutoClose) {
        closeMenu();
      }
    }
  };
  let content;
  if (is7.function(children)) {
    content = children({ closeMenu });
  } else if (!isValidElement8(children)) {
    content = /* @__PURE__ */ jsx19(StyledMenuItemContent, { children });
  } else {
    content = children;
  }
  return /* @__PURE__ */ jsx19(
    StyledMenuItem,
    {
      accent: accent ?? state.accent,
      ...getDataAttributes("MenuItem"),
      disableHover,
      disabled,
      onClick: handleToggle,
      onKeyDown: handleToggle,
      role: "menuitem",
      tabIndex: disabled || state.disableKeyboardNavigation ? -1 : 0,
      ...rest,
      children: content
    }
  );
}
MenuItem.displayName = "MenuItem";

// src/components/Menu/Menu.tsx
import {
  Children as Children4,
  cloneElement as cloneElement2,
  forwardRef as forwardRef11,
  isValidElement as isValidElement9,
  useCallback as useCallback6,
  useEffect as useEffect5,
  useId as useId2,
  useRef as useRef6,
  useState as useState8
} from "react";
import { css as css18 } from "@emotion/react";
import styled20 from "@emotion/styled";
import { omit as omit7 } from "@gilbarbara/helpers";
import { useLatest as useLatest2, useMergeRefs as useMergeRefs2, useUpdateEffect } from "@gilbarbara/hooks";
import is8 from "is-lite";

// src/components/ClickOutside/ClickOutside.tsx
import { memo, useCallback as useCallback5, useEffect as useEffect3, useRef as useRef5, useState as useState6 } from "react";
import { css as css16 } from "@emotion/react";
import styled18 from "@emotion/styled";

// src/components/ClickOutside/useClickOutside.ts
function useClickOutside(props) {
  return useComponentProps(props);
}

// src/components/ClickOutside/ClickOutside.tsx
import { jsx as jsx20 } from "react/jsx-runtime";
var StyledClickOutside = styled18(
  "div",
  getStyledOptions()
)((props) => {
  const { display = "inline-flex" } = props;
  return css16`
    display: ${display};
    ${layoutStyles(props)};
    ${flexBoxStyles(props)};
  `;
});
function ClickOutsideComponent(props) {
  const { componentProps, getDataAttributes } = useClickOutside(props);
  const { active, children, onClick, ...rest } = componentProps;
  const containerRef = useRef5(null);
  const [isReady, setReady] = useState6(false);
  const isTouch = useRef5(false);
  const handleClick = useCallback5(
    (event) => {
      const container = containerRef.current;
      if (event.type === "touchend") {
        isTouch.current = true;
      }
      if (event.type === "click" && isTouch.current) {
        return;
      }
      if (container && !container.contains(event.target)) {
        onClick();
      }
    },
    [onClick]
  );
  useEffect3(() => {
    if (!isReady) {
      setReady(true);
    }
    if (active) {
      document.addEventListener("touchend", handleClick, true);
      document.addEventListener("click", handleClick, true);
    }
    return () => {
      document.removeEventListener("touchend", handleClick, true);
      document.removeEventListener("click", handleClick, true);
    };
  }, [active, handleClick, isReady]);
  return /* @__PURE__ */ jsx20(
    StyledClickOutside,
    {
      ref: containerRef,
      ...getDataAttributes("ClickOutside"),
      "data-ready": isReady,
      ...rest,
      children
    }
  );
}
var ClickOutside = memo(ClickOutsideComponent);
ClickOutside.displayName = "ClickOutside";

// src/components/Menu/Items.tsx
import { useEffect as useEffect4, useState as useState7 } from "react";
import { css as css17 } from "@emotion/react";
import styled19 from "@emotion/styled";
import { px as px12 } from "@gilbarbara/helpers";
import { jsx as jsx21 } from "react/jsx-runtime";
var StyledMenuItems = styled19("div", getStyledOptions())(
  {
    position: "absolute",
    transform: "scaleY(0)"
  },
  (props) => {
    const { bg, isActive, isOpen, minWidth, orientation, position, theme } = props;
    const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2, shadow: shadow2, spacing: spacing2, white: white2, zIndex: zIndex2 } = theme;
    const [positionMain, positionCross] = position.split("-");
    let bgColor = darkMode2 ? grayScale2["800"] : white2;
    if (bg) {
      bgColor = getColorTokens(bg, null, theme).mainColor;
    }
    return css17`
      transition: transform 0.3s ${easing};

      ${isActive && isOpen && css17`
        transform: scaleY(1);
      `}

      ${positionMain === "bottom" && css17`
        top: 100%;
        transform-origin: top;
      `}

      ${positionMain === "left" && css17`
        right: 100%;
      `}

      ${positionMain === "right" && css17`
        left: 100%;
      `}

      ${positionMain === "top" && css17`
        bottom: 100%;
        transform-origin: bottom;
      `}

      ${positionCross === "bottom" && css17`
        bottom: 0;
        transform-origin: bottom;
      `}
      
      ${positionCross === "left" && css17`
        left: 0;
      `}
      
      ${positionCross === "right" && css17`
        right: 0;
      `}
      
      ${positionCross === "top" && css17`
        top: 0;
        transform-origin: top;
      `}

      > ul {
        background-color: ${bgColor};
        border-radius: ${radius2.xxs};
        box-shadow: ${shadow2.low};
        color: ${darkMode2 ? grayScale2["200"] : grayScale2["800"]};
        display: ${orientation === "horizontal" ? "flex" : "block"};
        flex-wrap: ${orientation === "horizontal" ? "wrap" : void 0};
        list-style: none;
        margin: 0;
        min-width: ${px12(minWidth)};
        overflow: hidden;
        padding: 0;
        z-index: ${zIndex2.xxs};

        ${positionMain === "bottom" && css17`
          margin-top: ${spacing2.xxs};
        `}

        ${positionMain === "left" && css17`
          margin-right: ${spacing2.xxs};
        `}

        ${positionMain === "right" && css17`
          margin-left: ${spacing2.xxs};
        `}

        ${positionMain === "top" && css17`
          margin-bottom: ${spacing2.xxs};
        `}
      }
    `;
  }
);
function MenuItems(props) {
  const {
    componentProps: { children, id, isOpen, orientation, ...rest },
    getDataAttributes
  } = useMenu(props);
  const [isActive, setActive] = useState7(isOpen);
  useEffect4(() => {
    setActive((s) => isOpen ? true : s);
  }, [isOpen]);
  const handleTransitionEnd = () => {
    if (!isOpen) {
      setActive(false);
    }
  };
  return /* @__PURE__ */ jsx21(
    StyledMenuItems,
    {
      isActive,
      isOpen,
      ...getDataAttributes("MenuItems"),
      "data-state": isOpen ? "open" : "closed",
      onTransitionEnd: handleTransitionEnd,
      orientation,
      ...rest,
      children: (isOpen || isActive) && /* @__PURE__ */ jsx21("ul", { "aria-orientation": orientation, id, role: "menu", children })
    }
  );
}
MenuItems.displayName = "MenuItems";

// src/components/Menu/Menu.tsx
import { jsx as jsx22, jsxs as jsxs9 } from "react/jsx-runtime";
var StyledMenu = styled20.nav(
  {
    display: "inline-flex",
    position: "relative",
    verticalAlign: "middle"
  },
  (props) => {
    const {
      theme: { dataAttributeName: dataAttributeName2 }
    } = props;
    return css18`
      [data-${dataAttributeName2}='ClickOutside'] {
        width: 100%;
      }
    `;
  }
);
var StyledMenuButton = styled20(ButtonUnstyled)(
  {
    borderRadius: "2px"
  },
  (props) => {
    const {
      theme: { spacing: spacing2, typography: typography2 }
    } = props;
    return css18`
      font-size: ${typography2.md.fontSize};
      min-height: ${spacing2.lg};
      min-width: ${spacing2.lg};
    `;
  }
);
var Menu = forwardRef11((props, ref) => {
  const { componentProps, getDataAttributes } = useMenu(props);
  const {
    accent,
    bg,
    button: button2,
    children,
    disableCloseOnBlur,
    disabled,
    disableKeyboardNavigation,
    labels,
    minWidth,
    onToggle,
    open,
    orientation,
    position,
    theme,
    trigger
  } = componentProps;
  const [isOpen, setIsOpen] = useState8(open ?? false);
  const localRef = useRef6(null);
  const mergedRefs = useMergeRefs2(localRef, ref);
  const onToggleRef = useLatest2(onToggle);
  const id = useId2();
  const disableToggle = disabled || is8.boolean(open);
  useEffect5(() => {
    if (is8.boolean(open)) {
      setIsOpen(open);
    }
  }, [open]);
  const handleClickOutside = useCallback6(() => {
    if (is8.boolean(open) || disableCloseOnBlur) {
      return;
    }
    setIsOpen(false);
  }, [disableCloseOnBlur, open]);
  const handleKeyDownButton = useCallback6(
    (event) => {
      if (disableKeyboardNavigation) {
        event.preventDefault();
      }
    },
    [disableKeyboardNavigation]
  );
  const handleToggleMenu = useCallback6(
    (force) => {
      return () => {
        if (disableToggle) {
          return;
        }
        setIsOpen((state) => force ?? !state);
      };
    },
    [disableToggle]
  );
  const handleClickButton = useCallback6(
    (event) => {
      event.preventDefault();
      event.stopPropagation();
      if (disableToggle) {
        return;
      }
      setIsOpen((state) => !state);
    },
    [disableToggle]
  );
  const { addScope, removeScope } = useKeyboardNavigation(localRef, {
    arrowNavigation: "both",
    disabled: disableKeyboardNavigation,
    escCallback: handleToggleMenu(false),
    selector: `#${id.replace(/:/g, "\\:")} > [data-${theme.dataAttributeName}="MenuItem"]`
  });
  useUpdateEffect(() => {
    if (isOpen) {
      addScope();
    }
    onToggleRef.current?.(isOpen);
    return () => {
      if (!is8.boolean(open)) {
        removeScope();
      }
    };
  }, [isOpen, addScope, onToggleRef, open, removeScope]);
  const content = Children4.map(children, (child) => {
    if (isValidElement9(child)) {
      return cloneElement2(child, {
        accent: child.props.accent ?? accent
      });
    }
    return child;
  });
  return /* @__PURE__ */ jsx22(
    StyledMenu,
    {
      ref: mergedRefs,
      "aria-label": labels.name,
      ...getDataAttributes("Menu"),
      onMouseEnter: trigger === "hover" ? handleToggleMenu(true) : void 0,
      onMouseLeave: trigger === "hover" ? handleToggleMenu(false) : void 0,
      theme,
      children: /* @__PURE__ */ jsx22(ClickOutside, { active: isOpen, onClick: handleClickOutside, children: /* @__PURE__ */ jsxs9(
        MenuProvider,
        {
          closeMenu: handleToggleMenu(false),
          props: omit7(componentProps, "button", "children", "onToggle"),
          children: [
            /* @__PURE__ */ jsx22(
              StyledMenuButton,
              {
                "aria-controls": id,
                "aria-expanded": isOpen,
                "aria-haspopup": "menu",
                "aria-label": isOpen ? labels.close : labels.open,
                ...getDataAttributes("MenuButton"),
                disabled,
                onClick: handleClickButton,
                onKeyDown: handleKeyDownButton,
                tabIndex: disableKeyboardNavigation ? -1 : 0,
                theme,
                title: isOpen ? labels.close : labels.open,
                type: "button",
                children: is8.function(button2) ? button2(isOpen) : button2
              }
            ),
            /* @__PURE__ */ jsx22(
              MenuItems,
              {
                bg,
                id,
                isOpen,
                minWidth,
                orientation,
                position,
                children: content
              }
            )
          ]
        }
      ) })
    }
  );
});
Menu.displayName = "Menu";

// src/components/Menu/Separator.tsx
import { css as css19 } from "@emotion/react";
import styled21 from "@emotion/styled";
import { jsx as jsx23 } from "react/jsx-runtime";
var StyledMenuSeparator = styled21(
  "div",
  getStyledOptions()
)((props) => {
  const {
    theme: { grayScale: grayScale2 }
  } = props;
  return css19`
    background-color: ${grayScale2["200"]};
    height: 1px;
    ${marginStyles(props)};
  `;
});
function MenuSeparator(props) {
  const { componentProps, getDataAttributes } = useMenu(props);
  return /* @__PURE__ */ jsx23(
    StyledMenuSeparator,
    {
      ...getDataAttributes("MenuSeparator"),
      role: "separator",
      ...componentProps
    }
  );
}
MenuSeparator.displayName = "MenuSeparator";

// src/components/Menu/Title.tsx
import { isValidElement as isValidElement10 } from "react";
import { css as css20 } from "@emotion/react";
import styled22 from "@emotion/styled";
import { jsx as jsx24 } from "react/jsx-runtime";
var StyledMenuTitle = styled22(
  "li",
  getStyledOptions()
)((props) => {
  const {
    theme: { dataAttributeName: dataAttributeName2, grayScale: grayScale2, spacing: spacing2, typography: typography2 }
  } = props;
  return css20`
    ${colorStyles(props)};

    [data-${dataAttributeName2}='MenuTitleContent'] {
      padding: ${spacing2.xs} ${spacing2.sm};
    }

    [data-${dataAttributeName2}='MenuTitleText'] {
      color: ${grayScale2["500"]};
      font-size: ${typography2.xs.fontSize};
      text-transform: uppercase;
      ${textStyles(props)};
    }
  `;
});
function MenuTitle(props) {
  const {
    componentProps: { children, ...rest },
    getDataAttributes
  } = useMenu(props);
  const content = isValidElement10(children) ? children : /* @__PURE__ */ jsx24("span", { ...getDataAttributes("MenuTitleText"), children });
  return /* @__PURE__ */ jsx24(StyledMenuTitle, { ...getDataAttributes("MenuTitle"), role: "presentation", ...rest, children: /* @__PURE__ */ jsx24("div", { ...getDataAttributes("MenuTitleContent"), children: content }) });
}
MenuTitle.displayName = "MenuTitle";

// src/components/ButtonSplit/useButtonSplit.ts
var defaultProps17 = {
  bg: "primary",
  block: false,
  bordered: false,
  busy: false,
  disabled: false,
  position: "bottom-right",
  size: "md"
};
function useButtonSplit(props) {
  return useComponentProps(props, defaultProps17);
}

// src/components/ButtonSplit/ButtonSplit.tsx
import { jsx as jsx25, jsxs as jsxs10 } from "react/jsx-runtime";
var StyledButtonSplit = styled23("div", getStyledOptions())(
  {
    display: "inline-flex"
  },
  (props) => {
    const { block, bordered, disabled, size, theme } = props;
    const { button: button2, darkMode: darkMode2, dataAttributeName: dataAttributeName2, grayScale: grayScale2, spacing: spacing2 } = theme;
    const propsWithVariant = { ...props, variant: bordered ? "bordered" : "solid" };
    const { borderRadius, height, padding } = button2[size];
    const buttonPadding = `${padding[0]} ${padding[1]}`;
    const styles2 = colorStyles(propsWithVariant);
    if (disabled) {
      styles2.border = `1px solid ${darkMode2 ? grayScale2["800"] : grayScale2["100"]}`;
      styles2.borderColor = grayScale2["100"];
      styles2.color = grayScale2["500"];
    }
    const disabledStyles = disabled ? css21`
          ${getDisableStyles(propsWithVariant, { isButton: true })};
          border-color: ${darkMode2 ? grayScale2["850"] : grayScale2["100"]};
        ` : void 0;
    const outlineStyle = outlineStyles(styles2.backgroundColor, theme);
    return css21`
      display: inline-flex;
      min-height: ${height};
      min-width: ${height};
      width: ${block ? "100%" : "auto"};
      ${getStyles(omit8(props, "position"), { skipColor: true })};

      [data-${dataAttributeName2}='ButtonSplitMainButton'] {
        ${styles2};
        border-bottom-left-radius: ${borderRadius};
        border-right: 0;
        border-top-left-radius: ${borderRadius};
        display: flex;
        flex: 1;
        justify-content: center;
        opacity: 1;
        padding: ${buttonPadding};

        ${disabledStyles};
        ${outlineStyle};
      }

      [data-${dataAttributeName2}='MenuButton'] {
        ${styles2};
        ${disabledStyles};
        align-items: center;
        border-left: ${bordered ? styles2.border : `1px solid ${styles2.color}`};
        border-radius: 0 ${borderRadius} ${borderRadius} 0;
        display: flex;
        height: 100%;
        opacity: 1;
        padding: 0 ${spacing2[size === "xs" ? "xxs" : "xs"]};
        width: 100%;
        ${outlineStyle};
      }
    `;
  }
);
function ButtonSplit(props) {
  const { componentProps, getDataAttributes } = useButtonSplit(props);
  const { busy, buttonProps, children, label, onClick, onToggle, position, ...rest } = componentProps;
  const { bg, disabled, size } = rest;
  const [active, setActive] = useState9(false);
  const handleToggle = useCallback7(
    (status) => {
      setActive(status);
      onToggle?.(status);
    },
    [onToggle]
  );
  let iconSize = 14;
  switch (size) {
    case "sm": {
      iconSize = 16;
      break;
    }
    case "md": {
      iconSize = 18;
      break;
    }
    case "lg": {
      iconSize = 22;
      break;
    }
    default: {
    }
  }
  return /* @__PURE__ */ jsxs10(
    StyledButtonSplit,
    {
      busy,
      ...getDataAttributes("ButtonSplit"),
      position,
      ...rest,
      children: [
        /* @__PURE__ */ jsx25(
          ButtonUnstyled,
          {
            busy,
            ...getDataAttributes("ButtonSplitMainButton"),
            disabled,
            onClick,
            size,
            ...buttonProps,
            children: label
          }
        ),
        /* @__PURE__ */ jsx25(
          Menu,
          {
            accent: bg,
            button: /* @__PURE__ */ jsx25(Icon, { name: active ? "chevron-up" : "chevron-down", size: iconSize }),
            disabled: disabled || busy,
            onToggle: handleToggle,
            position,
            children
          }
        )
      ]
    }
  );
}
ButtonSplit.displayName = "ButtonSplit";

// src/components/CheckboxAndRadio/Checkbox.tsx
import { forwardRef as forwardRef12 } from "react";

// src/components/CheckboxAndRadio/useCheckboxAndRadio.tsx
import { css as css22 } from "@emotion/react";
import styled24 from "@emotion/styled";
import { pick, px as px13 } from "@gilbarbara/helpers";
var checkBoxDefaultProps = {
  accent: "primary",
  align: "center",
  borderless: false,
  disabled: false,
  size: "md"
};
var radioDefaultProps = {
  accent: "primary",
  align: "center",
  borderless: false,
  disabled: false,
  size: "md"
};
var StyledCheckboxRadioInput = styled24("input", getStyledOptions())`
  left: 0;
  opacity: 0;
  position: absolute;
  top: 0;
  z-index: -1;
`;
var StyledText2 = styled24(
  "span",
  getStyledOptions()
)((props) => {
  const { size, theme } = props;
  const { typography: typography2 } = theme;
  const { fontSize } = typography2[size ?? "md"];
  return css22`
    font-size: ${fontSize};
  `;
});
var StyledElement = styled24("span", getStyledOptions("label"))(
  {
    display: "inline-flex",
    flexShrink: 0,
    overflow: "hidden",
    position: "relative",
    transition: "background-color 0.2s, border-color 0.2s"
  },
  (props) => {
    const { accent = "primary", borderless, category = "checkbox", label, size, theme } = props;
    const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2, white: white2 } = theme;
    const { mainColor } = getColorTokens(accent, null, theme);
    let backgroundColor = darkMode2 ? grayScale2["800"] : white2;
    if (borderless) {
      backgroundColor = darkMode2 ? grayScale2["700"] : grayScale2["100"];
    }
    let after;
    let dimensions = 18;
    if (size === "md") {
      dimensions = 20;
    }
    if (size === "lg") {
      dimensions = 22;
    }
    if (category === "checkbox") {
      let height = 4;
      let width = 7;
      if (size === "md") {
        height = 6;
        width = 9;
      }
      if (size === "lg") {
        height = 7;
        width = 11;
      }
      after = css22`
        border-bottom: 2px solid ${mainColor};
        border-left: 2px solid ${mainColor};
        height: ${px13(height)};
        transform: rotate(-45deg) translateY(-100%);
        width: ${px13(width)};
      `;
    } else {
      let innerDimensions = 6;
      if (size === "md") {
        innerDimensions = 7;
      }
      if (size === "lg") {
        innerDimensions = 8;
      }
      after = css22`
        background-color: ${mainColor};
        border-radius: 50%;
        height: ${px13(innerDimensions)};
        transform: translate(-50%, -50%);
        width: ${px13(innerDimensions)};
      `;
    }
    return css22`
      background-color: ${backgroundColor};
      border: ${borderless ? 0 : `2px solid ${grayScale2["700"]}`};
      border-radius: ${category === "checkbox" ? radius2.xxs : radius2.round};
      height: ${px13(dimensions)};
      margin-right: ${label ? "6px" : "0"};
      width: ${px13(dimensions)};
      ${getStyles(props, { skipColor: true })};

      input:not(:disabled) ~ &:focus {
        ${getOutlineStyles(mainColor, theme)};
      }

      &:after {
        content: '';
        display: none;
        position: absolute;
        left: 50%;
        top: 50%;
        ${after};
      }

      input:checked ~ & {
        border-color: ${mainColor};

        &:after {
          display: inline-block;
        }
      }

      input:disabled ~ & {
        ${getDisableStyles(props)};
      }
    `;
  }
);
var StyledLabel = styled24(
  "label",
  getStyledOptions()
)((props) => {
  const { align, disabled } = props;
  return css22`
    ${marginStyles(props)};
    align-items: ${align};
    cursor: ${disabled ? "not-allowed" : "pointer"};
    display: flex;
    justify-content: flex-start;
    position: relative;
  `;
});
function getMarginProps(props) {
  return pick(props, "margin", "mb", "ml", "mr", "mt", "mx", "my", "theme");
}
function handleKeyDown(event) {
  const target = event.target;
  const input = target.previousElementSibling;
  if (!input || input.disabled || !["Enter", "Space"].includes(event.code)) {
    return;
  }
  input.click();
}
function useCheckboxAndRadio(props, type) {
  return useComponentProps(props, type === "checkbox" ? checkBoxDefaultProps : radioDefaultProps);
}

// src/components/CheckboxAndRadio/Checkbox.tsx
import { jsx as jsx26, jsxs as jsxs11 } from "react/jsx-runtime";
var Checkbox = forwardRef12((props, ref) => {
  const { componentProps, getDataAttributes } = useCheckboxAndRadio(props, "checkbox");
  const {
    accent,
    align,
    borderless,
    checked,
    defaultChecked,
    disabled,
    id,
    label,
    name,
    size,
    style,
    ...rest
  } = componentProps;
  const inputId = id ?? name;
  return /* @__PURE__ */ jsxs11(
    StyledLabel,
    {
      align,
      ...getDataAttributes("Checkbox"),
      disabled,
      htmlFor: inputId,
      size,
      ...getMarginProps(componentProps),
      children: [
        /* @__PURE__ */ jsx26(
          StyledCheckboxRadioInput,
          {
            ref,
            "aria-checked": checked ?? defaultChecked,
            checked,
            defaultChecked,
            disabled,
            id: inputId,
            name,
            type: "checkbox",
            ...rest
          }
        ),
        /* @__PURE__ */ jsx26(
          StyledElement,
          {
            accent,
            borderless,
            category: "checkbox",
            ...getDataAttributes("CheckboxElement"),
            label,
            onKeyDown: handleKeyDown,
            size,
            style,
            tabIndex: disabled ? -1 : 0,
            theme: rest.theme
          }
        ),
        label && /* @__PURE__ */ jsx26(StyledText2, { category: "checkbox", size, theme: rest.theme, children: label })
      ]
    }
  );
});
Checkbox.displayName = "Checkbox";

// src/components/CheckboxAndRadio/Radio.tsx
import { forwardRef as forwardRef13 } from "react";
import { jsx as jsx27, jsxs as jsxs12 } from "react/jsx-runtime";
var Radio = forwardRef13((props, ref) => {
  const { componentProps, getDataAttributes } = useCheckboxAndRadio(props, "radio");
  const {
    accent,
    align,
    borderless,
    checked,
    defaultChecked,
    disabled,
    id,
    label,
    name,
    size,
    style,
    ...rest
  } = componentProps;
  return /* @__PURE__ */ jsxs12(
    StyledLabel,
    {
      align,
      category: "radio",
      ...getDataAttributes("Radio"),
      disabled,
      htmlFor: id,
      ...getMarginProps(componentProps),
      children: [
        /* @__PURE__ */ jsx27(
          StyledCheckboxRadioInput,
          {
            ref,
            "aria-checked": !!(checked ?? defaultChecked),
            checked,
            defaultChecked,
            disabled,
            id,
            name,
            role: "radio",
            type: "radio",
            ...rest
          }
        ),
        /* @__PURE__ */ jsx27(
          StyledElement,
          {
            accent,
            borderless,
            category: "radio",
            ...getDataAttributes("RadioElement"),
            label,
            onKeyDown: handleKeyDown,
            size,
            style,
            tabIndex: disabled ? -1 : 0,
            theme: rest.theme
          }
        ),
        label && /* @__PURE__ */ jsx27(StyledText2, { category: "radio", size, theme: rest.theme, children: label })
      ]
    }
  );
});
Radio.displayName = "Radio";

// src/components/Chip/Chip.tsx
import { forwardRef as forwardRef14, isValidElement as isValidElement11 } from "react";
import { css as css23 } from "@emotion/react";
import styled25 from "@emotion/styled";

// src/components/Chip/useChip.ts
import { omit as omit9 } from "@gilbarbara/helpers";
var defaultProps19 = {
  ...omit9(textDefaultOptions, "size"),
  bg: "primary",
  gap: "xxs",
  radius: "md",
  size: "sm",
  variant: "solid"
};
function useChip(props) {
  return useComponentProps(props, defaultProps19);
}

// src/components/Chip/Chip.tsx
import { jsx as jsx28, jsxs as jsxs13 } from "react/jsx-runtime";
var StyledChip = styled25("span", getStyledOptions())(
  {
    alignItems: "center",
    display: "inline-flex",
    justifyContent: "center"
  },
  (props) => {
    const { theme } = props;
    const { spacing: spacing2 } = theme;
    return css23`
      padding: ${spacing2.xxs} ${spacing2.sm};
      ${getStyles(props, { lineHeightCustom: 1, useFontSize: true })};
    `;
  }
);
var Chip = forwardRef14((props, ref) => {
  const { componentProps, getDataAttributes } = useChip(props);
  const { children, endContent, endContentOnClick, startContent, startContentOnClick, ...rest } = componentProps;
  const content = {};
  if (startContent) {
    content.startContent = startContent;
    if (startContentOnClick) {
      content.startContent = /* @__PURE__ */ jsx28(ButtonUnstyled, { onClick: startContentOnClick, children: content.startContent });
    } else {
      content.startContent = isValidElement11(startContent) ? startContent : /* @__PURE__ */ jsx28("span", { children: startContent });
    }
  }
  if (endContent) {
    content.endContent = endContent;
    if (endContentOnClick) {
      content.endContent = /* @__PURE__ */ jsx28(ButtonUnstyled, { onClick: endContentOnClick, children: content.endContent });
    } else {
      content.endContent = isValidElement11(endContent) ? endContent : /* @__PURE__ */ jsx28("span", { children: endContent });
    }
  }
  return /* @__PURE__ */ jsxs13(StyledChip, { ref, ...getDataAttributes("Chip"), ...rest, children: [
    content.startContent,
    /* @__PURE__ */ jsx28("span", { children }),
    content.endContent
  ] });
});
Chip.displayName = "Chip";

// src/components/Container/Container.tsx
import { forwardRef as forwardRef15 } from "react";
import { css as css24 } from "@emotion/react";
import styled26 from "@emotion/styled";
import { px as px14 } from "@gilbarbara/helpers";

// src/components/Container/useContainer.ts
var defaultProps21 = {
  align: "stretch",
  direction: "column",
  fullScreen: false,
  responsive: true,
  textAlign: "left",
  justify: "start",
  verticalPadding: false
};
function useContainer(props) {
  return useComponentProps(props, defaultProps21);
}

// src/components/Container/Container.tsx
import { jsx as jsx29 } from "react/jsx-runtime";
var StyledContainer = styled26(Box)(
  {
    display: "flex",
    flexDirection: "column",
    marginLeft: "auto",
    marginRight: "auto",
    position: "relative",
    width: "100%"
  },
  (props) => {
    const { fullScreen, fullScreenOffset, responsive: responsive2, verticalPadding } = props;
    const styles2 = {};
    if (fullScreen) {
      styles2.minHeight = fullScreenOffset ? `calc(100vh - ${px14(fullScreenOffset)})` : "100vh";
    }
    return css24`
      ${styles2};
      ${getContainerStyles(props, { responsive: responsive2, verticalPadding })};
      ${getStyles(props, { skipBorder: true })};
    `;
  }
);
var Container = forwardRef15((props, ref) => {
  const { componentProps, getDataAttributes } = useContainer(props);
  return /* @__PURE__ */ jsx29(StyledContainer, { ref, ...getDataAttributes("Container"), ...componentProps });
});
Container.displayName = "Container";

// src/components/CopyToClipboard/CopyToClipboard.tsx
import {
  cloneElement as cloneElement3,
  isValidElement as isValidElement13,
  useMemo as useMemo5,
  useRef as useRef7,
  useState as useState11
} from "react";
import innerText4 from "react-innertext";
import styled28 from "@emotion/styled";
import { omit as omit12 } from "@gilbarbara/helpers";
import { useIsMounted } from "@gilbarbara/hooks";

// src/components/Tooltip/Tooltip.tsx
import { isValidElement as isValidElement12, useEffect as useEffect6, useMemo as useMemo4, useState as useState10 } from "react";
import innerText3 from "react-innertext";
import { css as css25 } from "@emotion/react";
import styled27 from "@emotion/styled";
import { omit as omit11, px as px15 } from "@gilbarbara/helpers";
import is9 from "is-lite";

// src/components/Tooltip/useTooltip.ts
import { omit as omit10 } from "@gilbarbara/helpers";
var defaultProps22 = {
  ...omit10(textDefaultOptions, "size"),
  arrowDistance: 4,
  arrowMargin: 4,
  arrowLength: 8,
  bg: "gray.700",
  delay: 180,
  disabled: false,
  duration: 260,
  easing: "ease-in-out",
  eventType: "hover",
  placement: "bottom-middle",
  radius: "xxs",
  size: "sm",
  zIndex: 100
};
function useTooltip(props) {
  return useComponentProps(props, defaultProps22);
}

// src/components/Tooltip/Tooltip.tsx
import { jsx as jsx30, jsxs as jsxs14 } from "react/jsx-runtime";
var arrowSize = 6;
var StyledTooltip = styled27(
  "div",
  getStyledOptions()
)(
  (props) => css25`
    ${baseStyles(props.theme)};
    display: inline-flex;
    line-height: 1;
    position: relative;
  `
);
var StyledArrow = styled27.span(
  (props) => {
    const { arrowLength, arrowMargin, bg, placement } = props;
    const [position, align] = placement.split("-");
    const arrowStyles = {};
    const styles2 = {};
    switch (position) {
      case "bottom": {
        arrowStyles.borderLeft = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderRight = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderBottom = `${px15(arrowLength)} solid ${bg}`;
        styles2.top = `-${px15(arrowLength)}`;
        styles2.height = arrowLength;
        styles2.width = arrowSize * 2;
        break;
      }
      case "left": {
        arrowStyles.borderTop = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderBottom = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderLeft = `${px15(arrowLength)} solid ${bg}`;
        styles2.right = `-${px15(arrowLength)}`;
        styles2.height = arrowSize * 2;
        styles2.width = arrowLength;
        break;
      }
      case "right": {
        arrowStyles.borderTop = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderBottom = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderRight = `${px15(arrowLength)} solid ${bg}`;
        styles2.left = `-${px15(arrowLength)}`;
        styles2.height = arrowSize * 2;
        styles2.width = arrowLength;
        break;
      }
      case "top": {
        arrowStyles.borderLeft = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderRight = `${px15(arrowSize)} solid transparent`;
        arrowStyles.borderTop = `${px15(arrowLength)} solid ${bg}`;
        styles2.bottom = `-${px15(arrowLength)}`;
        styles2.height = arrowLength;
        styles2.width = arrowSize * 2;
        break;
      }
    }
    if (["bottom", "top"].includes(position)) {
      if (align === "start") {
        styles2.left = arrowMargin;
      } else if (align === "middle") {
        styles2.left = "50%";
        styles2.transform = "translateX(-50%)";
      } else {
        styles2.right = arrowMargin;
      }
    } else if (["left", "right"].includes(position)) {
      if (align === "start") {
        styles2.top = arrowMargin;
      } else if (align === "middle") {
        styles2.top = "50%";
        styles2.transform = "translateY(-50%)";
      } else {
        styles2.bottom = arrowMargin;
      }
    }
    return css25`
      display: block;
      position: absolute;
      z-index: 5;
      ${styles2};

      &:before {
        content: '';
        display: block;
        height: 0;
        width: 0;
        ${arrowStyles};
      }
    `;
  }
);
var StyledBody = styled27(
  "span",
  getStyledOptions()
)((props) => {
  const {
    arrowDistance,
    arrowLength,
    bg,
    color,
    delay,
    duration,
    easing: easing2,
    placement,
    size,
    theme,
    wrap,
    zIndex: zIndex2
  } = props;
  const { spacing: spacing2 } = theme;
  const arrowSpacing = arrowLength + arrowDistance;
  const [position, align] = placement.split("-");
  const styles2 = {};
  if (align === "start") {
    if (["left", "right"].includes(position)) {
      styles2.top = arrowDistance;
    } else {
      styles2.left = 0;
    }
  } else if (align === "middle") {
    if (["left", "right"].includes(position)) {
      styles2.top = "50%";
      styles2.transform = "translateY(-50%)";
    } else {
      styles2.left = "50%";
      styles2.transform = "translateX(-50%)";
    }
  } else if (["left", "right"].includes(position)) {
    styles2.bottom = arrowDistance;
  } else {
    styles2.right = arrowDistance;
  }
  switch (position) {
    case "bottom": {
      styles2.marginTop = arrowSpacing;
      styles2.top = "100%";
      break;
    }
    case "left": {
      styles2.right = "100%";
      styles2.marginRight = arrowSpacing;
      break;
    }
    case "right": {
      styles2.left = "100%";
      styles2.marginLeft = arrowSpacing;
      break;
    }
    case "top": {
      styles2.bottom = "100%";
      styles2.marginBottom = arrowSpacing;
      break;
    }
  }
  switch (size) {
    case "xs":
    case "sm": {
      styles2.padding = `${spacing2.xxs} ${spacing2.xs}`;
      break;
    }
    default: {
      styles2.padding = `${spacing2.xs} ${spacing2.sm}`;
      break;
    }
  }
  let width;
  switch (wrap) {
    case "sm": {
      width = "100px";
      break;
    }
    case "md": {
      width = "200px";
      break;
    }
    case "lg": {
      width = "320px";
      break;
    }
  }
  return css25`
    animation: ${fadeIn} ${duration}ms forwards ${easing2};
    animation-delay: ${delay}ms;
    background-color: ${bg};
    color: ${color};
    opacity: 0;
    position: absolute;
    text-align: center;
    white-space: ${wrap ? "initial" : "nowrap"};
    width: ${width};
    z-index: ${zIndex2};
    ${styles2};
    ${getStyles(omit11(props, "wrap"), { useFontSize: true })};
  `;
});
var StyledContent = styled27(Text)`
  position: relative;
  z-index: 10;
`;
function TooltipBody(props) {
  const {
    arrowDistance,
    arrowLength,
    arrowMargin,
    bg,
    bold,
    color,
    content,
    getDataAttributes,
    italic,
    placement,
    radius: radius2,
    shadow: shadow2,
    size,
    style,
    theme,
    wrap,
    ...rest
  } = props;
  return /* @__PURE__ */ jsxs14(
    StyledBody,
    {
      arrowDistance,
      arrowLength,
      arrowMargin,
      bg,
      color,
      ...getDataAttributes("TooltipBody"),
      placement,
      radius: radius2,
      shadow: shadow2,
      size,
      style,
      theme,
      wrap,
      ...rest,
      children: [
        isValidElement12(content) ? content : /* @__PURE__ */ jsx30(
          StyledContent,
          {
            bold,
            ...getDataAttributes("TooltipContent"),
            italic,
            size,
            children: content
          }
        ),
        /* @__PURE__ */ jsx30(
          StyledArrow,
          {
            arrowDistance,
            arrowLength,
            arrowMargin,
            bg,
            color,
            ...getDataAttributes("TooltipArrow"),
            placement,
            theme
          }
        )
      ]
    }
  );
}
function Tooltip(props) {
  const { componentProps, getDataAttributes } = useTooltip(props);
  const {
    ariaLabel,
    bg,
    children,
    color,
    content,
    disabled,
    eventType,
    open,
    theme,
    title,
    ...rest
  } = componentProps;
  const [isOpen, setOpen] = useState10(open ?? false);
  const label = useMemo4(() => ariaLabel ?? innerText3(content), [ariaLabel, content]);
  const { mainColor, textColor: textColor2 } = getColorTokens(bg, color, theme);
  useEffect6(() => {
    setOpen(open ?? false);
  }, [open]);
  const handleClick = () => {
    if (eventType === "click" && !disabled) {
      setOpen(!isOpen);
    }
  };
  const handleMouseEnter = () => {
    if (eventType === "hover" && !is9.boolean(open) && !disabled) {
      setOpen(true);
    }
  };
  const handleMouseLeave = () => {
    if (eventType === "hover" && !is9.boolean(open) && !disabled) {
      setOpen(false);
    }
  };
  return /* @__PURE__ */ jsxs14(
    StyledTooltip,
    {
      "aria-label": label,
      ...getDataAttributes("Tooltip"),
      onClick: handleClick,
      onMouseEnter: handleMouseEnter,
      onMouseLeave: handleMouseLeave,
      role: "tooltip",
      theme,
      title,
      ...rest,
      children: [
        children,
        isOpen && /* @__PURE__ */ jsx30(
          TooltipBody,
          {
            getDataAttributes,
            ...componentProps,
            bg: mainColor,
            color: textColor2,
            theme
          }
        )
      ]
    }
  );
}
Tooltip.displayName = "Tooltip";

// src/components/CopyToClipboard/useCopyToClipboard.ts
var defaultProps23 = {
  disableAnimation: false,
  hideTooltip: false,
  size: 16,
  timeout: 2e3,
  tooltipText: "Click to copy"
};
function useCopyToClipboard(props) {
  return useComponentProps(props, defaultProps23);
}

// src/components/CopyToClipboard/CopyToClipboard.tsx
import { jsx as jsx31 } from "react/jsx-runtime";
var StyledCopyToClipboard = styled28("span", getStyledOptions())(
  {
    cursor: "pointer",
    display: "inline-flex",
    lineHeight: 1,
    position: "relative"
  },
  (props) => getStyles(omit12(props, "size"))
);
function CopyToClipboard(props) {
  const {
    componentProps: {
      checkIcon = /* @__PURE__ */ jsx31(Icon, { name: "check" }),
      children,
      copyIcon = /* @__PURE__ */ jsx31(Icon, { name: "copy" }),
      disableAnimation,
      hideTooltip,
      onCopy,
      onError,
      size,
      timeout,
      tooltipCopiedText,
      tooltipProps,
      tooltipText,
      value,
      ...rest
    },
    getDataAttributes
  } = useCopyToClipboard(props);
  const isMounted = useIsMounted();
  const [tooltipContent, setTooltipContent] = useState11(tooltipText);
  const [copied, setCopied] = useState11(false);
  const iconRef = useRef7(null);
  const valueText = useMemo5(() => {
    let stringValue = "";
    if (Array.isArray(value)) {
      value.forEach((child) => {
        const childString = innerText4(child);
        if (childString) {
          stringValue += `${childString}
`;
        }
      });
    } else {
      stringValue = innerText4(value);
    }
    return stringValue.trim();
  }, [value]);
  const handleClick = async (event) => {
    event.stopPropagation();
    event.preventDefault();
    if (!disableAnimation && iconRef.current) {
      animateIcon(iconRef.current, rest.color ?? "primary", rest.theme);
    }
    try {
      await navigator.clipboard.writeText(valueText);
      onCopy?.(valueText);
      if (tooltipCopiedText) {
        setTooltipContent(tooltipCopiedText);
      }
      setTimeout(
        () => {
          if (isMounted()) {
            setCopied(true);
          }
        },
        disableAnimation ? 0 : 300
      );
      setTimeout(() => {
        if (isMounted()) {
          setTooltipContent(tooltipText);
          setCopied(false);
        }
      }, timeout);
    } catch (error) {
      setTooltipContent(error.message);
      onError?.(error.message);
    }
  };
  const copyIconElement = copyIcon && !isValidElement13(copyIcon) ? /* @__PURE__ */ jsx31("span", { children: copyIcon }) : copyIcon;
  const checkIconElement = checkIcon && !isValidElement13(checkIcon) ? /* @__PURE__ */ jsx31("span", { children: checkIcon }) : checkIcon;
  let main = cloneElement3(
    copied ? checkIconElement : copyIconElement,
    {
      ref: iconRef,
      size,
      title: null
    }
  );
  if (children) {
    main = children;
  }
  if (!hideTooltip && (tooltipCopiedText || !copied)) {
    main = /* @__PURE__ */ jsx31(Tooltip, { content: tooltipContent, placement: "top-middle", size: "xs", ...tooltipProps, children: main });
  }
  return /* @__PURE__ */ jsx31(
    StyledCopyToClipboard,
    {
      ...getDataAttributes("CopyToClipboard"),
      onClick: handleClick,
      ...rest,
      children: main
    }
  );
}
CopyToClipboard.displayName = "CopyToClipboard";

// src/components/DataTable/DataTable.tsx
import { useCallback as useCallback8, useMemo as useMemo6, useRef as useRef8 } from "react";
import { useMount, useSetState, useUpdateEffect as useUpdateEffect2 } from "@gilbarbara/hooks";

// src/components/Pagination/Pagination.tsx
import { css as css27 } from "@emotion/react";
import styled30 from "@emotion/styled";
import { omit as omit13 } from "@gilbarbara/helpers";
import is10 from "is-lite";

// src/components/Pagination/Button.tsx
import { css as css26 } from "@emotion/react";
import styled29 from "@emotion/styled";

// src/components/Pagination/usePagination.ts
var defaultProps24 = {
  accent: "primary",
  align: "end",
  disableEdgeNavigation: false,
  edgeNavigationLimit: 3,
  showSinglePage: false
};
function usePagination(props) {
  return useComponentProps(props, defaultProps24);
}
function usePaginationButton(props) {
  return useComponentProps(props);
}

// src/components/Pagination/Button.tsx
import { jsx as jsx32 } from "react/jsx-runtime";
var StyledPaginationButton = styled29(
  ButtonUnstyled,
  getStyledOptions()
)((props) => {
  const { accent = "primary", current, theme } = props;
  const { black: black2, darkMode: darkMode2, opacity: opacity2, spacing: spacing2, typography: typography2, white: white2 } = theme;
  const color = darkMode2 ? white2 : black2;
  const { mainColor, textColor: textColor2 } = getColorTokens(accent, null, theme);
  return css26`
    align-items: center;
    border-radius: 50%;
    background-color: ${current ? mainColor : "transparent"};
    color: ${current ? textColor2 : color};
    display: flex;
    font-size: ${typography2.sm.fontSize};
    font-weight: ${700};
    justify-content: center;
    height: ${spacing2.xl};
    line-height: 1;
    width: ${spacing2.xl};

    &:disabled {
      opacity: ${current ? 1 : opacity2.medium};
      pointer-events: none;
    }
  `;
});
function PaginationButton(props) {
  const { componentProps, getDataAttributes } = usePaginationButton(props);
  const { accent, children, currentPage, disabled, onClick, page, theme, type } = componentProps;
  const current = page === currentPage && children === page;
  const handleClick = () => {
    onClick?.(page, type);
  };
  return /* @__PURE__ */ jsx32(
    StyledPaginationButton,
    {
      accent,
      current,
      ...getDataAttributes("PaginationButton"),
      "data-current": current,
      "data-page": page,
      "data-type": type,
      disabled,
      onClick: handleClick,
      theme,
      children: children ?? page
    }
  );
}
PaginationButton.displayName = "PaginationButton";

// src/components/Pagination/Pagination.tsx
import { jsx as jsx33 } from "react/jsx-runtime";
var StyledPagination = styled30("div", getStyledOptions())(
  {
    alignItems: "center",
    display: "flex"
  },
  (props) => {
    const { align } = props;
    return css27`
      justify-content: ${align};
      ${getStyles(omit13(props, "align"))};
    `;
  }
);
function Pagination(props) {
  const { componentProps, getDataAttributes } = usePagination(props);
  const {
    accent,
    currentPage,
    disableEdgeNavigation,
    edgeNavigationLimit = 3,
    onClick,
    showSinglePage,
    totalPages,
    ...rest
  } = componentProps;
  const items = [];
  if (totalPages === 0 || totalPages === 1 && !showSinglePage) {
    return null;
  }
  if (!disableEdgeNavigation && totalPages > edgeNavigationLimit) {
    items.push({
      type: "first",
      disabled: currentPage === 1,
      page: 1,
      content: /* @__PURE__ */ jsx33(Icon, { name: "chevron-double-left" })
    });
  }
  items.push({
    type: "previous",
    disabled: currentPage === 1,
    page: currentPage - 1,
    content: /* @__PURE__ */ jsx33(Icon, { name: "chevron-left" })
  });
  if (disableEdgeNavigation && totalPages > 6) {
    items.push({ type: "page", page: 1 });
    if (currentPage > 3) {
      items.push({ type: "between-1", content: "..." });
    }
    if (currentPage === totalPages) {
      items.push({ type: "page", page: currentPage - 2 });
    }
    if (currentPage > 2) {
      items.push({ type: "page", page: currentPage - 1 });
    }
    if (currentPage !== 1 && currentPage !== totalPages) {
      items.push({ type: "page", page: currentPage });
    }
    if (currentPage < totalPages - 1) {
      items.push({ type: "page", page: currentPage + 1 });
    }
    if (currentPage === 1) {
      items.push({ type: "page", page: currentPage + 2 });
    }
    if (currentPage < totalPages - 2) {
      items.push({ type: "between-2", content: "..." });
    }
    items.push({ type: "page", page: totalPages });
  } else {
    const pages = Array.from({ length: totalPages }, (_, index) => index + 1).filter((p) => {
      const limit = currentPage + 2 <= totalPages ? currentPage - 1 : totalPages - 2;
      return p >= limit && p < currentPage + (currentPage === 1 || currentPage === totalPages - 1 ? 3 : 2);
    });
    pages.forEach((d) => {
      items.push({ type: "page", page: d });
    });
  }
  items.push({
    type: "next",
    disabled: currentPage === totalPages,
    page: currentPage + 1,
    content: /* @__PURE__ */ jsx33(Icon, { name: "chevron-right" })
  });
  if (!disableEdgeNavigation && totalPages > edgeNavigationLimit) {
    items.push({
      type: "last",
      disabled: currentPage === totalPages,
      page: totalPages,
      content: /* @__PURE__ */ jsx33(Icon, { name: "chevron-double-right" })
    });
  }
  return /* @__PURE__ */ jsx33(StyledPagination, { ...getDataAttributes("Pagination"), ...rest, children: items.map(
    (d, index) => is10.number(d.page) ? /* @__PURE__ */ jsx33(
      PaginationButton,
      {
        accent,
        currentPage,
        disabled: d.disabled ?? d.page === currentPage,
        onClick: d.page !== currentPage ? onClick : void 0,
        page: d.page,
        type: d.type,
        children: d.content ?? d.page
      },
      `${d.type}-${d.page ?? index}`
    ) : /* @__PURE__ */ jsx33("span", { children: "..." }, d.type)
  ) });
}
Pagination.displayName = "Pagination";

// src/components/DataTable/Body.tsx
import { memo as memo2 } from "react";

// src/components/Loader/Loader.tsx
import { cloneElement as cloneElement4, isValidElement as isValidElement14, useId as useId3 } from "react";
import { css as css33 } from "@emotion/react";
import styled36 from "@emotion/styled";
import is12 from "is-lite";

// src/components/Loader/Grow.tsx
import { css as css28, keyframes as keyframes4 } from "@emotion/react";
import styled31 from "@emotion/styled";
import { px as px16 } from "@gilbarbara/helpers";
import { jsx as jsx34 } from "react/jsx-runtime";
var grow = ({ size = 32 }) => keyframes4`
  0% {
    height: 0;
    width: 0;
  }

  30% {
    border-width: ${px16(size && size / 2.5)};
    opacity: 1;
  }

  100% {
    border-width: 0;
    height: ${px16(size)};
    opacity: 0;
    width: ${px16(size)};
  }
`;
var StyledLoaderGrow = styled31(
  "div",
  getStyledOptions()
)((props) => {
  const { block, color = "primary", size = 32, theme } = props;
  const { spacing: spacing2 } = theme;
  const { mainColor } = getColorTokens(color, null, theme);
  return css28`
    display: ${block ? "flex" : "inline-flex"};
    height: ${px16(size)};
    margin: ${block ? spacing2.lg : 0} auto;
    position: relative;
    width: ${px16(size)};

    > div {
      animation: ${grow(props)} 1.15s infinite cubic-bezier(0.2, 0.6, 0.36, 1);
      border: 0 solid ${mainColor};
      border-radius: 50%;
      height: 0;
      left: 50%;
      position: absolute;
      top: 50%;
      transform: translate(-50%, -50%);
      width: 0;
    }
  `;
});
function LoaderGrow(props) {
  const { getDataAttributes } = props;
  return /* @__PURE__ */ jsx34(StyledLoaderGrow, { ...getDataAttributes("LoaderGrow"), ...props, children: /* @__PURE__ */ jsx34("div", {}) });
}
LoaderGrow.displayName = "LoaderGrow";

// src/components/Loader/Pill.tsx
import { css as css29, keyframes as keyframes5 } from "@emotion/react";
import styled32 from "@emotion/styled";
import { px as px17 } from "@gilbarbara/helpers";
import { opacify as opacify3 } from "colorizr";
import is11 from "is-lite";
import { jsx as jsx35, jsxs as jsxs15 } from "react/jsx-runtime";
var animation = keyframes5`
  0% {
    transform: translateX(-10%);
  }

  50% {
    transform: translateX(100%);
  }

  100% {
    transform: translateX(-10%);
  }
`;
var StyledLoaderPill = styled32(
  "div",
  getStyledOptions()
)((props) => {
  const { block, color = "primary", height, theme, width } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, spacing: spacing2 } = theme;
  const ratio = 0.16;
  const borderRadius = px17(height / 2);
  const { mainColor } = getColorTokens(color, null, theme);
  return css29`
    background-color: ${darkMode2 ? grayScale2["700"] : grayScale2["100"]};
    border-radius: ${borderRadius};
    display: ${block ? "flex" : "inline-flex"};
    height: ${px17(height === width ? Math.ceil(height * ratio) : height)};
    margin: ${block ? spacing2.lg : 0} auto;
    overflow: hidden;
    position: relative;
    width: ${px17(width)};

    div {
      animation: ${animation} 2s infinite ease-in-out;
      background-color: ${mainColor};
      border-radius: ${borderRadius};
      content: '';
      bottom: 0;
      display: block;
      left: -10%;
      position: absolute;
      top: 0;
      width: 70%;
      z-index: 10;
    }

    div:nth-of-type(2) {
      animation-delay: 0.04s;
      background-color: ${opacify3(mainColor, 0.7)};
      z-index: 5;
    }

    div:nth-of-type(3) {
      animation-delay: 0.05s;
      background-color: ${opacify3(mainColor, 0.8)};
      z-index: 4;
    }
  `;
});
function LoaderPill(props) {
  const { getDataAttributes, size } = props;
  const [width, height] = is11.array(size) ? size : [size, size];
  return /* @__PURE__ */ jsxs15(StyledLoaderPill, { ...getDataAttributes("LoaderPill"), height, width, ...props, children: [
    /* @__PURE__ */ jsx35("div", {}),
    /* @__PURE__ */ jsx35("div", {}),
    /* @__PURE__ */ jsx35("div", {})
  ] });
}
LoaderPill.displayName = "LoaderPill";

// src/components/Loader/Pride.tsx
import { css as css30 } from "@emotion/react";
import styled33 from "@emotion/styled";
import { px as px18 } from "@gilbarbara/helpers";
import { jsx as jsx36, jsxs as jsxs16 } from "react/jsx-runtime";
var StyledLoaderPride = styled33(
  "div",
  getStyledOptions()
)((props) => {
  const { block, size = 32, theme } = props;
  const { spacing: spacing2 } = theme;
  return css30`
    display: ${block ? "flex" : "inline-flex"};
    height: ${px18(size)};
    margin: ${block ? spacing2.lg : 0} auto;
    position: relative;
    width: ${px18(size)};

    .loaderPrideGroup {
      animation: ${rotate} 1s infinite linear;
      transform-origin: 10px 10px;
    }
  `;
});
function LoaderPride(props) {
  const { getDataAttributes, size } = props;
  return /* @__PURE__ */ jsx36(StyledLoaderPride, { ...getDataAttributes("LoaderPride"), ...props, children: /* @__PURE__ */ jsxs16(
    "svg",
    {
      height: size,
      version: "1.1",
      viewBox: "0 0 24 24",
      width: size,
      xmlns: "http://www.w3.org/2000/svg",
      children: [
        /* @__PURE__ */ jsx36("title", { children: "Pride" }),
        /* @__PURE__ */ jsxs16("defs", { children: [
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-1",
              x1: "0%",
              x2: "100%",
              y1: "44.721611%",
              y2: "55.278389%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#FFCE00" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#FB9600" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-2",
              x1: "23.6069814%",
              x2: "76.3930186%",
              y1: "0%",
              y2: "100%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#FB9600" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#E25335" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16("linearGradient", { id: "linearGradient-vitwvdhq8u-3", x1: "0%", x2: "0%", y1: "0%", y2: "100%", children: [
            /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#E25335" }),
            /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#DE349E" })
          ] }),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-4",
              x1: "76.3930186%",
              x2: "23.6069814%",
              y1: "0%",
              y2: "100%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#DE349E" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#BF2FDC" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-5",
              x1: "100%",
              x2: "7.47355734e-15%",
              y1: "44.721611%",
              y2: "55.278389%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#BF2FDC" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#5D33D5" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-6",
              x1: "100%",
              x2: "2.41767548e-14%",
              y1: "55.278389%",
              y2: "44.721611%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#5D33D5" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#2B7CD7" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-7",
              x1: "76.3930186%",
              x2: "23.6069814%",
              y1: "100%",
              y2: "0%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#2B7CD7" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#33C3DD" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-8",
              x1: "100%",
              x2: "100%",
              y1: "100%",
              y2: "-5.74835557e-15%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#33C3DD" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#32D9A1" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-9",
              x1: "23.6069814%",
              x2: "76.3930186%",
              y1: "100%",
              y2: "5.68434189e-14%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#32D9A1" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#3FCB2A" })
              ]
            }
          ),
          /* @__PURE__ */ jsxs16(
            "linearGradient",
            {
              id: "linearGradient-vitwvdhq8u-10",
              x1: "0%",
              x2: "100%",
              y1: "55.278389%",
              y2: "44.721611%",
              children: [
                /* @__PURE__ */ jsx36("stop", { offset: "0%", stopColor: "#3FCB2A" }),
                /* @__PURE__ */ jsx36("stop", { offset: "100%", stopColor: "#FFCE00" })
              ]
            }
          )
        ] }),
        /* @__PURE__ */ jsx36("g", { transform: "translate(2.000000, 2.000000)", children: /* @__PURE__ */ jsxs16("g", { className: "loaderPrideGroup", strokeWidth: "4", children: [
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M10,3.70074342e-16 C12.111796,3.70074342e-16 14.1693886,0.668517671 15.8778738,1.90979148",
              stroke: "url(#linearGradient-vitwvdhq8u-1)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M15.8778738,1.90979148 C17.5863375,3.15106838 18.8579841,4.9013458 19.5105576,6.90976918",
              stroke: "url(#linearGradient-vitwvdhq8u-2)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M19.5105576,6.90976918 C20.1631475,8.91821275 20.1631475,11.081698 19.5105576,13.0901416",
              stroke: "url(#linearGradient-vitwvdhq8u-3)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M19.5105576,13.0901416 C18.8579841,15.098565 17.5863375,16.8488424 15.8778738,18.0901193",
              stroke: "url(#linearGradient-vitwvdhq8u-4)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M15.8778738,18.0901193 C14.1693886,19.3313931 12.111796,19.9999108 10,19.9999108",
              stroke: "url(#linearGradient-vitwvdhq8u-5)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M10,19.9999108 C7.888204,19.9999108 5.83061142,19.3313931 4.12212622,18.0901193",
              stroke: "url(#linearGradient-vitwvdhq8u-6)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M4.12212622,18.0901193 C2.41366248,16.8488424 1.14201593,15.098565 0.48944242,13.0901416",
              stroke: "url(#linearGradient-vitwvdhq8u-7)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M0.48944242,13.0901416 C-0.163147473,11.081698 -0.163147473,8.91821275 0.48944242,6.90976918",
              stroke: "url(#linearGradient-vitwvdhq8u-8)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M0.48944242,6.90976918 C1.14201593,4.9013458 2.41366248,3.15106838 4.12212622,1.90979148",
              stroke: "url(#linearGradient-vitwvdhq8u-9)"
            }
          ),
          /* @__PURE__ */ jsx36(
            "path",
            {
              d: "M4.12212622,1.90979148 C5.83061142,0.668517671 7.888204,3.70074342e-16 10,3.70074342e-16",
              stroke: "url(#linearGradient-vitwvdhq8u-10)"
            }
          )
        ] }) })
      ]
    }
  ) });
}
LoaderPride.displayName = "LoaderPride";

// src/components/Loader/Pulse.tsx
import { css as css31, keyframes as keyframes6 } from "@emotion/react";
import styled34 from "@emotion/styled";
import { px as px19 } from "@gilbarbara/helpers";
import { jsx as jsx37, jsxs as jsxs17 } from "react/jsx-runtime";
var pulse = ({ size = 32 }) => keyframes6`
  0% {
    height: 0;
    left: ${px19(size / 2)};
    opacity: 1;
    top: ${px19(size / 2)};
    width: 0;
  }

  100% {
    height: ${px19(size)};
    left: 0;
    opacity: 0;
    top: 0;
    width: ${px19(size)};
  }
`;
var StyledLoaderPulse = styled34(
  "div",
  getStyledOptions()
)((props) => {
  const { block, color = "primary", size = 32, theme } = props;
  const { spacing: spacing2 } = theme;
  const { mainColor } = getColorTokens(color, null, theme);
  return css31`
    display: ${block ? "flex" : "inline-flex"};
    height: ${px19(size)};
    margin: ${block ? spacing2.lg : 0} auto;
    position: relative;
    width: ${px19(size)};

    > div {
      animation: ${pulse(props)} 1.2s cubic-bezier(0, 0.2, 0.8, 1) infinite;
      border: ${px19(Math.round(size / 16))} solid ${mainColor};
      border-radius: 50%;
      height: 0;
      left: ${px19(size / 2)};
      opacity: 1;
      position: absolute;
      top: ${px19(size / 2)};
      transform-origin: center;
      width: 0;
    }

    > div:nth-of-type(2) {
      animation-delay: -0.5s;
    }
  `;
});
function LoaderPulse(props) {
  const { getDataAttributes } = props;
  return /* @__PURE__ */ jsxs17(StyledLoaderPulse, { ...getDataAttributes("LoaderPulse"), ...props, children: [
    /* @__PURE__ */ jsx37("div", {}),
    /* @__PURE__ */ jsx37("div", {})
  ] });
}
LoaderPulse.displayName = "LoaderPulse";

// src/components/Loader/Rotate.tsx
import { css as css32, keyframes as keyframes7 } from "@emotion/react";
import styled35 from "@emotion/styled";
import { px as px20 } from "@gilbarbara/helpers";
import { jsx as jsx38 } from "react/jsx-runtime";
var dash = keyframes7`
  0% {
    stroke-dasharray: 1, 200;
    stroke-dashoffset: 0;
  }

  50% {
    stroke-dasharray: 89, 200;
    stroke-dashoffset: -35px;
  }

  100% {
    stroke-dasharray: 89, 200;
    stroke-dashoffset: -124px;
  }
`;
var StyledLoaderRotate = styled35(
  "div",
  getStyledOptions()
)((props) => {
  const { block, theme } = props;
  const { spacing: spacing2 } = theme;
  return css32`
    display: ${block ? "flex" : "inline-flex"};
    margin: ${block ? spacing2.lg : 0} auto;
    text-align: center;
  `;
});
var StyledLoaderRotateSVG = styled35(
  "svg",
  getStyledOptions()
)((props) => {
  const { size } = props;
  return css32`
    animation: ${rotate} 2s linear infinite;
    height: ${px20(size)};
    margin: auto;
    transform-origin: center center;
    width: ${px20(size)};
  `;
});
var StyledLoaderRotateCircle = styled35("circle", getStyledOptions())`
  animation: ${dash} 1.5s infinite ease-in-out;
  stroke: ${(props) => props.color};
  stroke-dasharray: 1, 200;
  stroke-dashoffset: 0;
  stroke-linecap: round;
`;
function LoaderRotate(props) {
  const { color = "primary", getDataAttributes, size = 32, theme } = props;
  const { mainColor } = getColorTokens(color, null, theme);
  return /* @__PURE__ */ jsx38(StyledLoaderRotate, { ...getDataAttributes("LoaderRotate"), ...props, children: /* @__PURE__ */ jsx38(StyledLoaderRotateSVG, { size, viewBox: "25 25 50 50", children: /* @__PURE__ */ jsx38(
    StyledLoaderRotateCircle,
    {
      color: mainColor,
      cx: "50",
      cy: "50",
      fill: "none",
      r: "20",
      strokeWidth: 2
    }
  ) }) });
}
LoaderRotate.displayName = "LoaderRotate";

// src/components/Loader/useLoader.ts
var defaultProps25 = {
  color: "primary",
  block: false,
  labelPosition: "bottom",
  labelSize: "sm",
  size: 32,
  type: "pill"
};
function useLoader(props) {
  return useComponentProps(props, defaultProps25);
}

// src/components/Loader/Loader.tsx
import { jsx as jsx39, jsxs as jsxs18 } from "react/jsx-runtime";
var StyledLabel2 = styled36("p")((props) => {
  const { labelPosition, labelSize, theme } = props;
  const { spacing: spacing2, typography: typography2 } = theme;
  if (labelPosition === "middle") {
    return css33`
      font-size: ${typography2[labelSize].fontSize};
      left: 50%;
      margin: 0;
      position: absolute;
      top: 50%;
      transform: translate(-50%, -50%);
      z-index: 10;
    `;
  }
  let margin;
  switch (labelPosition) {
    case "top": {
      margin = `0 0 ${spacing2.xs} 0`;
      break;
    }
    case "left": {
      margin = `0 ${spacing2.xs} 0 0`;
      break;
    }
    case "right": {
      margin = `0 0 0 ${spacing2.xs}`;
      break;
    }
    case "bottom":
    default: {
      margin = `${spacing2.xs} 0 0 0`;
      break;
    }
  }
  return css33`
    font-size: ${typography2[labelSize].fontSize};
    margin: ${margin};
  `;
});
function Loader(props) {
  const { componentProps, getDataAttributes } = useLoader(props);
  const { block, color, label, labelPosition, labelSize, size, type, ...rest } = componentProps;
  const labelId = useId3();
  const componentSize = is12.array(size) ? size[0] : size;
  let direction;
  switch (labelPosition) {
    case "left": {
      direction = "row-reverse";
      break;
    }
    case "right": {
      direction = "row";
      break;
    }
    case "top": {
      direction = "column-reverse";
      break;
    }
    default: {
      direction = "column";
      break;
    }
  }
  const content = {};
  switch (type) {
    case "grow": {
      content.loader = /* @__PURE__ */ jsx39(
        LoaderGrow,
        {
          block,
          color,
          getDataAttributes,
          size: componentSize,
          theme: rest.theme
        }
      );
      break;
    }
    case "pride": {
      content.loader = /* @__PURE__ */ jsx39(
        LoaderPride,
        {
          block,
          getDataAttributes,
          size: componentSize,
          theme: rest.theme
        }
      );
      break;
    }
    case "pulse": {
      content.loader = /* @__PURE__ */ jsx39(
        LoaderPulse,
        {
          block,
          color,
          getDataAttributes,
          size: componentSize,
          theme: rest.theme
        }
      );
      break;
    }
    case "rotate": {
      content.loader = /* @__PURE__ */ jsx39(
        LoaderRotate,
        {
          block,
          color,
          getDataAttributes,
          size: componentSize,
          theme: rest.theme
        }
      );
      break;
    }
    case "pill":
    default: {
      content.loader = /* @__PURE__ */ jsx39(
        LoaderPill,
        {
          block,
          color,
          getDataAttributes,
          size,
          theme: rest.theme
        }
      );
      break;
    }
  }
  if (label) {
    content.label = isValidElement14(label) ? cloneElement4(label, { id: labelId }) : /* @__PURE__ */ jsx39(
      StyledLabel2,
      {
        id: labelId,
        labelPosition,
        labelSize,
        theme: rest.theme,
        children: label
      }
    );
  }
  return /* @__PURE__ */ jsxs18(
    Flex,
    {
      align: "center",
      "aria-busy": true,
      "aria-label": !label ? "Loading..." : void 0,
      "aria-labelledby": label ? labelId : void 0,
      "aria-live": "polite",
      ...getDataAttributes("Loader"),
      direction,
      justify: "center",
      position: "relative",
      role: "status",
      ...rest,
      children: [
        content.loader,
        content.label
      ]
    }
  );
}
Loader.displayName = "Loader";

// src/components/Paragraph/Paragraph.tsx
import { forwardRef as forwardRef16, isValidElement as isValidElement15 } from "react";
import { css as css34 } from "@emotion/react";
import styled37 from "@emotion/styled";
import { omit as omit14, px as px21 } from "@gilbarbara/helpers";
import is13 from "is-lite";

// src/components/Paragraph/useParagraph.ts
var defaultProps26 = {
  ...textDefaultOptions
};
function useParagraph(props) {
  return useComponentProps(props, defaultProps26);
}

// src/components/Paragraph/Paragraph.tsx
import { jsx as jsx40 } from "react/jsx-runtime";
var StyledParagraph = styled37("p", getStyledOptions())(
  {
    marginBottom: 0,
    marginTop: 0
  },
  (props) => {
    const { mt, theme } = props;
    let marginTop;
    if (mt && mt !== "auto") {
      marginTop = px21(theme.spacing[mt]);
    } else if (is13.number(mt)) {
      marginTop = px21(mt);
    }
    return css34`
      ${getStyles(omit14(props, "align", "mt"), { useFontSize: true })};
      ${alignStyles(props)};
      margin-top: ${marginTop} !important;

      & + p {
        margin-top: ${px21(theme.paragraphMarginBetween)};
      }
    `;
  }
);
var Paragraph = forwardRef16((props, ref) => {
  const { componentProps, getDataAttributes } = useParagraph(props);
  const { children } = componentProps;
  return /* @__PURE__ */ jsx40(StyledParagraph, { ref, ...getDataAttributes("Paragraph"), ...componentProps, children: isValidElement15(children) ? children : /* @__PURE__ */ jsx40(Text, { ...componentProps }) });
});
Paragraph.displayName = "Paragraph";

// src/components/DataTable/useDataTable.ts
import innerText5 from "react-innertext";
import is14 from "is-lite";
var defaultProps27 = {
  accent: "primary",
  breakpoint: 768,
  clean: false,
  defaultSortDirection: "asc",
  disableScroll: false,
  loaderSize: 128,
  loaderType: "pill",
  loading: false,
  maxRows: 10,
  pagination: true,
  radius: "xs",
  responsive: false,
  scrollDuration: 400,
  scrollMargin: 16,
  stickyHeader: false
};
function getBorder(darkMode2) {
  return [{ side: "top", color: darkMode2 ? "gray.700" : "gray.100" }];
}
function getRowContent(input, key) {
  const item = input[key];
  return is14.plainObject(item) && "label" in item ? item.label : item;
}
function getRowKey(input, index) {
  return is14.string(input.id) || is14.number(input.id) ? input.id : index;
}
function sortData(data, sortBy, sortDirection) {
  if (!sortBy) {
    return data;
  }
  return [...data].sort((a, b) => {
    const leftValue = a[sortBy];
    const rightValue = b[sortBy];
    const left = is14.plainObject(leftValue) && "value" in leftValue ? leftValue.value : innerText5(leftValue);
    const right = is14.plainObject(rightValue) && "value" in rightValue ? rightValue.value : innerText5(rightValue);
    if (sortDirection === "desc") {
      return right.toLowerCase().localeCompare(left.toLowerCase(), void 0, { numeric: true });
    }
    return left.toLowerCase().localeCompare(right.toLowerCase(), void 0, { numeric: true });
  });
}
function useDataTable(props) {
  return useComponentProps(props, defaultProps27);
}

// src/components/DataTable/Body.tsx
import { jsx as jsx41, jsxs as jsxs19 } from "react/jsx-runtime";
function DataTableBody(props) {
  const {
    accent,
    clean,
    columns,
    data,
    getDataAttributes,
    isResponsive,
    loaderSize,
    loaderType,
    loading,
    sortColumn,
    theme
  } = props;
  const { darkMode: darkMode2, zIndex: zIndex2 } = theme;
  const isInitialLoad = loading && !data.length;
  return /* @__PURE__ */ jsxs19(
    Box,
    {
      ...getDataAttributes("DataTableBody"),
      minHeight: 55,
      mt: !clean ? "sm" : void 0,
      pb: !clean ? "sm" : void 0,
      position: "relative",
      children: [
        data.map((item, index) => /* @__PURE__ */ jsx41(
          Box,
          {
            bg: darkMode2 ? "gray.900" : "white",
            border: isResponsive ? getBorder(darkMode2) : void 0,
            ...getDataAttributes("DataTableBodyRow"),
            display: "flex",
            mt: !clean && index > 0 ? "sm" : void 0,
            radius: clean ? void 0 : "xs",
            wrap: isResponsive ? "wrap" : "nowrap",
            children: columns.map(
              ({ hideOnResponsive, isAction, key, max, min, size, title }, columnIndex) => {
                let maxWidth = max ?? size;
                if (isResponsive && sortColumn === key) {
                  maxWidth = void 0;
                }
                return /* @__PURE__ */ jsxs19(
                  Box,
                  {
                    align: "flex-start",
                    border: clean && !isResponsive ? getBorder(darkMode2) : void 0,
                    ...getDataAttributes("DataTableBodyColumn"),
                    direction: "column",
                    display: "flex",
                    flex: "grow",
                    maxWidth,
                    minWidth: min ?? size,
                    order: isAction ? 1 : columnIndex + 1,
                    px: clean ? "sm" : "md",
                    py: clean ? "sm" : "md",
                    wrap: "wrap",
                    children: [
                      isResponsive && !hideOnResponsive && /* @__PURE__ */ jsx41(
                        Paragraph,
                        {
                          color: "gray",
                          mb: "xxs",
                          size: "xs",
                          style: { textTransform: "uppercase" },
                          children: title
                        }
                      ),
                      getRowContent(item, key)
                    ]
                  },
                  key
                );
              }
            )
          },
          getRowKey(item, index)
        )),
        loading && /* @__PURE__ */ jsx41(
          FlexCenter,
          {
            bg: !isInitialLoad ? "rgba(200, 200, 200, 0.5)" : void 0,
            bottom: 0,
            left: 0,
            pointerEvents: "fill",
            position: "absolute",
            right: 0,
            top: 0,
            zIndex: zIndex2.xxs,
            children: /* @__PURE__ */ jsx41(Loader, { color: accent, size: loaderSize, type: loaderType })
          }
        )
      ]
    }
  );
}
DataTableBody.displayName = "DataTableBody";
var Body_default = memo2(DataTableBody);

// src/components/DataTable/Head.tsx
import { memo as memo3 } from "react";
import { css as css35 } from "@emotion/react";
import styled38 from "@emotion/styled";
import { jsx as jsx42, jsxs as jsxs20 } from "react/jsx-runtime";
var Title = styled38(
  ButtonUnstyled,
  getStyledOptions()
)((props) => {
  const { disableSort, isDisabled } = props;
  return css35`
    align-items: center;
    display: flex;
    font-weight: 700;
    pointer-events: ${disableSort || isDisabled ? "none" : "all"};
  `;
});
function DataTableHead(props) {
  const {
    accent,
    clean,
    columns,
    getDataAttributes,
    isDisabled,
    isResponsive,
    onClick,
    sortBy,
    sortDirection,
    stickyHeader,
    theme: { black: black2, darkMode: darkMode2, white: white2, zIndex: zIndex2 }
  } = props;
  const color = darkMode2 ? white2 : black2;
  if (isResponsive) {
    return /* @__PURE__ */ jsx42(Flex, { justify: "end", children: /* @__PURE__ */ jsx42(
      Menu,
      {
        button: /* @__PURE__ */ jsx42(Icon, { name: "sort", size: 24, title: null }),
        labels: { close: "Close sort", name: "Sort menu", open: "Open sort" },
        children: columns.filter((d) => !d.disableSort).map(({ key, title }) => /* @__PURE__ */ jsx42(MenuItem, { accent: "white", disableHover: true, children: /* @__PURE__ */ jsxs20(Flex, { flex: true, justify: "space-between", children: [
          title,
          /* @__PURE__ */ jsxs20(Flex, { children: [
            /* @__PURE__ */ jsx42(
              ButtonUnstyled,
              {
                "aria-label": `Sort by ${title} - asc`,
                "data-direction": "desc",
                "data-name": key,
                onClick,
                children: /* @__PURE__ */ jsx42(
                  Icon,
                  {
                    color: key === sortBy && sortDirection === "asc" ? accent : color,
                    name: "sort-asc",
                    size: 20
                  }
                )
              }
            ),
            /* @__PURE__ */ jsx42(
              ButtonUnstyled,
              {
                "aria-label": `Sort by ${title} - desc`,
                "data-direction": "asc",
                "data-name": key,
                onClick,
                children: /* @__PURE__ */ jsx42(
                  Icon,
                  {
                    color: key === sortBy && sortDirection === "desc" ? accent : color,
                    name: "sort-desc",
                    size: 20
                  }
                )
              }
            )
          ] })
        ] }) }, key))
      }
    ) });
  }
  const wrapperProps = {
    bg: darkMode2 ? "gray.900" : "white",
    display: "flex",
    radius: !clean ? "xs" : void 0
  };
  if (stickyHeader) {
    wrapperProps.position = "sticky";
    wrapperProps.top = 0;
    wrapperProps.zIndex = zIndex2.xxs;
  }
  return /* @__PURE__ */ jsx42(Box, { ...getDataAttributes("DataTableHead"), ...wrapperProps, children: columns.map(({ disableSort, key, max, min, size, title }) => {
    let icon;
    if (!disableSort) {
      icon = /* @__PURE__ */ jsx42(Icon, { ml: "xxs", name: "sort", size: 20 });
      if (key === sortBy) {
        icon = sortDirection === "asc" ? /* @__PURE__ */ jsx42(Icon, { color: accent, ml: "xxs", name: "sort-asc", size: 20 }) : /* @__PURE__ */ jsx42(Icon, { color: accent, ml: "xxs", name: "sort-desc", size: 20 });
      }
    }
    return /* @__PURE__ */ jsx42(
      Box,
      {
        align: "center",
        ...getDataAttributes("DataTableHeadColumn"),
        direction: "row",
        flex: "grow",
        maxWidth: max ?? size,
        minWidth: min ?? size,
        my: "xs",
        px: clean ? "sm" : "md",
        children: title && /* @__PURE__ */ jsxs20(
          Title,
          {
            "data-direction": sortDirection,
            "data-name": key,
            disableSort,
            isDisabled,
            onClick,
            children: [
              title,
              icon
            ]
          }
        )
      },
      key
    );
  }) });
}
DataTableHead.displayName = "DataTableHead";
var Head_default = memo3(DataTableHead);

// src/components/DataTable/DataTable.tsx
import { jsx as jsx43, jsxs as jsxs21 } from "react/jsx-runtime";
function DataTable(props) {
  const {
    componentProps: {
      accent,
      bg,
      breakpoint,
      clean,
      columns,
      data,
      defaultSortColumn,
      defaultSortDirection,
      disableScroll,
      loaderSize,
      loaderType,
      loading,
      maxRows,
      noResults,
      onClickPage,
      onClickSort,
      pagination,
      radius: radius2,
      remote,
      responsive: responsive2,
      scrollDuration,
      scrollElement,
      scrollMargin,
      stickyHeader,
      width,
      ...rest
    },
    getDataAttributes
  } = useDataTable(props);
  const element = useRef8(null);
  const resizeTimeout = useRef8(null);
  const { darkMode: darkMode2 } = rest.theme;
  const [{ currentPage, isResponsive, sortBy, sortDirection }, setState] = useSetState({
    currentPage: 1,
    isResponsive: responsive2 && (width ?? window.innerWidth) < breakpoint,
    sortBy: defaultSortColumn ?? null,
    sortDirection: defaultSortDirection
  });
  useUpdateEffect2(() => {
    const minLength = currentPage * maxRows - maxRows;
    if (data.length < minLength) {
      setState({ currentPage: 1 });
    }
  }, [currentPage, data.length, maxRows, setState]);
  useMount(() => {
    const resizeHandler = () => {
      if (resizeTimeout.current) {
        window.clearTimeout(resizeTimeout.current);
      }
      resizeTimeout.current = window.setTimeout(() => {
        setState({ isResponsive: responsive2 && (width ?? window.innerWidth) < breakpoint });
      }, 250);
    };
    window.addEventListener("resize", resizeHandler);
    return () => {
      window.removeEventListener("resize", resizeHandler);
    };
  });
  const totalPages = Math.ceil(data.length / maxRows);
  const handleClickPage = (page) => {
    const scrollTarget = scrollElement ?? element.current;
    onClickPage?.(page, remote?.totalPages ?? totalPages);
    if (scrollTarget && !disableScroll) {
      scrollTo(scrollTarget.getBoundingClientRect().top - scrollMargin, { scrollDuration });
    }
    if (remote) {
      return;
    }
    setState({ currentPage: page });
  };
  const handleClickSort = useCallback8(
    (event) => {
      const { direction, name = "" } = event.currentTarget.dataset;
      const reverseDirection = direction === "asc" ? "desc" : "asc";
      const nextDirection = sortBy === name ? reverseDirection : "asc";
      const options = {
        sortBy: name,
        sortDirection: nextDirection
      };
      onClickSort?.(name, nextDirection);
      setState(options);
    },
    [onClickSort, setState, sortBy]
  );
  const isEmpty = !loading && !data.length;
  const rows = useMemo6(() => {
    return remote && !remote?.useInternalSorting || !sortBy ? data : sortData(data, sortBy, sortDirection);
  }, [data, remote, sortBy, sortDirection]);
  const body = useMemo6(() => {
    if (isEmpty) {
      return /* @__PURE__ */ jsx43(FlexCenter, { bg: "white", padding: "md", radius: "sm", width: "100%", children: noResults ?? /* @__PURE__ */ jsx43(Text, { bold: true, children: "Nothing found" }) });
    }
    return /* @__PURE__ */ jsx43(
      Body_default,
      {
        accent,
        clean,
        columns,
        data: rows.slice(maxRows * (currentPage - 1), maxRows * currentPage),
        getDataAttributes,
        isResponsive,
        loaderSize,
        loaderType,
        loading,
        sortColumn: defaultSortColumn,
        theme: rest.theme
      }
    );
  }, [
    accent,
    clean,
    columns,
    currentPage,
    defaultSortColumn,
    getDataAttributes,
    isEmpty,
    isResponsive,
    loaderSize,
    loaderType,
    loading,
    maxRows,
    noResults,
    rest.theme,
    rows
  ]);
  const styles2 = {
    bg
  };
  if (clean) {
    styles2.bg = darkMode2 ? "gray.900" : "white";
    styles2.pb = "sm";
  }
  if (!clean) {
    styles2.padding = "md";
    if (!bg) {
      styles2.bg = darkMode2 ? "gray.800" : "gray.50";
    }
  }
  return /* @__PURE__ */ jsxs21(
    Box,
    {
      ref: element,
      ...getDataAttributes("DataTable"),
      maxWidth: "100%",
      radius: !clean ? radius2 : void 0,
      width,
      ...styles2,
      ...rest,
      children: [
        /* @__PURE__ */ jsx43(
          Head_default,
          {
            accent,
            clean,
            columns,
            getDataAttributes,
            isDisabled: loading ?? isEmpty,
            isResponsive,
            onClick: handleClickSort,
            sortBy,
            sortDirection,
            stickyHeader,
            theme: rest.theme
          }
        ),
        body,
        pagination && /* @__PURE__ */ jsx43(Box, { border: clean ? getBorder(darkMode2) : void 0, pt: clean ? "sm" : void 0, children: /* @__PURE__ */ jsx43(
          Pagination,
          {
            accent,
            currentPage: remote?.currentPage ?? currentPage,
            onClick: handleClickPage,
            totalPages: remote?.totalPages ?? totalPages
          }
        ) })
      ]
    }
  );
}
DataTable.displayName = "DataTable";

// src/components/DatePicker/Range.tsx
import { useState as useState12 } from "react";
import { DayPicker } from "react-day-picker";
import styled40 from "@emotion/styled";
import { formatDateLocale, omit as omit16 } from "@gilbarbara/helpers";

// src/components/DatePicker/utils.tsx
import { css as css36 } from "@emotion/react";
import { textColor } from "colorizr";
import { isSameMonth } from "date-fns";
import is15 from "is-lite";
import { jsx as jsx44, jsxs as jsxs22 } from "react/jsx-runtime";
function getFooter(setter, label, apply) {
  if (!label && !apply) {
    return null;
  }
  return /* @__PURE__ */ jsxs22(
    Box,
    {
      align: "end",
      direction: "row",
      display: "flex",
      justify: apply ? "space-between" : "center",
      mt: "xs",
      children: [
        /* @__PURE__ */ jsx44(ButtonUnstyled, { onClick: () => setter(/* @__PURE__ */ new Date()), children: label }),
        apply
      ]
    }
  );
}
function getNumberOfMonths(fromDate, toDate) {
  if (fromDate && toDate) {
    const day1 = is15.date(fromDate) ? fromDate : new Date(fromDate);
    const day2 = is15.date(toDate) ? toDate : new Date(toDate);
    return isSameMonth(day1, day2) ? 1 : 2;
  }
  return 2;
}
function getPickerStyles(props) {
  const { accent = "primary", theme } = props;
  const { colors: colors2, darkMode: darkMode2, grayScale: grayScale2, spacing: spacing2, textColorOptions: textColorOptions2, typography: typography2, variants: variants2 } = theme;
  const className = "rdp";
  const colorMain = colors2[accent];
  const colorVariant = variants2[accent];
  const cellSize = "40px";
  const disabledDays = darkMode2 ? grayScale2["500"] : grayScale2["200"];
  return css36`
    ${getStyles(props)};

    /* Hide elements for devices that are not screen readers */

    .${className}-vhidden {
      -moz-appearance: none;
      -webkit-appearance: none;
      appearance: none;
      background: transparent;
      border: 0;
      box-sizing: border-box;
      clip: rect(1px, 1px, 1px, 1px) !important;
      height: 1px !important;
      margin: 0;
      overflow: hidden !important;
      padding: 0;
      position: absolute !important;
      top: 0;
      width: 1px !important;
    }

    /* Buttons */

    .${className}-button_reset {
      -moz-appearance: none;
      -webkit-appearance: none;
      appearance: none;
      background: none;
      color: inherit;
      cursor: default;
      font: inherit;
      margin: 0;
      outline: none;
      padding: 0;
      position: relative;
    }

    .${className}-button {
      border: 0;

      &[aria-disabled='true'] {
        color: ${disabledDays};
        pointer-events: none;
      }

      &:not([aria-disabled='true']) {
        cursor: pointer;
      }

      &:focus,
      &:active {
        background-color: ${darkMode2 ? colorVariant[300] : colorVariant["50"]};
      }

      &:hover:not([aria-disabled='true']) {
        background-color: ${darkMode2 ? colorVariant[300] : colorVariant[50]};
      }
    }

    .${className}-months {
      display: flex;
    }

    .${className}-month {
      margin: 0 ${spacing2.xs};

      &:first-of-type {
        margin-left: 0;
      }

      &:last-of-type {
        margin-right: 0;
      }
    }

    .${className}-table {
      border-collapse: collapse;
      margin: 0;
      max-width: calc(${cellSize} * 7);
    }

    .${className}-with_weeknumber .${className}-table {
      border-collapse: collapse;
      max-width: calc(${cellSize} * 8);
    }

    .${className}-caption {
      align-items: center;
      display: flex;
      justify-content: space-between;
      margin-bottom: ${spacing2.xs};
      padding: 0;
      text-align: left;
    }

    .${className}-multiple_months .${className}-caption {
      display: block;
      position: relative;
      text-align: center;
    }

    .${className}-caption_dropdowns {
      display: inline-flex;
      position: relative;
    }

    .${className}-caption_label {
      align-items: center;
      border: 0;
      color: currentColor;
      display: inline-flex;
      font-family: inherit;
      font-size: ${typography2.lg.fontSize};
      font-weight: normal;
      margin: 0;
      padding: 0 ${spacing2.xs};
      position: relative;
      white-space: nowrap;
      z-index: 1;
    }

    .${className}-nav {
      display: flex;
      white-space: nowrap;
    }

    .${className}-multiple_months .${className}-caption_start .${className}-nav {
      left: 0;
      position: absolute;
      top: 50%;
      transform: translateY(-50%);
    }

    .${className}-multiple_months .${className}-caption_end .${className}-nav {
      position: absolute;
      right: 0;
      top: 50%;
      transform: translateY(-50%);
    }

    .${className}-nav_button {
      align-items: center;
      display: inline-flex;
      height: 22px;
      justify-content: center;
      padding: 0;
      width: 22px;

      &:focus,
      &:active {
        background-color: transparent;
      }

      &:hover:not([aria-disabled='true']) {
        background-color: transparent;
      }
    }

    .${className}:not(.${className}-multiple_months) {
      .${className}-caption {
        justify-content: center;
        position: relative;
      }

      .${className}-nav {
        left: 0;
        position: absolute;
        top: 0;
        right: 0;
      }

      .${className}-nav_button_next {
        position: absolute;
        right: 0;
      }
    }

    /* ---------- */
    /* Dropdowns  */
    /* ---------- */

    .${className}-dropdown_year, .${className}-dropdown_month {
      align-items: center;
      display: inline-flex;
      position: relative;
    }

    .${className}-dropdown {
      appearance: none;
      background-color: transparent;
      border: none;
      bottom: 0;
      cursor: inherit;
      font-family: inherit;
      font-size: inherit;
      left: 0;
      line-height: inherit;
      margin: 0;
      opacity: 0;
      padding: 0;
      position: absolute;
      top: 0;
      width: 100%;
      z-index: 2;

      &[disabled] {
        color: unset;
        opacity: unset;
      }
    }

    .${className}-dropdown_icon {
      margin: 0 0 0 5px;
    }

    .${className}-head {
      border: 0;
    }

    .${className}-head_row, .${className}-row {
      height: 100%;
    }

    .${className}-head_cell {
      color: ${grayScale2["500"]};
      font-size: ${typography2.sm.fontSize};
      font-weight: normal;
      height: 24px;
      padding: 0;
      text-align: center;
      vertical-align: middle;
    }

    .${className}-tbody {
      border: 0;
    }

    .${className}-tfoot {
      margin: ${spacing2.xs};
    }

    .${className}-cell {
      height: ${cellSize};
      padding: 0;
      text-align: center;
      width: ${cellSize};
    }

    .${className}-weeknumber {
      font-size: ${typography2.sm.fontSize};
    }

    .${className}-weeknumber, .${className}-day {
      align-items: center;
      border-radius: 100%;
      border: 2px solid transparent;
      box-sizing: border-box;
      display: flex;
      height: ${cellSize};
      justify-content: center;
      margin: 0;
      max-width: ${cellSize};
      overflow: hidden;
      width: ${cellSize};
    }

    .${className}-day_today:not(.${className}-day_outside) {
      color: ${colorMain};
      font-weight: bold;
    }

    .${className}-day_range_middle {
      border-radius: 0;
      background-color: ${darkMode2 ? colorVariant[200] : colorVariant[50]} !important;
      color: ${variants2.gray["900"]} !important;
    }

    .${className}-day_selected:not([aria-disabled='true']),
    .${className}-day_selected:focus:not([aria-disabled='true']),
    .${className}-day_selected:active:not([aria-disabled='true']),
    .${className}-day_selected:hover:not([aria-disabled='true']) {
      background-color: ${colorMain};
      color: ${textColor(colorMain, textColorOptions2)};
    }

    .${className}-day_selected:focus:not([aria-disabled='true']) {
      border: 2px solid ${colorMain};
    }

    .${className}:not([dir='rtl']) {
      .${className}-day_range_start:not(.${className}-day_range_end) {
        border-bottom-right-radius: 0;
        border-top-right-radius: 0;
      }

      .${className}-day_range_end:not(.${className}-day_range_start) {
        border-bottom-left-radius: 0;
        border-top-left-radius: 0;
      }
    }

    .${className}[dir='rtl'] {
      .${className}-day_range_start:not(.${className}-day_range_end) {
        border-bottom-left-radius: 0;
        border-top-left-radius: 0;
      }

      .${className}-day_range_end:not(.${className}-day_range_start) {
        border-bottom-right-radius: 0;
        border-top-right-radius: 0;
      }
    }

    .${className}-day_range_end.${className}-day_range_start {
      border-radius: 100%;
    }
  `;
}
function getRange(fromDate, toDate) {
  const additionalProps = {};
  let dateStart;
  let dateEnd;
  if (fromDate) {
    dateStart = is15.date(fromDate) ? fromDate : new Date(fromDate);
    additionalProps.fromMonth = new Date(dateStart.getFullYear(), dateStart.getMonth());
    additionalProps.disabled = [
      {
        from: new Date(dateStart.getFullYear(), dateStart.getMonth(), 0),
        to: new Date(dateStart.getFullYear(), dateStart.getMonth(), dateStart.getDate())
      }
    ];
  }
  if (toDate) {
    dateEnd = is15.date(toDate) ? toDate : new Date(toDate);
    const disabledDays = [];
    disabledDays.push({
      from: new Date(dateEnd.getFullYear(), dateEnd.getMonth(), dateEnd.getDate()),
      to: new Date(dateEnd.getFullYear(), dateEnd.getMonth() + 1, 1)
    });
    if (dateStart && dateStart.getMonth() === dateEnd.getMonth()) {
      disabledDays.push({
        from: new Date(dateEnd.getFullYear(), dateEnd.getMonth() + 1, 0),
        to: new Date(dateEnd.getFullYear(), dateEnd.getMonth() + 2, 1)
      });
    }
    additionalProps.toMonth = new Date(dateEnd.getFullYear(), dateEnd.getMonth());
    additionalProps.disabled = is15.array(additionalProps.disabled) ? [...additionalProps.disabled, ...disabledDays] : disabledDays;
  }
  return additionalProps;
}

// src/components/Spacer/Spacer.tsx
import { Children as Children5, forwardRef as forwardRef17, isValidElement as isValidElement16 } from "react";
import { css as css37 } from "@emotion/react";
import styled39 from "@emotion/styled";
import { omit as omit15 } from "@gilbarbara/helpers";

// src/components/Spacer/useSpacer.ts
var defaultProps28 = {
  orientation: "horizontal",
  distribution: "start",
  gap: "sm",
  grow: false,
  reverse: false,
  shadow: false,
  verticalAlign: "center",
  wrap: true
};
function useSpacer(props) {
  return useComponentProps(props, defaultProps28);
}

// src/components/Spacer/Spacer.tsx
import { jsx as jsx45 } from "react/jsx-runtime";
var StyledSpacer = styled39(
  "div",
  getStyledOptions("fill")
)((props) => {
  const { distribution, gap, orientation, reverse, theme, verticalAlign, wrap } = props;
  const { spacing: spacing2 } = theme;
  const isHorizontal = orientation === "horizontal";
  const flexGap = Array.isArray(gap) ? gap.map((value) => spacing2[value]).join(" ") : spacing2[gap];
  let distributionStyles;
  if (distribution) {
    distributionStyles = css37`
      justify-content: ${isHorizontal ? distribution : verticalAlign};
    `;
  }
  return css37`
    align-items: ${isHorizontal ? verticalAlign : distribution};
    display: flex;
    flex-direction: ${isHorizontal ? `row${reverse ? "-reverse" : ""}` : `column${reverse ? "-reverse" : ""}`};
    flex-wrap: ${wrap ? "wrap" : "nowrap"};
    gap: ${flexGap};
    ${distributionStyles};
    ${getStyles(omit15(props, "gap", "wrap"))};
  `;
});
var StyledSpacerItem = styled39(
  "div",
  getStyledOptions("fill")
)((props) => {
  const { flex, grow: grow2, orientation } = props;
  const isHorizontal = orientation === "horizontal";
  return css37`
    display: ${isHorizontal ? "flex" : "block"};
    flex: ${flex};
    width: ${!isHorizontal && grow2 ? "100%" : "auto"};
  `;
});
var Spacer = forwardRef17((props, ref) => {
  const {
    componentProps: { children, ...rest },
    getDataAttributes
  } = useSpacer(props);
  const nodes = Children5.toArray(children).map((child, index) => {
    const key = `SpacerItem-${index}`;
    const flex = isValidElement16(child) ? child.props["data-flex"] : void 0;
    return /* @__PURE__ */ jsx45(StyledSpacerItem, { flex, ...rest, ...getDataAttributes("SpacerItem"), children: child }, key);
  });
  return /* @__PURE__ */ jsx45(StyledSpacer, { ref, ...getDataAttributes("Spacer"), ...rest, children: nodes });
});
Spacer.displayName = "Spacer";

// src/components/DatePicker/useDatePicker.ts
var baseProps = {
  accent: "primary",
  formatLocale: "en-US",
  currentMonthLabel: "Go to today"
};
var rangeDefaultProps = {
  ...baseProps,
  readOnly: false,
  showApply: false
};
var selectorDefaultProps = {
  ...baseProps,
  borderless: false,
  disabled: false,
  height: "md",
  mode: "single",
  position: "bottom-right",
  separator: " \u2014 ",
  showRangeApply: false,
  width: "auto"
};
var singleDefaultProps = {
  ...baseProps,
  readOnly: false
};
function useDatePicker(props, type) {
  return useComponentProps(props, type === "single" ? singleDefaultProps : rangeDefaultProps);
}
function useDatePickerSelector(props) {
  return useComponentProps(props, selectorDefaultProps);
}

// src/components/DatePicker/Range.tsx
import { jsx as jsx46, jsxs as jsxs23 } from "react/jsx-runtime";
var StyledDatePicker = styled40(
  "div",
  getStyledOptions("onApply")
)((props) => {
  return getPickerStyles(props);
});
function DatePickerRange(props) {
  const { componentProps, getDataAttributes } = useDatePicker(props, "range");
  const {
    accent,
    currentMonthLabel,
    formatLocale,
    fromDate,
    month,
    onApply,
    onChange,
    readOnly,
    selected,
    showApply,
    theme: { radius: radius2, spacing: spacing2 },
    toDate,
    ...rest
  } = componentProps;
  const [selectedDates, setSelectedDates] = useState12(
    selected
  );
  let initialDate;
  let endDate;
  if (selectedDates) {
    initialDate = selectedDates[0] ? new Date(selectedDates[0]) : void 0;
    endDate = selectedDates[1] ? new Date(selectedDates[1]) : void 0;
  }
  const [selectedMonth, setSelectedMonth] = useState12(month ?? initialDate);
  const handleClickSelect = (selectedRange) => {
    setSelectedDates([selectedRange?.from?.toISOString(), selectedRange?.to?.toISOString()]);
    onChange?.([
      selectedRange?.from?.toISOString() ?? void 0,
      selectedRange?.to?.toISOString() ?? void 0
    ]);
  };
  const handleClickApply = () => {
    onApply?.([selectedDates?.[0], selectedDates?.[1]]);
  };
  const handleClickReset = () => {
    setSelectedDates([void 0, void 0]);
    onChange?.([void 0, void 0]);
  };
  const modifiers = {
    from: initialDate ? new Date(initialDate) : false,
    to: endDate ? new Date(endDate) : false
  };
  const content = {
    header: /* @__PURE__ */ jsx46(Paragraph, { children: "Select the initial date" })
  };
  if (showApply) {
    content.footer = getFooter(
      setSelectedMonth,
      currentMonthLabel,
      /* @__PURE__ */ jsxs23(Spacer, { children: [
        /* @__PURE__ */ jsx46(
          Button,
          {
            bg: accent,
            disabled: !initialDate,
            onClick: handleClickReset,
            size: "sm",
            variant: "bordered",
            children: "Reset"
          }
        ),
        /* @__PURE__ */ jsx46(Button, { bg: accent, disabled: !endDate, onClick: handleClickApply, size: "sm", children: "Apply" })
      ] })
    );
  } else {
    content.footer = getFooter(setSelectedMonth, currentMonthLabel);
    content.reset = /* @__PURE__ */ jsx46(
      Button,
      {
        bg: accent,
        onClick: handleClickReset,
        size: "sm",
        style: {
          borderRadius: radius2.xs,
          minHeight: 24,
          padding: `${spacing2.xxs} ${spacing2.xs}`
        },
        variant: "bordered",
        children: "Reset"
      }
    );
  }
  if (initialDate && endDate) {
    content.header = /* @__PURE__ */ jsxs23(Spacer, { distribution: "center", children: [
      /* @__PURE__ */ jsxs23(Text, { children: [
        "From ",
        formatDateLocale(initialDate.toISOString(), { locale: formatLocale }),
        " to",
        " ",
        formatDateLocale(endDate.toISOString(), { locale: formatLocale })
      ] }),
      content.reset
    ] });
  } else if (initialDate) {
    content.header = /* @__PURE__ */ jsx46(Paragraph, { children: "Select the final date" });
  }
  return /* @__PURE__ */ jsxs23(
    StyledDatePicker,
    {
      ...getDataAttributes("DatePickerRange"),
      ...omit16(componentProps, "hidden", "onChange"),
      children: [
        /* @__PURE__ */ jsx46(FlexCenter, { mb: "md", minHeight: 30, children: content.header }),
        /* @__PURE__ */ jsx46(
          DayPicker,
          {
            mode: readOnly ? void 0 : "range",
            modifiers,
            month: selectedMonth,
            numberOfMonths: getNumberOfMonths(fromDate, toDate),
            onMonthChange: setSelectedMonth,
            onSelect: handleClickSelect,
            selected: { from: initialDate, to: endDate },
            ...getRange(fromDate, toDate),
            ...rest
          }
        ),
        content.footer
      ]
    }
  );
}
DatePickerRange.displayName = "DatePickerRange";

// src/components/DatePicker/Selector.tsx
import { useCallback as useCallback9, useEffect as useEffect7 } from "react";
import { css as css38 } from "@emotion/react";
import styled42 from "@emotion/styled";
import { formatDateLocale as formatDateLocale2, omit as omit18, px as px22 } from "@gilbarbara/helpers";
import { useSetState as useSetState2 } from "@gilbarbara/hooks";
import { opacify as opacify4 } from "colorizr";
import is16 from "is-lite";

// src/components/DatePicker/Single.tsx
import { useState as useState13 } from "react";
import { DayPicker as DayPicker2 } from "react-day-picker";
import styled41 from "@emotion/styled";
import { omit as omit17 } from "@gilbarbara/helpers";
import { jsx as jsx47 } from "react/jsx-runtime";
var StyledDatePicker2 = styled41(
  "div",
  getStyledOptions()
)((props) => {
  return getPickerStyles(props);
});
function DatePicker(props) {
  const { componentProps, getDataAttributes } = useDatePicker(props);
  const { currentMonthLabel, fromDate, month, onChange, readOnly, selected, toDate, ...rest } = componentProps;
  const [selectedDate, setSelectedDate] = useState13(selected);
  const selectedDateObject = selectedDate ? new Date(selectedDate) : void 0;
  const [selectedMonth, setSelectedMonth] = useState13(month ?? selectedDateObject);
  const handleSelect = (_day, selectedDay, modifiers) => {
    if (modifiers.disabled || modifiers.outside) {
      return;
    }
    let nextDate = selectedDay.toISOString();
    if (selectedDate && selectedDate === selectedDay.toISOString()) {
      nextDate = void 0;
    }
    setSelectedDate(nextDate);
    onChange?.(nextDate ? selectedDay.toISOString() : "");
  };
  return /* @__PURE__ */ jsx47(
    StyledDatePicker2,
    {
      ...getDataAttributes("DatePicker"),
      ...omit17(componentProps, "hidden", "onDayClick", "onChange"),
      children: /* @__PURE__ */ jsx47(
        DayPicker2,
        {
          footer: getFooter(setSelectedMonth, currentMonthLabel),
          mode: readOnly ? void 0 : "single",
          month: selectedMonth,
          onMonthChange: setSelectedMonth,
          onSelect: handleSelect,
          selected: selectedDateObject,
          ...getRange(fromDate, toDate),
          ...rest
        }
      )
    }
  );
}
DatePicker.displayName = "DatePicker";

// src/components/DatePicker/Selector.tsx
import { jsx as jsx48, jsxs as jsxs24 } from "react/jsx-runtime";
var StyledSelector = styled42("div", getStyledOptions())(
  {
    width: "auto"
  },
  (props) => {
    return css38`
      display: inline-flex;
      position: relative;
      ${dimensionStyles(props)};
      ${marginStyles(props)};
    `;
  }
);
var StyledButton2 = styled42("div", getStyledOptions())(
  {
    alignItems: "center",
    cursor: "pointer",
    display: "flex",
    justifyContent: "space-between",
    minWidth: "200px"
  },
  (props) => {
    const { accent, borderless, disabled, height, isActive, isFilled, theme } = props;
    const { darkColor: darkColor2, darkMode: darkMode2, grayScale: grayScale2, inputHeight: inputHeight2, lightColor: lightColor2, radius: radius2, spacing: spacing2, white: white2 } = theme;
    const { mainColor } = getColorTokens(accent, null, theme);
    let borderColor = darkMode2 ? grayScale2["700"] : grayScale2["500"];
    let textColor2 = grayScale2["500"];
    if (isFilled) {
      borderColor = mainColor;
      textColor2 = darkMode2 ? lightColor2 : darkColor2;
    }
    const styles2 = borderless ? css38`
          border-bottom: 1px solid ${borderColor};
          border-radius: 0 !important;
          padding: ${spacing2.xxs} 0;
        ` : css38`
          background-color: ${darkMode2 ? grayScale2["800"] : white2};
          border: 1px solid ${borderColor};
          border-radius: ${radius2.xs};
          padding-left: ${spacing2.md};
        `;
    return css38`
      color: ${textColor2};
      min-height: ${inputHeight2[height]};
      ${styles2};

      ${disabled && css38`
        ${getDisableStyles(props)}
        color: ${grayScale2["500"]};
      `};

      ${isActive && (borderless ? css38`
            box-shadow: 0 ${theme.outlineWidth} 0 0 ${opacify4(mainColor, theme.outlineOpacity)};
            outline: none;
          ` : getOutlineStyles(mainColor, theme))};
    `;
  }
);
var StyledContent2 = styled42("div", getStyledOptions())(
  {
    display: "flex",
    flexDirection: "column",
    justifyContent: "center",
    overflowY: "auto",
    position: "absolute",
    transition: "transform 0.3s"
  },
  (props) => {
    const { isActive, position, theme, wide } = props;
    const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2, shadow: shadow2, spacing: spacing2, white: white2, zIndex: zIndex2 } = theme;
    let left = position?.endsWith("left") ? 0 : "auto";
    let translateX = "";
    if (position?.endsWith("center")) {
      left = "50%";
      translateX = " translateX(-50%)";
    }
    return css38`
      background-color: ${darkMode2 ? grayScale2["800"] : white2};
      border-radius: ${radius2.xxs};
      bottom: ${position?.startsWith("bottom") ? "auto" : "100%"};
      box-shadow: ${shadow2.mid};
      left: ${left};
      margin-top: ${position?.startsWith("bottom") ? spacing2.xs : 0};
      margin-bottom: ${position?.startsWith("top") ? spacing2.xs : 0};
      min-width: ${px22(wide ? 600 : 300)};
      padding: ${spacing2.md};
      right: ${position?.endsWith("right") ? 0 : "auto"};
      top: ${position?.startsWith("top") ? "auto" : "100%"};
      transform: ${`scaleY(0)${translateX}`};
      transform-origin: ${position?.startsWith("bottom") ? "top" : "bottom"};
      z-index: ${zIndex2.md};

      ${isActive && css38`
        transform: ${`scaleY(1)${translateX}`};
      `}
    `;
  }
);
function DatePickerSelector(props) {
  const { componentProps, getDataAttributes } = useDatePickerSelector(props);
  const {
    borderless,
    disabled,
    formatLocale,
    fromDate,
    mode,
    name,
    onChange,
    open,
    placeholder,
    position,
    selected,
    separator,
    showRangeApply,
    theme,
    toDate
  } = componentProps;
  const [{ isActive, isFilled, selectedDates }, setState] = useSetState2({
    isActive: open ?? false,
    isFilled: false,
    selectedDates: mode === "range" ? selected ?? [void 0, void 0] : selected ?? ""
  });
  useEffect7(() => {
    if (mode === "range" && !is16.array(selectedDates)) {
      setState({ selectedDates: [void 0, void 0] });
    } else if (mode === "single" && is16.array(selectedDates)) {
      setState({ selectedDates: "" });
    }
  }, [mode, selectedDates, setState]);
  const isRange = mode === "range";
  const toggle = useCallback9(() => {
    if (is16.boolean(open) || disabled) {
      return;
    }
    setState((s) => ({ isActive: !s.isActive }));
  }, [disabled, open, setState]);
  const handleApply = (isoDate) => {
    if (onChange) {
      onChange(isoDate);
    }
    toggle();
  };
  const handleSelect = (isoDate) => {
    setState({
      isFilled: is16.array(isoDate) ? isoDate.some(Boolean) : !!isoDate,
      selectedDates: isoDate
    });
    if (onChange && !showRangeApply) {
      onChange(isoDate);
    }
    if (!showRangeApply && (is16.array(isoDate) && isoDate.every(Boolean) || !is16.array(isoDate) && isoDate)) {
      toggle();
    }
  };
  let picker;
  if (isRange) {
    const dates = is16.array(selectedDates) ? selectedDates : [void 0, void 0];
    picker = /* @__PURE__ */ jsx48(
      DatePickerRange,
      {
        ...componentProps,
        onApply: handleApply,
        onChange: handleSelect,
        selected: dates,
        showApply: showRangeApply
      }
    );
  } else {
    const date = is16.array(selectedDates) ? selectedDates[0] : selectedDates;
    picker = /* @__PURE__ */ jsx48(
      DatePicker,
      {
        ...componentProps,
        onChange: handleSelect,
        selected: date
      },
      mode
    );
  }
  let title = isRange ? "Select a date range" : "Select a date";
  if (placeholder) {
    title = placeholder;
  }
  if (is16.array(selectedDates) && selectedDates.some(Boolean)) {
    const dates = selectedDates.reduce((acc, d, index) => {
      acc.push(d ? formatDateLocale2(d, { locale: formatLocale }) : "???");
      if (index === 0) {
        acc.push(separator);
      }
      return acc;
    }, []);
    title = /* @__PURE__ */ jsx48(Text, { children: dates.map((d) => d) });
  } else if (!is16.array(selectedDates) && selectedDates) {
    title = formatDateLocale2(selectedDates, { locale: formatLocale });
  }
  const numberOfMonths = getNumberOfMonths(fromDate, toDate);
  return /* @__PURE__ */ jsx48(
    StyledSelector,
    {
      ...getDataAttributes("DatePickerSelector"),
      ...omit18(componentProps, "hidden", "onChange", "mode"),
      children: /* @__PURE__ */ jsxs24(ClickOutside, { active: isActive, onClick: toggle, children: [
        /* @__PURE__ */ jsxs24(
          StyledButton2,
          {
            ...getDataAttributes("DatePickerSelectorButton"),
            isActive,
            isFilled,
            onClick: toggle,
            ...omit18(componentProps, "hidden", "onChange", "mode"),
            children: [
              title,
              /* @__PURE__ */ jsx48(FlexCenter, { width: borderless ? void 0 : 40, children: /* @__PURE__ */ jsx48(Icon, { name: "calendar" }) })
            ]
          }
        ),
        /* @__PURE__ */ jsx48(
          StyledContent2,
          {
            ...getDataAttributes("DatePickerSelectorContent"),
            "data-state": isActive ? "open" : "closed",
            isActive,
            position,
            theme,
            wide: isRange && numberOfMonths > 1,
            children: picker
          }
        ),
        name && /* @__PURE__ */ jsx48(
          "input",
          {
            name,
            type: "hidden",
            value: is16.array(selectedDates) ? selectedDates.filter(Boolean).join(",") : selectedDates
          }
        )
      ] })
    },
    mode
  );
}
DatePickerSelector.displayName = "DatePickerSelector";

// src/components/Dialog/Dialog.tsx
import { isValidElement as isValidElement17 } from "react";
import { css as css41 } from "@emotion/react";
import styled51 from "@emotion/styled";
import { px as px24 } from "@gilbarbara/helpers";

// src/components/Headings/H1.tsx
import { forwardRef as forwardRef18 } from "react";
import styled43 from "@emotion/styled";

// src/components/Headings/useHeading.ts
import { css as css39 } from "@emotion/react";
import { omit as omit19 } from "@gilbarbara/helpers";
var defaultProps29 = {
  light: false
};
var jumboDefaultProps = {
  ...defaultProps29,
  large: false
};
function headingStyle(key, props) {
  const { light, theme } = props;
  const { fontFamily: fontFamily2, fontWeights: fontWeights2, typography: typography2 } = theme;
  const selected = typography2[key];
  return css39`
    font-family: ${fontFamily2};
    font-size: ${selected.fontSize};
    font-weight: ${light ? fontWeights2.normal : fontWeights2.bold};
    line-height: ${selected.lineHeight};
    margin-bottom: 0.5em;
    margin-top: 0;
    ${alignStyles(props)};
    ${getStyles(omit19(props, "align"))};
  `;
}
function useHeading(props, type) {
  return useComponentProps(props, type === "jumbo" ? jumboDefaultProps : defaultProps29);
}

// src/components/Headings/H1.tsx
import { jsx as jsx49 } from "react/jsx-runtime";
var StyledH1 = styled43(
  "h1",
  getStyledOptions()
)((props) => headingStyle("h1", props));
var H1 = forwardRef18((props, ref) => {
  const { componentProps, getDataAttributes } = useHeading(props);
  return /* @__PURE__ */ jsx49(StyledH1, { ref, ...getDataAttributes("H1"), ...componentProps });
});
H1.displayName = "H1";

// src/components/Headings/H2.tsx
import { forwardRef as forwardRef19 } from "react";
import styled44 from "@emotion/styled";
import { jsx as jsx50 } from "react/jsx-runtime";
var StyledH2 = styled44(
  "h2",
  getStyledOptions()
)((props) => {
  return headingStyle("h2", props);
});
var H2 = forwardRef19((props, ref) => {
  const { componentProps, getDataAttributes } = useHeading(props);
  return /* @__PURE__ */ jsx50(StyledH2, { ref, ...getDataAttributes("H2"), ...componentProps });
});
H2.displayName = "H2";

// src/components/Headings/H3.tsx
import { forwardRef as forwardRef20 } from "react";
import styled45 from "@emotion/styled";
import { jsx as jsx51 } from "react/jsx-runtime";
var StyledH3 = styled45(
  "h3",
  getStyledOptions()
)((props) => {
  return headingStyle("h3", props);
});
var H3 = forwardRef20((props, ref) => {
  const { componentProps, getDataAttributes } = useHeading(props);
  return /* @__PURE__ */ jsx51(StyledH3, { ref, ...getDataAttributes("H3"), ...componentProps });
});
H3.displayName = "H3";

// src/components/Headings/H4.tsx
import { forwardRef as forwardRef21 } from "react";
import styled46 from "@emotion/styled";
import { jsx as jsx52 } from "react/jsx-runtime";
var StyledH4 = styled46(
  "h4",
  getStyledOptions()
)((props) => {
  return headingStyle("h4", props);
});
var H4 = forwardRef21((props, ref) => {
  const { componentProps, getDataAttributes } = useHeading(props);
  return /* @__PURE__ */ jsx52(StyledH4, { ref, ...getDataAttributes("H4"), ...componentProps });
});
H4.displayName = "H4";

// src/components/Headings/H5.tsx
import { forwardRef as forwardRef22 } from "react";
import styled47 from "@emotion/styled";
import { jsx as jsx53 } from "react/jsx-runtime";
var StyledH5 = styled47(
  "h5",
  getStyledOptions()
)((props) => {
  return headingStyle("h5", props);
});
var H5 = forwardRef22((props, ref) => {
  const { componentProps, getDataAttributes } = useHeading(props);
  return /* @__PURE__ */ jsx53(StyledH5, { ref, ...getDataAttributes("H5"), ...componentProps });
});
H5.displayName = "H5";

// src/components/Headings/H6.tsx
import { forwardRef as forwardRef23 } from "react";
import styled48 from "@emotion/styled";
import { jsx as jsx54 } from "react/jsx-runtime";
var StyledH6 = styled48(
  "h6",
  getStyledOptions()
)((props) => headingStyle("h6", props));
var H6 = forwardRef23((props, ref) => {
  const { componentProps, getDataAttributes } = useHeading(props);
  return /* @__PURE__ */ jsx54(StyledH6, { ref, ...getDataAttributes("H6"), ...componentProps });
});
H6.displayName = "H6";

// src/components/Headings/Jumbo.tsx
import { forwardRef as forwardRef24 } from "react";
import styled49 from "@emotion/styled";
import { jsx as jsx55 } from "react/jsx-runtime";
var StyledJumbo = styled49(
  "h1",
  getStyledOptions()
)(
  (props) => headingStyle(props.large ? "jumboLarge" : "jumbo", props)
);
var Jumbo = forwardRef24((props, ref) => {
  const { componentProps, getDataAttributes } = useHeading(props, "jumbo");
  return /* @__PURE__ */ jsx55(StyledJumbo, { ref, ...getDataAttributes("Jumbo"), ...componentProps, ...props });
});
Jumbo.displayName = "Jumbo";

// src/components/Portal/Portal.tsx
import { useCallback as useCallback10, useEffect as useEffect8, useRef as useRef9 } from "react";
import { createPortal } from "react-dom";
import { css as css40 } from "@emotion/react";
import styled50 from "@emotion/styled";
import { px as px23 } from "@gilbarbara/helpers";
import { useMount as useMount2, usePrevious as usePrevious2, useSetState as useSetState3, useUpdateEffect as useUpdateEffect3 } from "@gilbarbara/hooks";
import { opacify as opacify5 } from "colorizr";

// src/components/Portal/usePortal.ts
var defaultProps30 = {
  animationEasing: "ease-in-out",
  animationEnterDuration: 0.5,
  animationExitDuration: 0.5,
  container: "body",
  disableAnimation: false,
  disableCloseOnClickOverlay: false,
  disableCloseOnEsc: false,
  hideOverlay: false,
  isOpen: false,
  overlayBlur: false,
  overlayBlurAmount: 8,
  overlayOpacity: 0.3,
  showCloseButton: false,
  zIndex: 100
};
var portalPropsKeys = {
  animationEasing: void 0,
  animationEnterDuration: void 0,
  animationExitDuration: void 0,
  container: void 0,
  disableAnimation: void 0,
  disableCloseOnClickOverlay: void 0,
  disableCloseOnEsc: void 0,
  hideOverlay: void 0,
  isOpen: void 0,
  onClose: void 0,
  onDismiss: void 0,
  onOpen: void 0,
  overlayBlur: void 0,
  overlayBlurAmount: void 0,
  overlayOpacity: void 0,
  showCloseButton: void 0,
  zIndex: void 0
};
function createPortalElement() {
  const newElement = document.createElement("div");
  newElement.classList.add("__portal");
  return newElement;
}
function getPortalElement() {
  return document.querySelector(".__portal");
}
function splitPortalProps(props) {
  const otherProps = {};
  const portalProps = {};
  Object.keys(props).forEach((key) => {
    if (key in portalPropsKeys) {
      portalProps[key] = props[key];
    } else {
      otherProps[key] = props[key];
    }
  });
  return [
    otherProps,
    portalProps
  ];
}
function usePortal(props) {
  return useComponentProps(props, defaultProps30);
}

// src/components/Portal/Portal.tsx
import { jsx as jsx56, jsxs as jsxs25 } from "react/jsx-runtime";
var StyledPortal = styled50.div(
  {
    alignItems: "center",
    bottom: 0,
    display: "flex",
    justifyContent: "center",
    left: 0,
    opacity: 0,
    position: "fixed",
    right: 0,
    top: 0,
    visibility: "hidden"
  },
  (props) => {
    const { isActive } = props;
    return css40`
      opacity: ${isActive ? 1 : 0};
      visibility: ${isActive ? "visible" : "hidden"};
      ${positioningStyles(props)};
    `;
  }
);
var Overlay = styled50.div((props) => {
  const {
    animationEasing,
    animationEnterDuration,
    animationExitDuration,
    bg,
    disableAnimation,
    isActive,
    overlayBlur,
    overlayBlurAmount,
    overlayOpacity,
    theme
  } = props;
  const { black: black2, darkMode: darkMode2, grayScale: grayScale2 } = theme;
  const animationDuration = isActive ? animationEnterDuration : animationExitDuration;
  let selectedBg = darkMode2 ? grayScale2["150"] : black2;
  if (bg) {
    const { mainColor } = getColorTokens(bg, void 0, theme);
    selectedBg = mainColor;
  }
  if (selectedBg !== "transparent") {
    selectedBg = opacify5(selectedBg, overlayOpacity);
  }
  return css40`
    background-color: ${selectedBg};
    ${overlayBlur && `backdrop-filter: blur(${px23(overlayBlurAmount)});`};
    opacity: ${isActive ? 1 : 0};
    bottom: 0;
    left: 0;
    position: absolute;
    right: 0;
    top: 0;
    ${!disableAnimation && `transition: opacity ${animationDuration}s ${animationEasing};`};
  `;
});
var Content2 = styled50.div((props) => {
  const {
    animationEasing,
    animationEnterDuration,
    animationExitDuration,
    disableAnimation,
    isActive
  } = props;
  const animationDuration = isActive ? animationEnterDuration : animationExitDuration;
  return css40`
    max-height: 100%;
    opacity: ${isActive ? 1 : 0};
    position: relative;
    ${!disableAnimation && `transition: opacity ${animationDuration}s ${animationEasing};`};
    width: auto;
    z-index: 10;
  `;
});
var CloseButton = styled50(ButtonUnstyled)`
  position: absolute;
  right: 0;
  top: 0;
  z-index: 20;
`;
function Portal(props) {
  const { componentProps, getDataAttributes } = usePortal(props);
  const {
    animationEasing,
    animationEnterDuration,
    animationExitDuration,
    children,
    container,
    disableAnimation,
    disableCloseOnClickOverlay,
    disableCloseOnEsc,
    hideOverlay,
    isOpen,
    onClose,
    onDismiss,
    onOpen,
    showCloseButton,
    theme,
    ...rest
  } = componentProps;
  const { dataAttributeName: dataAttributeName2 } = theme;
  const [{ isActive, isReady, isRendering }, setState] = useSetState3({
    isActive: isOpen,
    isReady: false,
    isRendering: false
  });
  const portal = useRef9(null);
  const shouldRender = isOpen || isActive || isRendering;
  const previousIsOpen = usePrevious2(isOpen);
  useMount2(() => {
    let portalElement = getPortalElement();
    if (!getPortalElement()) {
      portalElement = createPortalElement();
      const target = getElement(container) ?? document.body;
      target.appendChild(portalElement);
    }
    portal.current = portalElement;
    setState({ isReady: true });
  });
  useEffect8(() => {
    const handleKeyDown2 = (event) => {
      if (disableCloseOnEsc) {
        return;
      }
      if (event.code === "Escape") {
        event.stopPropagation();
        onDismiss();
      }
    };
    if (isActive) {
      document.addEventListener("keydown", handleKeyDown2, { passive: true });
    }
    return () => {
      document.removeEventListener("keydown", handleKeyDown2);
    };
  }, [disableCloseOnEsc, isActive, onDismiss]);
  const openPortal = useCallback10(() => {
    setState({ isActive: true, isRendering: true });
    setTimeout(
      () => {
        onOpen?.();
      },
      disableAnimation ? 0 : (animationEnterDuration + 0.1) * 1e3
    );
  }, [animationEnterDuration, disableAnimation, onOpen, setState]);
  const closePortal = useCallback10(() => {
    setState({ isActive: false });
    setTimeout(
      () => {
        setState({ isRendering: false });
        onClose?.();
      },
      disableAnimation ? 0 : (animationExitDuration + 0.2) * 1e3
    );
  }, [animationExitDuration, disableAnimation, onClose, setState]);
  useUpdateEffect3(() => {
    const hasChanged = previousIsOpen !== isOpen;
    if (!hasChanged) {
      return;
    }
    if (isOpen) {
      openPortal();
    } else if (!isOpen && isActive) {
      closePortal();
    }
  }, [closePortal, disableCloseOnEsc, isActive, isOpen, openPortal, previousIsOpen, setState]);
  const handleClickClose = useCallback10(
    (event) => {
      const { dataset } = event.currentTarget;
      if (dataset[convertKebabCaseToCamelCase(dataAttributeName2)] === "PortalOverlay" && disableCloseOnClickOverlay) {
        return;
      }
      onDismiss();
    },
    [dataAttributeName2, disableCloseOnClickOverlay, onDismiss]
  );
  if (!isReady || !portal.current) {
    return null;
  }
  const content = {};
  if (shouldRender) {
    content.main = /* @__PURE__ */ jsx56(
      Content2,
      {
        ...getDataAttributes("PortalContent"),
        animationEasing,
        animationEnterDuration,
        animationExitDuration,
        disableAnimation,
        isActive,
        children
      }
    );
    if (!hideOverlay) {
      content.overlay = /* @__PURE__ */ jsx56(
        Overlay,
        {
          ...getDataAttributes("PortalOverlay"),
          animationEasing,
          animationEnterDuration,
          animationExitDuration,
          disableAnimation,
          isActive,
          onClick: handleClickClose,
          theme,
          ...rest
        }
      );
    }
    if (showCloseButton) {
      content.closeButton = /* @__PURE__ */ jsx56(
        CloseButton,
        {
          ...getDataAttributes("PortalCloseButton"),
          onClick: handleClickClose,
          p: "xs",
          radius: "round",
          title: "Close",
          children: /* @__PURE__ */ jsx56(Icon, { name: "close-o", size: 24, title: "Close" })
        }
      );
    }
  }
  return createPortal(
    /* @__PURE__ */ jsxs25(
      StyledPortal,
      {
        ...getDataAttributes("Portal"),
        "data-open": isOpen,
        isActive: shouldRender,
        ...rest,
        children: [
          content.overlay,
          content.closeButton,
          content.main
        ]
      }
    ),
    portal.current
  );
}
Portal.displayName = "Portal";

// src/components/Dialog/useDialog.ts
var defaultProps31 = {
  ...defaultProps30,
  accent: "primary",
  buttonCancelText: "Cancel",
  buttonConfirmText: "Confirm",
  buttonOrder: "ltr",
  padding: "xl",
  radius: "lg",
  shadow: "high",
  textAlign: "left",
  width: 380
};
function useDialog(props) {
  const { componentProps, getDataAttributes } = useComponentProps(props, defaultProps31);
  const [dialogProps, portalProps] = splitPortalProps(componentProps);
  return { dialogProps, portalProps, getDataAttributes };
}

// src/components/Dialog/Dialog.tsx
import { jsx as jsx57, jsxs as jsxs26 } from "react/jsx-runtime";
var StyledDialog = styled51(
  "div",
  getStyledOptions()
)((props) => {
  const { textAlign, theme, width } = props;
  const { black: black2, darkColor: darkColor2, darkMode: darkMode2, white: white2 } = theme;
  return css41`
    background-color: ${darkMode2 ? darkColor2 : white2};
    color: ${darkMode2 ? white2 : black2};
    max-width: 100%;
    text-align: ${textAlign};
    width: ${px24(width)};
    ${getStyles(props)};
  `;
});
function Dialog(props) {
  const { dialogProps, getDataAttributes, portalProps } = useDialog(props);
  const {
    accent,
    buttonCancelText,
    buttonConfirmText,
    buttonOrder,
    content,
    onClickCancel,
    onClickConfirmation,
    style,
    title,
    ...rest
  } = dialogProps;
  const actionButton = /* @__PURE__ */ jsx57(Button, { bg: accent, onClick: onClickConfirmation, children: buttonConfirmText });
  const cancelButton = /* @__PURE__ */ jsx57(Button, { bg: accent, onClick: onClickCancel, variant: "bordered", children: buttonCancelText });
  return /* @__PURE__ */ jsx57(Portal, { ...portalProps, showCloseButton: false, children: /* @__PURE__ */ jsxs26(
    StyledDialog,
    {
      ...getDataAttributes("Dialog"),
      "data-open": portalProps.isOpen,
      style,
      ...rest,
      children: [
        /* @__PURE__ */ jsx57(Box, { mb: "sm", ...getDataAttributes("DialogTitle"), children: title && isValidElement17(title) ? title : /* @__PURE__ */ jsx57(H3, { mb: 0, children: title }) }),
        /* @__PURE__ */ jsx57(Paragraph, { mb: "xl", children: content }),
        /* @__PURE__ */ jsxs26(Spacer, { distribution: "space-between", reverse: buttonOrder === "rtl", children: [
          cancelButton,
          actionButton
        ] })
      ]
    }
  ) });
}
Dialog.displayName = "Dialog";

// src/components/Dropdown/Dropdown.tsx
import { useState as useState14 } from "react";
import { css as css44 } from "@emotion/react";
import styled55 from "@emotion/styled";
import { px as px25 } from "@gilbarbara/helpers";
import ReactDropdown from "@gilbarbara/react-dropdown";
import { opacify as opacify6 } from "colorizr";

// src/components/Dropdown/Content.tsx
import { css as css42 } from "@emotion/react";
import styled52 from "@emotion/styled";
import { jsx as jsx58, jsxs as jsxs27 } from "react/jsx-runtime";
var StyledContent3 = styled52("div", getStyledOptions())`
  align-items: center;
  display: flex;
  flex-wrap: wrap;
  width: 100%;
`;
var Item = styled52(
  "div",
  getStyledOptions()
)((props) => {
  const { color, multi, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2, spacing: spacing2, white: white2 } = theme;
  let multiStyles;
  if (multi) {
    multiStyles = css42`
      border: 1px solid ${color};
      border-radius: ${radius2.xxs};
      background-color: ${darkMode2 ? grayScale2["700"] : white2};
      margin-bottom: ${spacing2.xxs};
      margin-right: ${spacing2.xs};
      margin-top: ${spacing2.xxs};
      padding: 3px 6px;
    `;
  }
  return css42`
    align-items: center;
    display: flex;
    line-height: 1;
    ${multiStyles};
  `;
});
var ItemClose = styled52(
  "span",
  getStyledOptions()
)((props) => {
  const { spacing: spacing2 } = props.theme;
  return css42`
    display: inline-flex;
    line-height: 1;
    margin-left: ${spacing2.xxs};
  `;
});
var Placeholder = styled52(
  "div",
  getStyledOptions()
)((props) => {
  const { grayScale: grayScale2 } = props.theme;
  return css42`
    align-items: center;
    color: ${grayScale2["500"]};
    display: flex;
  `;
});
function DropdownContent(props) {
  const {
    methods: { getStyles: getStyles2, removeItem },
    props: { multi, placeholder },
    state: { values }
  } = props;
  const { getDataAttributes, theme } = useTheme();
  const handleClickRemove = (value) => {
    return (event) => {
      event.stopPropagation();
      removeItem(null, value, true);
    };
  };
  if (values.length) {
    return /* @__PURE__ */ jsx58(StyledContent3, { children: values.map((item) => {
      const { label, prefix, suffix, value } = item || {};
      return /* @__PURE__ */ jsxs27(
        Item,
        {
          color: getStyles2().color,
          ...getDataAttributes("ContentItem"),
          multi,
          theme,
          children: [
            !!prefix && /* @__PURE__ */ jsx58(FlexInline, { ...getDataAttributes("ContentItemPrefix"), mr: "xxs", children: prefix }),
            /* @__PURE__ */ jsx58("span", { children: label ?? value }),
            !!suffix && /* @__PURE__ */ jsx58(FlexInline, { ...getDataAttributes("ContentItemSuffix"), ml: "xxs", children: suffix }),
            multi && /* @__PURE__ */ jsx58(ItemClose, { onClick: handleClickRemove(item), theme, children: /* @__PURE__ */ jsx58(Icon, { name: "close" }) })
          ]
        },
        value
      );
    }) });
  }
  return /* @__PURE__ */ jsx58(Placeholder, { theme, children: placeholder });
}
DropdownContent.displayName = "DropdownContent";
var Content_default = DropdownContent;

// src/components/Dropdown/Items.tsx
import { useEffect as useEffect9, useRef as useRef10 } from "react";
import { css as css43 } from "@emotion/react";
import styled54 from "@emotion/styled";

// src/components/Dropdown/Add.tsx
import styled53 from "@emotion/styled";
import { jsx as jsx59 } from "react/jsx-runtime";
var StyledDropdownAdd = styled53.div`
  width: 100%;

  button {
    display: flex;
    justify-content: center;
    padding: 8px;
    width: 100%;
  }
`;
function DropdownAdd(props) {
  const {
    accent = "primary",
    methods: { getLabels, setStatus },
    onCreate,
    state: { search }
  } = props;
  const { getDataAttributes, theme } = useTheme();
  const handleClick = () => {
    onCreate?.(search, () => setStatus("close"));
  };
  return /* @__PURE__ */ jsx59(StyledDropdownAdd, { ...getDataAttributes("DropdownAdd"), theme, children: /* @__PURE__ */ jsx59(ButtonUnstyled, { color: accent, onClick: handleClick, children: getLabels().create.replace(/{search}/, `"${search}"`) }) });
}
DropdownAdd.displayName = "DropdownAdd";
var Add_default = DropdownAdd;

// src/components/Dropdown/Items.tsx
import { jsx as jsx60, jsxs as jsxs28 } from "react/jsx-runtime";
var getSharedStyles = (spacing2) => css43`
  align-items: center;
  display: flex;
  padding: ${spacing2.xs} ${spacing2.sm};
  width: 100%;
`;
var Centered = styled54(
  "div",
  getStyledOptions()
)((props) => {
  const { theme, withBorder } = props;
  const { grayScale: grayScale2, spacing: spacing2 } = theme;
  return css43`
    ${getSharedStyles(spacing2)};
    border-top: ${withBorder ? `1px solid ${grayScale2["200"]}` : 0};
    justify-content: center;
    padding: 0;
  `;
});
var Empty = styled54(
  "div",
  getStyledOptions()
)((props) => {
  const { spacing: spacing2 } = props.theme;
  return css43`
    ${getSharedStyles(spacing2)};
    justify-content: center;
  `;
});
var Input = styled54(
  "input",
  getStyledOptions()
)((props) => {
  const { accent = "primary", theme } = props;
  const { radius: radius2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  return css43`
    border-radius: ${radius2.xs};

    :focus {
      filter: drop-shadow(0 0 2px ${mainColor});
      outline: none;
    }
  `;
});
var Item2 = styled54(
  "div",
  getStyledOptions()
)((props) => {
  const { accent = "primary", disabled, hovered, selected, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, spacing: spacing2, white: white2 } = theme;
  const { mainColor, textColor: textColor2 } = getColorTokens(accent, null, theme);
  const { mainColor: bgHoverLight, textColor: colorHoverLight } = getColorTokens(
    `${accent}.50`,
    null,
    theme
  );
  const { mainColor: bgHoverDark, textColor: colorHoverDark } = getColorTokens(
    `${accent}.800`,
    null,
    theme
  );
  let itemBgColor = darkMode2 ? grayScale2["800"] : white2;
  let itemColor = darkMode2 ? grayScale2["100"] : grayScale2["800"];
  const bgHover = darkMode2 ? bgHoverDark : bgHoverLight;
  const colorHover = darkMode2 ? colorHoverDark : colorHoverLight;
  if (disabled) {
    itemBgColor = darkMode2 ? grayScale2["700"] : grayScale2["40"];
    itemColor = darkMode2 ? grayScale2["200"] : grayScale2["500"];
  }
  return css43`
    ${getSharedStyles(spacing2)};
    background-color: ${itemBgColor};
    color: ${itemColor};
    cursor: pointer;
    pointer-events: ${disabled ? "none" : void 0};
    ${selected && css43`
      background-color: ${mainColor};
      color: ${textColor2};
    `};
    ${hovered && !disabled && css43`
      background-color: ${bgHover};
      color: ${colorHover};
    `};

    &:hover {
      background-color: ${bgHover};
      color: ${colorHover};
    }
  `;
});
var List = styled54(
  "div",
  getStyledOptions()
)((props) => {
  const { maxHeight, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, white: white2 } = theme;
  return css43`
    background-color: ${darkMode2 ? grayScale2["800"] : white2};
    color: ${darkMode2 ? grayScale2["200"] : grayScale2["700"]};
    cursor: default;
    max-height: ${maxHeight ?? "none"};
    overflow-y: auto;
  `;
});
var Items = styled54(
  "div",
  getStyledOptions()
)((props) => {
  const { darkMode: darkMode2, grayScale: grayScale2, white: white2 } = props.theme;
  return css43`
    background-color: ${darkMode2 ? grayScale2["800"] : white2};
    color: ${darkMode2 ? grayScale2["200"] : grayScale2["700"]};
  `;
});
var Search = styled54(
  "div",
  getStyledOptions()
)((props) => {
  const { darkColor: darkColor2, darkMode: darkMode2, grayScale: grayScale2, lightColor: lightColor2, spacing: spacing2, typography: typography2, white: white2 } = props.theme;
  return css43`
    ${getSharedStyles(spacing2)};
    background-color: ${darkMode2 ? grayScale2["800"] : white2};
    padding: ${spacing2.sm};
    position: sticky;
    top: 0;

    input {
      background-color: ${darkMode2 ? grayScale2["800"] : white2};
      border: 1px solid ${darkMode2 ? grayScale2["500"] : grayScale2["200"]};
      color: ${darkMode2 ? lightColor2 : darkColor2};
      font-size: ${typography2.md.fontSize};
      line-height: 1.6;
      padding: ${spacing2.xxs} ${spacing2.sm};
      width: 100%;
    }
  `;
});
function DropdownItems({ accent, methods, onCreate, onSearch, props, state }) {
  const { addItem, getLabels, getStyles: getStyles2, removeItem, setSearch } = methods;
  const { autoFocus, create, options, searchable } = props;
  const { cursor, search, values } = state;
  const { getDataAttributes, theme } = useTheme();
  const searchInput = useRef10(null);
  let children;
  if (create) {
    children = /* @__PURE__ */ jsx60(
      Add_default,
      {
        accent,
        methods,
        onCreate,
        props,
        state,
        theme
      }
    );
  }
  const regexp = new RegExp(search.replace(/[$()*+.?[\\\]^{|}]/g, "\\$&"), "i");
  useEffect9(() => {
    const { current } = searchInput;
    if (current && autoFocus) {
      current.focus();
    }
  }, [autoFocus]);
  const handleSearch = (event) => {
    const { value } = event.target;
    setSearch(event);
    onSearch?.(value);
  };
  const availableOptions = options.filter((item) => regexp.test(`${item.label ?? item.value}`)).map((option, index) => {
    const { disabled, label, prefix, suffix, value } = option;
    const isSelected = values.includes(option);
    const isHovered = cursor === index;
    return /* @__PURE__ */ jsxs28(
      Item2,
      {
        accent,
        ...getDataAttributes("DropdownItem"),
        disabled,
        hovered: isHovered,
        onClick: () => isSelected ? removeItem(null, option, false) : addItem(option),
        role: "listitem",
        selected: isSelected,
        theme,
        children: [
          prefix && /* @__PURE__ */ jsx60(FlexInline, { ...getDataAttributes("DropdownOptionPrefix"), mr: "xxs", children: prefix }),
          /* @__PURE__ */ jsx60(FlexInline, { flex: "grow", children: label ?? value }),
          suffix && /* @__PURE__ */ jsx60(FlexInline, { ...getDataAttributes("DropdownOptionSuffix"), ml: "xxs", children: suffix })
        ]
      },
      option.value
    );
  });
  const output = {
    options: availableOptions
  };
  if (children && !availableOptions.length) {
    output.create = /* @__PURE__ */ jsx60(Centered, { theme, withBorder: !!availableOptions.length, children });
  }
  if (!children && !availableOptions.length) {
    output.options = /* @__PURE__ */ jsx60(Empty, { theme, children: getLabels().noData });
  }
  return /* @__PURE__ */ jsxs28(
    List,
    {
      ...getDataAttributes("DropdownItems"),
      maxHeight: getStyles2().menuMaxHeight,
      theme,
      children: [
        searchable && /* @__PURE__ */ jsx60(Search, { ...getDataAttributes("DropdownItemsSearch"), theme, children: /* @__PURE__ */ jsx60(
          Input,
          {
            ref: searchInput,
            accent,
            onChange: handleSearch,
            theme,
            type: "text",
            value: search
          }
        ) }),
        /* @__PURE__ */ jsx60(Items, { ...getDataAttributes("DropdownItemsList"), theme, children: output.options }),
        output.create
      ]
    }
  );
}
DropdownItems.displayName = "DropdownItems";
var Items_default = DropdownItems;

// src/components/Dropdown/useDropdown.ts
var defaultProps32 = {
  accent: "primary",
  allowCreate: false,
  autoFocus: false,
  borderless: false,
  closeOnScroll: false,
  closeMultiOnSelect: false,
  direction: "ltr",
  disabled: false,
  height: "md",
  keepSelectedInList: true,
  labels: {
    create: "Create {search}",
    noData: "Nothing found"
  },
  loading: false,
  menuMaxHeight: 260,
  multi: false,
  placeholder: "Select an option",
  searchBy: "label",
  searchable: true,
  showClearButton: false,
  showSeparator: false,
  width: 260
};
function useDropdown(props) {
  return useComponentProps(props, defaultProps32);
}

// src/components/Dropdown/Dropdown.tsx
import { jsx as jsx61 } from "react/jsx-runtime";
var StyledDropdown = styled55(
  "div",
  getStyledOptions("placeholder", "onSearch")
)((props) => {
  const { accent, borderless, isFilled, multi, theme, width } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2, spacing: spacing2, white: white2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  let borderColor = darkMode2 ? grayScale2["700"] : grayScale2["500"];
  if (isFilled) {
    borderColor = mainColor;
  }
  const styles2 = borderless ? css44`
        border: 0 !important;
        border-bottom: 1px solid ${borderColor} !important;
        border-radius: 0 !important;
        padding: 0 !important;
      ` : css44`
        background-color: ${darkMode2 ? grayScale2["800"] : white2};
        border: 1px solid ${borderColor};
        border-radius: ${radius2.xs};
        padding-left: ${multi ? 0 : spacing2.xs} !important;
      `;
  return css44`
    min-width: ${px25(width ?? 260)};
    width: ${px25(width) ?? "auto"};
    ${marginStyles(props)};

    .react-dropdown {
      background-color: transparent;
      ${styles2};

      &:focus,
      &:focus-within {
        ${borderless ? css44`
              box-shadow: 0 3px 0 0 ${opacify6(mainColor, 0.5)};
            ` : getOutlineStyles(mainColor, theme)};

        .react-dropdown-separator {
          background-color: ${mainColor};
        }
      }

      &[disabled] {
        opacity: 1 !important;
        ${getDisableStyles(props)};

        .react-dropdown-content {
          color: ${grayScale2["500"]};
        }
      }

      &-clear {
        &:hover {
          color: ${theme.colors.red};
        }
      }

      &-content {
        align-items: center;
        width: calc(100% - 16px);

        span {
          max-width: 100%;

          + input {
            margin-left: 5px;
          }
        }
      }

      &-menu {
        border: 0 !important;
        border-radius: ${radius2.xs};
        overflow: hidden;
        width: 100% !important;
        z-index: 100;

        &:empty {
          display: none;
        }
      }

      &-loading {
        padding: 0 ${spacing2.xs};

        &:after {
          margin: 0;
        }
      }

      &-separator {
        background-color: ${borderColor};
      }
    }
  `;
});
function getDropdownComponent(props) {
  return function DropdownRenderer(renderer) {
    return /* @__PURE__ */ jsx61(Items_default, { ...renderer, ...props });
  };
}
function Dropdown(props) {
  const { componentProps, getDataAttributes } = useDropdown(props);
  const {
    allowCreate,
    closeMultiOnSelect,
    height = "md",
    inputOptions,
    items,
    menuMaxHeight = 260,
    onChange,
    onClear,
    open,
    showClearButton,
    values = [],
    ...rest
  } = componentProps;
  const { darkMode: darkMode2, grayScale: grayScale2, inputHeight: inputHeight2, white: white2 } = rest.theme;
  const [isFilled, setFilled] = useState14(!!values.length);
  const { mainColor } = getColorTokens(rest.accent ?? "primary", null, rest.theme);
  const handleChange = (value) => {
    setFilled(!!value.length);
    onChange?.(value);
  };
  return /* @__PURE__ */ jsx61(StyledDropdown, { ...getDataAttributes("DropdownWrapper"), isFilled, ...rest, children: /* @__PURE__ */ jsx61(
    ReactDropdown,
    {
      closeOnSelect: closeMultiOnSelect,
      contentComponent: Content_default,
      create: allowCreate,
      hiddenInput: inputOptions,
      menuComponent: getDropdownComponent({ allowCreate, ...rest }),
      onChange: handleChange,
      onClearAll: onClear,
      open,
      options: items,
      showClearButton,
      styles: {
        bgColor: darkMode2 ? grayScale2["700"] : white2,
        color: mainColor,
        gap: 0,
        minHeight: parseInt(inputHeight2[height], 10),
        menuMaxHeight,
        width: rest.width
      },
      values,
      ...rest
    }
  ) });
}
Dropdown.displayName = "Dropdown";

// src/components/Emoji/Emoji.tsx
import { forwardRef as forwardRef25 } from "react";
import innerText6 from "react-innertext";
import { css as css45 } from "@emotion/react";
import styled56 from "@emotion/styled";
import { omit as omit20, px as px26 } from "@gilbarbara/helpers";

// src/components/Emoji/useEmoji.ts
function useEmoji(props) {
  return useComponentProps(props);
}

// src/components/Emoji/Emoji.tsx
import { jsx as jsx62 } from "react/jsx-runtime";
var StyledEmoji = styled56(
  "span",
  getStyledOptions()
)((props) => {
  const { size } = props;
  return css45`
    display: inline-flex;
    line-height: 1;
    ${getStyles(omit20(props, "size"))};

    ${size && css45`
      font-size: ${px26(size)};
      height: ${px26(size)};
      width: ${px26(size)};
    `};
  `;
});
var Emoji = forwardRef25((props, ref) => {
  const { componentProps, getDataAttributes } = useEmoji(props);
  const { label, size, symbol, theme } = componentProps;
  return /* @__PURE__ */ jsx62(
    StyledEmoji,
    {
      ref,
      "aria-hidden": label ? "false" : "true",
      "aria-label": label ? innerText6(label) : "",
      ...getDataAttributes("Emoji"),
      size,
      theme,
      children: symbol
    }
  );
});
Emoji.displayName = "Emoji";

// src/components/Field/Field.tsx
import { useMemo as useMemo7 } from "react";
import { useFormContext, useWatch } from "react-hook-form";
import { useSetState as useSetState4, useUnmount } from "@gilbarbara/hooks";

// src/components/FormGroup/FormGroup.tsx
import { forwardRef as forwardRef28 } from "react";
import { css as css48 } from "@emotion/react";
import styled59 from "@emotion/styled";
import is19 from "is-lite";

// src/components/FormElementWrapper/FormElementWrapper.tsx
import { forwardRef as forwardRef26 } from "react";
import { css as css46 } from "@emotion/react";
import styled57 from "@emotion/styled";
import { px as px27 } from "@gilbarbara/helpers";
import is17 from "is-lite";

// src/components/FormElementWrapper/useFormElementWrapper.ts
var defaultProps33 = {
  size: 40,
  width: "100%"
};
function useFormElementWrapper(props) {
  return useComponentProps(props, defaultProps33);
}

// src/components/FormElementWrapper/FormElementWrapper.tsx
import { jsx as jsx63, jsxs as jsxs29 } from "react/jsx-runtime";
var StyledFormElementWrapper = styled57(
  "div",
  getStyledOptions()
)((props) => {
  const { width } = props;
  return css46`
    position: relative;
    width: ${px27(width)};
    ${marginStyles(props)};
  `;
});
var FormElementWrapper = forwardRef26(
  (props, ref) => {
    const { componentProps, getDataAttributes } = useFormElementWrapper(props);
    const { children, endContent, size, startContent, ...rest } = componentProps;
    const content = {};
    const [width, height] = is17.array(size) ? size : [size, size];
    if (startContent) {
      content.startContent = /* @__PURE__ */ jsx63(
        FlexCenter,
        {
          ...getDataAttributes("FormElementWrapperStartContent"),
          bottom: 0,
          height,
          left: 0,
          position: "absolute",
          top: 0,
          width,
          children: startContent
        }
      );
    }
    if (endContent) {
      content.endContent = /* @__PURE__ */ jsx63(
        FlexCenter,
        {
          ...getDataAttributes("FormElementWrapperEndContent"),
          bottom: 0,
          height,
          position: "absolute",
          right: 0,
          top: 0,
          width,
          children: endContent
        }
      );
    }
    return /* @__PURE__ */ jsxs29(StyledFormElementWrapper, { ref, ...getDataAttributes("FormElementWrapper"), ...rest, children: [
      content.startContent,
      children,
      content.endContent
    ] });
  }
);
FormElementWrapper.displayName = "FormElementWrapper";

// src/components/Label/Label.tsx
import { forwardRef as forwardRef27 } from "react";
import { css as css47 } from "@emotion/react";
import styled58 from "@emotion/styled";
import is18 from "is-lite";

// src/components/Label/useLabel.ts
var defaultProps34 = {
  ...textDefaultOptions,
  bold: true,
  inline: false
};
function useLabel(props) {
  return useComponentProps(props, defaultProps34);
}

// src/components/Label/Label.tsx
import { jsx as jsx64, jsxs as jsxs30 } from "react/jsx-runtime";
var StyledLabel3 = styled58("label", getStyledOptions())(
  {
    alignItems: "center",
    cursor: "pointer",
    lineHeight: 1,
    position: "relative"
  },
  (props) => {
    const { inline, theme } = props;
    const { dataAttributeName: dataAttributeName2, spacing: spacing2 } = theme;
    return css47`
      display: ${inline ? "inline-flex" : "flex"};
      ${!inline ? `margin-bottom: ${spacing2.sm}` : ""};
      ${getStyles(props, { useFontSize: true })};

      [data-${dataAttributeName2}='Text'] {
        line-height: 1;
        margin-left: ${spacing2.xxs};
      }
    `;
  }
);
var Label = forwardRef27((props, ref) => {
  const { componentProps, getDataAttributes } = useLabel(props);
  const { children, labelId, labelInfo, ...rest } = componentProps;
  let info;
  if (labelInfo) {
    info = is18.string(labelInfo) ? /* @__PURE__ */ jsx64(Text, { color: rest.color, size: "sm", children: labelInfo }) : labelInfo;
  }
  return /* @__PURE__ */ jsxs30(StyledLabel3, { ref, ...getDataAttributes("Label"), ...rest, htmlFor: labelId, children: [
    children,
    info
  ] });
});
Label.displayName = "Label";

// src/components/FormGroup/useFormGroup.ts
var defaultProps35 = {
  hideAssistiveText: false,
  inline: false,
  required: false,
  skipIcon: false
};
function useFormGroup(props) {
  return useComponentProps(props, defaultProps35);
}

// src/components/FormGroup/FormGroup.tsx
import { Fragment as Fragment3, jsx as jsx65, jsxs as jsxs31 } from "react/jsx-runtime";
var StyledFormGroup = styled59(
  "div",
  getStyledOptions()
)((props) => {
  const { dataAttributeName: dataAttributeName2, spacing: spacing2 } = props.theme;
  return css48`
    margin-bottom: ${spacing2.md};
    width: 100%;
    ${getStyles(props)};

    [data-${dataAttributeName2}='FormGroupContent'] {
      > * {
        margin-bottom: 0;
        margin-top: 0;
      }

      [data-${dataAttributeName2}='Label'] {
        margin-right: ${spacing2.xs};
      }

      [data-${dataAttributeName2}='FormGroupContent'] {
        flex: 1;
      }

      [data-${dataAttributeName2}='AssistiveContent'] {
        margin-left: ${spacing2.xs};

        &:empty {
          display: none;
        }
      }
    }
  `;
});
var AssistiveContent = styled59(
  "div",
  getStyledOptions()
)((props) => {
  const { darkMode: darkMode2, grayScale: grayScale2, spacing: spacing2, typography: typography2 } = props.theme;
  return css48`
    align-items: center;
    color: ${darkMode2 ? grayScale2["200"] : grayScale2["500"]};
    display: flex;
    font-size: ${typography2.sm.fontSize};
    line-height: 16px;
    margin-top: ${spacing2.xs};
    min-height: ${spacing2.md};
    text-align: left;
  `;
});
var ErrorComponent = styled59.div((props) => {
  const { colors: colors2 } = props.theme;
  return css48`
    align-items: center;
    color: ${colors2.red};
    display: flex;
  `;
});
var FormGroup = forwardRef28((props, ref) => {
  const { componentProps, getDataAttributes } = useFormGroup(props);
  const {
    assistiveText,
    children,
    error,
    hideAssistiveText,
    inline,
    label,
    labelId,
    labelInfo,
    labelStyles,
    required,
    skipIcon,
    valid,
    ...rest
  } = componentProps;
  const content = {
    assistiveText
  };
  if (error && valid === false) {
    content.assistiveText = /* @__PURE__ */ jsxs31(ErrorComponent, { theme: rest.theme, children: [
      /* @__PURE__ */ jsx65(Icon, { mr: "xxs", name: "danger-o", title: "Invalid" }),
      /* @__PURE__ */ jsx65("span", { children: error })
    ] });
  }
  content.children = !skipIcon ? /* @__PURE__ */ jsx65(
    FormElementWrapper,
    {
      endContent: is19.boolean(valid) && valid ? /* @__PURE__ */ jsx65(Icon, { color: "green", name: "check-o", size: 24, title: "valid" }) : void 0,
      children
    }
  ) : children;
  if (label) {
    content.label = /* @__PURE__ */ jsx65(
      Label,
      {
        labelId,
        labelInfo: labelInfo || required && /* @__PURE__ */ jsx65(Icon, { color: "red", ml: "xxs", name: "asterisk", size: 12 }),
        style: labelStyles,
        children: label
      }
    );
  }
  content.main = /* @__PURE__ */ jsxs31(Fragment3, { children: [
    content.label,
    content.children,
    !hideAssistiveText && /* @__PURE__ */ jsx65(AssistiveContent, { ...getDataAttributes("AssistiveContent"), theme: rest.theme, children: content.assistiveText })
  ] });
  if (inline) {
    content.main = /* @__PURE__ */ jsx65(Box, { ...getDataAttributes("FormGroupContent"), display: "flex", children: content.main });
  }
  return /* @__PURE__ */ jsx65(StyledFormGroup, { ref, ...getDataAttributes("FormGroup"), inline, ...rest, children: content.main });
});
FormGroup.displayName = "FormGroup";

// src/components/Field/Checkbox.tsx
import { useRef as useRef11 } from "react";
import { useUpdateEffect as useUpdateEffect4 } from "@gilbarbara/hooks";
import { jsx as jsx66 } from "react/jsx-runtime";
function FieldCheckbox(props) {
  const {
    accent,
    borderless,
    currentValue,
    disabled,
    items = [],
    name = "CheckboxGroup",
    onChange,
    readOnly,
    setValue
  } = props;
  const ref = useRef11(null);
  useUpdateEffect4(() => {
    currentValue.forEach((d) => {
      const input = ref.current?.querySelector(`[name=${d}]`);
      if (input) {
        input.checked = true;
      }
    });
  }, [currentValue]);
  const handleChange = (event) => {
    const { target } = event;
    const nextValue = target.checked ? [...currentValue, target.name] : currentValue?.filter((d) => d !== target.name);
    setValue(name, nextValue, { shouldDirty: true, shouldValidate: true });
    onChange?.(nextValue);
  };
  return /* @__PURE__ */ jsx66(Flex, { gap: "xs", children: items.map((d) => /* @__PURE__ */ jsx66(
    Checkbox,
    {
      accent,
      borderless,
      defaultChecked: currentValue.includes(d.name),
      disabled,
      label: d.label,
      name: d.name,
      onChange: handleChange,
      readOnly,
      size: "sm"
    },
    d.name
  )) });
}
FieldCheckbox.displayName = "FieldCheckbox";
var Checkbox_default = FieldCheckbox;

// src/components/Field/DatePicker.tsx
import { useCallback as useCallback11 } from "react";
import is21 from "is-lite";

// src/components/Field/utils.ts
import { omit as omit21 } from "@gilbarbara/helpers";
import is20 from "is-lite";

// src/modules/validations.ts
import {
  isValidEmail,
  validatePassword as validatePasswordHelper
} from "@gilbarbara/helpers";
function validateEmail(value) {
  return isValidEmail(value) || "Invalid email address";
}
function validateMatchField(compare, value, message = "Confirmation doesn't match") {
  return compare === value || message;
}
function validatePassword(value, options) {
  try {
    validatePasswordHelper(value, options);
    return true;
  } catch (error) {
    return error.message;
  }
}
function validatePhone(value) {
  if (!value) {
    return void 0;
  }
  return /^\d{10,11}$/.test(clearNumber(value)) || "Invalid phone";
}

// src/components/Field/utils.ts
function getDefaultValue(value, type) {
  if (type === "checkbox") {
    return value ?? [];
  } else if (type === "toggle") {
    return value ?? false;
  }
  return value;
}
function getError(name, errors) {
  const { message, type } = errors[name] ?? {};
  if (message) {
    return [message, type];
  }
  return [null];
}
function getInputParameters(props, ...exclude) {
  return omit21(
    props,
    "assistiveText",
    "children",
    "clearError",
    "debug",
    "dropdownProps",
    "formatter",
    "hideAssistiveText",
    "label",
    "maxLength",
    "minLength",
    "onBlur",
    "onChange",
    "onFocus",
    "required",
    "setValueAs",
    "skipValidation",
    "type",
    "validations",
    "value",
    ...exclude
  );
}
function getRegisterOptions(props) {
  const {
    formatter = "",
    getValues,
    maxLength,
    minLength,
    required,
    setValueAs,
    type = "text",
    validationOptions,
    validations = [],
    value
  } = props;
  const registerOptions = {};
  if (!is20.undefined(value) || ["checkbox", "toggle"].includes(type)) {
    registerOptions.value = getDefaultValue(value, type);
  }
  if (required) {
    registerOptions.required = "Required";
  }
  if (minLength) {
    registerOptions.minLength = {
      value: minLength,
      message: `Min. Characters: ${minLength}`
    };
  }
  if (maxLength) {
    registerOptions.maxLength = {
      value: maxLength,
      message: `Max. Characters: ${maxLength}`
    };
  }
  if (["money", "number", "phoneBR"].includes(formatter)) {
    registerOptions.setValueAs = (v) => {
      if (!v) {
        return void 0;
      }
      return is20.number(v) ? v : Number(clearNumber(v));
    };
  }
  if (setValueAs) {
    registerOptions.setValueAs = setValueAs;
  }
  const validated = validations.map((d) => {
    let result;
    if (d === "email") {
      result = validateEmail;
    }
    if (d === "password") {
      result = validatePassword;
    }
    if (d.startsWith("phone")) {
      result = validatePhone;
    }
    if (d.startsWith("equalsTo:")) {
      const [, field] = d.split(":");
      result = { field, fn: validateMatchField };
    }
    return result;
  }).filter(Boolean);
  if (validated.length) {
    registerOptions.validate = validated.reduce((acc, validation) => {
      if (is20.undefined(validation)) {
        return acc;
      }
      const fnName = is20.function(validation) ? validation.name : validation.fn.name;
      acc[fnName] = (value_) => {
        const input = value_ ? `${value_}` : "";
        let response;
        if (is20.function(validation)) {
          response = validation(input, validationOptions);
        } else if (validation.field && is20.function(validation.fn)) {
          const actualValues = getValues();
          response = validation.fn(`${actualValues[validation.field]}`, input);
        }
        return response;
      };
      return acc;
    }, {});
  }
  return registerOptions;
}

// src/components/Field/DatePicker.tsx
import { jsx as jsx67 } from "react/jsx-runtime";
function FieldDatePicker(props) {
  const { currentValue, datePickerProps = { mode: "single" }, name, onChange, setValue } = props;
  const handleChange = useCallback11(
    (selection) => {
      const setValueOptions = { shouldDirty: true, shouldValidate: true };
      const value = is21.array(selection) ? selection.filter(Boolean).join(",") : selection;
      setValue(name, value, setValueOptions);
      if (onChange && (!currentValue || currentValue !== value)) {
        onChange(value);
      }
    },
    [setValue, name, onChange, currentValue]
  );
  const parameters = getInputParameters(props, "currentValue", "registration", "setValue");
  let selected = currentValue;
  if (datePickerProps.mode === "range") {
    selected = currentValue?.split(",") ?? [void 0, void 0];
  }
  return /* @__PURE__ */ jsx67(
    DatePickerSelector,
    {
      selected,
      ...parameters,
      ...datePickerProps,
      onChange: handleChange
    }
  );
}
FieldDatePicker.displayName = "FieldDatePicker";
var DatePicker_default = FieldDatePicker;

// src/components/Field/Debug.tsx
import { objectEntries as objectEntries4, sortByLocaleCompare as sortByLocaleCompare2 } from "@gilbarbara/helpers";
import is22 from "is-lite";
import { jsx as jsx68, jsxs as jsxs32 } from "react/jsx-runtime";
function FieldDebug(props) {
  const { debug } = props;
  const { getDataAttributes } = useTheme();
  if (!debug) {
    return null;
  }
  return /* @__PURE__ */ jsx68(Box, { as: "code", bg: "gray.50", ...getDataAttributes("FieldDebug"), display: "block", padding: "md", children: objectEntries4(props).filter(([key]) => !["debug", "theme"].includes(key)).sort(sortByLocaleCompare2("0")).map(([key, value]) => /* @__PURE__ */ jsxs32(Paragraph, { mt: "xxs", children: [
    /* @__PURE__ */ jsx68("b", { children: key }),
    ": ",
    primitiveToString(value, key)
  ] }, key)) });
}
function primitiveToString(value, key) {
  if (key === "control") {
    return `{ RHF ${key} }`;
  }
  if (key === "children") {
    return "{ ReactNode }";
  }
  if (is22.function(value)) {
    return "{ Function }";
  }
  if (is22.plainObject(value) || is22.array(value)) {
    return JSON.stringify(value, null, 2);
  }
  if (is22.undefined(value)) {
    return "undefined";
  }
  return value.toString();
}
FieldDebug.displayName = "FieldDebug";
var Debug_default = FieldDebug;

// src/components/Field/Dropdown.tsx
import { useCallback as useCallback12 } from "react";
import is23 from "is-lite";
import { jsx as jsx69 } from "react/jsx-runtime";
function FieldDropdown(props) {
  const { currentValue, dropdownProps = {}, items = [], name, onChange, setValue } = props;
  const handleChangeDropdown = useCallback12(
    (data) => {
      const { multi } = dropdownProps;
      const setValueOptions = { shouldDirty: true, shouldValidate: true };
      if (multi) {
        const values = data.map((d) => d.value);
        setValue(name, values, setValueOptions);
        if (onChange && (!currentValue || currentValue !== values)) {
          onChange(values);
        }
      } else {
        const [selected] = data;
        if (selected) {
          setValue(name, selected.value, setValueOptions);
          if (onChange && (!currentValue || currentValue !== selected.value)) {
            onChange(selected.value);
          }
        } else {
          setValue(name, void 0, setValueOptions);
        }
      }
    },
    [dropdownProps, setValue, name, onChange, currentValue]
  );
  const parameters = getInputParameters(props, "currentValue", "registration", "setValue");
  return /* @__PURE__ */ jsx69(
    Dropdown,
    {
      items,
      values: items.filter(
        (d) => is23.array(currentValue) ? currentValue.includes(d.value) : d.value === currentValue
      ),
      width: "100%",
      ...parameters,
      ...dropdownProps,
      onChange: handleChangeDropdown
    }
  );
}
FieldDropdown.displayName = "FieldDropdown";
var Dropdown_default = FieldDropdown;

// src/components/Field/Input.tsx
import { useCallback as useCallback13 } from "react";
import { formatMoney, formatPhoneBR, formatPhoneUS } from "@gilbarbara/helpers";

// src/components/Input/Input.tsx
import { forwardRef as forwardRef29 } from "react";
import { css as css49 } from "@emotion/react";
import styled60 from "@emotion/styled";

// src/components/Input/useInput.ts
function useInput(props) {
  return useComponentProps(props);
}

// src/components/Input/Input.tsx
import { jsx as jsx70 } from "react/jsx-runtime";
var StyledInput = styled60(
  "input",
  getStyledOptions()
)((props) => {
  return css49`
    ${baseStyles(props.theme)};
    ${inputStyles(props, "input")};
  `;
});
var Input2 = forwardRef29((props, ref) => {
  const { componentProps, getDataAttributes } = useInput(props);
  return /* @__PURE__ */ jsx70(
    StyledInput,
    {
      ref,
      ...getDataAttributes("Input"),
      id: componentProps.name,
      ...componentProps
    }
  );
});
Input2.displayName = "Input";

// src/components/InputColor/InputColor.tsx
import { forwardRef as forwardRef30, useRef as useRef12, useState as useState15 } from "react";
import { css as css50 } from "@emotion/react";
import styled61 from "@emotion/styled";
import { px as px28 } from "@gilbarbara/helpers";

// src/components/InputColor/useInputColor.ts
var defaultProps36 = {
  accent: "primary",
  borderless: false,
  disabled: false,
  height: "md",
  onChangeDebounce: 250,
  placeholder: "Select a color",
  readOnly: false,
  width: "auto"
};
function useInputColor(props) {
  return useComponentProps(props, defaultProps36);
}

// src/components/InputColor/InputColor.tsx
import { jsx as jsx71, jsxs as jsxs33 } from "react/jsx-runtime";
var StyledInputColor = styled61(
  "div",
  getStyledOptions()
)((props) => {
  const { accent, borderless, disabled, isFilled, theme, width } = props;
  const { darkMode: darkMode2, dataAttributeName: dataAttributeName2, grayScale: grayScale2, radius: radius2, white: white2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  let borderColor = darkMode2 ? grayScale2["700"] : grayScale2["500"];
  if (isFilled) {
    borderColor = mainColor;
  }
  const styles2 = borderless ? css50`
        border: 0;
        border-bottom: 1px solid ${borderColor};
      ` : css50`
        background-color: ${darkMode2 ? grayScale2["800"] : white2};
        border: 1px solid ${borderColor};
        border-radius: ${radius2.xs};
      `;
  return css50`
    align-items: center;
    display: flex;
    padding: 4px 16px 4px 4px;
    width: ${px28(width)};
    ${styles2};

    ${disabled && css50`
      ${getDisableStyles(props)}
      color: ${grayScale2["500"]};
    `};

    [data-${dataAttributeName2}='Text'] {
      min-width: 75px;
    }
  `;
});
var StyledLabel4 = styled61(
  "label",
  getStyledOptions()
)((props) => {
  const { height, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2, spacing: spacing2 } = theme;
  const size = parseInt(inputHeight[height], 10) - 10;
  const inputSize = px28(size + 16);
  return css50`
    border: 1px solid ${darkMode2 ? grayScale2["700"] : grayScale2["100"]};
    border-radius: ${radius2.xs};
    height: ${px28(size)};
    overflow: hidden;
    position: relative;
    margin-right: ${spacing2.xs};
    width: ${px28(size)};

    input {
      appearance: none;
      background: none;
      border: 0;
      cursor: pointer;
      height: ${inputSize};
      margin: -8px;
      padding: 0;
      width: ${inputSize};

      &:disabled {
        cursor: not-allowed;
      }
    }
  `;
});
var InputColor = forwardRef30((props, ref) => {
  const { componentProps, getDataAttributes } = useInputColor(props);
  const {
    accent,
    borderless,
    disabled,
    height,
    name,
    onChange,
    onChangeDebounce,
    placeholder,
    readOnly,
    theme,
    value: initialValue,
    width,
    ...rest
  } = componentProps;
  const [value, setValue] = useState15(initialValue ?? "");
  const debounceTimeout = useRef12(0);
  const isDisabled = disabled || readOnly;
  const handleChange = (event) => {
    setValue(event.target.value);
    if (!onChange) {
      return;
    }
    if (!onChangeDebounce) {
      onChange(event);
      return;
    }
    clearTimeout(debounceTimeout.current);
    debounceTimeout.current = window.setTimeout(() => {
      onChange(event);
      debounceTimeout.current = 0;
    }, onChangeDebounce);
  };
  let text;
  if (value) {
    text = /* @__PURE__ */ jsx71(Text, { children: value });
  } else if (placeholder) {
    text = /* @__PURE__ */ jsx71(Text, { color: "gray.500", children: placeholder });
  }
  return /* @__PURE__ */ jsxs33(
    StyledInputColor,
    {
      accent,
      borderless,
      ...getDataAttributes("InputColor"),
      disabled: isDisabled,
      height,
      isFilled: !!value,
      theme,
      width,
      children: [
        /* @__PURE__ */ jsx71(StyledLabel4, { ...getDataAttributes("InputColorLabel"), height, theme, children: /* @__PURE__ */ jsx71(
          "input",
          {
            ref,
            disabled: isDisabled,
            id: name,
            name,
            onChange: handleChange,
            type: "color",
            value,
            ...rest
          }
        ) }),
        text
      ]
    }
  );
});
InputColor.displayName = "InputColor";

// src/components/InputFile/InputFile.tsx
import { forwardRef as forwardRef31, useState as useState16 } from "react";
import { css as css52 } from "@emotion/react";
import styled63 from "@emotion/styled";
import { px as px30 } from "@gilbarbara/helpers";

// src/components/Truncate/Truncate.tsx
import { css as css51 } from "@emotion/react";
import styled62 from "@emotion/styled";
import { px as px29 } from "@gilbarbara/helpers";

// src/components/Truncate/useTruncate.ts
var defaultProps37 = {
  lines: 2
};
function useTruncate(props) {
  return useComponentProps(props, defaultProps37);
}

// src/components/Truncate/Truncate.tsx
import { jsx as jsx72 } from "react/jsx-runtime";
var StyledTruncate = styled62(
  "span",
  getStyledOptions()
)((props) => {
  const { lines, maxWidth } = props;
  if (maxWidth) {
    return css51`
      display: inline-block;
      max-width: ${px29(maxWidth)};
      overflow: hidden;
      text-overflow: ellipsis;
      white-space: nowrap;
    }
    `;
  }
  return css51`
    display: -webkit-box;
    overflow: hidden;
    -webkit-box-orient: vertical;
    -webkit-line-clamp: ${lines ?? 2};
  `;
});
function Truncate(props) {
  const {
    componentProps: { children, ...rest },
    getDataAttributes
  } = useTruncate(props);
  return /* @__PURE__ */ jsx72(StyledTruncate, { ...getDataAttributes("Truncate"), ...rest, children });
}
Truncate.displayName = "Truncate";

// src/components/InputFile/useInputFile.ts
var defaultProps38 = {
  accent: "primary",
  disabled: false,
  height: "md",
  placeholder: "Upload a file",
  readOnly: false,
  solid: false,
  width: "100%"
};
function useInputFile(props) {
  return useComponentProps(props, defaultProps38);
}

// src/components/InputFile/InputFile.tsx
import { jsx as jsx73, jsxs as jsxs34 } from "react/jsx-runtime";
var StyledFileInput = styled63(
  "div",
  getStyledOptions()
)((props) => {
  const { theme, width } = props;
  const { dataAttributeName: dataAttributeName2, spacing: spacing2 } = theme;
  return css52`
    ${baseStyles(theme)};
    align-items: center;
    display: flex;
    width: ${px30(width)};

    [data-${dataAttributeName2}='Truncate'] {
      flex: 1;
      margin-left: ${spacing2.xs};

      &:empty {
        display: none;
      }
    }
  `;
});
var StyledInput2 = styled63("input", getStyledOptions())`
  bottom: 0;
  font-size: 24px;
  left: 0;
  opacity: 0;
  position: absolute;
  right: 0;
  top: 0;
  z-index: 1;

  &::file-selector-button {
    cursor: pointer;
  }
`;
var InputFile = forwardRef31((props, ref) => {
  const { componentProps, getDataAttributes } = useInputFile(props);
  const { accent, disabled, height, name, onChange, placeholder, readOnly, solid, value, ...rest } = componentProps;
  const [localValue, setLocalValue] = useState16(null);
  const isDisabled = disabled || readOnly;
  const handleChange = (event) => {
    const { files } = event.target;
    setLocalValue(files?.length ? files[0].name : "");
    onChange?.(event);
  };
  return /* @__PURE__ */ jsxs34(StyledFileInput, { ...getDataAttributes("InputFile"), ...rest, children: [
    /* @__PURE__ */ jsxs34(FlexInline, { position: "relative", children: [
      /* @__PURE__ */ jsx73(
        Button,
        {
          bg: accent,
          disabled: isDisabled,
          size: height,
          style: { zIndex: isDisabled ? 2 : 1 },
          variant: solid ? "solid" : "bordered",
          children: placeholder
        }
      ),
      /* @__PURE__ */ jsx73(StyledInput2, { ref, id: name, name, onChange: handleChange, type: "file" })
    ] }),
    /* @__PURE__ */ jsx73(Truncate, { maxWidth: "100%", children: localValue ?? value })
  ] });
});
InputFile.displayName = "InputFile";

// src/components/Field/Input.tsx
import { jsx as jsx74 } from "react/jsx-runtime";
function FieldInput(props) {
  const {
    accent,
    currentValue,
    formatter = "",
    id,
    isDirty,
    name,
    onBlur,
    onChange,
    onFocus,
    registration,
    setStatus,
    skipValidation,
    type
  } = props;
  const handleBlur = useCallback13(
    (event) => {
      setStatus({ isActive: false, isDirty });
      registration.onBlur(event);
      onBlur?.(event);
    },
    [isDirty, onBlur, registration, setStatus]
  );
  const handleFocus = useCallback13(
    (event) => {
      setStatus({ isActive: true });
      onFocus?.(event);
    },
    [onFocus, setStatus]
  );
  const handleChange = useCallback13(
    (event) => {
      const { value } = event.target;
      if (["phoneBR", "phoneUS"].includes(formatter)) {
        event.target.value = clearNumber(value).slice(0, 11);
      } else if (formatter) {
        event.target.value = clearNumber(value);
      }
      registration.onChange(event);
      onChange?.(value);
    },
    [formatter, onChange, registration]
  );
  const input = {
    ...getInputParameters(
      props,
      "currentValue",
      "inline",
      "isDirty",
      "registration",
      "setStatus"
    ),
    id: id ?? name,
    onBlur: handleBlur,
    onChange: handleChange,
    onFocus: handleFocus
  };
  let content;
  switch (type) {
    case "color": {
      content = /* @__PURE__ */ jsx74(InputColor, { ...registration, ...input, value: currentValue });
      break;
    }
    case "file": {
      content = /* @__PURE__ */ jsx74(
        InputFile,
        {
          accent,
          ...registration,
          ...input,
          value: currentValue?.length ? currentValue[0].name : ""
        }
      );
      break;
    }
    case "hidden": {
      content = /* @__PURE__ */ jsx74("input", { ...registration, ...input, type: "hidden" });
      break;
    }
    default: {
      const parameters = {};
      if (currentValue) {
        switch (formatter) {
          case "money": {
            parameters.value = formatMoney(currentValue);
            break;
          }
          case "phoneBR": {
            parameters.value = formatPhoneBR(`${currentValue}`);
            break;
          }
          case "phoneUS": {
            parameters.value = formatPhoneUS(`${currentValue}`);
            break;
          }
        }
      }
      content = /* @__PURE__ */ jsx74(
        Input2,
        {
          ...registration,
          ...input,
          ...parameters,
          suffixSpacing: !skipValidation,
          type
        }
      );
      break;
    }
  }
  return content;
}
FieldInput.displayName = "FieldInput";
var Input_default = FieldInput;

// src/components/Field/Radio.tsx
import { jsx as jsx75 } from "react/jsx-runtime";
function FieldRadio(props) {
  const { accent, borderless, disabled, items = [], onChange, readOnly, registration } = props;
  const handleChange = (event) => {
    const { target } = event;
    onChange?.(target.value);
  };
  return /* @__PURE__ */ jsx75(Spacer, { gap: "xs", children: items.map((d) => /* @__PURE__ */ jsx75(
    Radio,
    {
      ...d,
      ...registration,
      accent,
      borderless,
      disabled,
      onChange: handleChange,
      readOnly,
      size: "sm"
    },
    d.value
  )) });
}
FieldRadio.displayName = "FieldRadio";
var Radio_default = FieldRadio;

// src/components/Field/Select.tsx
import { useCallback as useCallback15 } from "react";

// src/components/Select/Select.tsx
import { forwardRef as forwardRef32, useCallback as useCallback14, useRef as useRef13, useState as useState17 } from "react";
import { css as css53 } from "@emotion/react";
import styled64 from "@emotion/styled";
import { px as px31 } from "@gilbarbara/helpers";
import { useMergeRefs as useMergeRefs3, useMount as useMount3 } from "@gilbarbara/hooks";
import is24 from "is-lite";

// src/components/Select/useSelect.ts
var defaultProps39 = {
  accent: "primary",
  borderless: false,
  disabled: false,
  height: "md",
  multiple: false,
  prefixSpacing: false,
  suffixSpacing: false,
  width: "100%"
};
function useSelect(props) {
  return useComponentProps(props, defaultProps39);
}

// src/components/Select/Select.tsx
import { jsx as jsx76 } from "react/jsx-runtime";
var StyledSelect = styled64(
  "select",
  getStyledOptions()
)((props) => {
  const { accent, filled, height, multiple, suffixSpacing, theme } = props;
  const { darkColor: darkColor2, darkMode: darkMode2, grayScale: grayScale2, spacing: spacing2, white: white2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  let backgroundPosition = "12px";
  let color = grayScale2["500"];
  const paddingY = selectPaddingY[height];
  if (filled) {
    color = darkMode2 ? white2 : darkColor2;
  }
  if (multiple) {
    color = grayScale2["500"];
  }
  if (suffixSpacing) {
    backgroundPosition = is24.boolean(suffixSpacing) ? "40px" : px31(suffixSpacing);
  }
  return css53`
    ${appearanceStyles};
    ${baseStyles(theme)};
    background-image: url('${`data:image/svg+xml,%3Csvg height="16px" version="1.1" viewBox="0 0 16 16" width="16px" xmlns="http://www.w3.org/2000/svg" %3E%3Cpath d="M14,5.52466366 C14,5.41704038 13.9641256,5.32735426 13.8923766,5.25560543 L13.3004484,4.60986548 C13.1928251,4.53811658 13.0852018,4.50224213 12.9775785,4.50224213 C12.8699551,4.50224213 12.7802691,4.53811658 12.7085202,4.60986548 L8.02690583,9.3452915 L3.29147982,4.60986548 C3.21973094,4.53811658 3.13004485,4.50224213 3.02242152,4.50224213 C2.91479821,4.50224213 2.82511211,4.53811658 2.75336323,4.60986548 L2.10762332,5.25560543 C2.03587444,5.32735426 2,5.41704038 2,5.52466366 C2,5.63228701 2.03587444,5.72197313 2.10762332,5.79372196 L7.70403588,11.3901345 C7.81165919,11.4618834 7.91928251,11.4977579 8.02690583,11.4977579 C8.13452915,11.4977579 8.22421524,11.4618834 8.29596412,11.3901345 L13.8923766,5.79372196 C13.9641256,5.72197313 14,5.63228701 14,5.52466366 Z" fill="${color.replace(
    "#",
    "%23"
  )}" /%3E%3C/svg%3E`}');
    background-repeat: no-repeat;
    background-position: right ${backgroundPosition} center;
    ${inputStyles(props, "select")};
    color: ${color};

    ${filled && css53`
      border-color: ${mainColor};
    `};

    &[multiple] {
      padding: 0;

      > option {
        padding: ${paddingY} ${spacing2.md};

        &:not(:checked) {
          background: ${`${white2} linear-gradient(0deg, ${white2} 0%, ${white2} 100%)`};
        }

        &:checked {
          background: ${`${mainColor} linear-gradient(0deg, ${mainColor} 0%, ${mainColor} 100%)`};
          color: ${white2};
          font-weight: bold;
        }
      }
    }
  `;
});
var Select = forwardRef32((props, ref) => {
  const {
    componentProps: { name, onChange, ...rest },
    getDataAttributes
  } = useSelect(props);
  const [isFilled, setFilled] = useState17(!!rest.defaultValue || !!rest.value);
  const localRef = useRef13(null);
  const mergedRefs = useMergeRefs3(localRef, ref);
  useMount3(() => {
    setFilled(!!localRef.current?.value);
  });
  const handleChange = useCallback14(
    (event) => {
      setFilled(!!event.target.value);
      onChange?.(event);
    },
    [onChange]
  );
  return /* @__PURE__ */ jsx76(
    StyledSelect,
    {
      ref: mergedRefs,
      ...getDataAttributes("Select"),
      filled: isFilled,
      id: name,
      name,
      onChange: handleChange,
      ...rest
    }
  );
});
Select.displayName = "Select";

// src/components/Field/Select.tsx
import { jsx as jsx77 } from "react/jsx-runtime";
function FieldSelect(props) {
  const { children, id, isDirty, name, onBlur, onChange, onFocus, registration, setStatus } = props;
  const handleBlur = useCallback15(
    (event) => {
      setStatus({ isActive: false, isDirty });
      registration.onBlur(event);
      onBlur?.(event);
    },
    [isDirty, onBlur, registration, setStatus]
  );
  const handleFocus = useCallback15(
    (event) => {
      setStatus({ isActive: true });
      onFocus?.(event);
    },
    [onFocus, setStatus]
  );
  const handleChange = useCallback15(
    (event) => {
      registration.onChange(event);
      onChange?.(event.target.value);
    },
    [onChange, registration]
  );
  const input = {
    ...getInputParameters(props, "isDirty", "registration", "setStatus"),
    id: id ?? name,
    onBlur: handleBlur,
    onChange: handleChange,
    onFocus: handleFocus
  };
  return /* @__PURE__ */ jsx77(Select, { ...registration, ...input, children });
}
FieldSelect.displayName = "FieldSelect";
var Select_default = FieldSelect;

// src/components/Field/Textarea.tsx
import { useCallback as useCallback16 } from "react";

// src/components/Textarea/Textarea.tsx
import { forwardRef as forwardRef33 } from "react";
import { css as css54 } from "@emotion/react";
import styled65 from "@emotion/styled";

// src/components/Textarea/useTextarea.ts
var defaultProps40 = {
  accent: "primary",
  borderless: false,
  disabled: false,
  prefixSpacing: false,
  readOnly: false,
  rows: 3,
  suffixSpacing: false,
  width: "100%"
};
function useTextarea(props) {
  return useComponentProps(props, defaultProps40);
}

// src/components/Textarea/Textarea.tsx
import { jsx as jsx78 } from "react/jsx-runtime";
var StyledTextarea = styled65(
  "textarea",
  getStyledOptions()
)((props) => {
  return css54`
    ${baseStyles(props.theme)};
    ${inputStyles(props, "textarea")};
  `;
});
var Textarea = forwardRef33((props, ref) => {
  const {
    componentProps: { name, ...rest },
    getDataAttributes
  } = useTextarea(props);
  return /* @__PURE__ */ jsx78(StyledTextarea, { ref, ...getDataAttributes("Textarea"), id: name, name, ...rest });
});
Textarea.displayName = "Textarea";

// src/components/Field/Textarea.tsx
import { jsx as jsx79 } from "react/jsx-runtime";
function FieldTextarea(props) {
  const { id, isDirty, name, onBlur, onChange, onFocus, registration, setStatus, skipValidation } = props;
  const handleBlur = useCallback16(
    (event) => {
      setStatus({ isActive: false, isDirty });
      registration.onBlur(event);
      onBlur?.(event);
    },
    [isDirty, onBlur, registration, setStatus]
  );
  const handleFocus = useCallback16(
    (event) => {
      setStatus({ isActive: true });
      onFocus?.(event);
    },
    [onFocus, setStatus]
  );
  const handleChange = useCallback16(
    (event) => {
      registration.onChange(event);
      onChange?.(event.target.value);
    },
    [onChange, registration]
  );
  const input = {
    ...getInputParameters(props, "isDirty", "registration", "setStatus"),
    id: id ?? name,
    onBlur: handleBlur,
    onChange: handleChange,
    onFocus: handleFocus
  };
  return /* @__PURE__ */ jsx79(Textarea, { ...registration, ...input, suffixSpacing: !skipValidation });
}
FieldTextarea.displayName = "FieldTextarea";
var Textarea_default = FieldTextarea;

// src/components/Field/Toggle.tsx
import { useCallback as useCallback17 } from "react";
import { Controller } from "react-hook-form";
import innerText7 from "react-innertext";
import is26 from "is-lite";

// src/components/Toggle/Toggle.tsx
import {
  cloneElement as cloneElement5,
  forwardRef as forwardRef34,
  isValidElement as isValidElement18,
  useId as useId4,
  useState as useState18
} from "react";
import { css as css55 } from "@emotion/react";
import styled66 from "@emotion/styled";
import { px as px32 } from "@gilbarbara/helpers";
import { usePrevious as usePrevious3, useUpdateEffect as useUpdateEffect5 } from "@gilbarbara/hooks";
import { VisuallyHidden } from "@react-aria/visually-hidden";
import is25 from "is-lite";

// src/components/Toggle/useToggle.ts
var defaultProps41 = {
  accent: "primary",
  defaultChecked: false,
  disabled: false,
  size: "md"
};
function useToggle(props) {
  return useComponentProps(props, defaultProps41);
}

// src/components/Toggle/Toggle.tsx
import { jsx as jsx80, jsxs as jsxs35 } from "react/jsx-runtime";
var styles = {
  sm: {
    borderRadius: 8,
    height: 16,
    space: 2,
    width: 32
  },
  md: {
    borderRadius: 10,
    height: 20,
    space: 2,
    width: 40
  },
  lg: {
    borderRadius: 12,
    height: 24,
    space: 2,
    width: 48
  }
};
var StyledLabel5 = styled66(
  "label",
  getStyledOptions()
)((props) => {
  const { accent, theme } = props;
  const { dataAttributeName: dataAttributeName2, radius: radius2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  return css55`
    display: inline-flex;

    &:focus {
      outline: none;

      [data-${dataAttributeName2}='ToggleElement'] {
        border-radius: ${radius2.sm};
        outline: none;
        ${getOutlineStyles(mainColor, theme)};
        z-index: unset;
      }
    }
  `;
});
var StyledTrack = styled66(
  "span",
  getStyledOptions()
)((props) => {
  const { accent, colorTrack, isChecked, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  let backgroundColor = darkMode2 ? grayScale2["700"] : grayScale2["200"];
  if (colorTrack) {
    backgroundColor = getColorTokens(colorTrack, null, theme).mainColor;
  }
  if (isChecked) {
    backgroundColor = mainColor;
  }
  return css55`
    background-color: ${backgroundColor};
    border-radius: ${radius2.sm};
    bottom: 0;
    left: 0;
    position: absolute;
    transition: background-color 0.4s;
    right: 0;
    top: 0;
  `;
});
var StyledTrackIcon = styled66("span")((props) => {
  const { accent, isChecked, size, theme } = props;
  const { darkColor: darkColor2 } = theme;
  const { textColor: textColor2 } = getColorTokens(accent, null, theme);
  const { height, space } = styles[size];
  return css55`
    align-items: center;
    bottom: 0;
    color: ${isChecked ? textColor2 : darkColor2};
    display: flex;
    justify-content: center;
    left: ${isChecked ? px32(space) : void 0};
    height: ${px32(height)};
    position: absolute;
    right: ${isChecked ? void 0 : px32(space)};
    top: 0;
  `;
});
var StyledButton3 = styled66(
  "span",
  getStyledOptions()
)((props) => {
  const { accent, colorButton, disabled, isChecked, size, theme } = props;
  const { grayScale: grayScale2, opacityDisabled: opacityDisabled2, white: white2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  let backgroundColor = white2;
  if (accent === "white" && isChecked) {
    backgroundColor = grayScale2["800"];
  } else if (isChecked) {
    backgroundColor = getColorWithTone(mainColor, "50");
  }
  if (colorButton) {
    backgroundColor = is25.array(colorButton) ? getColorTokens(isChecked ? colorButton[1] : colorButton[0], null, theme).mainColor : getColorTokens(colorButton, null, theme).mainColor;
  }
  const { height, space } = styles[size];
  return css55`
    align-items: center;
    background-color: ${backgroundColor};
    border-radius: 50%;
    bottom: ${px32(space)};
    display: flex;
    font-size: ${px32(height - 6)};
    justify-content: center;
    left: ${isChecked ? px32(height + 2) : px32(space)};
    opacity: ${disabled ? opacityDisabled2 : 1};
    position: absolute;
    top: ${px32(space)};
    transition:
      background-color 0.4s,
      left 0.2s ease;
    width: ${px32(height - 4)};
  `;
});
var StyledToggle = styled66("div")(
  (props) => {
    const { disabled, label, size, theme } = props;
    const { opacityDisabled: opacityDisabled2 } = theme;
    const { height, width } = styles[size];
    return css55`
      ${baseStyles(theme)};
      cursor: ${disabled ? "default" : "pointer"};
      height: ${px32(height)};
      margin-right: ${label ? "8px" : 0};
      opacity: ${disabled ? opacityDisabled2 : 1};
      position: relative;
      user-select: none;
      vertical-align: middle;
      width: ${px32(width)};
    `;
  }
);
var Toggle = forwardRef34((props, ref) => {
  const { componentProps, getDataAttributes } = useToggle(props);
  const {
    accent,
    as,
    checked,
    colorButton,
    colorTrack,
    defaultChecked,
    disabled,
    iconEnd,
    iconStart,
    label,
    name,
    onChange,
    onToggle,
    size,
    thumbIconChecked,
    thumbIconUnchecked,
    ...rest
  } = componentProps;
  const [isChecked, setChecked] = useState18(is25.boolean(checked) ? checked : defaultChecked);
  const previousChecked = usePrevious3(checked);
  const labelId = useId4();
  useUpdateEffect5(() => {
    if (is25.boolean(checked) && previousChecked !== checked) {
      setChecked(checked);
    }
  }, [checked, previousChecked]);
  const handleChange = (event) => {
    if (is25.boolean(checked)) {
      return;
    }
    const { target } = event;
    setChecked(target.checked);
    onChange?.(target.checked);
  };
  const handleClickLabel = () => {
    if (!disabled) {
      onToggle?.(!isChecked);
    }
  };
  const handleClickInput = (event) => {
    event.stopPropagation();
  };
  const handleKeyDown2 = (event) => {
    if (disabled || !["Enter", "Space"].includes(event.code)) {
      return;
    }
    const status = !isChecked;
    onToggle?.(status);
    if (is25.boolean(checked)) {
      return;
    }
    setChecked(status);
    onChange?.(status);
  };
  const value = isChecked ? "on" : "off";
  const checkStatus = {};
  if (is25.boolean(checked)) {
    checkStatus.checked = checked;
  } else {
    checkStatus.defaultChecked = defaultChecked;
  }
  let labelElement = null;
  if (label) {
    labelElement = isValidElement18(label) ? cloneElement5(label, { id: labelId }) : /* @__PURE__ */ jsx80("span", { id: labelId, children: label });
  }
  return /* @__PURE__ */ jsxs35(
    StyledLabel5,
    {
      accent,
      as,
      "data-checked": isChecked,
      ...getDataAttributes("Toggle"),
      "data-disabled": disabled,
      onClick: handleClickLabel,
      onKeyDown: handleKeyDown2,
      style: {
        cursor: disabled ? "default" : "pointer",
        pointerEvents: disabled ? "none" : "auto",
        touchAction: disabled ? "none" : void 0
      },
      tabIndex: disabled ? -1 : 0,
      ...rest,
      children: [
        /* @__PURE__ */ jsx80(VisuallyHidden, { elementType: "span", children: /* @__PURE__ */ jsx80(
          "input",
          {
            ref,
            "aria-checked": isChecked,
            "aria-labelledby": label ? labelId : void 0,
            disabled,
            name,
            onChange: handleChange,
            onClick: handleClickInput,
            role: "switch",
            type: "checkbox",
            value,
            ...checkStatus
          }
        ) }),
        /* @__PURE__ */ jsxs35(
          StyledToggle,
          {
            accent,
            "aria-hidden": true,
            ...getDataAttributes("ToggleElement"),
            disabled,
            label,
            name,
            size,
            theme: rest.theme,
            children: [
              /* @__PURE__ */ jsx80(
                StyledTrack,
                {
                  accent,
                  colorTrack,
                  ...getDataAttributes("ToggleTrack"),
                  isChecked,
                  size,
                  theme: rest.theme
                }
              ),
              /* @__PURE__ */ jsx80(
                StyledButton3,
                {
                  accent,
                  colorButton,
                  ...getDataAttributes("ToggleButton"),
                  disabled,
                  isChecked,
                  size,
                  theme: rest.theme,
                  children: isChecked ? thumbIconChecked : thumbIconUnchecked
                }
              ),
              !isChecked && iconStart && /* @__PURE__ */ jsx80(
                StyledTrackIcon,
                {
                  accent,
                  ...getDataAttributes("ToggleTrackIcon"),
                  isChecked,
                  size,
                  theme: rest.theme,
                  children: iconStart
                }
              ),
              isChecked && iconEnd && /* @__PURE__ */ jsx80(
                StyledTrackIcon,
                {
                  accent,
                  ...getDataAttributes("ToggleTrackIcon"),
                  isChecked,
                  size,
                  theme: rest.theme,
                  children: iconEnd
                }
              )
            ]
          }
        ),
        labelElement
      ]
    }
  );
});
Toggle.displayName = "Toggle";

// src/components/Field/Toggle.tsx
import { jsx as jsx81 } from "react/jsx-runtime";
function FieldToggle(props) {
  const { accent, disabled, label, name, onChange, required, setValue, toggleProps } = props;
  const handleToggle = useCallback17(
    (status) => {
      setValue(name, status, {
        shouldDirty: true,
        shouldValidate: true
      });
      onChange?.(status);
    },
    [name, onChange, setValue]
  );
  return /* @__PURE__ */ jsx81(
    Controller,
    {
      name,
      render: ({ field }) => {
        return /* @__PURE__ */ jsx81(
          Toggle,
          {
            accent,
            "aria-label": innerText7(label),
            checked: is26.undefined(field.value) ? false : field.value,
            disabled,
            name,
            onToggle: handleToggle,
            ...toggleProps
          }
        );
      },
      rules: { required }
    }
  );
}
FieldToggle.displayName = "FieldToggle";
var Toggle_default = FieldToggle;

// src/components/Field/useField.ts
var defaultProps42 = {
  accent: "primary",
  borderless: false,
  debug: false,
  disabled: false,
  hideAssistiveText: false,
  inline: false,
  label: "",
  readOnly: false,
  required: false,
  skipValidation: false,
  type: "text"
};
function useField(props) {
  return useComponentProps(props, defaultProps42);
}

// src/components/Field/Field.tsx
import { jsx as jsx82, jsxs as jsxs36 } from "react/jsx-runtime";
function Field(props) {
  const { componentProps, getDataAttributes } = useField(props);
  const {
    assistiveText,
    hideAssistiveText,
    id,
    inline,
    label,
    name,
    required,
    skipValidation,
    style,
    type,
    validations,
    value
  } = componentProps;
  const [{ isActive, isDirty }, setStatus] = useSetState4({
    isActive: false,
    isDirty: false
  });
  const formContext = useFormContext();
  if (!formContext) {
    throw new Error(
      'could not find the "form" context value; please ensure the component is wrapped in a <Form>'
    );
  }
  const {
    formState: { dirtyFields, errors },
    getValues,
    register,
    setValue,
    unregister
  } = formContext;
  const registerOptions = useMemo7(
    () => getRegisterOptions({ ...componentProps, getValues }),
    [getValues, componentProps]
  );
  const registration = register(name, registerOptions);
  const currentValue = useWatch({
    name,
    defaultValue: getDefaultValue(value ?? getValues()[name], type)
  });
  const [error, errorType = ""] = getError(name, errors);
  useUnmount(() => {
    unregister(name);
  });
  const showError = !!error && errorType !== "revalidate" && (!isActive || isDirty);
  const isValid = !!currentValue && !error && (required ?? validations?.length);
  const groupProps = {
    assistiveText,
    hideAssistiveText,
    inline,
    label,
    labelId: id ?? name,
    required,
    style
  };
  const output = { error };
  if (!skipValidation) {
    groupProps.skipIcon = [
      "checkbox",
      "color",
      "datePicker",
      "dropdown",
      "radio",
      "select",
      "toggle"
    ].includes(type);
    if (showError) {
      groupProps.error = error;
      groupProps.valid = false;
    } else if (isValid) {
      groupProps.valid = true;
    }
  }
  switch (type) {
    case "checkbox": {
      output.content = /* @__PURE__ */ jsx82(
        Checkbox_default,
        {
          currentValue,
          setValue,
          ...componentProps
        }
      );
      break;
    }
    case "datePicker": {
      output.content = /* @__PURE__ */ jsx82(
        DatePicker_default,
        {
          currentValue,
          registration,
          setValue,
          ...componentProps
        }
      );
      break;
    }
    case "dropdown": {
      output.content = /* @__PURE__ */ jsx82(
        Dropdown_default,
        {
          currentValue,
          registration,
          setValue,
          ...componentProps
        }
      );
      break;
    }
    case "password": {
      output.content = /* @__PURE__ */ jsx82(
        Input_default,
        {
          currentValue,
          isDirty: !!dirtyFields[name],
          registration,
          setStatus,
          ...componentProps
        }
      );
      break;
    }
    case "radio": {
      output.content = /* @__PURE__ */ jsx82(Radio_default, { registration, ...componentProps });
      break;
    }
    case "select": {
      output.content = /* @__PURE__ */ jsx82(
        Select_default,
        {
          isDirty: !!dirtyFields[name],
          registration,
          setStatus,
          ...componentProps
        }
      );
      break;
    }
    case "textarea": {
      output.content = /* @__PURE__ */ jsx82(
        Textarea_default,
        {
          isDirty: !!dirtyFields[name],
          registration,
          setStatus,
          ...componentProps
        }
      );
      break;
    }
    case "toggle": {
      output.content = /* @__PURE__ */ jsx82(Toggle_default, { ...componentProps, setValue });
      break;
    }
    default: {
      output.content = /* @__PURE__ */ jsx82(
        Input_default,
        {
          currentValue,
          isDirty: !!dirtyFields[name],
          registration,
          setStatus,
          ...componentProps
        }
      );
    }
  }
  if (type === "hidden") {
    return output.content;
  }
  return /* @__PURE__ */ jsxs36(FormGroup, { ...getDataAttributes("Field"), ...groupProps, children: [
    output.content,
    /* @__PURE__ */ jsx82(Debug_default, { ...componentProps })
  ] });
}
Field.displayName = "Field";

// src/components/Form/Form.tsx
import { FormProvider, useForm as useHookForm } from "react-hook-form";

// src/components/Form/useForm.ts
function useForm(props) {
  return useComponentProps(props);
}

// src/components/Form/Form.tsx
import { jsx as jsx83 } from "react/jsx-runtime";
function Form(props) {
  const {
    componentProps: { children, ...rest }
  } = useForm(props);
  const formMethods = useHookForm({
    mode: "onChange",
    ...rest
  });
  return /* @__PURE__ */ jsx83(FormProvider, { ...formMethods, children: children({ formMethods }) });
}
Form.displayName = "Form";

// src/components/Grid/Grid.tsx
import { forwardRef as forwardRef35 } from "react";
import styled67 from "@emotion/styled";

// src/components/Grid/useGrid.ts
function useGrid(props) {
  return useComponentProps(props);
}

// src/components/Grid/Grid.tsx
import { jsx as jsx84 } from "react/jsx-runtime";
var StyledGrid = styled67("div", getStyledOptions())(
  {
    display: "grid"
  },
  (props) => getStyles(props, { skipBorder: true, useFontSize: true })
);
var Grid = forwardRef35((props, ref) => {
  const { componentProps, getDataAttributes } = useGrid(props);
  return /* @__PURE__ */ jsx84(StyledGrid, { ref, ...getDataAttributes("Grid"), ...componentProps });
});
Grid.displayName = "Grid";

// src/components/Image/Image.tsx
import { forwardRef as forwardRef36, useMemo as useMemo9 } from "react";
import { css as css56, keyframes as keyframes8 } from "@emotion/react";
import styled68 from "@emotion/styled";
import { px as px33 } from "@gilbarbara/helpers";

// src/components/Image/useImage.ts
import { mergeProps as mergeProps2 } from "@gilbarbara/helpers";

// src/hooks/useImage.ts
import { useCallback as useCallback18, useEffect as useEffect10, useLayoutEffect, useMemo as useMemo8, useRef as useRef14, useState as useState19 } from "react";
function useImage(props) {
  const { crossOrigin, loading, onError, onLoad, sizes: sizes2, src, srcSet } = props;
  const [status, setStatus] = useState19("pending");
  useEffect10(() => {
    setStatus(src ? "loading" : "pending");
  }, [src]);
  const imageRef = useRef14();
  const load = useCallback18(() => {
    if (!src) {
      return;
    }
    flush();
    const img = new Image();
    img.src = src;
    if (crossOrigin) {
      img.crossOrigin = crossOrigin;
    }
    if (srcSet) {
      img.srcset = srcSet;
    }
    if (sizes2) {
      img.sizes = sizes2;
    }
    if (loading) {
      img.loading = loading;
    }
    img.onload = (event) => {
      flush();
      setStatus("loaded");
      onLoad?.(event);
    };
    img.onerror = (error) => {
      flush();
      setStatus("failed");
      onError?.(error);
    };
    imageRef.current = img;
  }, [src, crossOrigin, srcSet, sizes2, onLoad, onError, loading]);
  const flush = () => {
    if (imageRef.current) {
      imageRef.current.onload = null;
      imageRef.current.onerror = null;
      imageRef.current = null;
    }
  };
  useLayoutEffect(() => {
    if (status === "loading") {
      load();
    }
    return () => {
      flush();
    };
  }, [load, status]);
  return useMemo8(
    () => ({
      imageProps: {
        crossOrigin,
        loading,
        onError,
        onLoad,
        sizes: sizes2,
        srcSet
      },
      status
    }),
    [crossOrigin, loading, onError, onLoad, sizes2, srcSet, status]
  );
}

// src/components/Image/useImage.ts
var defaultProps43 = {
  disableSkeleton: false,
  loading: "lazy",
  removeWrapper: false,
  radius: "none",
  zoomOnHover: false,
  zoomPercentage: 1.25
};
function useImage2(props) {
  const { componentProps, getDataAttributes } = useComponentProps(props, defaultProps43);
  const { imageProps: hookProps, status } = useImage(componentProps);
  const imageProps = mergeProps2(hookProps, componentProps);
  return { componentProps: imageProps, getDataAttributes, status };
}

// src/components/Image/Image.tsx
import { jsx as jsx85 } from "react/jsx-runtime";
var animation2 = keyframes8`
  0% {
    transform: translateX(-100%);
  }
  
  100% {
    transform: translateX(100%);
  }
`;
var StyledImageWrapper = styled68("div", getStyledOptions())(
  {
    display: "inline-flex",
    flexShrink: 0,
    overflow: "hidden",
    position: "relative"
  },
  (props) => {
    const { showSkeleton, theme } = props;
    const { image: image2 } = theme;
    return css56`
      ${getStyles(props)};

      ${showSkeleton && css56`
        background-color: ${image2.skeletonBg};

        &:before {
          animation: ${animation2} ${image2.animationDuration}s infinite ${image2.timingFunction};
          background-image: linear-gradient(
            to right,
            transparent 0,
            transparent 10%,
            ${image2.skeletonColor} 25%,
            transparent 40%
          );
          content: '';
          display: block;
          position: absolute;
          bottom: 0;
          left: 0;
          right: 0;
          top: 0;
        }
      `}
    `;
  }
);
var StyledImage = styled68.img((props) => {
  const { isLoading, removeWrapper, zoomOnHover, zoomPercentage } = props;
  return css56`
    max-width: 100%;
    object-fit: cover;
    opacity: ${isLoading ? 0 : 1};
    transition:
      opacity 0.3s,
      transform 0.3s;
    z-index: 10;
    ${removeWrapper && radiusStyles(props)};
    ${removeWrapper && shadowStyles(props)};

    ${zoomOnHover && css56`
      &:hover {
        transform: scale(${zoomPercentage});
      }
    `}
  `;
});
var Image2 = forwardRef36((props, ref) => {
  const { componentProps, getDataAttributes, status } = useImage2(props);
  const {
    disableSkeleton,
    fallbackSrc,
    height,
    isLoading: isLoadingProp,
    removeWrapper,
    src,
    width,
    zoomOnHover,
    ...rest
  } = componentProps;
  const isLoaded = status === "loaded" && !isLoadingProp;
  const isLoading = isLoadingProp ?? ["loading", "pending"].includes(status);
  const hasError = status === "failed";
  const showFallback = (!src || !isLoaded) && !!fallbackSrc;
  const showSkeleton = !disableSkeleton && isLoading;
  const { h, w } = useMemo9(() => {
    return {
      w: width ? px33(width) : "fit-content",
      h: height ? px33(height) : "auto"
    };
  }, [width, height]);
  const image2 = /* @__PURE__ */ jsx85(
    StyledImage,
    {
      ref,
      ...componentProps,
      ...getDataAttributes("Image"),
      "data-loaded": isLoaded,
      height: h,
      isLoading,
      removeWrapper,
      src: hasError && showFallback ? fallbackSrc : src,
      width: w,
      zoomOnHover: zoomOnHover && !removeWrapper,
      ...rest
    }
  );
  if (removeWrapper) {
    return image2;
  }
  return /* @__PURE__ */ jsx85(
    StyledImageWrapper,
    {
      ...getDataAttributes("ImageWrapper"),
      height: h,
      showSkeleton,
      width: w,
      ...rest,
      children: image2
    }
  );
});
Image2.displayName = "Image";

// src/components/Keyboard/Keyboard.tsx
import { forwardRef as forwardRef37, Fragment as Fragment4, useMemo as useMemo10 } from "react";
import { css as css57 } from "@emotion/react";
import styled69 from "@emotion/styled";
import { useMemoizedValue } from "@gilbarbara/hooks";

// src/components/Keyboard/useKeyboard.ts
var keyboardKeysMap = {
  command: "\u2318",
  option: "\u2325",
  alt: "\u2325",
  control: "\u2303",
  ctrl: "\u2303",
  shift: "\u21E7",
  enter: "\u21B5",
  delete: "\u232B",
  escape: "\u238B",
  tab: "\u21E5",
  capslock: "\u21EA",
  up: "\u2191",
  right: "\u2192",
  down: "\u2193",
  left: "\u2190",
  pageup: "\u21DE",
  pagedown: "\u21DF",
  home: "\u2196",
  end: "\u2198",
  help: "?",
  space: "\u2423"
};
var keyboardKeysLabelMap = {
  command: "Command",
  option: "Option",
  alt: "Alt",
  control: "Control",
  ctrl: "Control",
  shift: "Shift",
  enter: "Enter",
  delete: "Delete",
  escape: "Escape",
  tab: "Tab",
  capslock: "Caps Lock",
  up: "Up",
  right: "Right",
  down: "Down",
  left: "Left",
  pageup: "Page Up",
  pagedown: "Page Down",
  home: "Home",
  end: "End",
  help: "Help",
  space: "Space"
};
var defaultProps44 = {
  bg: "gray.100",
  border: { color: "gray.200" },
  color: "gray.600",
  gap: "xxxs",
  radius: "xs",
  shadow: "low",
  size: "md",
  textOnly: false
};
function useKeyboard(props) {
  return useComponentProps(props, defaultProps44);
}

// src/components/Keyboard/Keyboard.tsx
import { jsx as jsx86, jsxs as jsxs37 } from "react/jsx-runtime";
var StyledKeyboard = styled69("kbd", getStyledOptions())(
  {
    display: "inline-flex",
    lineHeight: 1
  },
  (props) => {
    const { bg, color, theme } = props;
    const { darkMode: darkMode2, spacing: spacing2 } = theme;
    const defaultBg = darkMode2 ? "gray.800" : "gray.50";
    const { mainColor, textColor: textColor2 } = getColorTokens(bg ?? defaultBg, color, theme);
    return css57`
      background-color: ${mainColor};
      color: ${textColor2};
      padding: ${spacing2.xxxs} ${spacing2.xs};
      ${getStyles(props, { skipColor: true, useFontSize: true })};

      > abbr {
        text-decoration: none;
      }
    `;
  }
);
var Keyboard = forwardRef37((props, ref) => {
  const { componentProps, getDataAttributes } = useKeyboard(props);
  const { children, keys, separator, textOnly, ...rest } = componentProps;
  const keysValue = useMemoizedValue(typeof keys === "string" ? [keys] : keys);
  const keysContent = useMemo10(() => {
    return keysValue.map((key, index) => /* @__PURE__ */ jsxs37(Fragment4, { children: [
      /* @__PURE__ */ jsx86("abbr", { title: keyboardKeysLabelMap[key], children: textOnly ? keyboardKeysLabelMap[key] : keyboardKeysMap[key] }),
      separator && index < keysValue.length - 1 && separator
    ] }, key));
  }, [keysValue, separator, textOnly]);
  return /* @__PURE__ */ jsxs37(StyledKeyboard, { ref, ...getDataAttributes("Keyboard"), ...rest, children: [
    keysContent,
    separator && children && keysValue.length > 0 && /* @__PURE__ */ jsx86("span", { children: separator }),
    children && /* @__PURE__ */ jsx86("span", { children })
  ] });
});
Keyboard.displayName = "Keyboard";

// src/components/List/Item.tsx
import { css as css58 } from "@emotion/react";
import styled70 from "@emotion/styled";
import { omit as omit22 } from "@gilbarbara/helpers";

// src/components/List/useList.ts
var defaultProps45 = {
  hideBorder: false,
  hideDivider: false,
  orientation: "vertical",
  radius: "xs",
  shadow: false,
  size: "md"
};
function getBorderColor(props) {
  const {
    borderColor,
    theme: { darkMode: darkMode2 }
  } = props;
  if (borderColor) {
    return borderColor;
  }
  return darkMode2 ? "gray.700" : "gray.100";
}
function useList(props) {
  return useComponentProps(props, defaultProps45);
}
function useListItem(props) {
  return useComponentProps(props);
}

// src/components/List/Item.tsx
import { jsx as jsx87 } from "react/jsx-runtime";
function getSpacing(size, spacing2) {
  switch (size) {
    case "sm": {
      return [spacing2.xs, spacing2.sm];
    }
    case "lg": {
      return [spacing2.md, spacing2.lg];
    }
    default: {
      return [spacing2.sm, spacing2.md];
    }
  }
}
var StyledListItem = styled70(
  Box,
  getStyledOptions()
)((props) => {
  const { hideBorder, hideDivider, orientation, size, theme } = props;
  const { spacing: spacing2 } = theme;
  const [spacerMain, spacerCross] = getSpacing(size, spacing2);
  const { mainColor } = getColorTokens(getBorderColor(props), null, theme);
  return css58`
    ${orientation === "vertical" && css58`
      border-bottom: ${hideDivider ? void 0 : `1px solid ${mainColor}`};
      padding: ${spacerMain} ${hideBorder ? 0 : spacerCross};

      &:last-of-type {
        border-bottom: none;
      }
    `};

    ${orientation === "horizontal" && css58`
      border-right: ${hideDivider ? void 0 : `1px solid ${mainColor}`};
      padding: ${hideBorder ? 0 : spacerMain} ${spacerCross};

      &:last-of-type {
        border-right: none;
      }
    `};

    ${getStyles(omit22(props, "border"), { skipBorder: true })};
  `;
});
function ListItem(props) {
  const {
    componentProps: { orientation, ...rest },
    getDataAttributes
  } = useListItem(props);
  return /* @__PURE__ */ jsx87(
    StyledListItem,
    {
      as: "li",
      ...getDataAttributes("ListItem"),
      ...rest,
      orientation
    }
  );
}

// src/components/List/List.tsx
import { forwardRef as forwardRef38 } from "react";
import { css as css59 } from "@emotion/react";
import styled71 from "@emotion/styled";
import { omit as omit23 } from "@gilbarbara/helpers";

// src/modules/react-helpers.tsx
import {
  Children as Children6,
  cloneElement as cloneElement6,
  isValidElement as isValidElement19
} from "react";
function enhanceChildren(children, type, props) {
  const getProps = (includeProps, nodes) => {
    const enhancedProps = includeProps ? { ...props } : {};
    if (nodes) {
      enhancedProps.children = nodes;
    }
    return enhancedProps;
  };
  return Children6.map(children, (child) => {
    if (!isValidElement19(child)) {
      return child;
    }
    const enhancedChildren = child.props.children ? enhanceChildren(child.props.children, type, props) : void 0;
    if (child.type === type) {
      return cloneElement6(child, getProps(true, enhancedChildren));
    }
    return cloneElement6(child, getProps(false, enhancedChildren));
  });
}
function getMatchingChildren(children, type) {
  const matchingElements = [];
  let hasInvalidElements = false;
  const processChildren = (nodes) => {
    Children6.forEach(nodes, (child) => {
      if (!isValidElement19(child)) {
        hasInvalidElements = true;
        console.warn("Invalid child detected: Not a React element.", child);
        return;
      }
      if (child.type === type) {
        matchingElements.push(child);
        return;
      }
      if (typeof child.type === "function") {
        const renderedOutput = child.type(child.props);
        processChildren(renderedOutput);
        return;
      }
      const { children: nestedChildren } = child.props || {};
      if (nestedChildren) {
        processChildren(nestedChildren);
      }
    });
  };
  processChildren(children);
  return { elements: matchingElements, hasInvalidElements };
}
function splitReactChildren(children, targetChild) {
  const matchingElements = [];
  const withoutTargetChildren = Children6.map(children, (item) => {
    if (!isValidElement19(item)) {
      return item;
    }
    if (item.type === targetChild) {
      matchingElements.push(item);
      return null;
    }
    return item;
  })?.filter(Boolean);
  return [withoutTargetChildren, matchingElements];
}

// src/components/List/List.tsx
import { jsx as jsx88 } from "react/jsx-runtime";
var StyledList = styled71("ul", getStyledOptions())(
  {
    display: "flex",
    listStylePosition: "inside",
    listStyleType: "none",
    margin: 0,
    overflow: "hidden",
    padding: 0
  },
  (props) => {
    const { hideBorder, orientation } = props;
    const borderProps = {};
    if (!hideBorder) {
      borderProps.border = [{ side: "all", color: getBorderColor(props) }];
    }
    return css59`
      flex-direction: ${orientation === "horizontal" ? "row" : "column"};
      ${getStyles({ ...props, ...borderProps })};
    `;
  }
);
var List2 = forwardRef38((props, ref) => {
  const {
    componentProps: { children, ...rest },
    getDataAttributes
  } = useList(props);
  return /* @__PURE__ */ jsx88(StyledList, { ref, ...getDataAttributes("List"), ...rest, children: enhanceChildren(children, ListItem, {
    ...omit23(rest, "radius", "shadow"),
    getDataAttributes
  }) });
});
List2.displayName = "List";

// src/components/MenuToggle/MenuToggle.tsx
import { useId as useId5, useState as useState20 } from "react";
import { css as css60 } from "@emotion/react";
import styled72 from "@emotion/styled";
import { omit as omit24, px as px34 } from "@gilbarbara/helpers";
import { useBreakpoint, usePrevious as usePrevious4, useUpdateEffect as useUpdateEffect6 } from "@gilbarbara/hooks";

// src/components/MenuToggle/useMenuToggle.ts
var defaultProps46 = {
  border: 2,
  isOpen: false,
  size: 16,
  srOnlyText: "Toggle Menu"
};
function useMenuToggle(props) {
  return useComponentProps(props, defaultProps46);
}

// src/components/MenuToggle/MenuToggle.tsx
import { jsx as jsx89, jsxs as jsxs38 } from "react/jsx-runtime";
var StyledMenuToggle = styled72(
  "label",
  getStyledOptions()
)((props) => {
  const { border, isActive, isOpen, radius: radius2, size } = props;
  const width = size * (22 / 16);
  const transform = size / 2 - border / 2;
  return css60`
    cursor: pointer;
    display: inline-flex;
    height: ${px34(size)};
    position: relative;
    width: ${px34(width)};
    ${getStyles(omit24(props, "border", "radius", "size"))};

    & input {
      display: none;
    }

    & span {
      background-color: currentcolor;
      border-radius: ${px34(radius2)};
      display: block;
      height: ${px34(border)};
      position: absolute;
      transition-duration: 0.25s;
      transition-property: transform, border-color;
      transition-timing-function: cubic-bezier(0.5, -0.5, 0.5, 1.5);
      left: 0;
      right: 0;

      &:nth-of-type(1) {
        top: 0;

        ${isOpen && css60`
          transform: translateY(${px34(transform)}) rotate(135deg);
        `};
      }

      &:nth-of-type(2),
      &:nth-of-type(3) {
        transform-origin: center;
      }

      &:nth-of-type(2) {
        transition-delay: 0.125s;
        top: ${px34(transform)};

        ${isActive && css60`
          background-color: transparent;
        `};
      }

      &:nth-of-type(3) {
        top: auto;
        bottom: 0;

        ${isOpen && css60`
          transform: translateY(-${px34(transform)}) rotate(-135deg);
        `};
      }
    }

    & input:checked + span {
      border-color: transparent;
      transition-delay: 0s;

      &:before,
      &:after {
        transition-delay: 0.125s;
      }

      &:before {
        transform: translateY(${px34(transform)}) rotate(135deg);
      }

      &:after {
        transform: translateY(-${px34(transform)}) rotate(-135deg);
      }
    }
  `;
});
function MenuToggle(props) {
  const { componentProps, getDataAttributes } = useMenuToggle(props);
  const { hideBreakpoint, isOpen, onToggle, srOnlyText, theme, ...rest } = componentProps;
  const [isActive, setActive] = useState20(isOpen);
  const id = useId5();
  const previousIsOpen = usePrevious4(isOpen);
  const breakpoints3 = formatBreakpoints(theme);
  const { min } = useBreakpoint(breakpoints3);
  useUpdateEffect6(() => {
    if (previousIsOpen === isOpen) {
      return;
    }
    if (isOpen) {
      setActive(true);
    } else {
      setTimeout(() => setActive(false), 250);
    }
  }, [isOpen, previousIsOpen]);
  const handleChange = () => {
    onToggle?.(!isOpen);
  };
  if (hideBreakpoint && min(hideBreakpoint)) {
    return null;
  }
  return /* @__PURE__ */ jsxs38(
    StyledMenuToggle,
    {
      "aria-label": srOnlyText,
      "data-open": isOpen,
      ...getDataAttributes("MenuToggle"),
      ...rest,
      htmlFor: id,
      isActive,
      isOpen,
      children: [
        /* @__PURE__ */ jsx89("input", { checked: isActive, id, onChange: handleChange, type: "checkbox" }),
        /* @__PURE__ */ jsx89("span", {}),
        /* @__PURE__ */ jsx89("span", {}),
        /* @__PURE__ */ jsx89("span", {})
      ]
    }
  );
}
MenuToggle.displayName = "MenuToggle";

// src/components/Modal/Modal.tsx
import { css as css61 } from "@emotion/react";
import styled73 from "@emotion/styled";
import { px as px35 } from "@gilbarbara/helpers";

// src/components/Modal/useModal.ts
var defaultProps47 = {
  ...defaultProps30,
  hideCloseButton: false,
  maxHeight: "80vh",
  maxWidth: "100vw",
  padding: "lg",
  radius: "lg",
  shadow: "high"
};
function useModal(props) {
  const { componentProps, getDataAttributes } = useComponentProps(props, defaultProps47);
  const [modalProps, portalProps] = splitPortalProps(componentProps);
  return { modalProps, portalProps, getDataAttributes };
}

// src/components/Modal/Modal.tsx
import { jsx as jsx90, jsxs as jsxs39 } from "react/jsx-runtime";
var StyledModal = styled73(
  "div",
  getStyledOptions()
)((props) => {
  const { maxWidth, theme, width } = props;
  const { darkColor: darkColor2, darkMode: darkMode2, white: white2 } = theme;
  return css61`
    background-color: ${darkMode2 ? darkColor2 : white2};
    color: ${darkMode2 ? white2 : darkColor2};
    max-width: ${px35(maxWidth)};
    width: ${width ? px35(width) : "auto"};
    ${getStyles(props)};
  `;
});
var StyledModalContent = styled73(
  "div",
  getStyledOptions()
)((props) => {
  const { maxHeight, padding, theme } = props;
  const { spacing: spacing2 } = theme;
  return css61`
    margin: 0 -${padding ? spacing2[padding] : padding};
    padding: 0 ${padding ? spacing2[padding] : padding};
    max-height: ${px35(maxHeight)};
    overflow-y: auto;
  `;
});
function Modal(props) {
  const { getDataAttributes, modalProps, portalProps } = useModal(props);
  const { children, hideCloseButton, maxHeight, style, title, ...rest } = modalProps;
  const { black: black2, darkMode: darkMode2, white: white2 } = rest.theme;
  let header;
  if (!hideCloseButton || title) {
    header = /* @__PURE__ */ jsxs39(Box, { align: "center", display: "flex", justify: title ? "space-between" : "flex-end", mb: "md", children: [
      title && /* @__PURE__ */ jsx90(H3, { style: { marginBottom: 0 }, children: title }),
      !hideCloseButton && /* @__PURE__ */ jsx90(ButtonUnstyled, { onClick: portalProps.onDismiss, children: /* @__PURE__ */ jsx90(Icon, { color: darkMode2 ? white2 : black2, name: "close", size: 26 }) })
    ] });
  }
  return /* @__PURE__ */ jsx90(Portal, { ...portalProps, showCloseButton: false, children: /* @__PURE__ */ jsxs39(
    StyledModal,
    {
      ...getDataAttributes("Modal"),
      ...rest,
      "data-open": portalProps.isOpen,
      style,
      children: [
        header,
        /* @__PURE__ */ jsx90(StyledModalContent, { maxHeight, padding: rest.padding, theme: rest.theme, children })
      ]
    }
  ) });
}
Modal.displayName = "Modal";

// src/components/NavBar/NavBar.tsx
import { forwardRef as forwardRef40, useCallback as useCallback20, useEffect as useEffect12, useRef as useRef16, useState as useState22 } from "react";
import { css as css63 } from "@emotion/react";
import styled75 from "@emotion/styled";
import { omit as omit26, px as px37 } from "@gilbarbara/helpers";
import { useMergeRefs as useMergeRefs4 } from "@gilbarbara/hooks";
import { opacify as opacify8 } from "colorizr";
import is27 from "is-lite";

// src/hooks/useScrollPosition.ts
import { useCallback as useCallback19, useEffect as useEffect11, useRef as useRef15 } from "react";
var isBrowser = typeof window !== "undefined";
function getScrollPosition(element) {
  if (!isBrowser) {
    return { x: 0, y: 0 };
  }
  if (!element) {
    return { x: window.scrollX, y: window.scrollY };
  }
  return { x: element.scrollLeft, y: element.scrollTop };
}
function useScrollPosition(props) {
  const { callback, delay = 30, elementRef, isEnabled } = props;
  const position = useRef15(
    isEnabled ? getScrollPosition(elementRef?.current) : { x: 0, y: 0 }
  );
  const throttleTimeout = useRef15(null);
  const handler = useCallback19(() => {
    const currentPos = getScrollPosition(elementRef?.current);
    if (typeof callback === "function") {
      callback({ prevPos: position.current, currPos: currentPos });
    }
    position.current = currentPos;
    throttleTimeout.current = null;
  }, [callback, elementRef]);
  useEffect11(() => {
    if (!isEnabled) {
      return () => {
      };
    }
    const handleScroll = () => {
      if (delay) {
        if (throttleTimeout.current) {
          clearTimeout(throttleTimeout.current);
        }
        throttleTimeout.current = setTimeout(handler, delay);
      } else {
        handler();
      }
    };
    const target = elementRef?.current || window;
    target.addEventListener("scroll", handleScroll);
    return () => {
      target.removeEventListener("scroll", handleScroll);
      if (throttleTimeout.current) {
        clearTimeout(throttleTimeout.current);
      }
    };
  }, [elementRef, delay, handler, isEnabled]);
  return position.current;
}

// src/components/Sidebar/Sidebar.tsx
import { forwardRef as forwardRef39 } from "react";
import { css as css62 } from "@emotion/react";
import styled74 from "@emotion/styled";
import { omit as omit25, pick as pick2, px as px36 } from "@gilbarbara/helpers";
import { useHasChanged, useSetState as useSetState5 } from "@gilbarbara/hooks";
import { opacify as opacify7 } from "colorizr";

// src/components/Sidebar/useSidebar.ts
var defaultProps48 = {
  ...defaultProps30,
  blurred: false,
  blurredRadius: 4,
  disableAnimation: false,
  isOpen: false,
  opacity: 1,
  p: "md",
  side: "left",
  width: 290
};
function useSidebar(props) {
  const { componentProps, getDataAttributes } = useComponentProps(props, defaultProps48);
  const [sidebarProps, portalProps] = splitPortalProps(componentProps);
  return { getDataAttributes, portalProps, sidebarProps };
}

// src/components/Sidebar/Sidebar.tsx
import { jsx as jsx91 } from "react/jsx-runtime";
var StyledSidebar = styled74(
  "div",
  getStyledOptions()
)((props) => {
  const {
    animationEasing,
    animationEnterDuration,
    animationExitDuration,
    bg,
    blurred,
    blurredRadius,
    color,
    disableAnimation,
    isActive,
    opacity: opacity2,
    origin,
    side,
    theme,
    width
  } = props;
  const { black: black2, darkColor: darkColor2, darkMode: darkMode2, white: white2 } = theme;
  const animationDuration = isActive ? animationExitDuration : animationEnterDuration;
  let selectedBg = darkMode2 ? darkColor2 : white2;
  let selectedColor = darkMode2 ? white2 : black2;
  let initialPosition = `translate3d(${side.startsWith("left") ? "-" : ""}100%, 0, 0)`;
  if (origin) {
    initialPosition = `translate3d(0, ${origin === "top" ? "-" : ""}100%, 0)`;
  }
  if (bg) {
    const { mainColor, textColor: textColor2 } = getColorTokens(bg, color, theme);
    selectedBg = mainColor;
    selectedColor = textColor2;
  }
  return css62`
    background-color: ${opacify7(selectedBg, opacity2, "rgb")};
    ${blurred && `backdrop-filter: blur(${px36(blurredRadius)});`};
    bottom: 0;
    color: ${selectedColor};
    left: ${side.startsWith("left") ? 0 : "auto"};
    overflow-y: auto;
    position: fixed;
    right: ${side.startsWith("right") ? 0 : "auto"};
    transform: ${isActive ? "translate3d(0, 0, 0)" : initialPosition};
    transition: ${disableAnimation ? "none" : `transform ${animationDuration}s ${animationEasing}`};
    top: 0;
    width: ${px36(width)};
    z-index: 20;
    ${getStyles(omit25(props, "opacity"), { skipColor: true })};
  `;
});
var Sidebar = forwardRef39((props, ref) => {
  const { getDataAttributes, portalProps, sidebarProps } = useSidebar(props);
  const {
    animationEasing,
    animationEnterDuration,
    animationExitDuration,
    disableAnimation,
    isOpen
  } = portalProps;
  const [{ isActive, isRendering }, setState] = useSetState5({
    isActive: isOpen,
    isRendering: isOpen
  });
  useHasChanged(isOpen, () => {
    if (isOpen) {
      setTimeout(
        () => {
          setState({ isActive: true, isRendering: true });
        },
        disableAnimation ? 0 : 100
      );
    } else {
      setState({ isActive: false });
      setTimeout(
        () => {
          setState({ isRendering: false });
        },
        disableAnimation ? 0 : animationExitDuration * 1e3
      );
    }
  });
  return /* @__PURE__ */ jsx91(
    Portal,
    {
      ...portalProps,
      isOpen: isOpen || isActive || isRendering,
      ...pick2(sidebarProps, "bottom", "left", "right", "top"),
      children: /* @__PURE__ */ jsx91(
        StyledSidebar,
        {
          ref,
          ...getDataAttributes("Sidebar"),
          animationEasing,
          animationEnterDuration,
          animationExitDuration,
          "data-open": isOpen,
          disableAnimation,
          isActive,
          ...sidebarProps
        }
      )
    }
  );
});
Sidebar.displayName = "Sidebar";

// src/components/NavBar/useNavBar.tsx
import { createContext as createContext2, useContext as useContext2, useMemo as useMemo11, useState as useState21 } from "react";
import { useEffectDeepCompare as useEffectDeepCompare3 } from "@gilbarbara/hooks";
import { jsx as jsx92 } from "react/jsx-runtime";
var defaultProps49 = {
  blurred: true,
  blurredRadius: 8,
  bordered: false,
  disableAnimation: false,
  disableScrollHandler: false,
  height: "64px",
  hideOnScroll: false,
  menuDefaultOpen: false,
  maxWidth: "100%",
  opacity: 0.8,
  placement: "top",
  position: "sticky",
  zIndex: 200
};
var NavBarContext = createContext2(void 0);
NavBarContext.displayName = "NavBarContext";
function NavBarProvider({ children, props, toggleMenu }) {
  const [state, setState] = useState21(props);
  useEffectDeepCompare3(() => {
    setState(props);
  }, [props]);
  const value = useMemo11(
    () => ({
      state,
      toggleMenu
    }),
    [state, toggleMenu]
  );
  return /* @__PURE__ */ jsx92(NavBarContext.Provider, { value, children });
}
function useNavBar(props) {
  return useComponentProps(props, defaultProps49);
}
function useNavBarContext() {
  const context = useContext2(NavBarContext);
  if (!context) {
    throw new Error("useNavBarContext must be used within a NavBarProvider");
  }
  return context;
}

// src/components/NavBar/NavBarMenu.tsx
import { jsx as jsx93 } from "react/jsx-runtime";
function NavBarMenu(props) {
  const { componentProps, getDataAttributes } = useComponentProps(props);
  const { onClose, onDismiss, onOpen, ...rest } = componentProps;
  const {
    state: { disableAnimation, height, isMenuOpen, placement },
    toggleMenu
  } = useNavBarContext();
  const handleDismiss = () => {
    toggleMenu(false);
  };
  return /* @__PURE__ */ jsx93(
    Sidebar,
    {
      ...getDataAttributes("NavBarMenu"),
      ...rest,
      animationExitDuration: 0.3,
      bottom: placement === "bottom" ? height : 0,
      disableAnimation,
      isOpen: isMenuOpen,
      onDismiss: handleDismiss,
      top: placement === "top" ? height : 0
    }
  );
}
NavBarMenu.displayName = "NavBarMenu";

// src/components/NavBar/NavBar.tsx
import { jsx as jsx94, jsxs as jsxs40 } from "react/jsx-runtime";
var StyledNavBar = styled75("nav", getStyledOptions())(
  {
    width: "100%"
  },
  (props) => {
    const {
      bg,
      blurred,
      blurredRadius,
      bordered,
      color,
      height,
      opacity: opacity2,
      placement,
      position,
      theme,
      zIndex: zIndex2
    } = props;
    const { black: black2, darkColor: darkColor2, darkMode: darkMode2, grayScale: grayScale2, white: white2 } = theme;
    const borderColor = darkMode2 ? grayScale2["700"] : grayScale2["200"];
    let selectedBg = darkMode2 ? darkColor2 : white2;
    let selectedColor = darkMode2 ? white2 : black2;
    if (bg) {
      const { mainColor, textColor: textColor2 } = getColorTokens(bg, color, theme);
      selectedBg = mainColor;
      selectedColor = textColor2;
    }
    if (opacity2) {
      selectedBg = opacify8(selectedBg, opacity2);
    }
    return css63`
      background-color: ${selectedBg};
      bottom: ${placement === "bottom" ? 0 : "auto"};
      color: ${selectedColor};
      ${bordered && `border-bottom: 1px solid ${borderColor};`};
      ${blurred && `backdrop-filter: blur(${px37(blurredRadius)});`};
      height: ${px37(height)};
      position: ${placement === "top" ? position : "fixed"};
      transform: translateY(${props.isHidden ? "-100%" : 0});
      transition: transform 0.3s;
      top: ${placement === "top" ? 0 : "auto"};
      z-index: ${zIndex2};
    `;
  }
);
var StyledHeader = styled75("header", getStyledOptions())(
  {
    alignItems: "center",
    display: "flex",
    justifyContent: "space-between",
    width: "100%"
  },
  (props) => {
    const { height, maxWidth, theme } = props;
    const { spacing: spacing2 } = theme;
    return css63`
      height: ${px37(height)};
      max-width: ${px37(maxWidth)};
      padding: 0 ${spacing2.md};
    `;
  }
);
var NavBar = forwardRef40((props, ref) => {
  const { componentProps, getDataAttributes } = useNavBar(props);
  const {
    children,
    disableScrollHandler,
    hideOnScroll,
    menuDefaultOpen,
    menuOpen,
    onScrollPosition,
    onToggleMenu,
    parentRef,
    ...rest
  } = componentProps;
  const [isHidden, setIsHidden] = useState22(false);
  const [isMenuOpen, setMenuOpen] = useState22(is27.boolean(menuOpen) ? menuOpen : menuDefaultOpen);
  const localRef = useRef16(null);
  const mergedRefs = useMergeRefs4(localRef, ref);
  const navHeight = useRef16(0);
  useEffect12(() => {
    navHeight.current = localRef.current?.offsetHeight ?? 0;
  }, []);
  useEffect12(() => {
    if (is27.boolean(menuOpen)) {
      setMenuOpen(menuOpen);
    }
  }, [menuOpen]);
  useScrollPosition({
    elementRef: parentRef,
    isEnabled: hideOnScroll || !disableScrollHandler,
    callback: ({ currPos, prevPos }) => {
      onScrollPosition?.(currPos.y);
      if (hideOnScroll) {
        setIsHidden((previous) => {
          const next = currPos.y > prevPos.y && currPos.y > navHeight.current;
          return next !== previous ? next : previous;
        });
      }
    }
  });
  const [childrenWithoutMenu, [menu]] = splitReactChildren(children, NavBarMenu);
  const handleToggleMenu = useCallback20(
    (isOpen) => {
      if (is27.boolean(menuOpen)) {
        return;
      }
      setMenuOpen(isOpen);
      onToggleMenu?.(isOpen);
    },
    [menuOpen, onToggleMenu]
  );
  return /* @__PURE__ */ jsx94(
    StyledNavBar,
    {
      ref: mergedRefs,
      ...getDataAttributes("NavBar"),
      "data-hidden": isHidden,
      isHidden,
      ...rest,
      children: /* @__PURE__ */ jsxs40(
        NavBarProvider,
        {
          props: { ...omit26(componentProps, "children", "theme"), isMenuOpen },
          toggleMenu: handleToggleMenu,
          children: [
            /* @__PURE__ */ jsx94(StyledHeader, { ...getDataAttributes("NavBarHeader"), ...rest, children: childrenWithoutMenu }),
            menu
          ]
        }
      )
    }
  );
});
NavBar.displayName = "NavBar";

// src/components/NavBar/NavBarContent.tsx
import { useBreakpoint as useBreakpoint2 } from "@gilbarbara/hooks";
import { jsx as jsx95 } from "react/jsx-runtime";
function NavBarContent(props) {
  const {
    componentProps: { hideBreakpoint, showBreakpoint, ...rest },
    getDataAttributes
  } = useComponentProps(props, {
    gap: "sm",
    justify: "start"
  });
  const breakpoints3 = formatBreakpoints(rest.theme);
  const { max, min } = useBreakpoint2(breakpoints3);
  let display = "flex";
  if (hideBreakpoint && min(hideBreakpoint) || showBreakpoint && max(showBreakpoint)) {
    display = "none";
  }
  return /* @__PURE__ */ jsx95(Flex, { ...getDataAttributes("NavBarContent"), display, ...rest });
}
NavBarContent.displayName = "NavBarContent";

// src/components/NavBar/NavBarMenuToggle.tsx
import { jsx as jsx96 } from "react/jsx-runtime";
function NavBarMenuToggle(props) {
  const { componentProps, getDataAttributes } = useComponentProps(props);
  const {
    state: { isMenuOpen },
    toggleMenu
  } = useNavBarContext();
  return /* @__PURE__ */ jsx96(
    MenuToggle,
    {
      ...componentProps,
      ...getDataAttributes("NavBarMenuToggle"),
      isOpen: isMenuOpen,
      onToggle: toggleMenu
    }
  );
}
NavBarMenuToggle.displayName = "NavBarMenuToggle";

// src/components/NonIdealState/NonIdealState.tsx
import { css as css64 } from "@emotion/react";
import styled76 from "@emotion/styled";
import { omit as omit27 } from "@gilbarbara/helpers";

// src/components/NonIdealState/useNonIdealState.ts
var defaultProps50 = {
  hideIcon: false,
  maxWidth: "600px",
  orientation: "vertical",
  padding: "md",
  shadow: false,
  size: "md",
  type: "not-found"
};
function useNonIdealState(props) {
  return useComponentProps(props, defaultProps50);
}

// src/components/NonIdealState/NonIdealState.tsx
import { jsx as jsx97, jsxs as jsxs41 } from "react/jsx-runtime";
var StyledNonIdealState = styled76(
  "div",
  getStyledOptions("type")
)((props) => {
  const { orientation } = props;
  const isHorizontal = orientation === "horizontal";
  return css64`
    ${isHorizontal ? "align-items: center;" : ""};
    display: ${isHorizontal ? "flex" : "block"};
    margin: 0 auto;
    text-align: ${isHorizontal ? "left" : "center"};
    width: 100%;
    ${getStyles(props, { skipBorder: true })};
  `;
});
function NonIdealState(props) {
  const { componentProps, getDataAttributes } = useNonIdealState(props);
  const { children, description, hideIcon, icon, orientation, size, title, type } = componentProps;
  const iconSize = {
    sm: 48,
    md: 64,
    lg: 96
  };
  const isVertical = orientation === "vertical";
  const template = {};
  const output = {};
  switch (type) {
    case "error": {
      template.icon = /* @__PURE__ */ jsx97(Icon, { name: "danger-o", size: iconSize[size] });
      template.title = "Something went wrong";
      template.description = "An unexpected error has occurred. Try reloading the page.";
      break;
    }
    case "no-results": {
      template.icon = /* @__PURE__ */ jsx97(Icon, { name: "search", size: iconSize[size] });
      template.title = "No search results";
      template.description = "Your search didn't match anything.";
      break;
    }
    case "not-found": {
      template.icon = /* @__PURE__ */ jsx97(Icon, { name: "smile-none", size: iconSize[size] });
      template.title = "Page not found";
      template.description = "We are sorry, but the page you requested doesn't exist.";
      break;
    }
    case "offline": {
      template.icon = /* @__PURE__ */ jsx97(Icon, { name: "arrows-exchange-alt-v", size: iconSize[size] });
      template.title = "No connection";
      template.description = "Please check our internet connection and try again.";
      break;
    }
  }
  if (!hideIcon && (icon ?? template.icon)) {
    output.icon = /* @__PURE__ */ jsx97(Flex, { align: "center", justify: "center", children: icon ? /* @__PURE__ */ jsx97(Icon, { name: icon, size: iconSize[size] }) : template.icon });
  }
  if (title !== null && (title || template.title)) {
    const content = title ?? template.title;
    switch (size) {
      case "sm": {
        output.title = /* @__PURE__ */ jsx97(H3, { mb: 0, children: content });
        break;
      }
      case "md": {
        output.title = /* @__PURE__ */ jsx97(H2, { mb: 0, children: content });
        break;
      }
      default: {
        output.title = /* @__PURE__ */ jsx97(H1, { mb: 0, children: content });
        break;
      }
    }
  }
  if (description !== null && (description || template.description)) {
    output.description = /* @__PURE__ */ jsx97(Paragraph, { mt: output.title ? "xxs" : void 0, children: description ?? template.description });
  }
  if (children) {
    output.content = /* @__PURE__ */ jsx97(Box, { mt: output.title ?? output.description ? "xl" : void 0, children });
  }
  return /* @__PURE__ */ jsxs41(
    StyledNonIdealState,
    {
      ...getDataAttributes("NonIdealState"),
      ...omit27(componentProps, "title", "type"),
      children: [
        output.icon,
        /* @__PURE__ */ jsxs41(Box, { ml: !isVertical ? "xs" : void 0, mt: isVertical && output.icon ? "sm" : void 0, children: [
          output.title,
          output.description
        ] }),
        output.content
      ]
    }
  );
}
NonIdealState.displayName = "NonIdealState";

// src/components/Page/Page.tsx
import { css as css65 } from "@emotion/react";
import styled77 from "@emotion/styled";
import { px as px38 } from "@gilbarbara/helpers";

// src/components/Page/usePage.ts
var defaultProps51 = {
  centered: false,
  isLoading: false,
  minHeight: "100vh",
  name: "Page",
  skipSpacing: false
};
function usePage(props) {
  return useComponentProps(props, defaultProps51);
}

// src/components/Page/Page.tsx
import { jsx as jsx98 } from "react/jsx-runtime";
var StyledPage = styled77(Box)((props) => {
  const { minHeight, skipSpacing } = props;
  return css65`
    ${paddingStyles(props, true)};
    display: grid;
    min-height: ${px38(minHeight)};
    width: 100%;
    ${!skipSpacing ? getContainerStyles(props, { responsive: true, verticalPadding: true }) : void 0};
  `;
});
function Page(props) {
  const { componentProps, getDataAttributes } = usePage(props);
  const { align, centered, children, isLoading, justify, maxWidth, name, textAlign, ...rest } = componentProps;
  const textAlignMap = {
    start: "left",
    "flex-start": "left",
    center: "center",
    end: "right",
    "flex-end": "right"
  };
  const shouldCenter = isLoading || centered;
  let textAlignValue = textAlign;
  if (!textAlign) {
    if (centered) {
      textAlignValue = "center";
    } else if (align && (["center", "end", "start"].includes(align) || align.startsWith("flex"))) {
      textAlignValue = textAlignMap[align];
    }
  }
  return /* @__PURE__ */ jsx98(StyledPage, { ...getDataAttributes(name), ...rest, children: /* @__PURE__ */ jsx98(
    Box,
    {
      align: shouldCenter ? "center" : align,
      direction: "column",
      display: shouldCenter || align || justify ? "flex" : void 0,
      fill: true,
      justify: shouldCenter ? "center" : justify,
      maxWidth,
      mx: maxWidth ? "auto" : void 0,
      textAlign: textAlignValue,
      children: isLoading ? /* @__PURE__ */ jsx98(Loader, { block: true }) : children
    }
  ) });
}
Page.displayName = "Page";

// src/components/ProgressBar/ProgressBar.tsx
import { cloneElement as cloneElement7, isValidElement as isValidElement20, useId as useId6 } from "react";
import { css as css66 } from "@emotion/react";
import styled78 from "@emotion/styled";
import { px as px39, round as round2 } from "@gilbarbara/helpers";
import is28 from "is-lite";

// src/components/ProgressBar/useProgressBar.ts
var defaultProps52 = {
  accent: "primary",
  formatLocale: "en-US",
  formatOptions: { style: "percent" },
  headerJustify: "space-between",
  headerPosition: "top",
  busy: false,
  maxValue: 100,
  minValue: 0,
  showValueLabel: false,
  size: "md",
  width: "100%"
};
function useProgressBar(props) {
  return useComponentProps(props, defaultProps52);
}

// src/components/ProgressBar/ProgressBar.tsx
import { jsx as jsx99, jsxs as jsxs42 } from "react/jsx-runtime";
var StyledProgressBar = styled78("div", getStyledOptions())(
  {
    display: "flex"
  },
  (props) => {
    const { headerPosition, theme, width } = props;
    const { darkMode: darkMode2, grayScale: grayScale2 } = theme;
    return css66`
      color: ${darkMode2 && grayScale2["200"]};
      flex-direction: ${headerPosition === "top" ? "column" : "column-reverse"};
      width: ${px39(width)};
      ${getStyles(props)};
    `;
  }
);
var StyledProgressTrack = styled78(
  "div",
  getStyledOptions()
)((props) => {
  const { accent, backgroundColor, busy, size, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2 } = theme;
  const { mainColor } = getColorTokens(accent, null, theme);
  let trackColor = darkMode2 ? grayScale2["800"] : grayScale2["100"];
  if (backgroundColor) {
    trackColor = getColorTokens(backgroundColor, null, theme).mainColor;
  }
  const heightMap = {
    sm: "6px",
    md: "12px",
    lg: "18px"
  };
  return css66`
    background-color: ${trackColor};
    border-radius: ${heightMap[size]};
    line-height: 1;
    height: ${heightMap[size]};
    overflow: hidden;

    > div {
      background-color: ${mainColor};
      border-radius: ${heightMap[size]};
      height: ${heightMap[size]};
      transition: width 0.4s;
      width: 0;

      ${busy && css66`
        animation: ${horizontalScale} 1.5s ${easing} infinite normal none running;
        width: 100%;
      `};
    }
  `;
});
function ProgressBar(props) {
  const { componentProps, getDataAttributes } = useProgressBar(props);
  const {
    accent,
    backgroundColor,
    busy,
    formatLocale,
    formatOptions,
    headerJustify,
    headerPosition,
    label,
    maxValue,
    minValue,
    showValueLabel,
    size,
    textSize,
    value,
    ...rest
  } = componentProps;
  const labelId = useId6();
  const percentage = is28.number(value) ? round2((value - minValue) / (maxValue - minValue)) : void 0;
  const formattedValue = is28.number(value) && is28.number(percentage) ? new Intl.NumberFormat(formatLocale, formatOptions).format(
    formatOptions.style === "percent" ? percentage : value
  ) : void 0;
  const content = {};
  if (label) {
    content.label = isValidElement20(label) ? cloneElement7(label, { id: labelId }) : /* @__PURE__ */ jsx99(Text, { id: labelId, size: textSize ?? size, children: label });
  }
  if (showValueLabel && formattedValue) {
    content.value = /* @__PURE__ */ jsx99(Text, { size: textSize ?? size, children: formattedValue });
  }
  if (content.label || content.value) {
    content.header = /* @__PURE__ */ jsxs42(
      Flex,
      {
        ...getDataAttributes("ProgressBarHeader"),
        justify: headerJustify,
        mb: headerPosition === "top" ? "xs" : 0,
        mt: headerPosition === "bottom" ? "xs" : 0,
        children: [
          content.label,
          content.value
        ]
      }
    );
  }
  return /* @__PURE__ */ jsxs42(
    StyledProgressBar,
    {
      "aria-labelledby": label ? labelId : void 0,
      "aria-valuemax": maxValue,
      "aria-valuemin": minValue,
      "aria-valuenow": value,
      "aria-valuetext": formattedValue,
      "data-busy": busy,
      ...getDataAttributes("ProgressBar"),
      headerPosition,
      role: "progressbar",
      ...rest,
      children: [
        content.header,
        /* @__PURE__ */ jsx99(
          StyledProgressTrack,
          {
            accent,
            backgroundColor,
            busy,
            size,
            theme: rest.theme,
            children: percentage ? /* @__PURE__ */ jsx99("div", { style: { width: `${percentage * 100}%` } }) : /* @__PURE__ */ jsx99("div", {})
          }
        )
      ]
    }
  );
}
ProgressBar.displayName = "ProgressBar";

// src/components/ProgressCircle/ProgressCircle.tsx
import { cloneElement as cloneElement8, isValidElement as isValidElement21, useId as useId7, useMemo as useMemo12 } from "react";
import { css as css67 } from "@emotion/react";
import styled79 from "@emotion/styled";
import { omit as omit28, px as px40, round as round3 } from "@gilbarbara/helpers";
import is29 from "is-lite";

// src/components/ProgressCircle/useProgressCircle.ts
var defaultProps53 = {
  accent: "primary",
  busy: false,
  formatLocale: "en-US",
  formatOptions: { style: "percent" },
  gap: "xs",
  labelPosition: "top",
  maxValue: 100,
  minValue: 0,
  showValueLabel: false,
  size: "md",
  strokeWidth: 3
};
function useProgressCircle(props) {
  return useComponentProps(props, defaultProps53);
}

// src/components/ProgressCircle/ProgressCircle.tsx
import { jsx as jsx100, jsxs as jsxs43 } from "react/jsx-runtime";
var StyledProgressCircle = styled79("div", getStyledOptions())(
  {
    alignItems: "center",
    display: "flex",
    justifyContent: "center"
  },
  (props) => {
    const { labelPosition, size, theme } = props;
    const { darkMode: darkMode2, grayScale: grayScale2 } = theme;
    return css67`
      color: ${darkMode2 && grayScale2["200"]};
      flex-direction: ${labelPosition === "top" ? "column" : "column-reverse"};
      width: ${px40(size)};
      ${getStyles(omit28(props, "size"))};
    `;
  }
);
var StyledSVG = styled79(
  "svg",
  getStyledOptions()
)((props) => {
  const { busy, size } = props;
  const sizeMap = {
    sm: "32px",
    md: "48px",
    lg: "64px"
  };
  const componentSize = is29.number(size) ? px40(size) : sizeMap[size];
  return css67`
    border-radius: ${componentSize};
    height: ${componentSize};
    overflow: hidden;
    position: relative;
    width: ${componentSize};

    ${busy && css67`
      animation: ${rotate} 0.8s ${easing} infinite normal none running;
    `};
  `;
});
var StyledWrapper = styled79.div`
  display: flex;
  position: relative;
`;
var StyledLabel6 = styled79(
  "span",
  getStyledOptions()
)(
  (props) => {
    const { absolute, size, textSize, theme } = props;
    const { typography: typography2 } = theme;
    const fontSizeMap = {
      sm: typography2.xxs.fontSize,
      md: typography2.xs.fontSize,
      lg: typography2.sm.fontSize
    };
    let fontSize = is29.number(size) ? typography2.md.fontSize : fontSizeMap[size];
    if (textSize) {
      fontSize = is29.number(textSize) ? px40(textSize) : typography2[textSize].fontSize;
    }
    if (!absolute && !is29.number(size) && !textSize) {
      fontSize = typography2[size].fontSize;
    }
    return css67`
      font-size: ${fontSize};

      ${absolute && css67`
        left: 50%;
        position: absolute;
        top: 50%;
        transform: translate(-50%, -50%);
        white-space: nowrap;
      `}
    `;
  }
);
function ProgressCircle(props) {
  const { componentProps, getDataAttributes } = useProgressCircle(props);
  const {
    accent,
    backgroundColor,
    busy,
    formatLocale,
    formatOptions,
    label,
    labelPosition,
    maxValue,
    minValue,
    showValueLabel,
    size,
    strokeWidth,
    textSize,
    value,
    ...rest
  } = componentProps;
  const labelId = useId7();
  const { darkMode: darkMode2, grayScale: grayScale2 } = rest.theme;
  const trackColor = darkMode2 ? grayScale2["800"] : grayScale2["100"];
  const { mainColor } = getColorTokens(accent, null, rest.theme);
  const center = 16;
  const radius2 = 16 - strokeWidth / 2;
  const circumference = 2 * radius2 * Math.PI;
  const percentage = useMemo12(() => {
    if (busy) {
      return 0.25;
    }
    return value ? round3((value - minValue) / (maxValue - minValue)) : 0;
  }, [busy, maxValue, minValue, value]);
  const offset = circumference - percentage * circumference;
  const formattedValue = is29.number(value) && is29.number(percentage) ? new Intl.NumberFormat(formatLocale, formatOptions).format(
    formatOptions.style === "percent" ? percentage : value
  ) : void 0;
  const content = {};
  if (label) {
    content.label = isValidElement21(label) ? cloneElement8(label, { id: labelId }) : /* @__PURE__ */ jsx100(StyledLabel6, { id: labelId, size, textSize, theme: rest.theme, children: label });
  }
  if (showValueLabel && formattedValue) {
    content.value = /* @__PURE__ */ jsx100(StyledLabel6, { absolute: true, size, textSize, theme: rest.theme, children: formattedValue });
  }
  return /* @__PURE__ */ jsxs43(
    StyledProgressCircle,
    {
      ...rest,
      "aria-labelledby": label ? labelId : void 0,
      "aria-valuemax": maxValue,
      "aria-valuemin": minValue,
      "aria-valuenow": value,
      "aria-valuetext": formattedValue,
      "data-busy": busy,
      ...getDataAttributes("ProgressCircle"),
      labelPosition,
      role: "progressbar",
      children: [
        /* @__PURE__ */ jsxs43(StyledWrapper, { children: [
          /* @__PURE__ */ jsxs43(
            StyledSVG,
            {
              busy,
              fill: "none",
              size,
              strokeWidth,
              viewBox: "0 0 32 32",
              children: [
                /* @__PURE__ */ jsx100(
                  "circle",
                  {
                    cx: center,
                    cy: center,
                    r: radius2,
                    role: "presentation",
                    stroke: backgroundColor ?? trackColor
                  }
                ),
                /* @__PURE__ */ jsx100(
                  "circle",
                  {
                    cx: center,
                    cy: center,
                    r: radius2,
                    role: "presentation",
                    stroke: mainColor,
                    strokeDasharray: `${circumference} ${circumference}`,
                    strokeDashoffset: offset,
                    strokeLinecap: "round",
                    transform: "rotate(-90 16 16)"
                  }
                )
              ]
            }
          ),
          content.value
        ] }),
        content.label
      ]
    }
  );
}
ProgressCircle.displayName = "ProgressCircle";

// src/components/Quote/Quote.tsx
import { forwardRef as forwardRef41 } from "react";
import { css as css68 } from "@emotion/react";
import styled80 from "@emotion/styled";
import { omit as omit29, px as px41 } from "@gilbarbara/helpers";

// src/components/Quote/useQuote.ts
var defaultProps54 = {
  ...textDefaultOptions,
  accent: "primary",
  attributionGap: "md",
  attributionSize: "sm",
  border: "left",
  borderSize: "md",
  gap: "md",
  size: "lg"
};
function useQuote(props) {
  return useComponentProps(props, defaultProps54);
}

// src/components/Quote/Quote.tsx
import { jsx as jsx101, jsxs as jsxs44 } from "react/jsx-runtime";
var borderSizes2 = {
  sm: "1px",
  md: "2px",
  lg: "4px"
};
var StyledFigure = styled80("figure", getStyledOptions())(
  {
    display: "flex",
    flexDirection: "column",
    margin: 0
  },
  (props) => {
    const { accent, border, borderSize, gap, theme } = props;
    const { spacing: spacing2 } = theme;
    const { mainColor } = getColorTokens(accent, null, theme);
    const styles2 = {};
    switch (border) {
      case "bottom": {
        styles2.borderBottom = `${borderSizes2[borderSize]} solid ${mainColor}`;
        styles2.paddingBottom = px41(spacing2[gap]);
        break;
      }
      case "left": {
        styles2.borderLeft = `${borderSizes2[borderSize]} solid ${mainColor}`;
        styles2.paddingLeft = px41(spacing2[gap]);
        break;
      }
      case "right": {
        styles2.borderRight = `${borderSizes2[borderSize]} solid ${mainColor}`;
        styles2.paddingRight = px41(spacing2[gap]);
        break;
      }
      case "top": {
        styles2.borderTop = `${borderSizes2[borderSize]} solid ${mainColor}`;
        styles2.paddingTop = px41(spacing2[gap]);
        break;
      }
    }
    return css68`
      ${styles2};
      ${getStyles(omit29(props, "border", "size"), { skipBorder: true })};
    `;
  }
);
var StyledQuote = styled80("blockquote", getStyledOptions())(
  {
    display: "block",
    margin: 0
  },
  (props) => {
    return css68`
      ${baseStyles(props.theme)};
      ${textStyles(props)};
    `;
  }
);
var StyledAttribution = styled80(
  "cite",
  getStyledOptions()
)((props) => {
  const { gap, theme } = props;
  const { spacing: spacing2 } = theme;
  return css68`
    display: flex;
    margin-top: ${spacing2[gap]};
    ${textStyles(props)};
  `;
});
var Quote = forwardRef41((props, ref) => {
  const { componentProps, getDataAttributes } = useQuote(props);
  const { attribution, attributionGap, attributionSize, children, ...rest } = componentProps;
  return /* @__PURE__ */ jsxs44(StyledFigure, { ref, ...getDataAttributes("Quote"), ...rest, children: [
    /* @__PURE__ */ jsx101(StyledQuote, { ...rest, children }),
    attribution && /* @__PURE__ */ jsx101(StyledAttribution, { gap: attributionGap, size: attributionSize, theme: rest.theme, children: attribution })
  ] });
});
Quote.displayName = "Quote";

// src/components/RadioGroup/RadioGroup.tsx
import { useCallback as useCallback21, useEffect as useEffect13, useState as useState23 } from "react";
import { css as css69 } from "@emotion/react";
import styled81 from "@emotion/styled";
import { usePrevious as usePrevious5 } from "@gilbarbara/hooks";

// src/components/RadioGroup/useRadioGroup.ts
var defaultProps55 = {
  accent: "primary",
  borderless: false,
  disabled: false,
  inline: false,
  size: "md"
};
function useRadioGroup(props) {
  return useComponentProps(props, defaultProps55);
}

// src/components/RadioGroup/RadioGroup.tsx
import { jsx as jsx102 } from "react/jsx-runtime";
var StyledRadioGroup = styled81(
  "div",
  getStyledOptions()
)((props) => {
  const { inline, theme } = props;
  const { dataAttributeName: dataAttributeName2, spacing: spacing2 } = theme;
  return css69`
    display: flex;
    flex-direction: ${inline ? "row" : "column"};
    ${getStyles(props)};

    ${inline && css69`
      margin-top: 0;

      [data-${dataAttributeName2}='Radio'] + [data-${dataAttributeName2}='Radio'] {
        margin-left: ${spacing2.xs};
      }
    `};
  `;
});
function RadioGroup(props) {
  const { componentProps, getDataAttributes } = useRadioGroup(props);
  const {
    accent,
    borderless,
    defaultValue,
    disabled,
    inline,
    items,
    name,
    onChange,
    size,
    value,
    ...rest
  } = componentProps;
  const [selectedValue, setSelectedValue] = useState23(value ?? defaultValue);
  const previousProps = usePrevious5(props);
  useEffect13(() => {
    if (previousProps && value && previousProps.value !== value) {
      setSelectedValue(value);
    }
  }, [previousProps, value]);
  const handleChange = useCallback21(
    (event) => {
      const { target } = event;
      const numericValue = Number(target.value);
      const currentValue2 = !Number.isNaN(numericValue) ? numericValue : target.value;
      onChange?.(event);
      if (!value && !disabled) {
        setSelectedValue(currentValue2);
      }
    },
    [disabled, onChange, value]
  );
  if (!items?.length) {
    return null;
  }
  const currentValue = !!value && value !== selectedValue ? value : selectedValue;
  return /* @__PURE__ */ jsx102(
    StyledRadioGroup,
    {
      ...getDataAttributes("RadioGroup"),
      inline,
      role: "radiogroup",
      ...rest,
      children: items.map((item) => /* @__PURE__ */ jsx102(
        Radio,
        {
          accent: item.accent ?? accent,
          align: "start",
          borderless,
          checked: item.value === currentValue,
          disabled: disabled || item.disabled,
          label: item.label ?? item.value,
          mb: "xxs",
          name,
          onChange: handleChange,
          size,
          type: "radio",
          value: item.value
        },
        item.value
      ))
    }
  );
}
RadioGroup.displayName = "RadioGroup";

// src/components/Search/Search.tsx
import {
  memo as memo5,
  useCallback as useCallback22,
  useEffect as useEffect15,
  useRef as useRef18
} from "react";
import { css as css72 } from "@emotion/react";
import styled84 from "@emotion/styled";
import { px as px43 } from "@gilbarbara/helpers";
import { useSetState as useSetState6 } from "@gilbarbara/hooks";

// src/components/Search/Items.tsx
import { forwardRef as forwardRef42, useEffect as useEffect14, useRef as useRef17 } from "react";
import { css as css71 } from "@emotion/react";
import styled83 from "@emotion/styled";
import { px as px42 } from "@gilbarbara/helpers";

// src/components/Search/Item.tsx
import { memo as memo4 } from "react";
import { css as css70 } from "@emotion/react";
import styled82 from "@emotion/styled";
import { jsx as jsx103 } from "react/jsx-runtime";
var StyledSearchItem = styled82(
  "div",
  getStyledOptions()
)((props) => {
  const { accent, isSelected, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, spacing: spacing2, typography: typography2, white: white2 } = theme;
  const { mainColor, textColor: textColor2 } = getColorTokens(accent, null, theme);
  const selected = css70`
    background-color: ${mainColor};
    color: ${textColor2};

    a {
      color: ${textColor2};
    }
  `;
  return css70`
    color: ${darkMode2 ? white2 : grayScale2["700"]};
    cursor: pointer;
    font-size: ${typography2.md.fontSize};
    padding: ${spacing2.sm} ${spacing2.md};
    transition: background-color 0.3s;

    &:focus-visible,
    &:hover,
    &:active {
      ${selected};
    }

    ${isSelected && selected},

    a {
      color: ${grayScale2["700"]};
      text-decoration: none;
    }
  `;
});
function SearchItemComponent(props) {
  const { accent, children, getDataAttributes, isSelected, onSelect, theme, value } = props;
  return /* @__PURE__ */ jsx103(
    StyledSearchItem,
    {
      accent,
      ...getDataAttributes("SearchItem"),
      "data-value": value,
      isSelected,
      onClick: onSelect,
      onKeyDown: onSelect,
      role: "listitem",
      tabIndex: 0,
      theme,
      children
    }
  );
}
SearchItemComponent.displayName = "SearchItem";
var Item_default = memo4(SearchItemComponent);

// src/components/Search/Items.tsx
import { jsx as jsx104 } from "react/jsx-runtime";
var StyledSearchItems = styled83(
  "div",
  getStyledOptions()
)((props) => {
  const { active, height, theme } = props;
  const { darkMode: darkMode2, grayScale: grayScale2, radius: radius2, shadow: shadow2, spacing: spacing2, white: white2 } = theme;
  return css71`
    background-color: ${darkMode2 ? grayScale2["800"] : white2};
    border-radius: ${radius2.xxs};
    box-shadow: ${shadow2.mid};
    left: 0;
    max-height: ${px42(height)};
    margin-top: ${spacing2.xs};
    overflow-y: auto;
    position: absolute;
    right: 0;
    top: 100%;
    transform-origin: top;
    transform: scaleY(0);
    transition: transform 0.3s;

    ${active && css71`
      transform: scaleY(1);
    `}
  `;
});
function getSharedStyles2(spacing2) {
  return css71`
    align-items: center;
    display: flex;
    padding: ${spacing2.xs} ${spacing2.sm};
    width: 100%;
  `;
}
var Empty2 = styled83(
  "div",
  getStyledOptions()
)((props) => {
  const { spacing: spacing2 } = props.theme;
  return css71`
    ${getSharedStyles2(spacing2)};
    justify-content: center;
  `;
});
var SearchItems = forwardRef42((props, ref) => {
  const {
    accent,
    active,
    cursor,
    getDataAttributes,
    height,
    isBusy,
    items,
    noResultsLabel,
    onSelect,
    theme
  } = props;
  const isActive = useRef17(false);
  useEffect14(() => {
    isActive.current = true;
    return () => {
      isActive.current = false;
    };
  }, []);
  const content = !items.length && !isBusy ? /* @__PURE__ */ jsx104(Empty2, { theme, children: noResultsLabel }) : items.map((data, index) => /* @__PURE__ */ jsx104(
    Item_default,
    {
      accent: data.accent ?? accent,
      getDataAttributes,
      isSelected: cursor === index,
      onSelect,
      theme,
      value: data.value,
      children: data.label ?? data.value
    },
    data.value
  ));
  return /* @__PURE__ */ jsx104(
    StyledSearchItems,
    {
      ref,
      active,
      ...getDataAttributes("SearchItems"),
      height,
      role: "list",
      theme,
      children: content
    }
  );
});
SearchItems.displayName = "SearchItems";
var Items_default2 = SearchItems;

// src/components/Search/useSearch.ts
var defaultProps56 = {
  accent: "primary",
  borderless: false,
  disableCloseOnBlur: false,
  disableKeyboardNavigation: false,
  disabled: false,
  height: 230,
  hideIcon: false,
  icon: "search",
  loading: false,
  noResultsLabel: "Nothing found",
  onSearchDebounce: 250,
  placeholder: "Search for...",
  showListOnFocus: true
};
function useSearch(props) {
  return useComponentProps(props, defaultProps56);
}

// src/components/Search/Search.tsx
import { jsx as jsx105, jsxs as jsxs45 } from "react/jsx-runtime";
var StyledSearch = styled84(
  "div",
  getStyledOptions()
)((props) => {
  const { width = "100%" } = props;
  return css72`
    position: relative;
    width: ${px43(width)};
    ${marginStyles(props)};
  `;
});
function SearchComponent(props) {
  const { componentProps, getDataAttributes } = useSearch(props);
  const {
    accent,
    borderless,
    disableCloseOnBlur,
    disabled,
    disableKeyboardNavigation,
    height,
    hideIcon,
    icon,
    items,
    loading,
    onBlur,
    onFocus,
    onSearch,
    onSearchDebounce,
    onSelect,
    onType,
    placeholder,
    remote,
    showListOnFocus,
    ...rest
  } = componentProps;
  const { dataAttributeName: dataAttributeName2 } = rest.theme;
  const [{ active, currentItems, cursor, focus, typing, value }, setState] = useSetState6({
    active: false,
    currentItems: remote ? [] : items,
    cursor: -1,
    focus: false,
    typing: false,
    value: ""
  });
  const mainRef = useRef18(null);
  const itemsRef = useRef18(null);
  const isMounted = useRef18(false);
  const timeout = useRef18(0);
  useEffect15(() => {
    isMounted.current = true;
    return () => {
      isMounted.current = false;
    };
  }, []);
  const updateState = useCallback22(
    (state) => {
      if (isMounted.current) {
        setState(state);
      }
    },
    [setState]
  );
  const close = useCallback22(() => {
    if (disableCloseOnBlur) {
      return;
    }
    updateState({ active: false });
  }, [disableCloseOnBlur, updateState]);
  const handleBlur = useCallback22(
    (event) => {
      const inputValue = event.target.value;
      updateState({ cursor: -1, focus: false });
      onBlur?.(inputValue);
    },
    [onBlur, updateState]
  );
  const handleChange = useCallback22(
    (event) => {
      const inputValue = event.target.value;
      const nextState = { active: !!inputValue, value: inputValue };
      onType?.(inputValue);
      if (onSearchDebounce) {
        updateState({ ...nextState, typing: true });
        clearTimeout(timeout.current);
        timeout.current = window.setTimeout(() => {
          updateState({
            typing: false,
            currentItems: remote ? [] : items.filter((d) => d.value.toLowerCase().includes(inputValue.toLowerCase()))
          });
          onSearch?.(inputValue);
          timeout.current = 0;
        }, onSearchDebounce);
      } else {
        updateState({
          ...nextState,
          currentItems: remote ? [] : items.filter((d) => d.value.toLowerCase().includes(inputValue.toLowerCase()))
        });
        onSearch?.(inputValue);
      }
    },
    [items, onSearch, onSearchDebounce, onType, remote, updateState]
  );
  const handleFocus = useCallback22(
    (event) => {
      const inputValue = event.target.value;
      updateState({
        active: showListOnFocus && (remote ? !!items.length : !!currentItems.length),
        focus: true
      });
      onFocus?.(inputValue);
    },
    [currentItems.length, items.length, onFocus, remote, showListOnFocus, updateState]
  );
  const handleKeyDown2 = useCallback22(
    (event) => {
      const { code } = event;
      const itemElement = itemsRef.current;
      if (!active || !itemElement) {
        return;
      }
      const nextCursor = cursor;
      if (code === "Enter") {
        const { dataset } = itemElement.children[cursor];
        updateState({ active: false, value: "" });
        onSelect(dataset.value ?? "");
      }
      updateState({ cursor: nextCursor });
      if (itemElement.children[nextCursor]) {
        itemElement.children[nextCursor].scrollIntoView({ block: "end" });
      }
    },
    [active, cursor, onSelect, updateState]
  );
  const handleSelect = useCallback22(
    (event) => {
      const { dataset } = event.currentTarget;
      if ("code" in event && !disableKeyboardNavigation) {
        if (["Enter", "Space"].includes(event.code)) {
          updateState({ active: false, value: "" });
          onSelect(dataset.value ?? "");
        }
      } else {
        updateState({ active: false, value: "" });
        onSelect(dataset.value ?? "");
      }
    },
    [disableKeyboardNavigation, onSelect, updateState]
  );
  const handleToggleList = (force) => {
    return () => {
      updateState({ active: force ?? !active });
    };
  };
  const { addScope, removeScope } = useKeyboardNavigation(mainRef, {
    arrowNavigation: "both",
    disabled: disableKeyboardNavigation,
    escCallback: handleToggleList(false),
    selector: `[data-${dataAttributeName2}="SearchItem"]`
  });
  useEffect15(() => {
    if (active) {
      addScope();
    }
    return () => {
      removeScope();
    };
  }, [active, addScope, removeScope]);
  let prefixSpacing = borderless ? 32 : true;
  if (hideIcon) {
    prefixSpacing = false;
  }
  const isBusy = typing || loading;
  return /* @__PURE__ */ jsx105(StyledSearch, { ref: mainRef, ...getDataAttributes("Search"), ...rest, children: /* @__PURE__ */ jsxs45(ClickOutside, { active, onClick: close, children: [
    /* @__PURE__ */ jsx105(
      FormElementWrapper,
      {
        endContent: isBusy ? /* @__PURE__ */ jsx105(Icon, { name: "spinner", spin: true }) : void 0,
        size: borderless ? [24, 40] : 40,
        startContent: hideIcon ? void 0 : /* @__PURE__ */ jsx105(Icon, { color: focus || value ? accent : void 0, name: icon, size: 24 }),
        children: /* @__PURE__ */ jsx105(
          Input2,
          {
            accent,
            autoComplete: "off",
            borderless,
            ...getDataAttributes("SearchInput"),
            disabled,
            name: "search",
            onBlur: handleBlur,
            onChange: handleChange,
            onFocus: handleFocus,
            onKeyDown: handleKeyDown2,
            placeholder,
            prefixSpacing,
            value
          }
        )
      }
    ),
    /* @__PURE__ */ jsx105(
      Items_default2,
      {
        ref: itemsRef,
        accent,
        active,
        cursor,
        getDataAttributes,
        height,
        isBusy,
        items: remote ? items : currentItems,
        onSelect: handleSelect,
        ...rest
      }
    )
  ] }) });
}
var Search2 = memo5(SearchComponent);
Search2.displayName = "Search";

// src/components/Skeleton/Skeleton.tsx
import { forwardRef as forwardRef43, isValidElement as isValidElement22 } from "react";
import { css as css73, keyframes as keyframes9 } from "@emotion/react";
import styled85 from "@emotion/styled";
import { useIsFirstRender } from "@gilbarbara/hooks";

// src/components/Skeleton/useSkeleton.ts
var baseDefaultProps = {
  accent: "white",
  animationDelay: 0,
  animationDuration: 1.2,
  appearDuration: 0.4,
  bg: "gray.50",
  isLoaded: false,
  radius: "xs"
};
var defaultProps57 = {
  ...baseDefaultProps,
  fitContent: false
};
var circleDefaultProps = {
  ...baseDefaultProps,
  size: 48
};
var textDefaultProps = {
  ...baseDefaultProps,
  gap: "xs",
  lines: 3,
  height: 16
};
function useSkeleton(props) {
  return useComponentProps(props, defaultProps57);
}
function useSkeletonCircle(props) {
  return useComponentProps(props, circleDefaultProps);
}
function useSkeletonText(props) {
  return useComponentProps(props, textDefaultProps);
}

// src/components/Skeleton/Skeleton.tsx
import { jsx as jsx106 } from "react/jsx-runtime";
var bgAnimation = keyframes9`
  0% {
    background-position: 60% 0;
  }
  100% {
    background-position: -100% 0;
  }
`;
var StyledSkeleton = styled85("div", getStyledOptions())(
  {
    display: "flex",
    flexDirection: "column",
    pointerEvents: "none",
    userSelect: "none"
  },
  (props) => {
    const { accent, animationDelay, animationDuration, bg, fitContent, theme } = props;
    const { mainColor: accentColor } = getColorTokens(accent, null, theme);
    const { mainColor: bgColor } = getColorTokens(bg, null, theme);
    return css73`
    animation: ${bgAnimation} ${animationDuration}s infinite ease-in-out;
    animation-delay: ${animationDelay}s;
    background: ${bgColor} linear-gradient(90deg, ${bgColor} 0, ${bgColor} 10%, ${accentColor} 25%, ${bgColor} 40%, ${bgColor} 100%);
    background-position: 60% 0;
    background-repeat: no-repeat;
    background-size: 200% 100%;
    width: ${fitContent ? "fit-content" : void 0};
    ${getStyles(props, { skipColor: true })};
    
    &:before, &:after, > * {
      visibility: hidden;
    },
  `;
  }
);
var StyledContent4 = styled85("div", getStyledOptions())(
  {
    display: "flex",
    flexDirection: "column"
  },
  (props) => {
    const { appearDuration, isFirstRender } = props;
    return css73`
      animation: ${isFirstRender ? "none" : css73`
            ${fadeIn} ${appearDuration}s ease-in-out forwards
          `};
      opacity: ${isFirstRender ? 1 : 0};
    `;
  }
);
var Skeleton = forwardRef43((props, ref) => {
  const { componentProps, getDataAttributes } = useSkeleton(props);
  const { appearDuration, children, isLoaded, ...rest } = componentProps;
  const isFirstRender = useIsFirstRender();
  if (isLoaded) {
    return /* @__PURE__ */ jsx106(
      StyledContent4,
      {
        ref,
        appearDuration,
        ...getDataAttributes("Skeleton"),
        isFirstRender,
        children
      }
    );
  }
  let content;
  if (children) {
    content = isValidElement22(children) ? children : /* @__PURE__ */ jsx106("div", { children });
  }
  return /* @__PURE__ */ jsx106(StyledSkeleton, { ref, ...getDataAttributes("Skeleton"), ...rest, children: content });
});
Skeleton.displayName = "Skeleton";

// src/components/Skeleton/SkeletonCircle.tsx
import { forwardRef as forwardRef44 } from "react";
import { jsx as jsx107 } from "react/jsx-runtime";
var SkeletonCircle = forwardRef44((props, ref) => {
  const { componentProps, getDataAttributes } = useSkeletonCircle(props);
  const { size, ...rest } = componentProps;
  return /* @__PURE__ */ jsx107(
    Skeleton,
    {
      ref,
      ...getDataAttributes("SkeletonCircle"),
      ...rest,
      height: size,
      radius: "round",
      width: size
    }
  );
});
SkeletonCircle.displayName = "SkeletonCircle";

// src/components/Skeleton/SkeletonText.tsx
import { forwardRef as forwardRef45 } from "react";
import { createArray } from "@gilbarbara/helpers";
import { jsx as jsx108 } from "react/jsx-runtime";
var SkeletonText = forwardRef45((props, ref) => {
  const { componentProps, getDataAttributes } = useSkeletonText(props);
  const { children, gap, height, isLoaded, lines, ...rest } = componentProps;
  const getWidth = (index) => {
    if (lines > 1) {
      return index === lines ? "80%" : "100%";
    }
    return "100%";
  };
  return /* @__PURE__ */ jsx108("div", { ref, ...getDataAttributes("SkeletonText"), children: createArray(lines).map((line, index) => {
    if (isLoaded && index > 0) {
      return null;
    }
    const sizeProps = isLoaded ? null : {
      mb: line === lines ? void 0 : gap,
      width: getWidth(line),
      height
    };
    return /* @__PURE__ */ jsx108(Skeleton, {
      isLoaded,
      ...sizeProps,
      ...rest,
      // allows animating the children
      children: index === 0 ? children : void 0
    }, lines.toString() + line);
  }) });
});
SkeletonText.displayName = "SkeletonText";

// src/components/Snippet/Snippet.tsx
import { css as css74 } from "@emotion/react";
import styled86 from "@emotion/styled";
import { px as px44 } from "@gilbarbara/helpers";

// src/components/Snippet/useSnippet.ts
var defaultProps58 = {
  align: "center",
  display: "inline-flex",
  disableAnimation: false,
  gap: "xs",
  hideCopyButton: false,
  hideSymbol: false,
  hideTooltip: false,
  preventWrap: false,
  radius: "xs",
  removeFormatting: false,
  size: "md",
  symbol: "$"
};
function useSnippet(props) {
  return useComponentProps(props, defaultProps58);
}

// src/components/Snippet/Snippet.tsx
import { jsx as jsx109, jsxs as jsxs46 } from "react/jsx-runtime";
var StyledSnippet = styled86("div", getStyledOptions())(
  {
    alignItems: "center",
    display: "inline-flex"
  },
  (props) => {
    const { bg, color, size, theme } = props;
    const { darkMode: darkMode2, spacing: spacing2 } = theme;
    const defaultBg = darkMode2 ? "gray.800" : "gray.50";
    const { mainColor, textColor: textColor2 } = getColorTokens(bg ?? defaultBg, color, theme);
    const heightMap = {
      sm: px44(32),
      md: px44(40),
      lg: px44(48)
    };
    const paddingMap = {
      sm: `${spacing2.xs} ${spacing2.sm}`,
      md: `${spacing2.sm} ${spacing2.md}`,
      lg: `${spacing2.sm} ${spacing2.md}`
    };
    return css74`
      background-color: ${mainColor};
      color: ${textColor2};
      min-height: ${heightMap[size]};
      padding: ${paddingMap[size]};
      ${getStyles(props, { skipColor: true, useFontSize: true })};
    `;
  }
);
var StyledWrapper2 = styled86(
  "div",
  getStyledOptions()
)((props) => {
  const { gap, removeFormatting, theme } = props;
  const { fontFamily: fontFamily2, fontMonospace: fontMonospace2, spacing: spacing2 } = theme;
  return css74`
    align-items: center;
    font-family: ${removeFormatting ? fontFamily2 : fontMonospace2};
    display: flex;
    gap: ${spacing2[gap]};
  `;
});
var StyledSymbol = styled86.span`
  display: inline-flex;
`;
var StyledPre = styled86(
  "pre",
  getStyledOptions()
)((props) => {
  const { preventWrap, removeFormatting, theme } = props;
  const { fontFamily: fontFamily2, fontMonospace: fontMonospace2 } = theme;
  return css74`
    font-family: ${removeFormatting ? fontFamily2 : fontMonospace2};
    display: flex;
    margin: 0;
    ${preventWrap && "white-space: nowrap"};
  `;
});
function Snippet(props) {
  const { componentProps, getDataAttributes } = useSnippet(props);
  const {
    checkIcon = /* @__PURE__ */ jsx109(Icon, { name: "check" }),
    children,
    copyIcon = /* @__PURE__ */ jsx109(Icon, { name: "copy" }),
    copyValue,
    disableAnimation,
    gap,
    hideCopyButton,
    hideSymbol,
    hideTooltip,
    onCopy,
    onError,
    preventWrap,
    removeFormatting,
    symbol,
    theme,
    timeout,
    tooltipCopiedText,
    tooltipProps,
    tooltipText,
    ...rest
  } = componentProps;
  const content = {};
  if (!hideSymbol) {
    content.symbol = /* @__PURE__ */ jsx109(StyledSymbol, { children: symbol });
  }
  content.main = Array.isArray(children) ? /* @__PURE__ */ jsx109("div", { children: children.map((child, index) => (
    // eslint-disable-next-line react/no-array-index-key
    /* @__PURE__ */ jsxs46(StyledWrapper2, { gap, removeFormatting, theme, children: [
      content.symbol,
      /* @__PURE__ */ jsx109(
        StyledPre,
        {
          gap,
          preventWrap,
          removeFormatting,
          theme,
          children: child
        }
      )
    ] }, index)
  )) }) : /* @__PURE__ */ jsxs46(StyledWrapper2, { gap, removeFormatting, theme, children: [
    content.symbol,
    /* @__PURE__ */ jsx109(
      StyledPre,
      {
        gap,
        preventWrap,
        removeFormatting,
        theme,
        children
      }
    )
  ] });
  if (!hideCopyButton) {
    content.copyButton = /* @__PURE__ */ jsx109(
      CopyToClipboard,
      {
        checkIcon,
        copyIcon,
        disableAnimation,
        hideTooltip,
        onCopy,
        onError,
        padding: "xxs",
        timeout,
        tooltipCopiedText,
        tooltipProps,
        tooltipText,
        value: copyValue ?? children
      }
    );
  }
  return /* @__PURE__ */ jsxs46(StyledSnippet, { ...getDataAttributes("Snippet"), gap, theme, ...rest, children: [
    content.main,
    content.copyButton
  ] });
}
Snippet.displayName = "Snippet";

// src/components/StatusIndicator/StatusIndicator.tsx
import { cloneElement as cloneElement9, isValidElement as isValidElement23, useId as useId8 } from "react";
import { css as css75 } from "@emotion/react";
import styled87 from "@emotion/styled";
import { px as px45 } from "@gilbarbara/helpers";

// src/components/StatusIndicator/useStatusIndicator.ts
var defaultProps59 = {
  borderRatio: 0.7,
  color: "green",
  gap: "xxs",
  labelPosition: "bottom",
  tone: "100",
  size: 24
};
function useStatusIndicator(props) {
  return useComponentProps(props, defaultProps59);
}

// src/components/StatusIndicator/StatusIndicator.tsx
import { jsx as jsx110, jsxs as jsxs47 } from "react/jsx-runtime";
var StyledStatusIndicatorWrapper = styled87("div", getStyledOptions())(
  {
    alignItems: "center",
    display: "inline-flex",
    justifyContent: "center"
  },
  (props) => {
    const { gap, labelPosition, theme } = props;
    const { spacing: spacing2 } = theme;
    const flexDirectionMap = {
      bottom: "column",
      left: "row-reverse",
      right: "row",
      top: "column-reverse"
    };
    return css75`
      flex-direction: ${flexDirectionMap[labelPosition]};
      gap: ${spacing2[gap]};
    `;
  }
);
var StyledStatusIndicator = styled87("div", getStyledOptions())(
  {
    alignItems: "center",
    borderRadius: "50%",
    display: "inline-flex",
    justifyContent: "center",
    lineHeight: 1,
    position: "relative"
  },
  (props) => {
    const { borderRatio, color, size, theme, tone } = props;
    const { mainColor, variant } = getColorTokens(color, null, theme);
    let centerBg;
    if (variant) {
      ({ mainColor: centerBg } = getColorTokens(`${variant}.${tone}`, null, theme));
    } else {
      centerBg = getColorWithTone(mainColor, tone);
    }
    const innerSize = size * borderRatio < size ? size * borderRatio : size;
    return css75`
      background-color: ${mainColor};
      height: ${px45(size)};
      width: ${px45(size)};
      ${marginStyles(props)};

      &:before {
        background-color: ${centerBg};
        border-radius: 50%;
        content: '';
        display: block;
        height: ${px45(innerSize)};
        position: absolute;
        width: ${px45(innerSize)};
      }

      > * {
        position: absolute;
        left: 50%;
        top: 50%;
        transform: translate(-50%, -50%);
      }
    `;
  }
);
function StatusIndicator(props) {
  const { componentProps, getDataAttributes } = useStatusIndicator(props);
  const { gap, icon, label, labelPosition, ...rest } = componentProps;
  const labelId = useId8();
  const content = {};
  if (label) {
    content.label = isValidElement23(label) ? cloneElement9(label, { id: labelId }) : /* @__PURE__ */ jsx110(Text, { ...getDataAttributes("StatusIndicatorLabel"), id: labelId, size: "md", children: label });
  }
  return /* @__PURE__ */ jsxs47(
    StyledStatusIndicatorWrapper,
    {
      ...getDataAttributes("StatusIndicator"),
      gap,
      labelPosition,
      theme: rest.theme,
      children: [
        /* @__PURE__ */ jsx110(StyledStatusIndicator, { ...rest, children: icon }),
        content.label
      ]
    }
  );
}
StatusIndicator.displayName = "StatusIndicator";

// src/components/Tabs/Tab.tsx
import { jsx as jsx111 } from "react/jsx-runtime";
function Tab(props) {
  const { children } = props;
  const { getDataAttributes } = useTheme();
  return /* @__PURE__ */ jsx111("div", { ...getDataAttributes("Tab"), children });
}
Tab.displayName = "Tab";

// src/components/Tabs/Tabs.tsx
import { useEffect as useEffect17, useRef as useRef19 } from "react";
import { css as css77 } from "@emotion/react";
import styled89 from "@emotion/styled";
import { px as px47, unique } from "@gilbarbara/helpers";
import { useSetState as useSetState7 } from "@gilbarbara/hooks";
import is30 from "is-lite";

// src/components/Tabs/TabsMenu.tsx
import { useEffect as useEffect16, useId as useId9, useState as useState24 } from "react";
import { css as css76 } from "@emotion/react";
import styled88 from "@emotion/styled";
import { debounce, px as px46 } from "@gilbarbara/helpers";

// src/components/Tabs/useTabs.ts
var defaultProps60 = {
  accent: "primary",
  gap: "md",
  hideIndicator: false,
  menu: {},
  orientation: "horizontal",
  width: "100%"
};
function useTabs(props) {
  return useComponentProps(props, defaultProps60);
}

// src/components/Tabs/TabsMenu.tsx
import { jsx as jsx112 } from "react/jsx-runtime";
var StyledMenu2 = styled88("div", getStyledOptions())(
  {
    alignItems: "flex-start",
    display: "flex",
    position: "relative"
  },
  (props) => {
    const { accent, activeId, dimensions, menu, orientation, theme } = props;
    const { darkMode: darkMode2, grayScale: grayScale2 } = theme;
    const accentColor = getColorTokens(accent, null, theme).mainColor;
    const { borderColor, borderSize = 2, indicatorColor, indicatorLength, indicatorStyle } = menu;
    const isHorizontal = orientation === "horizontal";
    const isVertical = orientation === "vertical";
    let bgColor = darkMode2 ? grayScale2["800"] : grayScale2["50"];
    if (borderColor) {
      bgColor = getColorTokens(borderColor, null, theme).mainColor;
    }
    const base = css76`
      flex-direction: ${isHorizontal ? "row" : "column"};
      flex-shrink: 0;
      overflow: ${isHorizontal ? "auto hidden" : void 0};
      width: ${isVertical ? px46(menu.width) : void 0};
      ${flexBoxStyles({ ...menu, theme })};
    `;
    const before = css76`
      &:before {
        background-color: ${borderColor ?? bgColor};
        bottom: 0;
        content: '';
        height: ${isHorizontal ? px46(borderSize) : void 0};
        left: ${isHorizontal ? 0 : void 0};
        position: absolute;
        right: 0;
        top: ${isVertical ? 0 : void 0};
        width: ${isHorizontal ? void 0 : px46(borderSize)};
        z-index: 1;
      }
    `;
    let after = css76``;
    if (Object.keys(dimensions).length) {
      const active = dimensions[activeId];
      let lenght = isHorizontal ? active.width : active.height;
      let left = isHorizontal ? px46(active.left) : void 0;
      let top = isVertical ? px46(active.top) : void 0;
      bgColor = accentColor;
      if (indicatorColor) {
        bgColor = getColorTokens(indicatorColor, null, theme).mainColor;
      }
      if (indicatorLength) {
        if (typeof indicatorLength === "string") {
          const ratio = parseInt(indicatorLength, 10) / 100;
          lenght = isHorizontal ? active.width * ratio : active.height * ratio;
          left = isHorizontal ? px46(active.left + (active.width - lenght) / 2) : void 0;
          top = isVertical ? px46(active.top + (active.height - lenght) / 2) : void 0;
        } else {
          lenght = indicatorLength;
          left = isHorizontal ? px46(active.left + (active.width - indicatorLength) / 2) : void 0;
          top = isVertical ? px46(active.top + (active.height - indicatorLength) / 2) : void 0;
        }
      }
      after = css76`
        &:after {
          background-color: ${bgColor};
          bottom: ${isHorizontal ? 0 : void 0};
          content: '';
          display: block;
          height: ${isHorizontal ? px46(borderSize) : px46(lenght)};
          left: ${left};
          position: absolute;
          right: ${isVertical ? 0 : void 0};
          top: ${top};
          transition: ${`${isVertical ? "top" : "left"} 0.3s ease-in-out, width 0.2s`};
          transition-origin: bottom;
          width: ${isHorizontal ? px46(lenght) : px46(borderSize)};
          z-index: 2;
          ${stringifyCSSProperties(indicatorStyle)};
        }
      `;
    }
    return css76`
      ${base};
      ${before};
      ${after};
    `;
  }
);
var StyledMenuItem2 = styled88(ButtonUnstyled, getStyledOptions("disabled"))(
  {
    position: "relative",
    whiteSpace: "nowrap"
  },
  (props) => {
    const { accent, disabled, isActive, menu, orientation, theme } = props;
    const { darkMode: darkMode2, grayScale: grayScale2, spacing: spacing2, white: white2 } = theme;
    const { activeItemBgColor, activeItemColor, expand, itemBgColor, itemColor } = menu;
    const accentColor = getColorTokens(accent, null, theme).mainColor;
    let bgColor = darkMode2 ? grayScale2["800"] : white2;
    let color = darkMode2 ? grayScale2["200"] : grayScale2["800"];
    const isVertical = orientation === "vertical";
    if (itemBgColor) {
      const { mainColor: tagBgColor, textColor: textColor2 } = getColorTokens(itemBgColor, null, theme);
      bgColor = tagBgColor;
      color = textColor2;
    }
    if (itemColor) {
      const { mainColor: tabMainColor } = getColorTokens(itemColor, null, theme);
      color = tabMainColor;
    }
    if (isActive) {
      bgColor = darkMode2 ? grayScale2["900"] : white2;
      color = accentColor;
      if (activeItemBgColor) {
        const { mainColor, textColor: textColor2 } = getColorTokens(activeItemBgColor, null, theme);
        bgColor = mainColor;
        color = textColor2;
      }
      if (activeItemColor) {
        const { mainColor } = getColorTokens(activeItemColor, null, theme);
        color = mainColor;
      }
    }
    if (disabled) {
      color = grayScale2["500"];
    }
    return css76`
      background-color: ${bgColor};
      color: ${disabled ? grayScale2["500"] : color};
      display: flex;
      justify-content: center;
      flex-grow: ${expand ? 1 : 0};
      cursor: ${disabled ? "not-allowed" : "pointer"};
      padding: ${spacing2.sm} ${spacing2.lg};
      width: ${isVertical ? "100%" : void 0};
      ${stringifyCSSProperties(menu.itemStyle)};

      ${!isActive && !disabled && css76`
        &:hover {
          transition: transform 0.2s;
          transform: scale(1.05);
        }
      `};
    `;
  }
);
function TabsMenu(props) {
  const { activeId, onClickItem, tabs, uniqueId, ...rest } = props;
  const { componentProps: tabsProps, getDataAttributes } = useTabs(rest);
  const { accent, gap, menu, onClick, orientation, theme, ...otherTabsProps } = tabsProps;
  const [dimensions, setDimensions] = useState24({});
  const id = useId9();
  useEffect16(() => {
    const elements = document.querySelectorAll(`[data-tab-id]`);
    const calculateDimensions = () => {
      setDimensions(
        [...elements].reduce((acc, el) => {
          const tabId = el.getAttribute("data-tab-id");
          if (tabId) {
            acc[tabId] = {
              left: el.offsetLeft,
              top: el.offsetTop,
              width: el.clientWidth,
              height: el.clientHeight
            };
          }
          return acc;
        }, {})
      );
    };
    const debouncedCalculateDimensions = debounce(calculateDimensions, 50);
    const observer = new ResizeObserver(debouncedCalculateDimensions);
    elements.forEach((el) => observer.observe(el));
    calculateDimensions();
    return () => {
      observer.disconnect();
    };
  }, [menu.expand]);
  return /* @__PURE__ */ jsx112(
    StyledMenu2,
    {
      ...getDataAttributes("TabsMenu"),
      ...otherTabsProps,
      accent,
      activeId,
      dimensions,
      gap,
      id,
      menu,
      orientation,
      role: "tablist",
      theme,
      children: tabs.map((d) => /* @__PURE__ */ jsx112(
        StyledMenuItem2,
        {
          accent,
          "aria-controls": `panel-${uniqueId}-${d.id}`,
          "aria-selected": d.id === activeId,
          ...getDataAttributes("TabsMenuItem"),
          "data-disabled": !!d.disabled,
          "data-tab-id": d.id,
          disabled: !!d.disabled,
          isActive: d.id === activeId,
          menu,
          onClick: onClickItem,
          orientation,
          role: "tab",
          theme,
          children: d.title
        },
        d.id
      ))
    }
  );
}

// src/components/Tabs/Tabs.tsx
import { jsx as jsx113, jsxs as jsxs48 } from "react/jsx-runtime";
var StyledTabs = styled89(
  "div",
  getStyledOptions()
)((props) => {
  const { orientation } = props;
  return css77`
    display: flex;
    flex-direction: ${orientation === "vertical" ? "row" : "column"};
    flex-grow: 1;
    ${getStyles(props, { skipBorder: true })};
  `;
});
var StyledContent5 = styled89(
  "div",
  getStyledOptions()
)((props) => {
  const { maxHeight, minHeight } = props;
  return css77`
    display: flex;
    flex-direction: column;
    flex-grow: 1;
    max-height: ${maxHeight ? px47(maxHeight) : void 0};
    min-height: ${minHeight ? px47(minHeight) : void 0};
    overflow-y: auto;
  `;
});
function Tabs(props) {
  const { componentProps, getDataAttributes } = useTabs(props);
  const {
    accent,
    children,
    defaultId = "",
    id,
    loader,
    maxHeight,
    minHeight,
    noContent,
    onClick,
    ...rest
  } = componentProps;
  const [{ activeId, error, isReady, tabs }, setState] = useSetState7({
    activeId: id ?? defaultId,
    error: false,
    isReady: false,
    tabs: [],
    width: null
  });
  const isMounted = useRef19(false);
  const uniqueId = useRef19(unique(6));
  useEffect17(() => {
    isMounted.current = true;
    return () => {
      isMounted.current = false;
    };
  }, []);
  useEffect17(() => {
    const nextState = {
      error: false,
      isReady: true,
      tabs: []
    };
    const { elements, hasInvalidElements } = getMatchingChildren(children, Tab);
    elements.forEach((child, index) => {
      nextState.tabs.push(child.props);
      if (!activeId && index === 0) {
        nextState.activeId = child.props.id;
      }
    });
    nextState.error = hasInvalidElements;
    setState(nextState);
  }, [activeId, children, setState]);
  useEffect17(() => {
    if (id) {
      setState({ activeId: id });
    }
  }, [id, setState]);
  if (error) {
    return null;
  }
  const handleClickItem = (event) => {
    const { disabled, tabId = "" } = event.currentTarget.dataset;
    if (activeId === tabId || disabled === "true") {
      return;
    }
    if (is30.undefined(id)) {
      setState({ activeId: tabId });
    }
    onClick?.(tabId);
  };
  const content = {};
  if (isReady) {
    if (tabs.length) {
      content.menu = /* @__PURE__ */ jsx113(
        TabsMenu,
        {
          ...props,
          activeId,
          onClickItem: handleClickItem,
          tabs,
          uniqueId: uniqueId.current
        }
      );
      content.main = /* @__PURE__ */ jsx113(
        StyledContent5,
        {
          ...getDataAttributes("TabsContent"),
          maxHeight,
          minHeight,
          children: tabs.filter((d) => d.id === activeId).map(({ id: tabId, title, ...tabProps }) => {
            return /* @__PURE__ */ jsx113(
              Flex,
              {
                ...getDataAttributes("TabsPanel"),
                direction: "column",
                fill: true,
                id: `panel-${uniqueId.current}-${tabId}`,
                role: "tabpanel",
                ...tabProps
              },
              tabId
            );
          })
        }
      );
    } else {
      content.main = noContent ?? /* @__PURE__ */ jsx113(NonIdealState, { description: "Content not available", icon: "danger-o", size: "sm" });
    }
  } else {
    content.main = loader ?? /* @__PURE__ */ jsx113(Loader, {});
  }
  return /* @__PURE__ */ jsxs48(StyledTabs, { ...getDataAttributes("Tabs"), minHeight, ...rest, children: [
    content.menu,
    content.main
  ] });
}
Tabs.displayName = "Tabs";

// src/types/index.ts
var types_exports = {};

// src/types/props.ts
var props_exports = {};

// src/index.ts
import { px as px48 } from "@gilbarbara/helpers";
export * from "colorizr";
import { default as default2 } from "react-inlinesvg";
export {
  Accordion,
  AccordionItem,
  Alert,
  Anchor,
  AspectRatio,
  Avatar,
  Badge,
  Box,
  Button,
  ButtonGroup,
  ButtonSplit,
  MenuItem as ButtonSplitItem,
  MenuSeparator as ButtonSplitSeparator,
  ButtonUnstyled,
  Checkbox,
  Chip,
  ClickOutside,
  Collapse,
  Container,
  CopyToClipboard,
  DataTable,
  DatePicker,
  DatePickerRange,
  DatePickerSelector,
  Dialog,
  Divider,
  Dropdown,
  Emoji,
  Field,
  Flex,
  FlexCenter,
  FlexInline,
  Form,
  FormElementWrapper,
  FormGroup,
  Grid,
  H1,
  H2,
  H3,
  H4,
  H5,
  H6,
  Icon,
  Image2 as Image,
  Input2 as Input,
  InputColor,
  InputFile,
  Jumbo,
  Keyboard,
  Label,
  List2 as List,
  ListItem,
  Loader,
  Menu,
  MenuItem,
  MenuSeparator,
  MenuTitle,
  MenuToggle,
  Modal,
  NavBar,
  NavBarContent,
  NavBarMenu,
  NavBarMenuToggle,
  NonIdealState,
  Page,
  Pagination,
  Paragraph,
  Portal,
  ProgressBar,
  ProgressCircle,
  props_exports as Props,
  Quote,
  Radio,
  RadioGroup,
  Ripple,
  default2 as SVG,
  Search2 as Search,
  Select,
  Sidebar,
  Skeleton,
  SkeletonCircle,
  SkeletonText,
  Snippet,
  Spacer,
  StatusIndicator,
  Tab,
  Tabs,
  Text,
  Textarea,
  Toggle,
  Tooltip,
  Truncate,
  types_exports as Types,
  animateIcon,
  fadeIn,
  fadeInOut,
  fadeOut,
  getContainerStyles,
  horizontalScale,
  icons,
  mergeTheme,
  px48 as px,
  responsive,
  ripple,
  rotate,
  theme_exports as theme,
  useImage,
  useKeyboardNavigation,
  useRipple,
  useTheme
};
//# sourceMappingURL=index.mjs.map